<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit( 'restricted access' );
}

/*
 * This is a function that create menu
 */
if ( ! function_exists( 'gf_sc_add_configuration_sub_menu' ) ) {
    add_action('admin_menu', 'gf_sc_add_configuration_sub_menu');
    function gf_sc_add_configuration_sub_menu() {
        
        add_submenu_page( 'gf_sc-integration', esc_html__( 'GF - SuiteCRM: Configuration', 'gf_sc' ), esc_html__( 'Configuration', 'gf_sc' ), 'manage_options', 'gf_sc-configuration', 'gf_sc_configuration_sub_menu_callback' );
        add_submenu_page( 'gf_sc-integration', esc_html__( 'GF - SuiteCRM: API Error Logs', 'gf_sc' ), esc_html__( 'API Error Logs', 'gf_sc' ), 'manage_options', 'gf_sc_api_error_logs', 'gf_sc_api_error_logs_callback' );
        add_submenu_page( 'gf_sc-integration', esc_html__( 'GF - SuiteCRM: Settings', 'gf_sc' ), esc_html__( 'Settings', 'gf_sc' ), 'manage_options', 'gf_sc_settings', 'gf_sc_settings_callback' );
        add_submenu_page( 'gf_sc-integration', esc_html__( 'GF - SuiteCRM: Licence Verification', 'gf_sc' ), esc_html__( 'Licence Verification', 'gf_sc' ), 'manage_options', 'gf_sc_licence_verification', 'gf_sc_licence_verification' );
    }
}

/*
 * This is a function for configuration
 */
if ( ! function_exists( 'gf_sc_configuration_sub_menu_callback' ) ) {
    function gf_sc_configuration_sub_menu_callback() {
        
        if ( isset( $_REQUEST['submit'] ) ) {
            $request = $_REQUEST;
            unset( $request['submit'] );
            if ( $request != null ) {
                foreach ( $request as $key => $value ) {
                    if ( $key == 'gf_sc_password' ) {
                        update_option( $key, gf_sc_crypt( $value, 'e', $request['gf_sc_username'] ) );
                    } else {
                        update_option( $key, $value );
                    }
                }
            }
        }
        
        $sc_url = get_option( 'gf_sc_url' );
        $username = get_option( 'gf_sc_username' );
        $password = gf_sc_crypt( get_option( 'gf_sc_password' ), 'd', $username );
        
        $gf_sc_licence = get_site_option( 'gf_sc_licence' );
        ?>
            <div class="wrap">                
                <h1><?php esc_html_e( 'SuiteCRM Configuration', 'gf_sc' ); ?></h1>
                <hr>
                <?php
                if ( $gf_sc_licence ) {
                    if ( isset( $_REQUEST['submit'] ) ) {
                        $gf_sc = new SuiteCRM_REST_API( $sc_url, $username, $password );
                        $authentication = $gf_sc->authentication();
                        if ( ! isset( $authentication->id ) ) {                            
                            ?>
                                <div class="notice notice-error is-dismissible">
                                    <p><?php esc_html_e( 'Configuration failure.', 'gf_sc' ); ?></p>
                                </div>
                            <?php
                        } else {
                            $modules = unserialize( get_option( 'gf_sc_modules' ) );                            
                            $gf_sc_modules_fields = array();
                            if ( $modules != null ) {
                                foreach( $modules as $key => $value ) {
                                    $fields = $gf_sc->getModuleFields( $authentication->id, $key );
                                    asort( $fields );
                                    $gf_sc_modules_fields[$key] = $fields;
                                }
                            }
                            update_option( 'gf_sc_modules_fields', $gf_sc_modules_fields );
                            ?>
                                <div class="notice notice-success is-dismissible">
                                    <p><?php esc_html_e( 'Configuration successful.', 'gf_sc' ); ?></p>
                                </div>
                            <?php
                        }
                    }
                    ?>
                    <form method="post">
                        <table class="form-table">
                            <tbody>
                                <tr>
                                    <th scope="row"><label><?php esc_html_e( 'URL', 'gf_sc' ); ?> <span class="description">(required)</span></label></th>
                                    <td>
                                        <input class="regular-text" type="text" name="gf_sc_url" value="<?php echo $sc_url; ?>" required />
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><label><?php esc_html_e( 'Username', 'gf_sc' ); ?> <span class="description">(required)</span></label></th>
                                    <td>
                                        <input class="regular-text" type="text" name="gf_sc_username" value="<?php echo $username; ?>" required />
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><label><?php esc_html_e( 'Password', 'gf_sc' ); ?> <span class="description">(required)</span></label></th>
                                    <td>
                                        <input class="regular-text" type="password" name="gf_sc_password" value="" required />
                                    </td>
                                </tr>
                            </tbody>
                        </table>
                        <p><input type='submit' class='button-primary' name="submit" value="<?php esc_html_e( 'Save Changes', 'gf_sc' ); ?>" /></p>
                    </form>
                    <?php
                } else {
                    ?>
                        <div class="notice notice-error is-dismissible">
                            <p><?php esc_html_e( 'Please verify purchase code.', 'gf_sc' ); ?></p>
                        </div>
                    <?php
                }
                ?>
            </div>
        <?php
    }
}

/*
 * This is a function that verify product licence.
 */
if ( ! function_exists( 'gf_sc_licence_verification' ) ) {
    function gf_sc_licence_verification() {
        
        if ( isset( $_REQUEST['verify'] ) ) {
            if ( isset( $_REQUEST['gf_sc_purchase_code'] ) ) {
                update_site_option( 'gf_sc_purchase_code', $_REQUEST['gf_sc_purchase_code'] );
                
                $data = array(
                    'sku'           => '20174494',
                    'purchase_code' => $_REQUEST['gf_sc_purchase_code'],
                    'domain'        => site_url(),
                    'status'        => 'verify',
                    
                );

                $ch = curl_init();
                curl_setopt( $ch, CURLOPT_URL, 'https://obtaincode.net/extension/' );
                curl_setopt( $ch, CURLOPT_POST, 1 );
                curl_setopt( $ch, CURLOPT_POSTFIELDS, http_build_query( $data ) );
                curl_setopt( $ch, CURLOPT_RETURNTRANSFER, 1 );
                curl_setopt( $ch, CURLOPT_SSL_VERIFYPEER, 0 );
                $json_response = curl_exec( $ch );
                curl_close ($ch);
                
                $response = json_decode( $json_response );
                $response = json_decode( $json_response );
                if ( isset( $response->success ) ) {
                    if ( $response->success ) {
                        update_site_option( 'gf_sc_licence', 1 );
                    }
                }
            }
        } else if ( isset( $_REQUEST['unverify'] ) ) {
            if ( isset( $_REQUEST['gf_sc_purchase_code'] ) ) {
                $data = array(
                    'sku'           => '20174494',
                    'purchase_code' => $_REQUEST['gf_sc_purchase_code'],
                    'domain'        => site_url(),
                    'status'        => 'unverify',
                    
                );

                $ch = curl_init();
                curl_setopt( $ch, CURLOPT_URL, 'https://obtaincode.net/extension/' );
                curl_setopt( $ch, CURLOPT_POST, 1 );
                curl_setopt( $ch, CURLOPT_POSTFIELDS, http_build_query( $data ) );
                curl_setopt( $ch, CURLOPT_RETURNTRANSFER, 1 );
                curl_setopt( $ch, CURLOPT_SSL_VERIFYPEER, 0 );
                $json_response = curl_exec( $ch );
                curl_close ($ch);

                $response = json_decode( $json_response );
                if ( isset( $response->success ) ) {
                    if ( $response->success ) {
                        update_site_option( 'gf_sc_purchase_code', '' );
                        update_site_option( 'gf_sc_licence', 0 );
                    }
                }
            }
        }    
        
        $gf_sc_purchase_code = get_site_option( 'gf_sc_purchase_code' );
        ?>
            <div class="wrap">      
                <h2><?php esc_html_e( 'Licence Verification', 'gf_sc' ); ?></h2>
                <hr>
                <?php
                    if ( isset( $response->success ) ) {
                        if ( $response->success ) {                            
                             ?>
                                <div class="notice notice-success is-dismissible">
                                    <p><?php echo $response->message; ?></p>
                                </div>
                            <?php
                        } else {
                            update_site_option( 'gf_sc_licence', 0 );
                            ?>
                                <div class="notice notice-error is-dismissible">
                                    <p><?php echo $response->message; ?></p>
                                </div>
                            <?php
                        }
                    }
                ?>
                <form method="post">
                    <table class="form-table">                    
                        <tbody>
                            <tr>
                                <th scope="row"><?php esc_html_e( 'Purchase Code', 'gf_sc' ); ?></th>
                                <td>
                                    <input name="gf_sc_purchase_code" type="text" class="regular-text" value="<?php echo $gf_sc_purchase_code; ?>" />
                                </td>
                            </tr>
                        </tbody>
                    </table>
                    <p>
                        <input type='submit' class='button-primary' name="verify" value="<?php esc_html_e( 'Verify', 'gf_sc' ); ?>" />
                        <input type='submit' class='button-primary' name="unverify" value="<?php esc_html_e( 'Unverify', 'gf_sc' ); ?>" />
                    </p>
                </form>   
            </div>
        <?php
    }
}

if ( ! function_exists( 'gf_sc_api_error_logs_callback' ) ) {
    function gf_sc_api_error_logs_callback() {
        
        $file_path = GF_SC_PLUGIN_PATH.'debug.log';
        if ( isset( $_POST['submit'] ) ) {
            $file = fopen( $file_path, 'w' );
            fclose( $file );
        }
        
        $licence = get_site_option( 'gf_sc_licence' );
        ?>
            <div class="wrap">
                <h1><?php esc_html_e( 'SuiteCRM API Error Logs', 'gf_sc' ); ?></h1>
                <hr>
                <?php
                    if ( $licence ) {
                        $file = fopen( $file_path, 'r' );
                            $file_size = filesize( $file_path );
                            if ( $file_size ) {
                                $file_data = fread( $file, $file_size );
                                if ( $file_data ) {
                                    echo '<pre style="overflow: scroll;">'; print_r( $file_data ); echo '</pre>';
                                    ?>
                                        <form method="post">
                                            <p>
                                                <input type='submit' class='button-primary' name="submit" value="<?php esc_html_e( 'Clear API Error Logs', 'gf_sc' ); ?>" />
                                            </p>
                                        </form>
                                    <?php
                                }
                            } else {
                                ?><p><?php esc_html_e( 'No API error logs found.', 'gf_sc' ); ?></p><?php
                            }
                        fclose( $file );
                    } else {
                        ?>
                            <div class="notice notice-error is-dismissible">
                                <p><?php esc_html_e( 'Please verify purchase code.', 'gf_sc' ); ?></p>
                            </div>
                        <?php
                    }
                ?>
            </div>
        <?php
    }
}

if ( ! function_exists( 'gf_sc_settings_callback' ) ) {
    function gf_sc_settings_callback() {
        
        if ( isset( $_POST['submit'] ) ) {
            $notification_subject = sanitize_text_field( $_POST['gf_sc_notification_subject'] );
            update_option( 'gf_sc_notification_subject', $notification_subject );
            
            $notification_send_to = sanitize_text_field( $_POST['gf_sc_notification_send_to'] );
            update_option( 'gf_sc_notification_send_to', $notification_send_to );
            
            $ignore_spam_entry = (int) $_POST['gf_sc_ignore_spam_entry'];
            update_option( 'gf_sc_ignore_spam_entry', $ignore_spam_entry );
            
            $uninstall = (int) $_POST['gf_sc_uninstall'];
            update_option( 'gf_sc_uninstall', $uninstall );
            
            ?>
                <div class="notice notice-success is-dismissible">
                    <p><?php esc_html_e( 'Settings saved.', 'gf_sc' ); ?></p>
                </div>
            <?php
        }
        
        $notification_subject = get_option( 'gf_sc_notification_subject' );
        if ( ! $notification_subject ) {
            $notification_subject = esc_html__( 'API Error Notification', 'gf_sc' );
        }
        $notification_send_to = get_option( 'gf_sc_notification_send_to' );
        $ignore_spam_entry = get_option( 'gf_sc_ignore_spam_entry' );
        $uninstall = get_option( 'gf_sc_uninstall' );
        $licence = get_site_option( 'gf_sc_licence' );
        ?>
            <div class="wrap">
                <h1><?php esc_html_e( 'Settings', 'gf_sc' ); ?></h1>
                <hr>
                <?php
                    if ( $licence ) {
                        ?>
                            <form method="post">
                                <table class="form-table">
                                    <tbody>
                                        <tr>
                                            <th scope="row"><label><?php esc_html_e( 'API Error Notification', 'gf_sc' ); ?></label></th>
                                            <td>
                                                <label><?php esc_html_e( 'Subject', 'gf_sc' ); ?></label><br>
                                                <input class="regular-text" type="text" name="gf_sc_notification_subject" value="<?php echo $notification_subject; ?>" />
                                                <p class="description"><?php esc_html_e( 'Enter the subject.', 'gf_sc' ); ?></p><br><br>
                                                <label><?php esc_html_e( 'Send To', 'gf_sc' ); ?></label><br>
                                                <input class="regular-text" type="text" name="gf_sc_notification_send_to" value="<?php echo $notification_send_to; ?>" />
                                                <p class="description"><?php esc_html_e( 'Enter the email address. For multiple email addresses, you can add email address by comma separated.', 'gf_sc' ); ?></p>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th scope="row"><label><?php esc_html_e( 'Ignore spam entry?', 'gf_sc' ); ?></label></th>
                                            <td>
                                                <input type="hidden" name="gf_sc_ignore_spam_entry" value="0" />
                                                <input type="checkbox" name="gf_sc_ignore_spam_entry" value="1"<?php echo ( $ignore_spam_entry ? ' checked' : '' ); ?> />
                                            </td>
                                        </tr>
                                        <tr>
                                            <th scope="row"><label><?php esc_html_e( 'Delete data on uninstall?', 'gf_sc' ); ?></label></th>
                                            <td>
                                                <input type="hidden" name="gf_sc_uninstall" value="0" />
                                                <input type="checkbox" name="gf_sc_uninstall" value="1"<?php echo ( $uninstall ? ' checked' : '' ); ?> />
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <p>
                                    <input type='submit' class='button-primary' name="submit" value="<?php esc_html_e( 'Save Changes', 'gf_sc' ); ?>" />
                                </p>
                            </form>
                        <?php
                    } else {
                        ?>
                            <div class="notice notice-error is-dismissible">
                                <p><?php esc_html_e( 'Please verify purchase code.', 'gf_sc' ); ?></p>
                            </div>
                        <?php
                    }
                ?>
            </div>
        <?php
    }
}