<?php
/*
Plugin Name: Gravity Forms - SuiteCRM Integration
Description: Gravity Forms - SuiteCRM Integration plugin allows you to connect WordPress Gravity Forms and SuiteCRM.
Version:     2.3.0
Author:      Obtain Code
Author URI:  https://obtaincode.net/
License:     GPL2
Text Domain: gf_sc
*/

if ( ! defined( 'ABSPATH' ) ) {
    exit( 'restricted access' );
}

define( 'GF_SC_PLUGIN_PATH', plugin_dir_path( __FILE__ ) );

/*
 * This is a class file for Suite CRM API
 */
include_once( 'includes/class-suitecrm.php' );

/*
 * This is a core functions file
 */
include_once( 'includes/functions.php' );

/*
 * This is a integration file
 */
include_once( 'admin/integration.php' );

/*
 * This is a configuration file
 */
include_once( 'admin/configuration.php' );

/*
 * This is a function that run during active plugin
 */
if ( ! function_exists( 'gf_sc_activation' ) ) {
    register_activation_hook( __FILE__, 'gf_sc_activation' );
    function gf_sc_activation() {
        
        update_option( 'gf_sc_modules', 'a:3:{s:5:"Cases";s:5:"Cases";s:8:"Contacts";s:8:"Contacts";s:5:"Leads";s:5:"Leads";}' );
    }
}

/*
 * This is a function that integrate form
 * $gf variable return form data
 */
if ( ! function_exists( 'gf_sc_integration' ) ) {
    add_action( 'gform_after_submission', 'gf_sc_integration', 20, 2 );
    function gf_sc_integration( $entry, $gf ) {
        
        $licence = get_site_option( 'gf_sc_licence' );
        if ( $licence ) {
            $posted_data = $entry;
            $form_id = 0;
            if ( isset( $gf['id'] ) ) {
                $form_id = intval( $gf['id'] );
            }

            $not_ignore_spam_entry = 1;
            $ignore_spam_entry = get_option( 'gf_sc_ignore_spam_entry' );
            if ( $ignore_spam_entry ) {
                if ( $posted_data['status'] == 'spam' ) {
                    $not_ignore_spam_entry = 0;
                }
            }
            
            if ( $form_id && $not_ignore_spam_entry ) {
                $gf_sc = get_option( 'gf_sc_'.$form_id );
                if ( $gf_sc ) {
                    $gf_sc_fields = get_option( 'gf_sc_fields_'.$form_id );
                    if ( $gf_sc_fields != null ) {                    
                        $gf_sc_data = array();
                        $attachment_fields = array();
                        foreach ( $gf_sc_fields as $gf_field_key => $sc_field ) {
                            if ( isset( $sc_field['key'] ) && $sc_field['key'] ) {
                                if ( isset( $sc_field['field_type'] ) && $sc_field['field_type'] == 'checkbox' ) {
                                    for( $i = 1; $i <= 20; $i++ ) {
                                        if ( isset( $entry[$gf_field_key.'.'.$i] ) ) {
                                            if ( $entry[$gf_field_key.'.'.$i] ) {
                                                $entry[$gf_field_key][] = $entry[$gf_field_key.'.'.$i];
                                            }
                                        }
                                    }
                                } else if ( isset( $sc_field['field_type'] ) && $sc_field['field_type'] == 'multiselect' ) {
                                    if ( $entry[$gf_field_key] ) {
                                        $entry[$gf_field_key] = json_decode( $entry[$gf_field_key] );
                                    }
                                }
                                
                                if ( is_array( $entry[$gf_field_key] ) ) {
                                    $entry[$gf_field_key] = implode( ',', $entry[$gf_field_key] );
                                }
                                
                                if ( $sc_field['key'] == 'attachment_field' ) {
                                    $attachment_fields[] = $gf_field_key;
                                } else {
                                    $gf_sc_data[$sc_field['key']] = strip_tags( $entry[$gf_field_key] );
                                }
                            }
                        }

                        if ( $gf_sc_data != null ) {
                            $data = $gf_sc_data;
                            $sc_url = get_option( 'gf_sc_url' );
                            $username = get_option( 'gf_sc_username' );
                            $password = gf_sc_crypt( get_option( 'gf_sc_password' ), 'd', $username );                        
                            $gf_sc = new SuiteCRM_REST_API( $sc_url, $username, $password );
                            $authentication = $gf_sc->authentication();
                            if ( ! isset( $authentication->error ) && isset( $authentication->id ) ) {
                                $gf_sc_module = get_option( 'gf_sc_module_'.$form_id );
                                $action = get_option( 'gf_sc_action_'.$form_id );
                                if ( ! $action ) {
                                    $action = 'create';
                                }
                                
                                $ids = array();
                                if ( $action == 'create' ) {
                                    $record = $gf_sc->addRecord( $authentication->id, $gf_sc_module, $gf_sc_data, $form_id );
                                    if ( isset( $record->id ) ) {
                                        $ids[] = $record->id;
                                    }
                                } else if ( $action == 'create_or_update' ) {
                                    $email = ( isset( $data['email1'] ) ? $data['email1'] : '' );
                                    if ( ! $email ) {
                                        $email = ( isset( $data['email'] ) ? $data['email'] : '' );
                                    }

                                    if ( ! $email ) {
                                        $email = ( isset( $data['webtolead_email1'] ) ? $data['webtolead_email1'] : '' );
                                    }
                                    
                                    if ( $email ) {
                                        $records = $gf_sc->getRecords( $authentication->id, $gf_sc_module, $email );
                                        if ( $records != null ) {
                                            foreach ( $records as $record_id ) {
                                                $ids[] = $record_id;
                                                $gf_sc->updateRecord( $authentication->id, $gf_sc_module, $gf_sc_data, $record_id, $form_id );
                                            }
                                        } else {
                                            $record = $gf_sc->addRecord( $authentication->id, $gf_sc_module, $gf_sc_data, $form_id );
                                            if ( isset( $record->id ) ) {
                                                $ids[] = $record->id;
                                            }
                                        }
                                    } else {
                                        $record = $gf_sc->addRecord( $authentication->id, $gf_sc_module, $gf_sc_data, $form_id );
                                        if ( isset( $record->id ) ) {
                                            $ids[] = $record->id;
                                        }
                                    }
                                }
                                
                                if ( $attachment_fields != null && $ids != null ) {
                                    foreach ( $ids as $id ) {
                                        foreach ( $attachment_fields as $attachment_field ) {
                                            $files = json_decode( $posted_data[$attachment_field] );
                                            if ( $files != null ) {
                                                foreach ( $files as $file ) {
                                                    $file = str_replace( site_url( '/' ), ABSPATH, $file );
                                                    if ( $file ) {
                                                        $file = str_replace( site_url( '/' ), ABSPATH, $file );
                                                        $filename = basename( $file );
                                                        $record = $gf_sc->addRecord( $authentication->id, 'Notes', array( 'name' => $filename ), $form_id );
                                                        if ( isset( $record->id ) ) {
                                                            $gf_sc->setRecord( $authentication->id, $gf_sc_module, $id, $record->id );
                                                            $attachment_body = file_get_contents( $file );                           
                                                            $attachment_body = base64_encode( $attachment_body );
                                                            $file_data = array(
                                                                'id'        => $record->id,
                                                                'filename'  => $filename,
                                                                'file'      => $attachment_body,
                                                            );
                                                            $gf_sc->addFile( $authentication->id, $file_data, $form_id );
                                                        }
                                                    }
                                                }
                                            } else {
                                                $file = $posted_data[$attachment_field];
                                                if ( $file ) {
                                                    $file = str_replace( site_url( '/' ), ABSPATH, $file );
                                                    $filename = basename( $file );
                                                    $record = $gf_sc->addRecord( $authentication->id, 'Notes', array( 'name' => $filename ), $form_id );
                                                    if ( isset( $record->id ) ) {
                                                        $gf_sc->setRecord( $authentication->id, $gf_sc_module, $id, $record->id );
                                                        $attachment_body = file_get_contents( $file );                           
                                                        $attachment_body = base64_encode( $attachment_body );
                                                        $file_data = array(
                                                            'id'        => $record->id,
                                                            'filename'  => $filename,
                                                            'file'      => $attachment_body,
                                                        );
                                                        $gf_sc->addFile( $authentication->id, $file_data, $form_id );
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
    }
}