<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit( 'restricted access' );
}

/*
 * This is a class for SuiteCRM API
 */
if ( ! class_exists( 'SuiteCRM_REST_API' ) ) {
    class SuiteCRM_REST_API {

        var $url;
        var $username;
        var $password;
        
        function __construct( $url, $username, $password ) {
            
            $url = rtrim( $url, '/' );
            $this->url      = $url.'/service/v4_1/rest.php';
            $this->username = $username;
            $this->password = $password;
        }
        
        function authentication() {
            
            $data = array(
                'method'        => 'login',
                'input_type'    => 'JSON',
                'response_type' => 'JSON',
                'rest_data'     => json_encode( array(
                        'user_auth' => array(
                            'user_name'     => $this->username,
                            'password'      => $this->password,
                            'version'       => '1',
                            'encryption'    => 'PLAIN',
                        ),
                        'name_value_list'   => array(),
                    )),
            );
            
            $ch = curl_init( $this->url );
            curl_setopt( $ch, CURLOPT_HEADER, false );
            curl_setopt( $ch, CURLOPT_RETURNTRANSFER, true );
            curl_setopt( $ch, CURLOPT_SSL_VERIFYPEER, false );
            curl_setopt( $ch, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_0 );
            curl_setopt( $ch, CURLOPT_POST, true );
            curl_setopt( $ch, CURLOPT_POSTFIELDS, $data );
            $json_response = curl_exec( $ch );
            curl_close( $ch );
            
            $response = json_decode( $json_response );
            if ( isset( $response->name ) ) {
                $log = "Error Code: ".$response->name."\n";
                $log .= "Message: ".$response->description."\n";
                $log .= "Date: ".date( 'Y-m-d H:i:s' )."\n\n";                            
                
                $send_to = get_option( 'gf_sc_notification_send_to' );
                if ( $send_to ) {
                    $to = $send_to;
                    $subject = get_option( 'gf_sc_notification_subject' );
                    $body = "Error Code: ".$response->name."<br>";
                    $body .= "Message: ".$response->description."<br>";
                    $body .= "Date: ".date( 'Y-m-d H:i:s' );
                    $headers = array(
                        'Content-Type: text/html; charset=UTF-8',
                    );
                    wp_mail( $to, $subject, $body, $headers );
                }
                
                file_put_contents( GF_SC_PLUGIN_PATH.'debug.log', $log, FILE_APPEND );
            }
            
            return $response;
        }
        
        function addRecord( $session_id, $module, $data, $form_id ) {            
            
            $filter_data = array();
            if ( $data != null ) {
                foreach ( $data as $key => $value ) {
                    $filter_data[] = array(
                        'name'  => $key,
                        'value' => $value,
                    );
                }
            }
            
            $data = array(
                'method'        => 'set_entry',
                'input_type'    => 'JSON',
                'response_type' => 'JSON',
                'rest_data'     => json_encode( array(
                        'session'           => $session_id,
                        'module_name'       => $module,
                        'name_value_list'   => $filter_data,
                    )),                
            );
            
            $ch = curl_init( $this->url );
            curl_setopt( $ch, CURLOPT_HEADER, false );
            curl_setopt( $ch, CURLOPT_RETURNTRANSFER, true );
            curl_setopt( $ch, CURLOPT_SSL_VERIFYPEER, false );
            curl_setopt( $ch, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_0 );
            curl_setopt( $ch, CURLOPT_POST, true );
            curl_setopt( $ch, CURLOPT_POSTFIELDS, $data );
            $json_response = curl_exec( $ch );
            curl_close( $ch );
            
            $response = json_decode( $json_response );

            if ( isset( $response->name ) ) {
                $log = "Form ID: ".$form_id."\n";
                $log .= "Error Code: ".$response->name."\n";
                $log .= "Message: ".$response->description."\n";
                $log .= "Date: ".date( 'Y-m-d H:i:s' )."\n\n";                            
                
                $send_to = get_option( 'gf_sc_notification_send_to' );
                if ( $send_to ) {
                    $to = $send_to;
                    $subject = get_option( 'gf_sc_notification_subject' );
                    $body = "Form ID: ".$form_id."<br>";
                    $body .= "Error Code: ".$response->name."<br>";
                    $body .= "Message: ".$response->description."<br>";
                    $body .= "Date: ".date( 'Y-m-d H:i:s' );
                    $headers = array(
                        'Content-Type: text/html; charset=UTF-8',
                    );
                    wp_mail( $to, $subject, $body, $headers );
                }
                
                file_put_contents( GF_SC_PLUGIN_PATH.'debug.log', $log, FILE_APPEND );
            }
            
            return $response;
        }
        
        function getModuleFields( $session_id, $module ) {
            
            $data = array(
                'method'        => 'get_module_fields',
                'input_type'    => 'JSON',
                'response_type' => 'JSON',
                'rest_data'     => json_encode( array(
                        'session'           => $session_id,
                        'module_name'       => $module,
                        'fields'            => array(),
                    )),                
            );
            
            $ch = curl_init( $this->url );
            curl_setopt( $ch, CURLOPT_HEADER, false );
            curl_setopt( $ch, CURLOPT_RETURNTRANSFER, true );
            curl_setopt( $ch, CURLOPT_SSL_VERIFYPEER, false );
            curl_setopt( $ch, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_0 );
            curl_setopt( $ch, CURLOPT_POST, true );
            curl_setopt( $ch, CURLOPT_POSTFIELDS, $data );
            $json_response = curl_exec( $ch );
            curl_close( $ch );
            
            $response = json_decode( $json_response );
            
            if ( isset( $response->name ) ) {
                $log = "Error Code: ".$response->name."\n";
                $log .= "Message: ".$response->description."\n";
                $log .= "Date: ".date( 'Y-m-d H:i:s' )."\n\n";                            
                
                $send_to = get_option( 'gf_sc_notification_send_to' );
                if ( $send_to ) {
                    $to = $send_to;
                    $subject = get_option( 'gf_sc_notification_subject' );
                    $body = "Error Code: ".$response->name."<br>";
                    $body .= "Message: ".$response->description."<br>";
                    $body .= "Date: ".date( 'Y-m-d H:i:s' );
                    $headers = array(
                        'Content-Type: text/html; charset=UTF-8',
                    );
                    wp_mail( $to, $subject, $body, $headers );
                }
                
                file_put_contents( GF_SC_PLUGIN_PATH.'debug.log', $log, FILE_APPEND );
            }
            
            $filter_fields = array();
            if ( isset( $response->module_fields ) && $response->module_fields != null ) {
                foreach ( $response->module_fields as $field ) {
                    if ( $field->related_module == null && $field->type != 'id' && $field->type != 'assigned_user_name' && $field->type != 'relate' && $field->type != 'fullname' && $field->type != 'image' ) {
                        $filter_fields[$field->name] = array(
                            'label'     => $field->label,
                            'type'      => $field->type,  
                            'required'  => $field->required,
                        );
                    }
                }
                
                $filter_fields['assigned_user_id'] = array(
                    'label'     => 'Assigned to',
                    'type'      => 'relate',  
                    'required'  => 0,
                );
                
                $filter_fields['attachment_field'] = array(
                    'label'     => 'Attachments',
                    'type'      => 'relate',
                    'required'  => 0,
                );
            }
            
            return $filter_fields;
        }
        
        function getRecords( $session_id, $module, $email_address ) {
            
            $data = array(
                'method'        => 'search_by_module',
                'input_type'    => 'JSON',
                'response_type' => 'JSON',
                'rest_data'     => json_encode( array(
                        'session'           => $session_id,
                        'search_string'     => $email_address,
                        'modules'           => array( $module ),
                        'offset'            => 0,
                        'max_results'       => -1,
                        'id'                => '',
                        'select_fields'     => array( 'id' ),
                        'unified_search_only'   => false,
                        'favorites'             => false,
                    )),                
            );
            
            $ch = curl_init( $this->url );
            curl_setopt( $ch, CURLOPT_HEADER, false );
            curl_setopt( $ch, CURLOPT_RETURNTRANSFER, true );
            curl_setopt( $ch, CURLOPT_SSL_VERIFYPEER, false );
            curl_setopt( $ch, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_0 );
            curl_setopt( $ch, CURLOPT_POST, true );
            curl_setopt( $ch, CURLOPT_POSTFIELDS, $data );
            $json_response = curl_exec( $ch );
            curl_close( $ch );
            
            $response = json_decode( $json_response );
            
            if ( isset( $response->name ) ) {
                $log = "Error Code: ".$response->name."\n";
                $log .= "Message: ".$response->description."\n";
                $log .= "Date: ".date( 'Y-m-d H:i:s' )."\n\n";                            
                
                $send_to = get_option( 'gf_sc_notification_send_to' );
                if ( $send_to ) {
                    $to = $send_to;
                    $subject = get_option( 'gf_sc_notification_subject' );
                    $body = "Error Code: ".$response->name."<br>";
                    $body .= "Message: ".$response->description."<br>";
                    $body .= "Date: ".date( 'Y-m-d H:i:s' );
                    $headers = array(
                        'Content-Type: text/html; charset=UTF-8',
                    );
                    wp_mail( $to, $subject, $body, $headers );
                }
                
                file_put_contents( GF_SC_PLUGIN_PATH.'debug.log', $log, FILE_APPEND );
            }
            
            $records = array();
            if ( isset( $response->entry_list[0]->records ) && $response->entry_list[0]->records != null ) {
                foreach ( $response->entry_list[0]->records as $record ) {
                    $records[] = $record->id->value;
                }
            }
            
            return $records;
        }
        
        function updateRecord( $session_id, $module, $data, $record_id, $form_id ) {
            
            $data['id'] = $record_id;
            
            $filter_data = array();
            if ( $data != null ) {
                foreach ( $data as $key => $value ) {
                    $filter_data[] = array(
                        'name'  => $key,
                        'value' => $value,
                    );
                }
            }
            
            $data = array(
                'method'        => 'set_entry',
                'input_type'    => 'JSON',
                'response_type' => 'JSON',
                'rest_data'     => json_encode( array(
                        'session'           => $session_id,
                        'module_name'       => $module,
                        'name_value_list'   => $filter_data,
                    )),                
            );
            
            $ch = curl_init( $this->url );
            curl_setopt( $ch, CURLOPT_HEADER, false );
            curl_setopt( $ch, CURLOPT_RETURNTRANSFER, true );
            curl_setopt( $ch, CURLOPT_SSL_VERIFYPEER, false );
            curl_setopt( $ch, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_0 );
            curl_setopt( $ch, CURLOPT_POST, true );
            curl_setopt( $ch, CURLOPT_POSTFIELDS, $data );
            $json_response = curl_exec( $ch );
            curl_close( $ch );
            
            $response = json_decode( $json_response );
            if ( isset( $response->name ) ) {
                $log = "Form ID: ".$form_id."\n";
                $log .= "Error Code: ".$response->name."\n";
                $log .= "Message: ".$response->description."\n";
                $log .= "Date: ".date( 'Y-m-d H:i:s' )."\n\n";                            
                
                $send_to = get_option( 'gf_sc_notification_send_to' );
                if ( $send_to ) {
                    $to = $send_to;
                    $subject = get_option( 'gf_sc_notification_subject' );
                    $body = "Form ID: ".$form_id."<br>";
                    $body .= "Error Code: ".$response->name."<br>";
                    $body .= "Message: ".$response->description."<br>";
                    $body .= "Date: ".date( 'Y-m-d H:i:s' );
                    $headers = array(
                        'Content-Type: text/html; charset=UTF-8',
                    );
                    wp_mail( $to, $subject, $body, $headers );
                }
                
                file_put_contents( GF_SC_PLUGIN_PATH.'debug.log', $log, FILE_APPEND );
            }
            
            return $response;
        }
        
        function addFile( $session_id, $data, $form_id ) {
            
            $data = array(
                'method'        => 'set_note_attachment',
                'input_type'    => 'JSON',
                'response_type' => 'JSON',
                'rest_data'     => json_encode( array(
                    'session'   => $session_id,
                    'note'      => $data,
                )),                
            );
            
            $ch = curl_init( $this->url );
            curl_setopt( $ch, CURLOPT_HEADER, false );
            curl_setopt( $ch, CURLOPT_RETURNTRANSFER, true );
            curl_setopt( $ch, CURLOPT_SSL_VERIFYPEER, false );
            curl_setopt( $ch, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_0 );
            curl_setopt( $ch, CURLOPT_POST, true );
            curl_setopt( $ch, CURLOPT_POSTFIELDS, $data );
            $json_response = curl_exec( $ch );
            curl_close( $ch );
            
            $response = json_decode( $json_response );
            if ( isset( $response->name ) ) {
                $log = "Form ID: ".$form_id."\n";
                $log .= "Error Code: ".$response->name."\n";
                $log .= "Message: ".$response->description."\n";
                $log .= "Date: ".date( 'Y-m-d H:i:s' )."\n\n";                            
                
                $send_to = get_option( 'gf_sc_notification_send_to' );
                if ( $send_to ) {
                    $to = $send_to;
                    $subject = get_option( 'gf_sc_notification_subject' );
                    $body = "Form ID: ".$form_id."<br>";
                    $body .= "Error Code: ".$response->name."<br>";
                    $body .= "Message: ".$response->description."<br>";
                    $body .= "Date: ".date( 'Y-m-d H:i:s' );
                    $headers = array(
                        'Content-Type: text/html; charset=UTF-8',
                    );
                    wp_mail( $to, $subject, $body, $headers );
                }
                
                file_put_contents( GF_SC_PLUGIN_PATH.'debug.log', $log, FILE_APPEND );
            }
            
            return $response;
        }
        
        function setRecord( $session_id, $module, $record_id, $note_id ) {
            
            $data = array(
                'method'        => 'set_relationship',
                'input_type'    => 'JSON',
                'response_type' => 'JSON',
                'rest_data'     => json_encode( array(
                    'session'           => $session_id,
                    'module_name'       => $module,
                    'module_id'         => $record_id,
                    'link_field_name'   => 'notes',
                    'related_ids'       => array( $note_id ),
                    'name_value_list'   => array(),
                    'deleted'           => 0,
                )),
            );
            
            $ch = curl_init( $this->url );
            curl_setopt( $ch, CURLOPT_HEADER, false );
            curl_setopt( $ch, CURLOPT_RETURNTRANSFER, true );
            curl_setopt( $ch, CURLOPT_SSL_VERIFYPEER, false );
            curl_setopt( $ch, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_0 );
            curl_setopt( $ch, CURLOPT_POST, true );
            curl_setopt( $ch, CURLOPT_POSTFIELDS, $data );
            $json_response = curl_exec( $ch );
            curl_close( $ch );
            
            $response = json_decode( $json_response );
            
            return $response;
        }
    }
}