<?php
/**
 * @package   Gravity_Forms_Encrypted_Fields
 * @author    PluginOwl <info@pluginowl.com>
 * @link      https://codecanyon.net/user/pluginowl/portfolio
 * @Copyright: Plugin Owl Software
 *
 * @wordpress-plugin
 * Plugin Name: Gravity Forms Encrypted Fields
 * Plugin URI: https://codecanyon.net/item/gravity-forms-encrypted-fields/18564931
 * Description: Extends Gravity Forms with encryption and data access controls and tools.
 * Version: 6.1.4
 * Author: Plugin Owl
 * Author URI: https://codecanyon.net/user/pluginowl/portfolio
 * Copyright: Plugin Owl Software
 */

// Prevent direct access to this file.
if (!defined('ABSPATH')) {
    header('HTTP/1.0 403 Forbidden');
    echo '404 File Not Found';
    exit; // Exit if accessed directly
}
//redundancy with alt instruction
defined('ABSPATH') or die();

// Main logic file path
define('GFEF_MAIN_FILE', __FILE__);

// Set Gravity Forms dependency on activation
function gfef_activate() {
    if (!function_exists('is_plugin_active_for_network')) {
      include_once(ABSPATH . '/wp-admin/includes/plugin.php');
    }
    if (current_user_can('activate_plugins') && (!class_exists('GFCommon'))) {
        deactivate_plugins(plugin_basename(__FILE__));
        $error_message = '<p style="font-family:-apple-system,BlinkMacSystemFont,\'Segoe UI\',Roboto,Oxygen-Sans,Ubuntu,Cantarell,\'Helvetica Neue\',sans-serif;font-size: 13px;line-height: 1.5;color:#444;">' . esc_html__('GF Encrypted Fields plugin is an add-on to ', 'gfef') . '<a href="' . esc_url('https://gravityforms.com') . '" target="blank" rel="nofollow noopener">Gravity Forms</a>' . esc_html(' and requires the ', 'gfef') . '<a href="' . esc_url('https://gravityforms.com') . '" target="blank" rel="nofollow noopener">Gravity Forms</a>' . esc_html__(' plugin to be installed and active. Plugin has not been activated', 'gfef') . '</p>';
        die($error_message);
    }
    if (current_user_can('activate_plugins') && !version_compare(get_bloginfo('version'), '4.9', '>=')){
        deactivate_plugins(plugin_basename(__FILE__));
        $error_message = '<p style="font-family:-apple-system,BlinkMacSystemFont,\'Segoe UI\',Roboto,Oxygen-Sans,Ubuntu,Cantarell,\'Helvetica Neue\',sans-serif;font-size: 13px;line-height: 1.5;color:#444;">' . esc_html__('GF Encrypted Fields plugin is an add-on to ', 'gfef') . '<a href="' . esc_url('https://gravityforms.com') . '" target="blank" rel="nofollow noopener">Gravity Forms</a>' . esc_html(' and requires WordPress 4.9 or higher. Plugin has not been activated.', 'gfef') . '</p>';
        die($error_message);
    }
}
register_activation_hook(__FILE__, 'gfef_activate');

//GFEF Cron Create/Destroy/Clean 
function cron_gfef_add_week($schedules) {
    $schedules['gfef_weekly'] = array(
        'interval'  => 604800,
        'display'   => 'Once Every Week - GFEF'
    );
    return $schedules;
}
add_filter('cron_schedules', 'cron_gfef_add_week');

function gfef_cron_create() {
    $args           = array('gfef_cron');
    if (!wp_next_scheduled('gfef_cron_reg', $args) && !wp_installing()) {     
        $cron_interval  = version_compare(get_bloginfo('version'), '5.4', '<') ? 'gfef_weekly' : 'weekly';
        $success        = wp_schedule_event(time() + 604800, $cron_interval, 'gfef_cron_reg', $args);
        return $success;
    }
}
register_activation_hook(__FILE__, 'gfef_cron_create');
add_action('gfef_cron_reg', 'gravity_forms_encrypted_fields_settings_page', 10, 1);

function gfef_cron_destroy() {
    $clear      = wp_unschedule_hook('gfef_cron_reg');
    $args       = array('gfef_cron');
    $destroy    = wp_clear_scheduled_hook('gfef_cron_reg', $args);
    if ($clear !== false || $destroy !== false){
        update_option('gfef_cron_cleaned', true);
        $answer = $clear !== false ? $clear : $destroy;
    }
    return $answer;
}
register_deactivation_hook(__FILE__, 'gfef_cron_destroy');
register_uninstall_hook(__FILE__, 'gfef_cron_destroy');

// Gfef Cron Cleaner
function gfef_cron_clean() {
    $clean = gfef_cron_destroy();
    $create = gfef_cron_create();
    if (wp_next_scheduled('gfef_cron_cleaner')){
        wp_clear_scheduled_hook('gfef_cron_cleaner');
    }
}

//load plugin on gform_loaded
add_action('gform_loaded', array('GFEF_Framework_AddOn', 'gfef_load'), 5);
class GFEF_Framework_AddOn {
    public static function gfef_load() {
        if (!method_exists('GFForms', 'include_addon_framework')) {
            return;
        }
        require_once('gfef.php');
    }
}