<?php
namespace GravityWP\List_Number_Format;

use GFForms;
use RGCurrency;
use RGFormsModel;
use GFAddOn;
use GFAPI;
use GFCommon;
use GFFormDisplay;
use GF_Field;
use GravityWP\LicenseHandler;
use GFPDF\Fields\Field_List_Total_Row;

defined( 'ABSPATH' ) || die();
GFForms::include_addon_framework();

/**
 * GravityWPListNumberFormat.
 *
 * @author GravityWP
 * @since v0.0.1
 * @version v1.0.0
 * @see GFAddOn
 *
 * @global
 */
class GravityWPListNumberFormat extends GFAddOn {

	/**
	 * @var GravityWPListNumberFormat $_instance
	 */
	private static $_instance = null;
	/**
	 * @var string $_version
	 */
	protected $_version = GWP_LIST_NUMBER_FORMAT_VERSION;
	/**
	 * @var string $_min_gravityforms_version
	 */
	protected $_min_gravityforms_version = '2.4.24.1';
	/**
	 * @var string $_slug
	 */
	protected $_slug = 'gravitywp-list-number-format';
	/**
	 * @var string $_path
	 */
	protected $_path = 'gravitywp-list-number-format/gravitywp-list-number-format.php';
	/**
	 * @var string $_full_path
	 */
	protected $_full_path = __FILE__;
	/**
	 * @var string $_title
	 */
	protected $_title = 'GravityWP - List Number Format';
	/**
	 * @var string $_short_title
	 */
	protected $_short_title = 'List Number Format';
	/**
	 * @var mixed $_gwp_license_handler
	 */
	protected $_gwp_license_handler;

	/**
	 * Defines if Add-On should use Gravity Forms servers for update data.
	 *
	 * @since  1.1
	 * @access protected
	 * @var    bool
	 */
	protected $_enable_rg_autoupgrade = false;

	/**
	 * Defines the capabilities needed for the GravityWP Advanced Number Field Add-On
	 *
	 * @since  1.1
	 * @access protected
	 * @var    array<string> $_capabilities The capabilities needed for the Add-On
	 */
	protected $_capabilities = array( 'gravityforms_gravitywplistnumberformat', 'gravityforms_gravitywplistnumberformat_uninstall' );

	/**
	 * Defines the capability needed to access the Add-On settings page.
	 *
	 * @since  1.1
	 * @access protected
	 * @var    string $_capabilities_settings_page The capability needed to access the Add-On settings page.
	 */
	protected $_capabilities_settings_page = 'gravityforms_gravitywplistnumberformat';

	/**
	 * Defines the capability needed to access the Add-On form settings page.
	 *
	 * @since  1.1
	 * @access protected
	 * @var    string $_capabilities_form_settings The capability needed to access the Add-On form settings page.
	 */
	protected $_capabilities_form_settings = 'gravityforms_gravitywplistnumberformat';

	/**
	 * Defines the capability needed to uninstall the Add-On.
	 *
	 * @since  1.1
	 * @access protected
	 * @var    string $_capabilities_uninstall The capability needed to uninstall the Add-On.
	 */
	protected $_capabilities_uninstall = 'gravityforms_gravitywplistnumberformat_uninstall';

	/**
	 * @var string $gwp_site_slug
	 */
	public $gwp_site_slug = 'list-number-format';

	/**
	 * Get an instance of this class.
	 *
	 * @return GravityWPListNumberFormat
	 */
	public static function get_instance() {
		if ( self::$_instance == null ) {
			self::$_instance = new self();
		}

		return self::$_instance;
	}

	/**
	 * Function: init.
	 *
	 * @author GravityWP
	 * @since v0.0.1
	 * @version v1.0.0
	 * @access public
	 *
	 * @return void
	 */
	public function init() {

		add_filter( 'gform_custom_merge_tags', array( $this, 'list_col_number_field_calculations_merge_tags' ), 10, 4 );
		// gf list column number validate values.
		add_filter( 'gform_validation', array( $this, 'validate_list_col_number_values' ), 10, 1 );
		// gf calculate list field according to insert formula.
		add_filter( 'gform_calculation_formula', array( $this, 'gf_list_field_calculations' ), 10, 4 );
		// format numbers as raw values for the list to entries workflowstep.
		add_filter( 'gravitywp/listtoentries/rows', array( $this, 'value_to_raw_value_array' ), 10, 2 );
		// format numbers as raw values for the field to entries addon.
		add_filter( 'gravitywp/fieldtoentries/source_values', array( $this, 'value_to_raw_value_array' ), 10, 2 );
		// display column totals when the field value is shown ( entry detail, all_fields, merge tag).
		add_filter( 'gform_get_field_value', array( $this, 'list_column_display_total' ), 10, 3 );
		// print initialization script for realtime calculations in entry edit via admin.
		add_action( 'gform_entry_detail', array( $this, 'print_init_script' ), 10, 2 );
		// Support for total row in GravityPDF. Note this filter is temporarily unhooked in the GPDF Helper Field. Update priority there if changed here.
		add_filter( 'gfpdf_field_class_list', array( $this, 'filter_gpdf_total_row' ), 10, 3 );
		// gf list column number format frontend.
		add_filter( 'gform_column_input_content', array( $this, 'gf_list_col_num_format' ), 10, 6 );
		// Add javascript init script to frontend.
		add_filter( 'gform_register_init_scripts', array( $this, 'register_init_scripts' ), 10, 3 );
		parent::init();
	}

	/**
	 * Initialize the admin specific hooks.
	 *
	 * @author GravityWP
	 * @since v0.0.1
	 * @version v1.0.0
	 * @access public
	 *
	 * @return void
	 */
	public function init_admin() {

		// Init license handler.
		if ( ! $this->_gwp_license_handler ) {
			$this->_gwp_license_handler = new GravityWP\LicenseHandler\LicenseHandler( __CLASS__, 'fa637d30-7cfd-42e7-ba50-095a6fc9783a', plugin_dir_path( __FILE__ ) . 'gravitywp-list-number-format.php' );
		}

		// gh list col settings (single / multi columns).
		add_action( 'gform_field_standard_settings', array( $this, 'field_settings' ), 10, 2 );
		// df list col tooltip.
		add_filter( 'gform_tooltips', array( $this, 'add_field_tooltips' ) );
		// include gf list total column format.
		add_filter( 'gform_entry_detail_content_before', array( $this, 'gf_list_col_total_format_admin' ), 10, 6 );
		// gf list column number format frontend.
		add_filter( 'gform_column_input_content', array( $this, 'gf_list_col_num_format_admin' ), 10, 6 );

		parent::init_admin();

	}

	/**
	 * Print init script in admin area.
	 *
	 * @since 1.2
	 *
	 * @param array<mixed> $form The form.
	 * @param array<mixed> $entry The entry.
	 * @return void
	 */
	public function print_init_script( $form, $entry ) {
		if ( GFCommon::is_entry_detail() && $this->form_has_list_field( $form ) ) {
			$number_format_fields = $this->gf_list_col_num_field_settings( $form );
			$script               = 'jQuery(document).ready(function (jQuery) {new GWPListNumberFormat(' . $form['id'] . ',' . wp_json_encode( $number_format_fields, JSON_FORCE_OBJECT ) . ',jQuery);});';
			echo '<script>' . $script . '</script>';
		}
	}
	/**
	 * Add data for frontpage form script.
	 *
	 * @author GravityWP
	 * @since v1.2
	 * @access public
	 *
	 * @param mixed $form
	 * @param mixed $field_values
	 * @param bool  $is_ajax      If form is being submitted via AJAX.
	 *
	 * @return void
	 */
	public function register_init_scripts( $form, $field_values, $is_ajax ) {
		$number_format_fields = $this->gf_list_col_num_field_settings( $form );
		if ( empty( $number_format_fields ) ) {
			return;
		}

		// Load all advanced number settings.
		$fields = GFAPI::get_fields_by_type( $form, array( 'list' ) );
		$args   = array();
		foreach ( $fields as $field ) {
			if ( ! empty( $field->gwp ) ) {
				$args[ $form['id'] . '_' . $field['id'] ] = array_merge(
					$field->gwp,
					array(
						'numberFormat' => $field->numberFormat,
						'formula'      => $field->calculationFormula,
					)
				);
			}
		}

		$script = 'new GWPListNumberFormat(' . $form['id'] . ',' . wp_json_encode( $number_format_fields, JSON_FORCE_OBJECT ) . ', jQuery);';

		// Add the inline script to form scripts./*
		GFFormDisplay::add_init_script( $form['id'], $this->get_slug(), GFFormDisplay::ON_PAGE_RENDER, $script );

		$init_scripts = GFFormDisplay::$init_scripts[ $form['id'] ];
		$key          = $this->get_slug() . '_' . GFFormDisplay::ON_PAGE_RENDER;
		$value        = $init_scripts[ $key ];
		unset( $init_scripts[ $key ] );

		// Force our script to be added in the beginning of init scripts. This is necessary because our scripts (with action hooks) must be loaded before the GF scripts start initializing calculations.
		GFFormDisplay::$init_scripts[ $form['id'] ] = array( $key => $value ) + $init_scripts;

	}

	/**
	 * Define plugin settings fields.
	 *
	 * @since  1.1.2
	 *
	 * @return array<mixed>
	 */
	public function plugin_settings_fields() {
		// Retrieve license fields.
		$license_fields = $this->_gwp_license_handler->plugin_settings_license_fields();

		$fields = array( $license_fields );
		return $fields;

	}

	/**
	 * Enqueue list column number scripts.
	 *
	 * @return array<mixed>
	 */
	public function scripts() {
		$min = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG || isset( $_GET['gform_debug'] ) ? '' : '.min';

		$scripts = array(
			array(
				'handle'    => 'gf_list_col_num_format_frontend_js',
				'src'       => $this->get_base_url() . "/assets/js/list-col-num-frontend{$min}.js",
				'version'   => $this->_version,
				'deps'      => array( 'jquery', 'wp-util' ),
				'enqueue'   => array( array( $this, 'form_has_list_field' ) ),
				'in_footer' => true,
				'callback'  => array( $this, 'localize_scripts' ),
			),
			array(
				'handle'    => 'gravitywp_list_col_num_format_admin_js',
				'src'       => $this->get_base_url() . "/assets/js/list-col-num-admin{$min}.js",
				'version'   => $this->_version,
				'deps'      => array( 'jquery', 'wp-util' ),
				'enqueue'   => array(
					array( 'admin_page' => array( 'form_editor' ) ),
				),
				'in_footer' => true,
				'callback'  => array( $this, 'localize_scripts_admin' ),
			),
		);

		return array_merge( parent::scripts(), $scripts );
	}

	/**
	 * Return the stylesheets which should be enqueued.
	 *
	 * @return array<mixed>
	 */
	public function styles() {
		$min = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG || isset( $_GET['gform_debug'] ) ? '' : '.min';

		$styles = array(
			array(
				'handle'  => 'gravitywp_list_col_num_format_frontend_css',
				'src'     => $this->get_base_url() . "/assets/css/list-col-num-frontend{$min}.css",
				'version' => $this->_version,
				'media'   => 'screen',
				'enqueue' => array( array( $this, 'form_has_list_field' ) ),
			),
			array(
				'handle'  => 'gravitywp_list_col_num_format_admin_css',
				'src'     => $this->get_base_url() . "/assets/css/list-col-num-admin{$min}.css",
				'version' => $this->_version,
				'enqueue' => array(
					array( 'admin_page' => array( 'form_editor' ) ),
				),
			),
		);

		return array_merge( parent::styles(), $styles );
	}

	/**
	 * Localize form data.
	 *
	 * @author GravityWP
	 * @since v0.0.1
	 * @version v1.0.0
	 * @access public
	 *
	 * @param array<mixed> $form
	 * @param bool         $is_ajax
	 *
	 * @return void
	 */
	public function localize_scripts( $form, $is_ajax ) {
		$is_entry_detail = GFCommon::is_entry_detail();

		// localize gf list column number field settings.
		wp_localize_script(
			'gf_list_col_num_format_frontend_js',
			'gf_list_col_num_settings',
			array(
				'is_entry_detail'             => $is_entry_detail,
				'min_range_formula_error'     => esc_js( __( 'This column cannot be less than {{min}}', 'gravitywp-list-number-format' ) ),
				'max_range_formula_error'     => esc_js( __( 'This column cannot be more than {{max}}', 'gravitywp-list-number-format' ) ),
				'min_max_range_formula_error' => esc_js( __( 'This column must have value between {{min}} and {{max}}', 'gravitywp-list-number-format' ) ),
			)
		);
		if ( $is_entry_detail && wp_script_is( 'gform_gravityforms' ) ) {
			wp_localize_script( 'gform_gravityforms', 'gf_global', GFCommon::gf_global( false, true ) );
		}
	}

	/**
	 * Localize admin scripts.
	 *
	 * @author GravityWP
	 * @since v0.0.1
	 * @version v1.0.0
	 * @access public
	 *
	 * @param array<mixed> $form
	 * @param bool         $is_ajax
	 *
	 * @return void
	 */
	public function localize_scripts_admin( $form, $is_ajax ) {
		$settings_array = array(
			'text_column_row_value' => esc_js( __( 'Column row value', 'gravitywp-list-number-format' ) ),
		);

		wp_localize_script( 'gravitywp_list_col_num_format_admin_js', 'gf_list_col_num_settings_admin', $settings_array );
	}

	/**
	 * set list column number merge tags.
	 *
	 * @param array<mixed> $merge_tags
	 * @param int          $form_id
	 * @param array<mixed> $fields
	 * @param string       $element_id
	 * @return array<mixed>
	 */
	public function list_col_number_field_calculations_merge_tags( $merge_tags, $form_id, $fields, $element_id ) {

		// check the type of merge tag dropdown.
		if ( strpos( $element_id, 'list_col_calculation' ) === false && $element_id != 'field_calculation_formula' ) {
			return $merge_tags;
		}

		foreach ( $fields as $field ) {

			// check the field type as we only want to generate merge tags for list fields.
			if ( $field->get_input_type() != 'list' ) {
				continue;
			}

			$label = $field->label;
			$tag   = '{' . $label . ':' . $field->id;

			$column_count = ( is_array( $field->choices ) ) ? count( $field->choices ) : 0;

			if ( $column_count > 1 ) {

				$i = 0;

				foreach ( $field->choices as $column ) {
					// skip if column is not a number.
					if ( ! rgar( $column, 'isNumber' ) ) {
						$i++;
						continue;
					}
					$col_label    = ( $element_id == 'field_calculation_formula' ) ? __( '(Column sum)', 'gravitywp-list-number-format' ) : __( '(Column row value)', 'gravitywp-list-number-format' );
					$merge_tags[] = array(
						'label' => $label . ' - ' . $column['text'] . " $col_label",
						'tag'   => $tag . '.' . ++$i . '}',
					);
				}
			} else {
				// return col sum for number field.
				if ( $element_id == 'field_calculation_formula' ) {
					$merge_tags[] = array(
						'label' => $label . ' (Column sum)',
						'tag'   => $tag . '.1}',
					);
				}
			}
			// return row count for number field.
			if ( $element_id == 'field_calculation_formula' ) {
				$merge_tags[] = array(
					'label' => $label . ' (Row count)',
					'tag'   => $tag . '}',
				);
			}
		}

		return $merge_tags;
	}

	/**
	 * Handles custom validation for range.
	 *
	 * @author GravityWP
	 * @since v0.0.1
	 * @version v1.0.0
	 * @access public
	 *
	 * @param array<mixed> $validation_result
	 *
	 * @return array<mixed>
	 */
	public function validate_list_col_number_values( $validation_result ) {
		// get form
		$form = $validation_result['form'];
		if ( $this->form_has_list_field( $form ) ) {
			$current_page = rgpost( 'gform_source_page_number_' . $form['id'] ) ? rgpost( 'gform_source_page_number_' . $form['id'] ) : 1;
			foreach ( $form['fields'] as &$field ) {
				if ( $field->type !== 'list' ) {
					continue;
				}
				$field_page = $field->pageNumber;
				$is_hidden  = RGFormsModel::is_field_hidden( $form, $field, array() );
				if ( $field_page != $current_page || $is_hidden ) {
					continue;
				}
				// if gf list column is multiple.
				if ( is_array( $field->choices ) ) {
					$list_values = maybe_unserialize( RGFormsModel::get_field_value( $field ) );  // get the value of the field.
					if ( is_array( $list_values ) ) {
						foreach ( $list_values as $row ) { // get each row.
							foreach ( $field->choices as $key => &$choice ) { // for each column.
								$column = rgars( $field->choices, "{$key}/text" ); // we'll be using the column label as the key.
								if ( rgar( $choice, 'isNumber' ) ) {
									$value                       = $row[ $column ];
									$list_col_number_format      = rgar( $choice, 'isNumberFormat' );
									$list_col_number_rounding    = rgar( $choice, 'isNumberRounding' );
									$list_col_number_fixed_point = rgar( $choice, 'isNumberFixedPoint' );
									$list_col_number_range_min   = isset( $choice['isNumberRangeMin'] ) ? $choice['isNumberRangeMin'] : '';
									$list_col_number_range_max   = isset( $choice['isNumberRangeMax'] ) ? $choice['isNumberRangeMax'] : '';
									if ( $list_col_number_range_min !== '' || $list_col_number_range_max !== '' ) {
										// validate column number and add field validation message.
										$validation_result = $this->add_validation_message_list_col_number_values( $validation_result, $value, $form, $field, $row, $list_col_number_format, $list_col_number_rounding, $list_col_number_fixed_point, $list_col_number_range_min, $list_col_number_range_max, true, $choice['text'] );
										if ( isset( $validation_result['break_loop'] ) && $validation_result['break_loop'] ) {
											unset( $validation_result['break_loop'] );
											break;
										}
									}
								}
							}
						}
					}
				} elseif ( rgar( $field, 'isNumber' ) ) {
					$value = rgpost( "input_{$field['id']}" );
					if ( is_array( $value ) ) {
						foreach ( $value as $row => $column_value ) {
							$value                       = $column_value;
							$list_col_number_format      = rgar( $field, 'isNumberFormat' );
							$list_col_number_rounding    = rgar( $field, 'isNumberRounding' );
							$list_col_number_fixed_point = rgar( $field, 'isNumberFixedPoint' );
							// validate column number and add field validation message.
							$list_col_number_range_min = isset( $field['isNumberRangeMin'] ) ? $field['isNumberRangeMin'] : '';
							$list_col_number_range_max = isset( $field['isNumberRangeMax'] ) ? $field['isNumberRangeMax'] : '';
							if ( $list_col_number_range_min !== '' || $list_col_number_range_max !== '' ) {
								$validation_result = $this->add_validation_message_list_col_number_values( $validation_result, $value, $form, $field, $row, $list_col_number_format, $list_col_number_rounding, $list_col_number_fixed_point, $list_col_number_range_min, $list_col_number_range_max, false );
								if ( isset( $validation_result['break_loop'] ) && $validation_result['break_loop'] ) {
									unset( $validation_result['break_loop'] );
									break;
								}
							}
						}
					}
				}
			}
		}
		// Assign modified $form object back to the validation result.
		$validation_result['form'] = $form;
		return $validation_result;
	}

	/**
	 * gf calculate list field according to insert formula.
	 *
	 * @author GravityWP
	 * @since v0.0.1
	 * @version v1.0.0
	 * @access public
	 *
	 * @param string       $formula
	 * @param GF_Field     $field
	 * @param array<mixed> $form
	 * @param array<mixed> $lead
	 *
	 * @return string
	 */
	public function gf_list_field_calculations( $formula, $field, $form, $lead ) {

		// {List:1.3} - {Label:ID.Column} - sum column values.
		// {List:1} - {Label:ID} - count rows.
		preg_match_all( '/{[^{]*?:(\d+)\.?(\d+)?}/mi', $formula, $matches, PREG_SET_ORDER );

		if ( is_array( $matches ) ) {

			foreach ( $matches as $match ) {

				// $match[0] = merge tag e.g. {List:1.3}
				// $match[1] = field id e.g. 1
				// $match[2] = column number e.g. 3
				// get the $field object for the provided id
				$field_id = $match[1];
				$field    = RGFormsModel::get_field( $form, $field_id );

				// check that we have a field.
				if ( ! $field ) {
					continue;
				}

				// check the field type as we only want the rest of the function to run if the field type is list.
				if ( $field->get_input_type() !== 'list' ) {
					continue;
				}

				// get the list fields values from the $lead.
				$list_values = empty( $lead[ $field_id ] ) ? array() : maybe_unserialize( $lead[ $field_id ] );

				// check if we have an array
				if ( ! is_array( $list_values ) ) {
					$this->log_error( __METHOD__ . "(): The value of Listfield #{$field_id} is not countable. Value from lead/entry: " . print_r( $lead[ $field_id ], true ) );
					continue;
				}

				$count       = 0;

				// if column number found sum column values otherwise count number of rows.
				if ( isset( $match[2] ) ) {

					// count the actual number of columns.
					$column_count = ( is_array( $field->choices ) ) ? count( $field->choices ) : 1;

					if ( $column_count > 1 ) {
						// subtract 1 from column number as the choices array is zero based.
						$column_num = $match[2] - 1;
						// get the column label so we can use that as the key to the multi-column values.
						$column = rgars( $field->choices, "{$column_num}/text" );
					}

					foreach ( $list_values as $value ) {
						if ( $column_count == 1 ) {
							// clean matched value
							$column_val    = $value;
							$number_format = ( rgars( $field, 'isNumberFormat' ) ) ? rgars( $field, 'isNumberFormat' ) : 'decimal_dot';
							if ( $number_format ) {
								$column_val = $this->get_clean_value( $column_val, $number_format );
							}
							$count += GFCommon::to_number( $column_val );
						} else {
							// clean matched value.
							$column_val    = $value[ $column ];
							$number_format = ( rgars( $field->choices, "{$column_num}/isNumberFormat" ) ) ? rgars( $field->choices, "{$column_num}/isNumberFormat" ) : 'decimal_dot';
							if ( $number_format ) {
								$column_val = $this->get_clean_value( $column_val, $number_format );
							}
							$count += GFCommon::to_number( $column_val );
						}
					}
				} else {
					$count = count( $list_values );
				}

				// replace the merge tag with the row count or column sum.
				$formula = str_replace( $match[0], (string) $count, $formula );
			}
		}

		// return the modified formula so the rest of the calculation can be run by GF.
		return $formula;
	}

	/**
	 * validate column number and add field validation message.
	 *
	 * @author GravityWP
	 * @since v0.0.1
	 * @version v1.0.0
	 * @access public
	 *
	 * @param array<mixed> $validation_result
	 * @param string       $value
	 * @param array<mixed> $form
	 * @param GF_Field     $field
	 * @param array<mixed> $row
	 * @param string       $list_col_number_format
	 * @param string       $list_col_number_rounding
	 * @param bool       $list_col_number_fixed_point
	 * @param string       $list_col_number_range_min
	 * @param string       $list_col_number_range_max
	 * @param bool         $has_columns
	 * @param string       $column_text                 Default: ''
	 *
	 * @return array<mixed>
	 */
	public function add_validation_message_list_col_number_values( $validation_result, $value, $form, $field, $row, $list_col_number_format, $list_col_number_rounding, $list_col_number_fixed_point, $list_col_number_range_min, $list_col_number_range_max, $has_columns, $column_text = '' ) {
		// check number is in correct format
		if ( ! $this->is_column_value_valid_format( $value, $list_col_number_format ) ) {
			$validation_result['is_valid'] = false; // set the form validation to false.
			$field->failed_validation      = true;
			$number_format_text            = $this->get_formatted_value( '9999', $list_col_number_format, $list_col_number_rounding );
			if ( $has_columns ) {
				$message = sprintf( esc_html__( "The column '%1\$s' requires a value in %2\$s format.", 'gravitywp-list-number-format' ), $column_text, $number_format_text );
			} else {
				$message = sprintf( esc_html__( 'Requires a value in %s format.', 'gravitywp-list-number-format' ), $number_format_text );
			}

			$field->validation_message       = $message;
			$validation_result['break_loop'] = true;
			return $validation_result;
		}
		// check is value provided is value, compared to number format and min/max range - used in validation.
		$is_valid_number = $this->is_valid_number( $value, $list_col_number_format, $list_col_number_range_min, $list_col_number_range_max, $form, $field, $row );

		// check number is in correct range.
		if ( ! $is_valid_number['result'] ) {
			$validation_result['is_valid'] = false; // set the form validation to false.
			$field->failed_validation      = true;
			// if multiple column
			if ( $has_columns ) {
				$message = $this->get_column_validation_range_message( $is_valid_number['result_min'], $is_valid_number['result_max'], $list_col_number_format, $list_col_number_rounding, $list_col_number_fixed_point, $column_text );
			} else {
				$message = $this->get_validation_range_message( $is_valid_number['result_min'], $is_valid_number['result_max'], $list_col_number_format, $list_col_number_rounding, $list_col_number_fixed_point );
			}

			$field->validation_message = $message;
		}

		return $validation_result;
	}

	/**
	 * Add the custom settings for the list number field format general tab.
	 *
	 * @author GravityWP
	 * @since v0.0.1
	 * @version v1.0.0
	 * @access public
	 *
	 * @param int $position The position the settings should be located at.
	 * @param int $form_id  The ID of the form currently being edited.
	 *
	 * @return void
	 */
	public function field_settings( $position, $form_id ) {
		// Create settings on position 50 (top position).
		if ( 50 == $position ) {
			$form        = GFAPI::get_form( $form_id );
			$entry_count = GFAPI::count_entries( $form_id );
			// include list multi col number.
			include $this->get_base_path() . '/templates/gwp-list-multi-col-field-number-format.php';
		} elseif ( 1287 == $position ) {
			// include list single col number.
			$form        = GFAPI::get_form( $form_id );
			$entry_count = GFAPI::count_entries( $form_id );
			include $this->get_base_path() . '/templates/gwp-list-single-col-field-number-format.php';
		}
	}

	/**
	 * Add the tooltips for the list nemaber format field.
	 *
	 * @param array<string> $tooltips An associative array of tooltips where the key is the tooltip name and the value is the tooltip.
	 *
	 * @return array<string>
	 */
	public function add_field_tooltips( $tooltips ) {
		// form settings
		$tooltips['list_number_enable'] = '<h6>' . esc_html__( 'Number Format', 'gravitywp-list-number-format' ) . '</h6>' . esc_html__( 'Select this option to set column as a number format field.', 'gravitywp-list-number-format' );

		return $tooltips;
	}

	/**
	 * include gf list total column format
	 *
	 * @author GravityWP
	 * @since v0.0.1
	 * @version v1.0.0
	 * @access public
	 *
	 * @param array<mixed> $form
	 * @param array<mixed> $lead
	 *
	 * @return void
	 */
	public function gf_list_col_total_format_admin( $form, $lead ) {

		include $this->get_base_path() . '/templates/gwp-list-col-num-total-row.php';
	}

	/**
	 * gf list column number format admin
	 *
	 * @author GravityWP
	 * @since v0.0.1
	 * @version v1.0.0
	 * @access public
	 *
	 * @param string       $input
	 * @param array<mixed> $input_info
	 * @param GF_Field     $field
	 * @param string       $text
	 * @param string       $value
	 * @param int          $form_id
	 *
	 * @return string
	 */
	public function gf_list_col_num_format_admin( $input, $input_info, $field, $text, $value, $form_id ) {
		if ( GFCommon::is_form_editor() ) {
			$has_columns = is_array( $field->choices );
			if ( $has_columns ) {
				foreach ( $field->choices as $choice ) {
					if ( $text == rgar( $choice, 'text' ) ) {
						$input = $this->gf_list_col_num_format_admin_text( $choice, $input );
					}
				}
			} else {
				if ( rgar( $field, 'isNumber' ) ) {
					$input = $this->gf_list_col_num_format_admin_text( $field, $input );
				}
			}
		}

		return $input;
	}

	/**
	 * gf list column number format admin text
	 *
	 * @param GF_Field $field
	 * @param string   $input
	 * @return string
	 */
	public function gf_list_col_num_format_admin_text( $field, $input ) {
		if ( $field && rgar( $field, 'isNumber' ) && $input ) {
			$list_col_number_format   = rgar( $field, 'isNumberFormat' );
			$list_col_number_rounding = rgar( $field, 'isNumberRounding' );
			$number_format_text       = $this->get_formatted_value( '9999', $list_col_number_format, $list_col_number_rounding );
			$input                    = str_replace( "value='' ", "value='{$number_format_text}' ", $input );
		}

		return $input;
	}

	/**
	 * Display gf list column total.
	 *
	 * @author GravityWP
	 * @since v0.0.1
	 * @version v1.0.0
	 * @access public
	 *
	 * @param string       $value
	 * @param array<mixed> $entry
	 * @param GF_Field     $field
	 * @param string       $total_cell_markup Default: ''
	 *
	 * @return string
	 */
	public function list_column_display_total( $value, $entry, $field, $total_cell_markup = '' ) {
		if ( is_object( $field ) && 'list' == $field->type && $value ) {
			$is_entry_detail = GFCommon::is_entry_detail();
			// get form by form id
			if ( ! ( $is_entry_detail && 'edit' == rgpost( 'screen_mode' ) ) ) {
				if ( $field->gravityflow_is_editable ) {
					return $value;
				}
				// check if field mutli columns or single column.
				$has_columns = is_array( $field->choices );

				// get field values. Do some checks to prevent fatal errors, for example when using GPPA v1.2.37 Live merge tags.
				if ( is_string( $value ) ) {
					$values = maybe_unserialize( $value );
				}

				if ( is_array( $values ) && ! empty( $values ) ) {
					$total_row    = array(); // we'll be storing the total row as an array here
					$column_total = $this->gf_entry_get_list_column_total( $values, $field, $has_columns ); // get field columns total

					if ( $has_columns ) {
						if ( $column_total ) {
							foreach ( $column_total as $key => $total ) {
								$col_total_row = $this->gf_list_col_get_total_row( $total, $field->choices[ $key ], $total_cell_markup );
								if ( $col_total_row ) {
									$column_label               = rgars( $field->choices, "{$key}/text" ); // we'll be using the column label as the key
									$total_row[ $column_label ] = $col_total_row;
								}
							}
						}
					} else {
						$total_row = $this->gf_list_col_get_total_row( $column_total, $field, $total_cell_markup );
					}

					// only add total row if field contains a total enabled field - avoids blank total row
					if ( ! empty( $total_row ) ) {
						array_push( $values, $total_row ); // add row to submit value array
					}
				$value = serialize( $values );
				}
			}
		}

		return $value;
	}

	/**
	 * get gf list column total row text
	 *
	 * @author GravityWP
	 * @since v0.0.1
	 * @version v1.0.0
	 * @access public
	 *
	 * @param float|false   $column_total
	 * @param GF_Field $field
	 * @param string   $total_cell_markup
	 *
	 * @return string
	 */
	public function gf_list_col_get_total_row( $column_total, $field, $total_cell_markup ) {
		$total_row = '';
		if ( empty( $total_cell_markup ) ) {
			$total_cell_markup = "<div style='border-top: medium double; border-bottom: 1px solid;'><strong>%1s</strong></div>";
		}
		if ( $field && rgar( $field, 'isNumber' ) && rgar( $field, 'isNumberColumnTotal' ) && $column_total !== false ) {
			$list_col_num_format         = rgar( $field, 'isNumberFormat' );
			$list_col_number_rounding    = rgar( $field, 'isNumberRounding' );
			$list_col_number_fixed_point = rgar( $field, 'isNumberFixedPoint' );
			$number_format_text          = $this->get_formatted_value( $column_total, $list_col_num_format, $list_col_number_rounding );
			$total_row                   = sprintf( $total_cell_markup, $number_format_text );
		}

		return $total_row;
	}

	/**
	 * Function: gf_entry_get_list_column_total.
	 *
	 * @author GravityWP
	 * @since v0.0.1
	 * @version v1.0.0
	 * @access public
	 *
	 * @param array<mixed> $values
	 * @param GF_Field     $field
	 * @param bool         $has_columns
	 *
	 * @return array<mixed>|false
	 */
	public function gf_entry_get_list_column_total( $values, $field, $has_columns ) {

		if ( $values && $field ) {
			foreach ( $values as &$val ) {
				$column_number = 0;
				if ( $has_columns ) {
					foreach ( $val as &$column ) {
						// skip if column is not a number.
						if ( ! rgar( $field['choices'][ $column_number ], 'isNumber' ) ) {
							$column_number++;
							continue;
						}
						// init column total value
						if ( ! isset( $column_total[ $column_number ] ) ) {
							$column_total[ $column_number ] = 0;
						}

						if ( rgar( $field['choices'][ $column_number ], 'isNumberColumnTotal' ) ) {
							$number_format                   = ( rgar( $field['choices'][ $column_number ], 'isNumberFormat' ) ) ? rgar( $field['choices'][ $column_number ], 'isNumberFormat' ) : 'decimal_dot';
							$column_total[ $column_number ] += $this->get_clean_value( $column, $number_format );
						}

						if ( $column_number >= ( count( $field->choices ) - 1 ) ) {
							$column_number = 0; // reset column number
						} else {
							$column_number = $column_number + 1; // increment column number
						}
					}
				} elseif ( ! $has_columns && rgar( $field, 'isNumber' ) && rgar( $field, 'isNumberColumnTotal' ) ) {
					if ( ! isset( $column_total ) ) {
						$column_total = 0;
					}
					$number_format = ( rgar( $field, 'isNumberFormat' ) ) ? rgar( $field, 'isNumberFormat' ) : 'decimal_dot';
					$column_total += $this->get_clean_value( $val, $number_format );
				}
			}
		}

		if ( ! isset( $column_total ) ) {
			return false;
		}
		return $column_total;
	}

	/**
	 * Output the total row template.
	 *
	 * @return void
	 */
	public function output_template() {
		include_once $this->get_base_path() . '/templates/gwp-list-col-num-total-row.php';
	}

	/**
	 * gf list column number format frontend
	 *
	 * @author GravityWP
	 * @since v0.0.1
	 * @version v1.0.0
	 * @access public
	 *
	 * @param string       $input
	 * @param array<mixed> $input_info
	 * @param GF_Field     $field
	 * @param string       $text
	 * @param string       $value
	 * @param int          $form_id
	 *
	 * @return string
	 */
	public function gf_list_col_num_format( $input, $input_info, $field, $text, $value, $form_id ) {
		// Hooked into wp_footer as a fix for the template not being outputted to the DOM when editing entry via GView. Note this action will be hooked multiple times in case of multiple columns. Because of include_once the template is included just 1 time. Which is cleaner than before.
		add_action( 'wp_footer', array( $this, 'output_template' ) );
		add_action( 'gform_preview_footer', array( $this, 'output_template' ) );

		$field_id                           = $field->id;
		$has_columns                        = is_array( $field->choices );
		$list_col_number_range_instructions = '';
		$list_col_number_range_min          = '';
		$list_col_number_range_max          = '';

		// check if gf list is multiple column or single column
		if ( $has_columns ) {
			foreach ( $field->choices as $choice ) {

				if ( $text == rgar( $choice, 'text' ) && rgar( $choice, 'isNumber' ) ) {

					$list_col_number_range_instructions       = false != rgar( $choice, 'isNumberRangeInstructions' );
					$list_col_number_enable_range_calculation = rgar( $choice, 'isNumberEnableRangeCalculation' ) ? rgar( $choice, 'isNumberEnableRangeCalculation' ) : 'false';

					if ( $list_col_number_range_instructions && $list_col_number_enable_range_calculation === 'false' ) {
						// get min and max field value
						$list_col_number_range_min = rgar( $choice, 'isNumberRangeMin' );
						$list_col_number_range_max = rgar( $choice, 'isNumberRangeMax' );
					}
				}
			}
		} else {
			if ( $text == rgar( $field, 'text' ) && rgar( $field, 'isNumber' ) ) {

				$list_col_number_range_instructions = false != rgar( $field, 'isNumberRangeInstructions' );
				if ( $list_col_number_range_instructions ) {
					// get min and max field value
					$list_col_number_range_min = rgar( $field, 'isNumberRangeMin' );
					$list_col_number_range_max = rgar( $field, 'isNumberRangeMax' );
				}
			}
		}
		// add instructions range message
		if ( $list_col_number_range_instructions && ( is_numeric( $list_col_number_range_min ) || is_numeric( $list_col_number_range_max ) ) ) {
			// add instructions
			$message = $this->get_input_range_message( $list_col_number_range_min, $list_col_number_range_max );
			$input   = $input . '<div class="instruction ">' . $message . '</div>';
		}

		return $input;
	}

	/**
	 * Filters the GravityPDF field value html to properly show total row.
	 *
	 * @param Object       $class The current field helper class.
	 * @param GF_Field     $field The current field being processed.
	 * @param array<mixed> $entry The Gravity Forms entry array.
	 * @return Object
	 */
	public function filter_gpdf_total_row( $class, $field, $entry ) {

		if ( $this->list_field_has_total_row( $field ) ) {
			/* Initialise the custom class so it can be returned */
			require_once __DIR__ . '/includes/gfpdf/fields/class-field-list-total-row.php';
			$class = new GFPDF\Fields\Field_List_Total_Row( $field, $entry, \GPDFAPI::get_form_class(), \GPDFAPI::get_misc_class() );
		}

		return $class;
	}

	/**
	 * Determine if the field has a total row.
	 *
	 * @param GF_Field $field The Field Object.
	 * @return bool
	 */
	public function list_field_has_total_row( $field ) {

		if ( $field->type === 'list' ) {
			if ( is_array( $field->choices ) ) {
				// List with multiple columns.
				foreach ( $field->choices as $column ) {
					if ( rgar( $column, 'isNumber' ) && rgar( $column, 'isNumberColumnTotal' ) ) {
						return true;
					}
				}
			} else {
				// List with single column.
				if ( rgar( $field, 'isNumber' ) && rgar( $field, 'isNumberColumnTotal' ) ) {
					return true;
				}
			}
		}
		return false;
	}

	/**
	 * Check if form has a list field
	 *
	 * @param array<mixed> $form
	 * @return boolean
	 */
	public function form_has_list_field( $form ) {
		if ( ! GFCommon::is_form_editor() && isset( $form['fields'] ) ) {
			foreach ( $form['fields'] as $field ) {
				if ( 'list' === $field->type ) {
					return true;
				}
			}
		}
		return false;
	}

	/**
	 * check that number provided is in the correct format - used in validation
	 *
	 * @param string $value
	 * @param string $number_format
	 * @return boolean
	 */
	public function is_column_value_valid_format( $value, $number_format ) {
		// The POST value has already been converted from currency or decimal_comma to decimal_dot and then cleaned in get_field_value().
		$value = GFCommon::maybe_add_leading_zero( $value );
		// Checks if the string is empty
		$requires_valid_number = ! rgblank( $value );
		// check if field value is numeric
		$is_numeric = GFCommon::is_numeric( $value, $number_format );

		if ( $requires_valid_number && ! $is_numeric ) {
			return false;
		} else {
			return true;
		}
	}

	/**
	 * check is value provided is value, compared to number format and min/max range - used in validation
	 *
	 * @author GravityWP
	 * @since v0.0.1
	 * @version v1.0.0
	 * @access public
	 *
	 * @param string       $value
	 * @param string       $list_col_number_format
	 * @param string       $list_col_number_range_min
	 * @param string       $list_col_number_range_max
	 * @param array<mixed> $form
	 * @param GF_Field     $field
	 * @param array<mixed> $row
	 *
	 * @return array<mixed>
	 */
	public function is_valid_number( $value, $list_col_number_format, $list_col_number_range_min, $list_col_number_range_max, $form, $field, $row ) {
		$is_valid_number               = array(); // we'll be returning the result along with evaluated range details as an array
		$is_valid_number['result']     = true;
		$is_valid_number['result_min'] = null;
		$is_valid_number['result_max'] = null;
		// list column number min and max value
		$list_col_number_range_min = trim( $list_col_number_range_min );
		$list_col_number_range_max = trim( $list_col_number_range_max );
		// converts formatted number to standard number
		$value = $this->get_clean_value( $value, $list_col_number_format );
		// Adds a leading zero if the first character is a comma or period.
		$value = GFCommon::maybe_add_leading_zero( $value );
		// note: this is the clean value - which is always decimal_dot
		if ( ! GFCommon::is_numeric( $value, 'decimal_dot' ) ) {
			$is_valid_number['result'] = false;
			return $is_valid_number;
		}

		// if min / max number value then check field range validation
		if ( ( is_numeric( $list_col_number_range_min ) && $value < $list_col_number_range_min ) ||
				( is_numeric( $list_col_number_range_max ) && $value > $list_col_number_range_max ) ) {
			$is_valid_number['result']     = false;
			$is_valid_number['result_min'] = $list_col_number_range_min;
			$is_valid_number['result_max'] = $list_col_number_range_max;
		} else {
			if ( ! is_null( $list_col_number_range_min ) && '' !== $list_col_number_range_min ) {
				// calculate min range formula value
				$result = $this->get_row_formula_result( $list_col_number_range_min, $form, $field, $row );

				// check if field value validate with min range value
				if ( GFCommon::is_numeric( $result, 'decimal_dot' ) && $value < $result ) {
					$is_valid_number['result']     = false;
					$is_valid_number['result_min'] = $result;
				}
			}
			if ( ! is_null( $list_col_number_range_max ) && '' !== $list_col_number_range_max ) {
				// calculate max range formula value
				$result = $this->get_row_formula_result( $list_col_number_range_max, $form, $field, $row );
				// check if field value validate with max range value
				if ( GFCommon::is_numeric( $result, 'decimal_dot' ) && $value > $result ) {
					$is_valid_number['result']     = false;
					$is_valid_number['result_max'] = $result;
				}
			}
		}

		return $is_valid_number;
	}

	/**
	 * calculate field formula value
	 *
	 * @author GravityWP
	 * @since v0.0.1
	 * @version v1.0.0
	 * @access public
	 *
	 * @param string       $formula
	 * @param array<mixed> $form
	 * @param GF_Field     $field
	 * @param array<mixed> $row
	 *
	 * @return float|bool
	 */
	public function get_row_formula_result( $formula, $form, $field, $row ) {
		// replace multiple spaces and new lines with single space
		$formula = trim( preg_replace( '/\s+/', ' ', $formula ) );

		// get field matches out of formula
		preg_match_all( '/{[^{]*?:(\d+)\.?(\d+)?}/mi', $formula, $matches, PREG_SET_ORDER );

		if ( is_array( $matches ) ) {

			foreach ( $matches as $match ) {
				$field_id = $match[1];

				$field = RGFormsModel::get_field( $form, $field_id );

				// check the field type as we only want the rest of the function to run if the field type is list
				if ( 'list' != $field->get_input_type() ) {
					$match_field = $field->get_value_submission( array() );
				} else {

					$column_number     = $match[2];
					$column_number_key = $column_number - 1;

					$column_title = rgars( $field->choices, "{$column_number_key}/text" );
					$match_field  = $row[ $column_title ];
					// clean matched value
					if ( rgars( $field->choices, "{$column_number_key}/isNumberFormat" ) ) {
						$match_field = $this->get_clean_value( $match_field, rgars( $field->choices, "{$column_number_key}/isNumberFormat" ) );
					} elseif ( rgars( $field, 'isNumberFormat' ) ) {
						$match_field = $this->get_clean_value( $match_field, rgars( $field, 'isNumberFormat' ) );
					}
				}

				$match_value = GFCommon::to_number( $match_field ); // value from total column
				if ( ! $match_value ) {
					$match_value = 0;
				}

				$formula = str_replace( $match[0], $match_value, $formula ); // replace field with value
			}
		}

		// check that formula is valid expression, e.g. 1 + 2 ( 3 + 4 )
		if ( preg_match( '/^[0-9 -\/*\(\)]+$/', $formula ) ) {
			$result = eval( "return {$formula};" );
			return $result;
		}

		return false;
	}

	/**
	 * converts formatted number to standard number
	 *
	 * @param string $value
	 * @param string $number_format
	 * @return mixed
	 */
	public function get_clean_value( $value, $number_format ) {
		$value = trim( $value );
		if ( 'currency' == $number_format ) {
			$currency = new RGCurrency( GFCommon::get_currency() );
			$value    = $currency->to_number( $value );
		} else {
			$value = floatval( GFCommon::clean_number( $value, $number_format ) );
		}

		return ( $value ) ? $value : 0;
	}

	/**
	 * gf list col format value accoring to number format, rounding and fixed point selected
	 *
	 * @param float|string $value
	 * @param string $number_format
	 * @param string $rounding
	 * @return string
	 */
	public function get_formatted_value( $value, $number_format, $rounding ) {

		// check number format is curreny
		if ( 'currency' == $number_format ) {
			// convert value to curreny format
			$currency = new RGCurrency( GFCommon::get_currency() );
			$value    = $currency->to_money( $value );
		} else {
			// round column number value
			$value = GFCommon::round_number( $value, $rounding );

			// check column number is fixed point
			if ( $rounding != '' && $rounding != 'norounding' ) {
				if ( $number_format == 'decimal_comma' ) {
					$dec_point     = ',';
					$thousands_sep = '.';
				} else {
					$dec_point     = '.';
					$thousands_sep = ',';
				}
				// format list col numbet value
				$value = number_format( $value, absint( $rounding ), $dec_point, $thousands_sep );
			} else {
				// format column number value
				$value = GFCommon::format_number( $value, $number_format, '', true );
			}
		}
		return $value;
	}

	/**
	 * get list column number field settings
	 *
	 * @param array<mixed> $form
	 * @return array<mixed>
	 */
	public function gf_list_col_num_field_settings( $form ) {

		$list_col_num_default_format   = apply_filters( 'gf_list_col_num_default_format', '' );
		$list_col_num_default_rounding = apply_filters( 'gf_list_col_num_default_rounding', '' );
		$number_format_fields          = array();

		if ( $form && isset( $form['fields'] ) && is_array( $form['fields'] ) ) {
			foreach ( $form['fields'] as $field ) {
				$field_type = $field->type;
				if ( 'list' == $field_type ) {
					$form_id  = $form['id'];
					$field_id = $field->id;
					// check if list field multiple column or single column
					$has_columns = is_array( $field->choices );
					if ( $has_columns ) {
						// set list number of columns
						$number_format_fields[ $field_id ]['col_count'] = count( $field->choices );
						$list_total_cols                                = array();
						foreach ( $field->choices as $key => $choice ) {

							if ( rgar( $choice, 'isNumber' ) ) {
								$column_number = $key + 1;
								// get list col number format
								$list_col_num_format = $list_col_num_default_format ? $list_col_num_default_format : rgar( $choice, 'isNumberFormat' );
								$number_format_fields[ $field_id ][ $column_number ]['list_col_num_format'] = $list_col_num_format;
								// get list col number rounding. Don't use rgar() here, because it returns null when property = '0'.
								$list_col_number_rounding = $list_col_num_default_rounding ? $list_col_num_default_rounding : ( isset( $choice['isNumberRounding'] ) && $choice['isNumberRounding'] !== '' ? $choice['isNumberRounding'] : 'norounding' );
								$number_format_fields[ $field_id ][ $column_number ]['list_col_number_rounding'] = $list_col_number_rounding;
								// get list col number rounding direction
								$list_col_number_rounding_direction = strlen( rgar( $choice, 'isNumberRoundingDirection' ) ) > 0 ? rgar( $choice, 'isNumberRoundingDirection' ) : 'roundclosest';
								$number_format_fields[ $field_id ][ $column_number ]['list_col_number_rounding_direction'] = $list_col_number_rounding_direction;
								// get list col number fixed point
								$list_col_number_fixed_point = rgar( $choice, 'isNumberFixedPoint' ) ? rgar( $choice, 'isNumberFixedPoint' ) : 'false';
								$number_format_fields[ $field_id ][ $column_number ]['list_col_number_fixed_point'] = $list_col_number_fixed_point;
								// get list col number column total
								$list_col_number_column_total = rgar( $choice, 'isNumberColumnTotal' ) ? rgar( $choice, 'isNumberColumnTotal' ) : 'false';
								$number_format_fields[ $field_id ][ $column_number ]['list_col_number_column_total'] = $list_col_number_column_total;
								if ( $list_col_number_column_total !== 'false' ) {
									$list_total_cols[] = $column_number;
								}
								// get list col enable calculation
								$list_col_number_enable_calculation = rgar( $choice, 'isNumberEnableCalculation' ) ? rgar( $choice, 'isNumberEnableCalculation' ) : 'false';
								$number_format_fields[ $field_id ][ $column_number ]['list_col_number_enable_calculation'] = $list_col_number_enable_calculation;
								// get list col number calculation formula
								if ( $list_col_number_enable_calculation !== 'false' && '' !== rgar( $choice, 'isNumberCalculationFormula' ) ) {
									$number_format_fields[ $field_id ][ $column_number ]['list_col_calculation_formula'] = esc_js( rgar( $choice, 'isNumberCalculationFormula' ) );
								}
								// get list col enable range calculation
								$list_col_number_enable_range_calculation = rgar( $choice, 'isNumberEnableRangeCalculation' ) ? rgar( $choice, 'isNumberEnableRangeCalculation' ) : 'false';
								$number_format_fields[ $field_id ][ $column_number ]['list_col_number_enable_range_calculation'] = $list_col_number_enable_range_calculation;

								// get list col number min range calculation formula (or value). Don't use rgar() here, because it returns null when property = '0'.
								$list_col_calculation_range_min_formula = isset( $choice['isNumberRangeMin'] ) ? $choice['isNumberRangeMin'] : '';
								$number_format_fields[ $field_id ][ $column_number ]['list_col_calculation_range_min_formula'] = esc_js( $list_col_calculation_range_min_formula );
								// get list col number max range calculation formula (or value). Don't use rgar() here, because it returns null when property = '0'.
								$list_col_calculation_range_max_formula = isset( $choice['isNumberRangeMax'] ) ? $choice['isNumberRangeMax'] : '';
								$number_format_fields[ $field_id ][ $column_number ]['list_col_calculation_range_max_formula'] = esc_js( $list_col_calculation_range_max_formula );
							}
						}

						$number_format_fields[ $field_id ]['list_total_cols'] = $list_total_cols;
					} else {
						if ( rgar( $field, 'isNumber' ) ) {
							$column_number = 1;
							// set list number of columns
							$number_format_fields[ $field_id ]['col_count'] = $column_number;
							// get list col number format
							$list_col_num_format = $list_col_num_default_format ? $list_col_num_default_format : rgar( $field, 'isNumberFormat' );
							$number_format_fields[ $field_id ][ $column_number ]['list_col_num_format'] = $list_col_num_format;
							// get list col number rounding. Don't use rgar() here, because it returns null when property = '0'.
							$list_col_number_rounding = $list_col_num_default_rounding ? $list_col_num_default_rounding : ( isset( $field['isNumberRounding'] ) && $field['isNumberRounding'] !== '' ? $field['isNumberRounding'] : 'norounding' );
							$number_format_fields[ $field_id ][ $column_number ]['list_col_number_rounding'] = $list_col_number_rounding;
							// get list col number rounding direction
							$list_col_number_rounding_direction = strlen( rgar( $field, 'isNumberRoundingDirection' ) ) > 0 ? rgar( $field, 'isNumberRoundingDirection' ) : 'roundclosest';
							$number_format_fields[ $field_id ][ $column_number ]['list_col_number_rounding_direction'] = $list_col_number_rounding_direction;
							// get list col number fixed point
							$list_col_number_fixed_point = rgar( $field, 'isNumberFixedPoint' ) > 0 ? rgar( $field, 'isNumberFixedPoint' ) : 'false';
							$number_format_fields[ $field_id ][ $column_number ]['list_col_number_fixed_point'] = $list_col_number_fixed_point;
							// get list col number column total
							$list_col_number_column_total = rgar( $field, 'isNumberColumnTotal' ) ? rgar( $field, 'isNumberColumnTotal' ) : 'false';
							$number_format_fields[ $field_id ][ $column_number ]['list_col_number_column_total'] = $list_col_number_column_total;
							if ( $list_col_number_column_total !== 'false' ) {
								$number_format_fields[ $field_id ]['list_total_cols'][] = $column_number;
							}
							// get list col number min range calculation formula (or value). Don't use rgar() here, because it returns null when property = '0'.
							$list_col_calculation_range_min_formula = isset( $field['isNumberRangeMin'] ) ? $field['isNumberRangeMin'] : '';
							$number_format_fields[ $field_id ][ $column_number ]['list_col_calculation_range_min_formula'] = esc_js( $list_col_calculation_range_min_formula );
							// get list col number max range calculation formula (or value). Don't use rgar() here, because it returns null when property = '0'.
							$list_col_calculation_range_max_formula = isset( $field['isNumberRangeMax'] ) ? $field['isNumberRangeMax'] : '';
							$number_format_fields[ $field_id ][ $column_number ]['list_col_calculation_range_max_formula'] = esc_js( $list_col_calculation_range_max_formula );
						}
					}
				}
			}
		}
		return $number_format_fields;
	}

	// create validation message for multi-column list field

	/**
	 * $min_range_number, $max_range_number, $list_col_number_format, $list_col_number_rounding, $list_col_number_fixed_point, $column_title
	 *
	 * @author GravityWP
	 * @since v0.0.1
	 * @version v1.0.0
	 * @access public
	 *
	 * @param string $min_range_number
	 * @param string $max_range_number
	 * @param string $list_col_number_format
	 * @param string $list_col_number_rounding
	 * @param bool   $list_col_number_fixed_point
	 * @param string $column_title
	 *
	 * @return string
	 */
	public function get_column_validation_range_message( $min_range_number, $max_range_number, $list_col_number_format, $list_col_number_rounding, $list_col_number_fixed_point, $column_title ) {
		$message               = '';
		$min_range_format_text = "<strong>{$this->get_formatted_value($min_range_number, $list_col_number_format, $list_col_number_rounding)}</strong>";
		$max_range_format_text = "<strong>{$this->get_formatted_value($max_range_number, $list_col_number_format, $list_col_number_rounding)}</strong>";
		if ( is_numeric( $min_range_number ) && is_numeric( $max_range_number ) ) {
			$message = sprintf( esc_html__( "The column '%1\$s' requires a value between %2\$s and %3\$s.", 'gravitywp-list-number-format' ), $column_title, $min_range_format_text, $max_range_format_text );
		} elseif ( is_numeric( $min_range_number ) ) {
			$message = sprintf( esc_html__( "The column '%1\$s' requires a value greater than or equal to %2\$s.", 'gravitywp-list-number-format' ), $column_title, $min_range_format_text );
		} elseif ( is_numeric( $max_range_number ) ) {
			$message = sprintf( esc_html__( "The column '%1\$s' requires a value less than or equal to %2\$s.", 'gravitywp-list-number-format' ), $column_title, $max_range_format_text );
		} else {
			$message = sprintf( esc_html__( "The column '%s' requires a valid number.", 'gravitywp-list-number-format' ), $column_title );
		}

		return $message;
	}

	/**
	 * create validation message for single-column list field
	 *
	 * @author GravityWP
	 * @since v0.0.1
	 * @version v1.0.0
	 * @access public
	 *
	 * @param string $min_range_number
	 * @param string $max_range_number
	 * @param string $list_col_number_format
	 * @param string $list_col_number_rounding
	 * @param bool $list_col_number_fixed_point
	 *
	 * @return string
	 */
	public function get_validation_range_message( $min_range_number, $max_range_number, $list_col_number_format, $list_col_number_rounding, $list_col_number_fixed_point ) {
		$message               = '';
		$min_range_format_text = "<strong>{$this->get_formatted_value($min_range_number, $list_col_number_format, $list_col_number_rounding)}</strong>";
		$max_range_format_text = "<strong>{$this->get_formatted_value($max_range_number, $list_col_number_format, $list_col_number_rounding)}</strong>";

		if ( is_numeric( $min_range_number ) && is_numeric( $max_range_number ) ) {
			$message = sprintf( esc_html__( 'Requires a value between %1$s and %2$s.', 'gravitywp-list-number-format' ), $min_range_format_text, $max_range_format_text );
		} elseif ( is_numeric( $min_range_number ) ) {
			$message = sprintf( esc_html__( 'Requires a value greater than or equal to %s.', 'gravitywp-list-number-format' ), $min_range_format_text );
		} elseif ( is_numeric( $max_range_number ) ) {
			$message = sprintf( esc_html__( 'Requires a value less than or equal to %s.', 'gravitywp-list-number-format' ), $max_range_format_text );
		} else {
			$message = esc_html__( 'Requires a valid number.', 'gravitywp-list-number-format' );
		}

		return $message;
	}

	/**
	 * get range message - used below each input if a min and/or max has been specified for the column
	 *
	 * @param string $list_col_number_range_min
	 * @param string $list_col_number_range_max
	 * @return string
	 */
	public function get_input_range_message( $list_col_number_range_min, $list_col_number_range_max ) {
		$message = '';
		if ( is_numeric( $list_col_number_range_min ) && is_numeric( $list_col_number_range_max ) ) {
			$message = sprintf( esc_html__( 'Please enter a value between %1$s and %2$s.', 'gravitywp-list-number-format' ), "<strong>{$list_col_number_range_min}</strong>", "<strong>{$list_col_number_range_max}</strong>" );
		} elseif ( is_numeric( $list_col_number_range_min ) ) {
			$message = sprintf( esc_html__( 'Please enter a value greater than or equal to %s.', 'gravitywp-list-number-format' ), "<strong>{$list_col_number_range_min}</strong>" );
		} elseif ( is_numeric( $list_col_number_range_max ) ) {
			$message = sprintf( esc_html__( 'Please enter a value less than or equal to %s.', 'gravitywp-list-number-format' ), "<strong>{$list_col_number_range_max}</strong>" );
		}

		return $message;
	}

	/**
	 * Converts formatted rows array to raw value array
	 *
	 * @param array<mixed> $rows
	 * @param GF_Field     $field $list_col_number_range_max
	 * @return array<mixed>
	 */
	public function value_to_raw_value_array( $rows, $field ) {
		if ( $field->type !== 'list' ) {
			return $rows;
		}

		if ( $field->enableColumns && is_array( $field->choices ) ) {
			$column_numberformat = array();
			// Retrieve numberformat setting for each number column.
			foreach ( $field->choices as $column_setting ) {
				$column_numberformat[] = $column_setting['isNumber'] ? $column_setting['isNumberFormat'] : '';
			}

			foreach ( $rows as $key => $row ) {
				$column_index = 0;
				foreach ( $row as $column_name => $value ) {
					// Convert the number to a clean number.
					if ( ! empty( $column_numberformat[ $column_index ] ) && ! empty( $value ) ) {
						$rows[ $key ][ $column_name ] = $this->get_clean_value( $value, $column_numberformat[ $column_index ] );
					}
					$column_index++;
				}
			}
		} elseif ( ! $field->enableColumns && $field->isNumber ) {
			foreach ( $rows as $key => $value ) {
				if ( ! empty( $field->isNumberFormat ) && ! empty( $value ) ) {
					$rows[ $key ] = $this->get_clean_value( $value, $field->isNumberFormat );
				}
			}
		}
		return $rows;
	}
}
