<?php
/**
 * Plugin Name: GravityWP - List Number Format
 * Description: Adds number field capabilities to the default Gravity Forms List Field
 * Version: 2.0.9
 * Requires PHP: 7.0
 * Text Domain: gravitywp-list-number-format
 * Domain Path: /languages
 * Author:  GravityWP
 * Author URI: https://gravitywp.com
 * License: GPL2
 * Credits: Adrian Gordon for the initial List Field Number Format plugin, Richard Wawrzyniak for the initial List Field calculation addon, WPExperts for integrating both projects and patching numerous bugs.
 */

defined( 'ABSPATH' ) || die();

define( 'GWP_LIST_NUMBER_FORMAT_VERSION', '2.0.9' );

// If Gravity Forms is not active, show admin notice.
add_action( 'plugins_loaded', 'check_gravityforms_is_installed' );

/**
 * Function: check_gravityforms_is_installed.
 *
 * @author GravityWP
 * @since v0.0.1
 * @version v1.0.0
 * @global
 *
 * @return void
 */
function check_gravityforms_is_installed() {
	if ( ! class_exists( 'GFForms' ) ) {
		add_action( 'admin_notices', 'gravityforms_not_active_notice' );

		return;
	}
}

/**
 * Function: gravityforms_not_active_notice.
 *
 * @author GravityWP
 * @since v0.0.1
 * @version v1.0.0
 * @global
 *
 * @return void
 */
function gravityforms_not_active_notice() {
	echo '<div class="error"><p><strong>' . sprintf( esc_html__( 'GravityWP List Number Format requires Gravity Forms to be installed and active. You can download %s here.', 'gravitywp-list-number-format' ), '<a href="https://gravityforms.com" target="_blank">Gravity Forms</a>' ) . '</strong></p></div>';
}

// If Gravity Forms is loaded, load GravityWP List Number Format Add-On.
add_action( 'gform_loaded', array( 'GF_List_Number_Format_Bootstrap', 'load' ), 5 );

/**
 * GF_List_Number_Format_Bootstrap.
 *
 * @author GravityWP
 * @since v0.0.1
 * @version v1.0.0
 *
 * @global
 */
class GF_List_Number_Format_Bootstrap {

	/**
	 * Function: load.
	 *
	 * @author GravityWP
	 * @since v0.0.1
	 * @version v1.0.0
	 * @access public
	 *
	 *
	 * @return void
	 */
	public static function load() {

		if ( ! method_exists( 'GFForms', 'include_addon_framework' ) ) {
			return;
		}

		// Autoloader.
		require_once __DIR__ . '/lib/autoload.php';

		require_once 'class-gravitywp-list-number-format.php';
		GFAddOn::register( 'GravityWP\List_Number_Format\GravityWPListNumberFormat' );
	}

}

/**
 * Returns an instance of the GravityWPListNumberFormat class
 *
 * @author GravityWP
 * @since v1.0
 * @version v1.0.0
 * @global
 *
 * @return GravityWP\List_Number_Format\GravityWPListNumberFormat
 */
function gwp_list_number_format() {

	return GravityWP\List_Number_Format\GravityWPListNumberFormat::get_instance();

}
