<?php

namespace GravityWP\List_Number_Format\GFPDF\Fields;

use Exception;
use GF_Field_List;
use GFPDF\Helper\Fields\Field_List;
use GFPDF\Helper\Helper_Abstract_Form;
use GFPDF\Helper\Helper_Abstract_Fields;
use GFPDF\Helper\Helper_Misc;

/* Exit if accessed directly */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Controls the display and output of a Gravity Form field
 *
 * @since 2.0
 */
class Field_List_Total_Row extends Field_List {

	/**
	 * Display the HTML version of this field
	 *
	 * @param string $value
	 * @param bool   $label
	 *
	 * @return string
	 *
	 * @since 2.0
	 */
	public function html( $value = '', $label = true ) {

		/* exit early if list field is empty */
		if ( $this->is_empty() ) {
			return parent::html( '' );
		}
		
		// Get list field value without total row.
		remove_filter( 'gform_get_field_value', array( gwp_list_number_format(), 'list_column_display_total', 10 ) );
		$this->remove_cache();

		// The value retrieved by this class is deserialized, so we serialize it again to pass it through the list_column_display_total() function.
		$value = maybe_serialize( $this->value() );

		// add total values to value array, but without html markup.
		$value = gwp_list_number_format()->list_column_display_total( $value, $this->entry, $this->field, '{gwp_total}%1s{/gwp_total}' );

		$value = maybe_unserialize( $value );
		
		// Reinstate the filter.
		add_filter( 'gform_get_field_value', array( gwp_list_number_format(), 'list_column_display_total' ), 10, 3 );
		$columns = is_array( $value[0] );

		/* Start buffer and generate a list table */
		ob_start();
		?>

		<table autosize="1" class="gfield_list gfield_list_with_total_row">

			<!-- Loop through the column names and output in a header (if using the advanced list) -->
			<?php
			if ( $columns ) :
				$columns = array_keys( $value[0] );
				?>
				<tbody class="head">
				<tr>
					<?php foreach ( $columns as $column ) : ?>
						<th>
							<?php echo esc_html( $column ); ?>
						</th>
					<?php endforeach; ?>
				</tr>
				</tbody>
			<?php endif; ?>

			<!-- Loop through each row -->
			<tbody class="contents">
			<?php foreach ( $value as $item ) : ?>
				<tr>
					<!-- handle the basic list -->
					<?php
					if ( ! $columns ) {
						$replace_count = 0;
						$td_content    = str_replace( array( '{gwp_total}', '{/gwp_total}' ), array( '<b>', '</b>' ), esc_html( $item ), $replace_count );
						$td_style      = $replace_count > 0 ? ' style="border-top: double black;border-bottom: 1px solid black;"' : '';
						echo "<td{$td_style}>{$td_content}</td>";
					} else {
						// handle the advanced list.
						foreach ( $columns as $column ) {
							$replace_count = 0;
							$td_content    = str_replace( array( '{gwp_total}', '{/gwp_total}' ), array( '<b>', '</b>' ), esc_html( rgar( $item, $column ) ), $replace_count );
							$td_style      = $replace_count > 0 ? ' style="border-top: double black;border-bottom: 1px solid black;"' : '';
							echo "<td{$td_style}>{$td_content}</td>";
						}
					}
					?>
				</tr>
			<?php endforeach; ?>
			</tbody>

		</table>

		<?php
		/* get buffer and return HTML */

		return Helper_Abstract_Fields::html( ob_get_clean() );
	}
}
