<?php
GFForms::include_payment_addon_framework();

class Gforms_Gsheet_Connector extends GFFeedAddOn {

   protected $_version = GRAVITY_GOOGLESHEET_PRO_VERSION;
   protected $_min_gravityforms_version = '1.0';
   protected $_slug = 'gsheetconnectorgravityforms';
   protected $_path = 'gsheetconnector-gravityforms-pro/gsheetconnector-gravityforms-pro.php';
   protected $_full_path = __FILE__;
   protected $_title = 'Gravity Forms Gsheet Connector Pro Addon';
   protected $_short_title = 'Googlesheet';
   protected $_single_feed_submission = true;
   protected $_enable_rg_autoupgrade = true;
   private static $_instance = null;
   protected $_capabilities_form_settings = array();

   /**
    * Get an instance of this class.
    *
    * @return Gforms_Gsheet_Connector
    */
   public static function get_instance() {
      if ( self::$_instance == null ) {
         self::$_instance = new Gforms_Gsheet_Connector();
      }

      return self::$_instance;
   }

   public function __construct() {
      parent::init();

      // add_action( 'wp_ajax_sync_with_google_account', array( $this, 'sync_with_google_account' ) );
      // add_action( 'sync_with_google_account', array( $this, 'sync_with_google_account' ) );
      add_action( 'wp_ajax_get_sheet_id_name', array( $this, 'get_sheet_id_name_by_sheetname' ) );
      add_action( 'wp_ajax_get_tabname_list', array( $this, 'get_tabname_list_by_sheetname' ) );
      add_action( 'admin_init', array( $this, 'after_save_form_settings' ) );
      // add_action( 'gform_after_submission', array( $this, 'after_submission' ), 10, 2 );
      add_action( 'admin_footer', array( $this, 'add_gf_nonce' ) );

      // Set capabilities
      $current_user_id = get_current_user_id();
      $user_meta = get_userdata( $current_user_id );
      if ( $user_meta ) {
         $user_roles = $user_meta->roles;
         $gs_roles = get_option( 'gfgs_tab_roles_setting' );
         $capability_role = array( "administrator" );
         if ( $user_roles ) {
            foreach ( $user_roles as $role ) {
               if ( ( is_array( $gs_roles ) && ( array_key_exists( $role, $gs_roles ) ) ) ) {
                  $capability_role[] = $role;
               }
            }
            $this->_capabilities_form_settings = $capability_role;
         }
      }
   }

   /**
    * settings for select the spreadsheets. Go Form Settings->Googlesheet->Feeds
    * @return array $fields
    * @since 1.0
    */
   public function feed_settings_fields() {
      $form_id = $_GET['id'];
      $form_data = get_post_meta( $form_id, 'gfgs_settings' );
      $sheet_data = get_option( 'gfgs_feeds' );

      return array(
         $fields['feed_settings'] = array(
    'title' => esc_html__( 'Gsheetconnector Gravityforms Feed Settings' ),
    'fields' => array(
       array(
          'name' => 'feedName',
          'label' => esc_html__( 'Feed Name', 'gsheetconnector-gravityforms' ),
          'type' => 'text',
          'required' => true,
          'class' => 'medium',
          'tooltip' => esc_html__( 'Enter a feed name to uniquely identify this setup.', 'gsheetconnector-gravityforms' ) ),
       array(
          'name' => 'sheet_details',
          'label' => esc_html__( 'Google Sheet Settings:', 'gsheetconnector-gravityforms' ),
          'type' => 'display_sheet_details',
       ),
       array(
          'name' => 'fieldlist',
          'label' => esc_html__( 'Note:', 'gsheetconnector-gravityforms' ),
          'type' => 'note_feed_description',
       ),
       array(
          'name' => 'fieldlist',
          'label' => esc_html__( 'Field List', 'gsheetconnector-gravityforms' ),
          'type' => 'display_form_field_list',
       ),
    ),
         ),
      );
   }

   /**
    * Display gravityforms gsheet settings for sheetname and tabname
    * @access public
    * @since 2.0
    */
   public function settings_display_sheet_details( $field ) {
      $form_id = $_GET['id'];
	  $get_data = get_post_meta( $form_id, 'gfgs_settings' );

	
		
      $saved_sheet_name = isset( $get_data[0]['sheet-name'] ) ? $get_data[0]['sheet-name'] : "";
      $saved_tab_name = isset( $get_data[0]['sheet-tab-name'] ) ? $get_data[0]['sheet-tab-name'] : "";

      $sheet_data = get_option( 'gfgs_feeds' );


      $val = get_post_meta( $form_id, 'gfgs_settings' );
      $checked = isset( $val[0]['manual-field'] ) ? $val[0]['manual-field'] : "";


      echo '<div class="gravityforms-panel-content-section-googlesheet-tab">';

      echo '<div class="gravityforms-panel-content-section-title">';
      ?>
      <form method="post">
         <div class = "gfgsheet-fields">

            <?php
            if ( $checked == 'on' ) {
               $class = 'hide';
            } else {
               $class = 'display_div';
            }
            ?>
            <div class="gf-gs-fields <?php echo $class; ?>">
               <p>
                  <label><?php echo esc_html( __( 'Google Sheet Name', 'gsheetconnector-gravityforms' ) ); ?></label>
                  <select name="gf-gs[sheet-name]" id="gf-gs-sheet-name" >
                     <option value=""><?php echo __( 'Select', 'gsheetconnector-gravityforms' ); ?></option>
                     <option value="create_new"><?php echo __( 'Create new sheet', 'gsheetconnector-gravityforms' ); ?></option> 
                     <?php
                     if ( !empty( $sheet_data ) ) {
                        foreach ( $sheet_data as $key => $value ) {
                           $selected = "";
                           if ( $saved_sheet_name !== "" && $key == $saved_sheet_name ) {
                              $selected = "selected";
                           }
                           ?>
                           <option value="<?php echo $key; ?>" <?php echo $selected; ?> ><?php echo $key; ?></option>
                           <?php
                        }
                     }
                     ?>
                  </select>
                  <span class="loading-sign">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
                  <input type="hidden" name="gf-ajax-nonce" id="gf-ajax-nonce" value="<?php echo wp_create_nonce( 'gf-ajax-nonce' ); ?>" />
               </p>
			   
			    <div class="create-ss-wrapper" style="display: none";>
					<label><?php echo esc_html( __( 'Create Spreadsheet', 'gsheetconnector-gravityforms' ) ); ?></label>
					<input type="text" id="gf-gs-create-sheet-name" value="" name="gf-gs[create-sheet-name]"/>
					<a style="display: none;" id="gfgs-create-sheet" href="javascript:void(0);"><?php echo esc_html( __( 'Create', 'gsheetconnector-gravityforms' ) ); ?> </a>
					<span class="clear-loading-sign">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
					<p class="create-ss-wrapper-message"></p>
				</div>			
				
			   
               <p class="google-sheet-tab-name-wrapper">
                  <label><?php echo esc_html( __( 'Google Sheet Tab Name', 'gsheetconnector-gravityforms' ) ); ?></label>

                  <select name="gf-gs[sheet-tab-name]" id="gf-gs-sheet-tab-name" >
                     <?php
                     if ( $saved_sheet_name !== "" ) {
                        $selected_tabs = $sheet_data[$saved_sheet_name];

                        if ( !empty( $selected_tabs ) ) {
                           foreach ( $selected_tabs as $tab ) {
                              $selected = "";
                              if ( $saved_tab_name !== "" && $tab == $saved_tab_name ) {
                                 $selected = "selected";
                              }
                              ?>
                              <option value="<?php echo $tab; ?>" <?php echo $selected; ?> ><?php echo $tab; ?></option>
                              <?php
                           }
                        }
                     }
                     ?>
                  </select>
               </p>
               <p class="sheet-url" id="sheet-url">
                  <?php
                  $sheet_id = "";
                  $getsheets_id = get_option( 'gfgs_sheetId' );
                  if ( !empty( $getsheets_id ) && array_key_exists( $saved_sheet_name, $getsheets_id ) ) {
                     $sheet_details = $getsheets_id[$saved_sheet_name];
                     $sheet_id = isset( $sheet_details['id'] ) ? $sheet_details['id'] : "";

                     $tab_id = 0;
                     if ( !empty( $sheet_details['tabId'] ) ) {
                        $tab_id = $sheet_details['tabId'][$saved_tab_name];
                     }
                  }
                  if ( $sheet_id !== "" ) {
                     ?>
                     <label><?php echo __( 'Google Sheet URL', 'gsheetconnector-gravityforms' ); ?> </label> <a href="https://docs.google.com/spreadsheets/d/<?php echo $sheet_id; ?>/edit#gid=<?php echo $tab_id; ?>" target="_blank">Sheet URL</a>
                     <?php
                  }
                  ?>
               </p>

            </div>
            <?php
            if ( $checked == 'on' ) {
               $class = 'display_div';
            } else {
               $class = 'hide';
            }
            ?>
            <div class="manual-fields <?php echo $class; ?>">
               <p>
                  <label><?php echo esc_html( __( 'Google Sheet Name', 'gsheetconnector-gravityforms' ) ); ?></label>
                  <input type="text" name="gf-gs[sheet-name-custom]" id="gf-gs-sheet-name" 
                         value="<?php echo ( isset( $get_data[0]['sheet-name'] ) ) ? esc_attr( $get_data[0]['sheet-name'] ) : ''; ?>"/>
                  <a href="" class="gs-name help-link"><?php echo esc_html( __( 'Google Sheet Name ?', 'gsheetconnector-gravityforms' ) ); ?><span class='hover-data'><?php echo esc_html( __( 'Go to your google account and click on"Google apps" icon and than click "Sheets". Select the name of the appropriate sheet you want to link your contact form or create new sheet.', 'gsheetconnector-gravityforms' ) ); ?> </span></a>
               </p>
			   
               <p>
                  <label><?php echo esc_html( __( 'Google Sheet Id', 'gsheetconnector-gravityforms' ) ); ?></label>
                  <input type="text" name="gf-gs[sheet-id-custom]" id="gf-gs-sheet-id"
                         value="<?php echo ( isset( $get_data[0]['sheet-id'] ) ) ? esc_attr( $get_data[0]['sheet-id'] ) : ''; ?>"/>
                  <a href="" class=" gs-name help-link"><?php echo esc_html( __( 'Google Sheet Id?', 'gsheetconnector-gravityforms' ) ); ?><span class='hover-data'><?php echo esc_html( __( 'you can get sheet id from your sheet URL', 'gsheetconnector-gravityforms' ) ); ?></span></a>
               </p>
               <p>
                  <label><?php echo esc_html( __( 'Google Sheet Tab Name', 'gsheetconnector-gravityforms' ) ); ?></label>
                  <input type="text" name="gf-gs[sheet-tab-name-custom]" id="gf-gs-sheet-tab-name"
                         value="<?php echo ( isset( $get_data[0]['sheet-tab-name'] ) ) ? esc_attr( $get_data[0]['sheet-tab-name'] ) : ''; ?>"/>
                  <a href="" class=" gs-name help-link"><?php echo esc_html( __( 'Google Sheet Tab Name ?', 'gsheetconnector-gravityforms' ) ); ?><span class='hover-data'><?php echo esc_html( __( 'Open your Google Sheet with which you want to link your contact form . You will notice a tab names at bottom of the screen. Copy the tab name where you want to have an entry of contact form.', 'gsheetconnector-gravityforms' ) ); ?></span></a>
               </p>
               <p>
                  <label><?php echo esc_html( __( 'Google Tab Id', 'gsheetconnector-gravityforms' ) ); ?></label>
                  <input type="text" name="gf-gs[tab-id-custom]" id="gf-gs-tab-id"
                         value="<?php echo ( isset( $get_data[0]['tab-id'] ) ) ? esc_attr( $get_data[0]['tab-id'] ) : ''; ?>"/>
                  <a href="" class=" gs-name help-link"><?php echo esc_html( __( 'Google Tab Id?', 'gsheetconnector-gravityforms' ) ); ?><span class='hover-data'><?php echo esc_html( __( 'you can get tab id from your sheet URL', 'gsheetconnector-gravityforms' ) ); ?></span></a>
               </p>
            </div>
            <?php
            if ( $checked == 'on' ) {
               $checked = 'checked';
            } else {
               $checked = "";
            }
            ?>
            <div class="custom-chk">
               <input type="checkbox" name="gf-gs[manual-field]" id="manual-name" <?php echo $checked ?>>
               <span class="enable-manual"><?php echo __( 'Enable Manually adding of sheet name and tab name.', 'gsheetconnector-gravityforms' ); ?></span>
               <span class="tooltip"> 
                  <img src="<?php echo GRAVITY_GOOGLESHEET_PRO_URL; ?>assets/image/help.png" class="help-icon"> 
                  <span class="tooltiptext tooltip-right-msg"><?php echo __( 'Not fetching sheet details to the dropdown than add sheet and tab name manually.', 'gsheetconnector-gravityforms' ); ?></span>
               </span>

            </div>
			
			
         </div>
         <?php
      }

      /**
       *   Fetch all the Sheets associated with your Google Account
       *   @since 1.0
       */
      public function add_spreadsheets_lists() {

         $sheet_data = get_option( 'gfgs_feeds' );

         /* Build choices array. */
         $sheetarray = array(
            array(
               'label' => esc_html__( 'Select Google Spreeadsheet', 'gsheetconnector-gravityforms' ),
               'value' => ''
            )
         );
         if ( empty( $sheet_data ) ) {
            
         } else {
            foreach ( $sheet_data as $sheetname => $id ) {
               $sheetarray[] = array(
                  'label' => esc_html__( $sheetname, 'gsheetconnector-gravityforms' ),
                  'value' => $sheetname,
               );
            }
         }
         return $sheetarray;
      }

      /**
       * AJAX Function - sync with google account to fetch sheet and tab name
       * @since 1.0
       */
      public function sync_with_google_account() {

         $return_ajax = false;
         if ( isset( $_POST['isajax'] ) && $_POST['isajax'] == 'yes' ) {
            // nonce check
            check_ajax_referer( 'gf-ajax-nonce', 'security' );
            $init = sanitize_text_field( $_POST['isinit'] );
            $return_ajax = true;
         }
         include_once( GRAVITY_GOOGLESHEET_PRO_ROOT . '/lib/google-sheets.php');
         $worksheet_array = array();
         $sheetdata = array();
         $doc = new GFGSC_googlesheet();
         $doc->auth();
         $spreadsheetFeed = $doc->get_spreadsheets();

         foreach ( $spreadsheetFeed as $sheetfeeds ) {
            $sheetId = $sheetfeeds['id'];
            $sheetname = $sheetfeeds['title'];

            $worksheetFeed = $doc->get_worktabs( $sheetId );
			
            foreach ( $worksheetFeed as $worksheet ) {
               $tab_id = $worksheet['id'];
               $tab_name = $worksheet['title'];


               $worksheet_array[] = $tab_name;
               $worksheet_ids[$tab_name] = $tab_id;
            }

            $sheetId_array[$sheetname] = array(
               "id" => $sheetId,
               "tabId" => $worksheet_ids
            );

            unset( $worksheet_ids );
            $sheetdata[$sheetname] = $worksheet_array;
            unset( $worksheet_array );
         }

         update_option( 'gfgs_sheetId', $sheetId_array );
         update_option( 'gfgs_feeds', $sheetdata );

         if ( $return_ajax == true ) {
            if ( $init == 'yes' ) {
               wp_send_json_success( array( "success" => 'yes' ) );
            } else {
               wp_send_json_success( array( "success" => 'no' ) );
            }
         }
      }

      /**
       * AJAX function - Fetch sheet URL
       * @since 1.0
       */
      public function get_sheet_id_name_by_sheetname() {
         // nonce check
         if ( wp_doing_ajax() ) {
            check_ajax_referer( 'gf-ajax-nonce', 'security' );
            $sheetname = sanitize_text_field( $_POST['sheetname'] );

            $tabname = sanitize_text_field( $_POST['tabname'] );
         } else {

            $form_id = $_GET['id'];
            $form_data = get_post_meta( $form_id, 'gfgs_settings' );

            $saved_sheet_name = isset( $form_data[0]['sheet-name'] ) ? $form_data[0]['sheet-name'] : "";
            $saved_tab_name = isset( $form_data[0]['sheet-tab-name'] ) ? $form_data[0]['sheet-tab-name'] : "";

            $sheet_id = "";
            $getsheets_id = get_option( 'gfgs_sheetId' );

            if ( !empty( $getsheets_id ) && array_key_exists( $saved_sheet_name, $getsheets_id ) ) {
               $sheet_details = $getsheets_id[$saved_sheet_name];

               $sheet_id = isset( $sheet_details['id'] ) ? $sheet_details['id'] : "";


               $tab_id = 0;
               if ( !empty( $sheet_details['tabId'] ) ) {
                  $tab_id = $sheet_details['tabId'][$saved_tab_name];
               }
            }


            $html = "";

            if ( $sheet_id !== "" ) {
               $html .= '<a href="https://docs.google.com/spreadsheets/d/' . $sheet_id . '/edit#gid=' . $tab_id . '" target="_blank">Sheet URL</a>
         <input type="hidden" name="gsheet_id" value="' . $sheet_id . '">';
               if ( wp_doing_ajax() ) {
                  wp_send_json_success( htmlentities( $html ) );
               } else {
                  return $html;
               }
            }
         }
      }

      /**
       * AJAX function - Fetch tab list by sheet name
       * @since 1.0
       */
      public function get_tabname_list_by_sheetname() {

         // nonce check
         check_ajax_referer( 'gf-ajax-nonce', 'security' );
         $sheetname = sanitize_text_field( $_POST['sheetname'] );
         $sheet_data = get_option( 'gfgs_feeds' );
         $html1 = "";
         $tablists = "";
         if ( !empty( $sheet_data ) && array_key_exists( $sheetname, $sheet_data ) ) {
            $tablists = $sheet_data[$sheetname];
         }


         if ( !empty( $tablists ) ) {
            $html1 = '<option value="">' . __( "Select Tab Name", "gsheetconnector-gravityforms" ) . '</option>';
            foreach ( $tablists as $tab ) {
               $html1 .= '<option value="' . $tab . '">' . $tab . '</option>';
            }
         } else {
            $html1 = '<option value="">' . __( "Select Tab Name", "gsheetconnector-gravityforms" ) . '</option>';
         }

         wp_send_json_success( htmlentities( $html1 ) );
      }

      /**
       * Configures which columns should be displayed on the feed list page.
       *
       * @return array
       */
      public function feed_list_columns() {
         return array(
            'feedName' => esc_html__( 'Name', 'ggspreadsheetaddon' ),
         );
      }

      public function settings_note_feed_description() {
         ?>
         <p class="gs-sync-row">
            <?php echo __( 'Not showing Sheet Name, Tab Name and Sheet URL Link ? <a id="gfgs-sync" data-init="no">Click here </a> to fetch it.', 'gsconnector' ); ?>
            <span class="loading-sign">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span></p>

         <?php
      }

      /**
       * Function - display Gravityforms fields to be mapped to google sheet
       * @param int $form_id
       * @since 1.0
       */
      public function settings_display_form_field_list( $form_id ) {
         ?>
         <hr class="divider">
         <div class="field-list">
            <span class="gf-title"><?php echo esc_html( __( 'Field List ', 'gsheetconnector-gravityforms' ) ); ?></span>
            <span class="gf-info"><?php echo esc_html( __( '( Map form fields to google sheet with custom header name. ) ', 'gsheetconnector-gravityforms' ) ); ?></span>
            </br>
         </div>
         <table class="gf-field-list">
            <?php
            $form_id = $_GET['id'];
            $form_meta = RGFormsModel::get_form_meta( $form_id );
            $field_list = $this->get_field_list( $form_meta );
            $data_meta = get_post_meta( $form_id, 'gravity_form_fields' );

            if ( !empty( $field_list ) ) {
               $count = 0;
               foreach ( $field_list as $field_data ) {
                  $field_name = $field_data['field_name'];
                  $field_id = $field_data['field_id'];

                  $saved_val = "";
                  $checked = "";
                  if ( !empty( $data_meta ) && array_key_exists( $field_id, $data_meta[0] ) ) :
                     $saved_val = $data_meta[0][$field_id];
                     $checked = "checked";
                  endif;
                  $placeholder = $field_name
                  ?>
                  <tr>
                     <td><input type="checkbox" class="fieldchkBoxClass" name="gf-custom-ck[<?php echo $count; ?>]" value="1" <?php echo $checked; ?>></td>
                     <td><?php echo $field_name; ?> : </td>
                     <td>
                        <input type="hidden" value="<?php echo $placeholder; ?>" name="gf-custom-header-key[<?php echo $count; ?>]">
                        <input type = "hidden" value = "<?php echo $field_id ?>" name="gf-custom-field-id[<?php echo $count; ?>]">
                        <input type="hidden" value="<?php echo $placeholder; ?>" name="gf-custom-header-placeholder[<?php echo $count; ?>]">
                        <input type="text" name="gf-custom-header[<?php echo $count; ?>]" value="<?php echo $saved_val; ?>" placeholder="<?php echo $placeholder; ?>">
                     </td>
                  </tr>
                  <?php
                  $count++;
               }
            }
            ?>
         </table>
         <?php
      }

      public function get_field_list( $form_meta ) {

         $field_list = array();

         $fields_inputs = array( "name", "address", "consent", "product" );

         $data_meta = $form_meta['fields'];
         foreach ( $data_meta as $field_meta ) {

            $field_name = $field_meta->label;
            $field_id = $field_meta->id;
            $field_list[] = array(
               "field_id" => $field_id,
               "field_name" => $field_name
            );

            $type = $field_meta->type;
            if ( in_array( $type, $fields_inputs ) ) {
               $inputs = $field_meta->inputs;
               foreach ( $inputs as $key => $value ) {
                  if ( isset( $value['isHidden'] ) && $value['isHidden'] == 1 ) {
                     continue;
                  }
                  $field_id = $value['id'];
                  $field_name = $value['label'];
                  $field_list[] = array(
                     "field_id" => $field_id,
                     "field_name" => $field_name
                  );
               }
            }
         }
         return $field_list;
      }

      /**
       * Set Google Sheet settings with GravityForms
       * @since 1.0
       */
      public function after_save_form_settings() {
         if ( isset( $_POST['gform-settings-save'] ) ) {
            $gravityform_tags = array();
            $form_id = $_GET['id'];
            $get_existing_data = get_post_meta( $form_id, 'gfgs_settings' );
			
			
            $sheet_id = "";
            $sheet_name_default = isset( $_POST['gf-gs']['sheet-name'] ) ? $_POST['gf-gs']['sheet-name'] : "";
            $tab_name_default = isset( $_POST['gf-gs']['sheet-tab-name'] ) && $_POST['gf-gs']['sheet-tab-name'] ? $_POST['gf-gs']['sheet-tab-name'] : "Sheet1";
			
			
			if( isset ($_POST['gf-gs']['sheet-name']) && $_POST['gf-gs']['sheet-name'] == "create_new") {
				if( ! $_POST['gf-gs']['create-sheet-name'] ) {
					$create_sheet_name = "GSheet Connector Pro";
				}
				else {
					$create_sheet_name = $_POST['gf-gs']['create-sheet-name'];
				}
				
				$spreadsheet = gsheet_create_google_sheet($create_sheet_name);
				$sheet_name_default = $create_sheet_name;
			}
			
            // get custom sheet name and tab name as per manual checkbox selection  
            $sheet_name_custom = isset( $_POST['gf-gs']['sheet-name-custom'] ) ? $_POST['gf-gs']['sheet-name-custom'] : "";

            $tab_name_custom = isset( $_POST['gf-gs']['sheet-tab-name-custom'] ) ? $_POST['gf-gs']['sheet-tab-name-custom'] : "";

            $sheet_id_custom = isset( $_POST['gf-gs']['sheet-id-custom'] ) ? $_POST['gf-gs']['sheet-id-custom'] : "";

            $tab_id_custom = isset( $_POST['gf-gs']['tab-id-custom'] ) ? $_POST['gf-gs']['tab-id-custom'] : "";

            $manual_field = isset( $_POST['gf-gs']['manual-field'] ) ? $_POST['gf-gs']['manual-field'] : "";
			
			
            $sheetId_data = get_option( 'gfgs_sheetId' );
            
			//if sheetId_data is not empty then get sheetid and tabid
            if ( !empty( $sheetId_data ) ) {
               $sheet_details = $sheetId_data[$sheet_name_default];

               $sheetid = $sheet_details['id'];

               $tab_id_default = 0;
               if ( !empty( $sheet_details ) ) {
                  $tab_ids = $sheet_details['tabId'];
                  $tabId = $tab_ids[$tab_name_default];
               }
            }
            $html = "";

            // Condition 1 : manual checkbox checked and inputed fields is not empty
            if ( $sheet_name_custom !== "" && $tab_name_custom !== "" && $sheet_id_custom !== "" && $tab_id_custom !== "" && $manual_field == "on" ) {
               $settingArray = array(
                  "sheet-name" => $sheet_name_custom,
                  "sheet-tab-name" => $tab_name_custom,
                  "sheet-id" => $sheet_id_custom,
                  "tab-id" => $tab_id_custom,
                  "manual-field" => 'on' );
               update_post_meta( $form_id, 'gfgs_settings', $settingArray );

               $sheet_name = $sheet_name_custom;
               $tab_name = $tab_name_custom;
               $sheet_id = $sheet_id_custom;
               $tab_id = $tab_id_custom;
            }


            // Condition 2 : manual checkbox checked and inputed fields is empty
            if ( $sheet_name_custom == "" && $tab_name_custom == "" && $sheet_id_custom !== "" && $tab_id_custom !== "" && $manual_field == "on" ) {
               $settingArray = array(
                  "sheet-name" => $sheet_name_custom,
                  "sheet-tab-name" => $tab_name_custom,
                  "sheet-id" => $sheet_id_custom,
                  "tab-id" => $tab_id_custom,
                  "manual-field" => 'on' );
               update_post_meta( $form_id, 'gfgs_settings', $settingArray );
               $sheet_name = $sheet_name_custom;
               $tab_name = $tab_name_custom;
               $sheet_id = $sheet_id_custom;
               $tab_id = $tab_id_custom;
            }

            // Conditon 3 : Manual Checkox unchecked and dropdown fields are selected
            if ( $sheet_name_default !== "" && $tab_name_default !== "" && $manual_field === "" ) {
               $sheet_name = $sheet_name_default;

               $tab_name = $tab_name_default;

               $settingArray = array(
                  "sheet-name" => $sheet_name,
                  "sheet-tab-name" => $tab_name,
                  "sheet-id" => '',
                  "tab-id" => '',
                  "manual-field" => ''
               );
               update_post_meta( $form_id, 'gfgs_settings', $settingArray );
            }

            // Conditon 4 : Manual Checkox unchecked and dropdown fields are not selected
            if ( $sheet_name_default === "" && $tab_name_default === "" && $manual_field === "" ) {
               $sheet_name = $sheet_name_default;

               $tab_name = $tab_name_default;

               $settingArray = array(
                  "sheet-name" => $sheet_name,
                  "sheet-tab-name" => $tab_name,
                  "sheet-id" => '',
                  "tab-id" => '',
                  "manual-field" => ''
               );
               update_post_meta( $form_id, 'gfgs_settings', $settingArray );
            }
            $field_tag = isset( $_POST['gf-custom-ck'] ) ? $_POST['gf-custom-ck'] : array();

            $field_tag_id = isset( $_POST['gf-custom-field-id'] ) ? $_POST['gf-custom-field-id'] : "";

            $field_tag_key = isset( $_POST['gf-custom-header-key'] ) ? $_POST['gf-custom-header-key'] : "";

            $field_tag_placeholder = isset( $_POST['gf-custom-header-placeholder'] ) ? $_POST['gf-custom-header-placeholder'] : "";


            $field_tag_column = isset( $_POST['gf-custom-header'] ) ? $_POST['gf-custom-header'] : "";
            $old_header = get_post_meta( $form_id, 'gravity_form_fields', true );
            $field_tag_array = array();

            if ( !empty( $field_tag ) ) {
               foreach ( $field_tag as $key => $value ) {

                  $gf_key = $field_tag_id[$key];
                  $gf_val = (!empty( $field_tag_column[$key] ) ) ? $field_tag_column[$key] : $field_tag_placeholder[$key];
                  if ( $gf_val !== "" ) {
                     $field_tag_array[$gf_key] = $gf_val;
                     $gravityform_tags[] = $gf_val;
                  }
               }
            }

            update_post_meta( $form_id, 'gravity_form_fields', $field_tag_array );

            // if not empty sheet and tab name than save and add header to sheet
            if ( !empty( $sheet_name ) && (!empty( $tab_name ) ) ) {
               $sheet_id_final = (isset( $sheetid )) ? $sheetid : $sheet_id;

               $tab_id_final = (isset( $tabId )) ? $tabId : $tab_id;

               try {
                  include_once( GRAVITY_GOOGLESHEET_PRO_ROOT . "/lib/google-sheets.php" );
                  $doc = new GFGSC_googlesheet();
                  $doc->auth();
                  $doc->setSpreadsheetId( $sheet_id_final );
                  $doc->setWorkTabId( $tab_id_final );
                  $doc->add_header( $sheet_name, $tab_name, $gravityform_tags, $old_header );
               } catch ( Exception $e ) {
                  $data['ERROR_MSG'] = $e->getMessage();
                  $data['TRACE_STK'] = $e->getTraceAsString();
                  GravityForms_Gs_Connector_Utility::gfgs_debug_log( $data );
               }
            }
         }
      }

      /**
       * Insert data into Google Spreadsheet after form submission.
       * 
       * @access public
       * @return array $row
       */
      public function after_submission( $entry, $form ) {

         // check for expiration
         $GFGS_Connector_Service = new GFGS_Connector_Service();

         $license_validation = get_option( "gfgs_license_status" );

         $expiration = $GFGS_Connector_Service->check_license_expiration();
         if ( $expiration || $license_validation === "invalid" ) {
            return;
         }

         $form_id = $form['id'];
         $get_existing_data = get_post_meta( $form_id, 'gfgs_settings' );
		
		if( ! $get_existing_data ) {
			return;
		}
		
         $data_value = array();
         $form_fields = get_post_meta( $form_id, 'gravity_form_fields', true );

         $sheet_name = $get_existing_data[0]['sheet-name'];
         $sheet_tab_name = $get_existing_data[0]['sheet-tab-name'];

         $sheetId_data = get_option( 'gfgs_sheetId' );

         $sheet_id = "";
         if ( !empty( $sheetId_data ) && array_key_exists( $sheet_name, $sheetId_data ) ) {
            $sheet_details = $sheetId_data[$sheet_name];
            $sheet_id = $sheet_details['id'];
            $tab_id = $sheet_details['tabId'][$sheet_tab_name];

            if ( (!empty( $sheet_name ) ) && (!empty( $sheet_tab_name ) ) ) {
               try {
                  include_once( GRAVITY_GOOGLESHEET_PRO_ROOT . "/lib/google-sheets.php" );
                  $doc = new GFGSC_googlesheet();
                  $doc->auth();
                  $doc->setSpreadsheetId( $sheet_id );
                  $doc->setWorkTabId( $tab_id );
                  $form_meta = RGFormsModel::get_form_meta( $form_id );
                  $data_meta = $form_meta['fields'];
                  $meta_inputs = array();
				  
				  
				  
                  foreach ( $data_meta as $meta_data ) {
                     $field_id = $meta_data->id;
                     $field_name = $meta_data->label;

                     $custom_name = $form_fields[$field_id];

                     if ( isset( $meta_data->inputs ) && array_key_exists( $field_id, $form_fields ) ) {
                        $meta_inputs = $meta_data->inputs;
                        $field = GFFormsModel::get_field( $form, $field_id );
                        $field_value = is_object( $field ) ? $field->get_value_export( $entry ) : '';
                        $data_value[$custom_name] = $field_value;
                     } else {
                        $data_value[$custom_name] = $entry[$field_id];
                     }
                     // add meta inputs
                     if ( !empty( $meta_inputs ) ) {
                        foreach ( $meta_inputs as $meta ) {
                           $field_id = $meta['id'];
                           $field_name = $meta['label'];
                           if ( array_key_exists( $field_id, $form_fields ) ) {
                              $custom_name = $form_fields[$field_id];
                              $data_value[$custom_name] = $entry[$field_id];
                           }
                        }
                     }
                  }
				  
                  $doc->add_row( $data_value );
               } catch ( Exception $e ) {
                  $data['ERROR_MSG'] = $e->getMessage();
                  $data['TRACE_STK'] = $e->getTraceAsString();
                  GravityForms_Gs_Connector_Utility::gfgs_debug_log( $data_value );
               }
            }
         }
      }

      //add nonce 
      public function add_gf_nonce() {
         wp_nonce_field( 'gf-ajax-nonce', 'gf-ajax-nonce' );
      }

   }
   