<?php

GFForms::include_feed_addon_framework();

class Gforms_Gsheet_Connector_Feeds extends GFFeedAddOn {

	protected $_version = GRAVITY_GOOGLESHEET_PRO_VERSION;
	protected $_min_gravityforms_version = '1.9.16';
	protected $_slug = 'gsheetconnectorgravityforms';
	protected $_path = 'gsheetconnector-gravityforms-pro/gsheetconnector-gravityforms-pro.php';
	protected $_full_path = __FILE__;
	protected $_title = 'GoogleSheet Pro Add-On';
	protected $_short_title = 'GoogleSheet Pro';
	// protected $_supports_feed_ordering = true;
	private static $_instance = null;
	
	public $_gfgsc_googlesheet = false;
	public $_gfgsc_header_cells = array();
	
	
	/** 
	* Gforms_Gsheet_Connector_Feeds::get_instance
	* Get instance of current class
	* @since 4.0 
	* @retun Gforms_Gsheet_Connector_Feeds $_instance
	**/
	public static function get_instance() {
		if ( self::$_instance == null ) {
			self::$_instance = new Gforms_Gsheet_Connector_Feeds();
		}

		return self::$_instance;
	}
	
	
	/**
	* Gforms_Gsheet_Connector_Feeds::Initialize Actions
	* @since 4.0 
	**/
	public function init(){
		
		parent::init();
		
		if (!class_exists('Gsheet_License_Settings')) {
			include( GRAVITY_GOOGLESHEET_PRO_PATH . 'includes/class-gs-license-settings.php' );
		}
		if (!class_exists('GFGS_License_Service')) {
			include ( GRAVITY_GOOGLESHEET_PRO_PATH . 'includes/class-gs-license-service.php' );
		}

		if (!class_exists('GSheet_Settings')) {
			include( GRAVITY_GOOGLESHEET_PRO_PATH . 'includes/class-gs-settings.php' );
		}
		
		add_action( 'admin_init', array( $this, 'run_on_upgrade' ), 5 );
		
		add_action( 'gform_after_submission', array( $this, 'add_entry_to_google_sheet' ),10, 2 );
		add_action( 'gsheet_after_added_entry', array( $this, 'sort_sheet_by_column' ),10, 2 );
		add_action( 'gform_after_update_entry', array( $this, 'update_entry_to_google_sheet' ),10, 2 );
		add_action( 'gform_delete_entry', array( $this, 'delete_entry_to_google_sheet' ),10, 2 );

		$current_user_id = get_current_user_id();
		$user_meta = get_userdata( $current_user_id );
		if ( $user_meta ) {
			$user_roles = $user_meta->roles;
			$gs_roles = get_option( 'gfgs_tab_roles_setting' );
			$capability_role = array( "administrator" );
			if ( $user_roles ) {
				foreach ( $user_roles as $role ) {
					if ( ( is_array( $gs_roles ) && ( array_key_exists( $role, $gs_roles ) ) ) ) {
						$capability_role[] = $role;
					}
				}
				$this->_capabilities_form_settings = $capability_role;
			}
		}
	
	
		$gfgsc_googlesheet = $this->get_gfgsc_googlesheet();		
		add_action( 'wp_ajax_sync_with_google_account', array( $gfgsc_googlesheet, 'sync_with_google_account' ) );
		add_action( 'sync_with_google_account', array( $gfgsc_googlesheet, 'sync_with_google_account' ) );
		
		add_filter('gform_tooltips', array( $this, 'plugin_tooltip_strings' ) );
		add_action( 'wp_ajax_gfgs_sync_form_entries', array( $this, 'sync_all_form_entries' ) );

		//Create New Sheet Using Ajax
		add_action( 'wp_ajax_create_new_sheet', array( $this, 'create_new_sheet' ) );
		
		if ( class_exists('Gravity_Forms\Gravity_Forms\Settings\Settings') ) {
			if ( $this->is_feed_edit_page() && $this->is_save_postback() ) {
				$renderer = $this->get_settings_renderer();
				if ( $renderer ) {
					$values = $renderer->get_current_values();
					
					// if( isset( $values['gs_sheet_select_name'] ) && $values['gs_sheet_select_name'] == "create_new" ) {
					// 	if( isset( $_POST['gs_sheet_select_name'] ) && $_POST['gs_sheet_select_name'] != "" ) {
					// 		$values['gs_sheet_select_name'] = $_POST['gs_sheet_select_name'];
					// 		$values['gs_sheet_select_tab'] = 0;
					// 		//$values['gs_sheet_select_create_sheet'] = "";
					// 	}
					// }
					
					//if( isset( $values['gsheet_header_columns_update_header'] ) && $values['gsheet_header_columns_update_header'] == "1" ) {
						//$values['gsheet_header_columns_update_header'] = 0;
					//}
					
					$renderer->set_values( $values );
				}			
			}
		}

		

		
		
	}

	/** 
	* Create New Google Sheet Using Ajax
	* Universal tooltips from gravity forms
	* @since 4.3.4 
	* @param array $__gf_tooltips
	* @retun array $__gf_tooltips
	**/
	public function create_new_sheet() {
		try {
			check_ajax_referer( 'gf-ajax-sync-entries-nonce', 'security' );
			
			$sheet_title = isset($_POST['newSheetname']) ? $_POST['newSheetname'] : "";
			$spreadsheet_id = "";
			$tab_id = 0;
			if($sheet_title!=""){
				$gfgsc_googlesheet = $this->get_gfgsc_googlesheet();
				$sheet_title = $sheet_title ? $sheet_title : "GravityFormSheet";
				
				$spreadsheet = $gfgsc_googlesheet->gsheet_create_google_sheet($sheet_title);
				
				if( $spreadsheet && $spreadsheet['result'] ) {
					$spreadsheet_id = $spreadsheet['spreadsheet']['spreadsheet_id'];
				}
			}
			wp_send_json_success(array('sheetName'=> $sheet_title, 'sheetId'=>$spreadsheet_id, 'tabId'=>$tab_id, 'tabName' => 'Sheet1'));	
			exit;
			
		} catch(Exception $e) {			
			$this->log_debug( __METHOD__ . "(): Error while adding the entry to sheet: \n " . $e->getMessage() );
			GravityForms_Gs_Connector_Utility::gfgs_debug_log( __METHOD__ . " Error while adding the entry to sheet: \n " . $e->getMessage() );
			exit;
		}
	}
	
	/** 
	* Gforms_Gsheet_Connector_Feeds::plugin_tooltip_strings
	* Universal tooltips from gravity forms
	* @since 4.0 
	* @param array $__gf_tooltips
	* @retun array $__gf_tooltips
	**/
	public function plugin_tooltip_strings($__gf_tooltips) {
		
		$__gf_tooltips['integration_mode'] = '<h6>' . __( 'Integration Mode', 'gsheetconnector-gravityforms' ) . '</h6>' . __( 'Selection of chosing google sheet for data submission.', 'gsheetconnector-gravityforms' );
		$__gf_tooltips['google_sheet_name'] = '<h6>' . __( 'Google Sheet Name', 'gsheetconnector-gravityforms' ) . '</h6>' . __( 'Select google sheet from your google account.', 'gsheetconnector-gravityforms' );
		$__gf_tooltips['create_spreadsheet'] = '<h6>' . __( 'Create New Spreadsheet', 'gsheetconnector-gravityforms' ) . '</h6>' . __( 'Create a new spreadsheet to your authorized google account. ', 'gsheetconnector-gravityforms' );
		$__gf_tooltips['google_sheet_tab_name'] = '<h6>' . __( 'Google Sheet Tab Name', 'gsheetconnector-gravityforms' ) . '</h6>' . __( 'Select tab from above chosen google sheet.', 'gsheetconnector-gravityforms' );
		
		$__gf_tooltips['google_manual_sheet_name'] = '<h6>' . __( 'Google Sheet Name', 'gsheetconnector-gravityforms' ) . '</h6>' . __( 'Enter spreadsheet name of sheet you want to send the data', 'gsheetconnector-gravityforms' );
		$__gf_tooltips['google_manual_sheet_id'] = '<h6>' . __( 'Google Sheet ID', 'gsheetconnector-gravityforms' ) . '</h6>' . __( 'Enter spreadsheet id of sheet you want to send the data', 'gsheetconnector-gravityforms' );
		$__gf_tooltips['google_manual_sheet_tab_name'] = '<h6>' . __( 'Google Sheet Tab Name', 'gsheetconnector-gravityforms' ) . '</h6>' . __( 'Enter tab name from above written google sheet.', 'gsheetconnector-gravityforms' );
		$__gf_tooltips['google_manual_sheet_tab_id'] = '<h6>' . __( 'Google Sheet Tab Name', 'gsheetconnector-gravityforms' ) . '</h6>' . __( 'Enter tab id from above written google sheet.', 'gsheetconnector-gravityforms' );
		
		
		$__gf_tooltips['google_sheet_url'] = '<h6>' . __( 'Google Sheet URL', 'gsheetconnector-gravityforms' ) . '</h6>' . __( 'Link to chosen google sheet.', 'gsheetconnector-gravityforms' );

		$__gf_tooltips['fetch_google_sheet'] = '<h6>' . __( 'Click Here to Fetch Sheets', 'gsheetconnector-gravityforms' ) . '</h6>' . __( 'Not showing Sheet Name, Tab Name and Sheet URL Link ? then click on a link to fetch sheets.', 'gsheetconnector-gravityforms' );
		
		$__gf_tooltips['sync_entries'] = '<h6>' . __( 'Sync Entries', 'gsheetconnector-gravityforms' ) . '</h6>' . __( 'Click to Sync Entries, Allows to Synchronize the Form Entries to the Selected Google Sheet in this Feed. It will show you a popup to Select the Pending Entries or All Entries, Make the Selection and Click on Start Sync </br> Note: First, Save the Feed to Sync the Entries.', 'gsheetconnector-gravityforms' );
		
		$__gf_tooltips['field_list'] = '<h6>' . __( 'Field List', 'gsheetconnector-gravityforms' ) . '</h6>' . __( 'Map fields with header (first row of your google sheet). Enabled fields will be sent to the google sheet if column written at right side exist on header.', 'gsheetconnector-gravityforms' );
		$__gf_tooltips['custom_tags'] = '<h6>' . __( 'Custom Tags', 'gsheetconnector-gravityforms' ) . '</h6>' . __( 'Map merge tags with header (first row of your google sheet). Added Fields will be sent to the google sheet if column written at left side exist on header.', 'gsheetconnector-gravityforms' );
		
		$__gf_tooltips['gsheet_headers'] = '<h6>' . __( 'Header', 'gsheetconnector-gravityforms' ) . '</h6>' . __( 'Control formatting of header. Check freeze header if you want to freeze first row considered as header.', 'gsheetconnector-gravityforms' );
		
		$__gf_tooltips['gsheet_colors'] = '<h6>' . __( 'Colors', 'gsheetconnector-gravityforms' ) . '</h6>' . __( 'Control background colors of odd even rows as well as background color of header row.', 'gsheetconnector-gravityforms' );
		
		$__gf_tooltips['gsheet_sorting'] = '<h6>' . __( 'Sheet Sorting', 'gsheetconnector-gravityforms' ) . '</h6>' . __( 'Set up this field if you want data to be sorted automatically upon the submission based on column.', 'gsheetconnector-gravityforms' );
		$__gf_tooltips['gsheet_sort_column_name'] = '<h6>' . __( 'Sort Column Name', 'gsheetconnector-gravityforms' ) . '</h6>' . __( 'Add column name from your google sheet to sort the sheet with that column.', 'gsheetconnector-gravityforms' );
		$__gf_tooltips['gsheet_sort_order'] = '<h6>' . __( 'Sort Order', 'gsheetconnector-gravityforms' ) . '</h6>' . __( 'Sort the sheet in Ascending or Descending order.', 'gsheetconnector-gravityforms' );
		
		$__gf_tooltips['gsheet_header_titles'] = '<h6>' . __( 'Header Titles', 'gsheetconnector-gravityforms' ) . '</h6>' . __( 'Manage header columns from here', 'gsheetconnector-gravityforms' );
		$__gf_tooltips['gsheet_sync_all'] = '<h6>' . __( 'Sync All Entries', 'gsheetconnector-gravityforms' ) . '</h6>' . __( 'Selecting this option will sync all the entries which meet with this feed. If entries are already synced with current feed settings, this option will still force them to be posted to google sheet.', 'gsheetconnector-gravityforms' );
		$__gf_tooltips['gsheet_sync_pending'] = '<h6>' . __( 'Sync Only Pending Entries', 'gsheetconnector-gravityforms' ) . '</h6>' . __( 'Selecting this option will sync only those entries which meet with this feed and not synced with current feed. If entries are already synced with current feed settings, this option will skip them to be posted to google sheet.', 'gsheetconnector-gravityforms' );
		
		return $__gf_tooltips;
	}
	
	
	/**
	* Gforms_Gsheet_Connector_Feeds::scripts
	* Scripts associated with plugin
	* @since 4.0 
	**/
	public function scripts() {
		$scripts = array(
			array(
				'handle'  => 'gfgs-connector-js-ui',
				'src'     => GRAVITY_GOOGLESHEET_PRO_URL . 'assets/js/jquery-ui.min.js',
				'version' => $this->_version,
				'deps'    => array( 'jquery' ),
				'enqueue' => array(
					array(
						'admin_page' => array( 'form_settings' ),
						'tab'        => 'gsheetconnectorgravityforms'
					)
				)
			),
			array(
				'handle'  => 'gfgs-connector-js',
				'src'     => GRAVITY_GOOGLESHEET_PRO_URL . 'assets/js/gfgs-connector.js',
				'version' => $this->_version,
				'deps'    => array( 'jquery', 'wp-color-picker' ),
				'enqueue' => array(
					array(
						'admin_page' => array( 'form_settings' ),
						'tab'        => 'gsheetconnectorgravityforms'
					)
				)
			),

		);
		
		$scripts = apply_filters( "gcgf_scripts", $scripts );
		return array_merge( parent::scripts(), $scripts );
	}
	
	
	/**
	* Gforms_Gsheet_Connector_Feeds::styles
	* styles associated with plugin
	* @since 4.0 
	**/
	public function styles() {
		$styles = array(
			array(
				'handle'  => 'gfgs-connector-css',
				'src'     => GRAVITY_GOOGLESHEET_PRO_URL . 'assets/css/gravity-form-style.css',
				'version' => $this->_version,
				'deps'    => array( 'wp-color-picker' ),
				'enqueue' => array(
					array(
						'admin_page' => array( 'form_settings' ),
						'tab'        => 'gsheetconnectorgravityforms'
					)
				)
			),
			array(
				'handle'  => 'wp-color-picker',
				'enqueue' => array(
					array(
						'admin_page' => array( 'form_settings' ),
						'tab'        => 'gsheetconnectorgravityforms'
					)
				)
			),
			
		);
		
		$styles = apply_filters( "gcgf_styles", $styles );
		
		return array_merge( parent::styles(), $styles );
	}
	
	
	/** 
	* Gforms_Gsheet_Connector_Feeds::get_gfgsc_googlesheet
	* Google Client property for mulitple usage
	* @since 4.0 
	* @retun GFGSC_googlesheet Object
	**/
	public function get_gfgsc_googlesheet() {
		
		if( $this->_gfgsc_googlesheet ) {
			return $this->_gfgsc_googlesheet;
		}
		
		$google_sheet = new GFGSC_googlesheet();
		$google_sheet->auth();		
		
		$this->_gfgsc_googlesheet = $google_sheet;		
		return $google_sheet;
	}
	
	
	/** 
	* Gforms_Gsheet_Connector_Feeds::add_entry_to_google_sheet
	* After Submission add entry to google sheet
	* @since 4.0 
	* @param array $entry
	* @param array $form
	**/
	public function add_entry_to_google_sheet( $entry, $form ) {
		
		$license_validation = get_option( "gfgs_license_status" );
		$GFGS_Connector_Service = new GFGS_Connector_Service();
		$expiration = $GFGS_Connector_Service->check_license_expiration();
			if ( $expiration || $license_validation === "invalid" ) {
			return;
		}
		$entry_id = isset($entry['id']) ? $entry['id'] : '';
		// $settings = $this->get_form_settings($form);
		
		// $feed = $this->current_feed;
		
		$feeds = $this->get_active_feeds( $form['id'] );
		if( ! $feeds ) {
			$this->submit_with_deprecated_method( $entry, $form );
			return;
		}
		
		$processable_feeds = array();
		
		foreach( $feeds as $feed ) {
			
			$feed_data = $feed['meta'];
			
			$is_condition_enabled = rgar( $feed_data, 'feed_condition_conditional_logic' );
			
			if( ! $is_condition_enabled ) {
				$processable_feeds[] = $feed;
			}
			else {				
				$logic = rgars( $feed_data, 'feed_condition_conditional_logic_object/conditionalLogic' );
				
				if( !empty( $logic ) ) {
					$check = GFCommon::evaluate_conditional_logic( $logic, $form, $entry );
					if( $check ) {
						$processable_feeds[] = $feed;
					}
				}
			}
			
		}
		
		$processable_feeds = apply_filters( "gcgf_processable_feeds", $processable_feeds, $entry, $form );		
		if( ! empty( $processable_feeds ) ) {
			
			foreach( $processable_feeds as $feed ) {
				
				$feed_id = $feed['id'];
				
				$send_row_data = $this->get_data_to_submit( $entry, $form, $feed_id );
				if( $send_row_data ) {
					$gfgsc_googlesheet = $this->get_gfgsc_googlesheet();
					$google_sheet_settings = $this->get_google_sheet_settings($form, $feed_id);
					
					if( $google_sheet_settings ) {
						$spreadsheet_id = $google_sheet_settings['spreadsheet_id'];
						$tab_id = $google_sheet_settings['tab_id'];
						$tab_title = $google_sheet_settings['tab_title'];
						
						$gfgsc_googlesheet->add_row_to_sheet( $spreadsheet_id, $tab_title, $send_row_data, $entry, false, $entry_id );
						do_action( "gsheet_after_added_entry", $form, $feed_id );
					}
				}
			}
		}
		
	}
	
	/** 
	* Gforms_Gsheet_Connector_Feeds::delete_entry_to_google_sheet
	* Before Delete entry to google sheet
	* @since 4.0 
	* @param array $entry
	* @param array $form
	**/
	public function delete_entry_to_google_sheet( $entry_id ) {

		$license_validation = get_option( "gfgs_license_status" );
		$GFGS_Connector_Service = new GFGS_Connector_Service();
		$expiration = $GFGS_Connector_Service->check_license_expiration();
			if ( $expiration || $license_validation === "invalid" ) {
			return;
		}
		$entry = GFAPI::get_entry( $entry_id );
		$form = GFAPI::get_form( $entry['form_id'] );


		$feeds = $this->get_active_feeds( $form['id'] );
		if( ! $feeds ) {
			$this->submit_with_deprecated_method( $entry, $form );
			return;
		}
		
		$processable_feeds = array();
		
		foreach( $feeds as $feed ) {
			
			$feed_data = $feed['meta'];
			
			$is_condition_enabled = rgar( $feed_data, 'feed_condition_conditional_logic' );
			
			if( ! $is_condition_enabled ) {
				$processable_feeds[] = $feed;
			}
			else {				
				$logic = rgars( $feed_data, 'feed_condition_conditional_logic_object/conditionalLogic' );
				
				if( !empty( $logic ) ) {
					$check = GFCommon::evaluate_conditional_logic( $logic, $form, $entry );
					if( $check ) {
						$processable_feeds[] = $feed;
					}
				}
			}
			
		}

		

		

		$processable_feeds = apply_filters( "gcgf_processable_feeds", $processable_feeds, $entry, $form );		
		if( ! empty( $processable_feeds ) ) {
            foreach( $processable_feeds as $feed ) {
                $feed_id = $feed['id'];
                $gfgsc_googlesheet = $this->get_gfgsc_googlesheet();
                $google_sheet_settings = $this->get_google_sheet_settings($form, $feed_id);
                if( $google_sheet_settings ) {
                    $spreadsheet_id = $google_sheet_settings['spreadsheet_id'];
                    $tab_id = $google_sheet_settings['tab_id'];
                    $tab_title = $google_sheet_settings['tab_title'];
                    $gfgsc_googlesheet->delete_row_to_sheet( $spreadsheet_id, $tab_title,$entry_id );
                }
            }
        
        }
	}

	/** 
	* Gforms_Gsheet_Connector_Feeds::update_entry_to_google_sheet
	* After Submission add entry to google sheet
	* @since 4.0 
	* @param array $entry
	* @param array $form
	**/
	public function update_entry_to_google_sheet( $form, $entry_id ) {
		$entry = GFAPI::get_entry( $entry_id );

		$license_validation = get_option( "gfgs_license_status" );
		$GFGS_Connector_Service = new GFGS_Connector_Service();
		$expiration = $GFGS_Connector_Service->check_license_expiration();
			if ( $expiration || $license_validation === "invalid" ) {
			return;
		}
		
		// $settings = $this->get_form_settings($form);
		
		// $feed = $this->current_feed;
		
		$feeds = $this->get_active_feeds( $form['id'] );
		if( ! $feeds ) {
			$this->submit_with_deprecated_method( $entry, $form );
			return;
		}
		
		$processable_feeds = array();
		
		foreach( $feeds as $feed ) {
			
			$feed_data = $feed['meta'];
			
			$is_condition_enabled = rgar( $feed_data, 'feed_condition_conditional_logic' );
			
			if( ! $is_condition_enabled ) {
				$processable_feeds[] = $feed;
			}
			else {				
				$logic = rgars( $feed_data, 'feed_condition_conditional_logic_object/conditionalLogic' );
				
				if( !empty( $logic ) ) {
					$check = GFCommon::evaluate_conditional_logic( $logic, $form, $entry );
					if( $check ) {
						$processable_feeds[] = $feed;
					}
				}
			}
			
		}
		
		$processable_feeds = apply_filters( "gcgf_processable_feeds", $processable_feeds, $entry, $form );		
		if( ! empty( $processable_feeds ) ) {
			
			foreach( $processable_feeds as $feed ) {
				
				$feed_id = $feed['id'];
				
				$send_row_data = $this->get_data_to_submit( $entry, $form, $feed_id );
				if( $send_row_data ) {
					$gfgsc_googlesheet = $this->get_gfgsc_googlesheet();
					$google_sheet_settings = $this->get_google_sheet_settings($form, $feed_id);
					
					if( $google_sheet_settings ) {
						$spreadsheet_id = $google_sheet_settings['spreadsheet_id'];
						$tab_id = $google_sheet_settings['tab_id'];
						$tab_title = $google_sheet_settings['tab_title'];
						

						$gfgsc_googlesheet->update_row_to_sheet( $spreadsheet_id, $tab_title, $send_row_data, $entry, $entry_id );
						do_action( "gsheet_after_added_entry", $form, $feed_id );
					}
				}
			}
		}
		
	}
	
	/** 
	* Gforms_Gsheet_Connector_Feeds::get_data_to_submit
	* Create array to submit to google sheet
	* @since 4.0 
	* @param array $entry
	* @param array $form
	* @param boolean $bulk
	* @retun array $send_row_data
	**/
	public function get_data_to_submit( $entry, $form, $feed_id, $bulk = false ) {
		
		$settings = $this->get_feed($feed_id);
		$settings = $settings && isset( $settings['meta'] ) && $settings['meta'] ? $settings['meta'] : array();
		
		if( ! $settings ) {
			return array();
		}
		
		$mapping_enabled_field = isset($settings['gsheet_field_maps_enable']) ? $settings['gsheet_field_maps_enable'] : array();
		$mapping_cells = isset($settings['gsheet_field_maps_header_cell']) ? $settings['gsheet_field_maps_header_cell'] : array();
		
		$send_row_data = array();
		$header_cells = array();
		$entry_cells = array();
		
		$entry_id = $entry['id'];
		$send_row_data[] = $entry['id'];
		
		$google_sheet_settings = $this->get_google_sheet_settings($form, $feed_id);
		
		if( ! $google_sheet_settings ) {
			$send_row_data = apply_filters( "gcgf_submit_data_to_google_sheet", $send_row_data, $entry, $form, $feed_id );
			return $send_row_data;
		}
		
		$spreadsheet_id = $google_sheet_settings['spreadsheet_id'];
		$tab_id = $google_sheet_settings['tab_id'];
		$tab_title = $google_sheet_settings['tab_title'];
		
		try {
			
			$gfgsc_googlesheet = $this->get_gfgsc_googlesheet();
			if( isset ( $this->_gfgsc_header_cells[$spreadsheet_id][$tab_id] ) && $this->_gfgsc_header_cells[$spreadsheet_id][$tab_id] ) {
				$header_cells = $this->_gfgsc_header_cells[$spreadsheet_id][$tab_id];
			}
			else {
				if( isset ( $_SESSION['gs_header_cells_'.$spreadsheet_id."_".$tab_id] ) && $bulk ) {
					$header_cells = $_SESSION['gs_header_cells_'.$spreadsheet_id."_".$tab_id];
					$this->_gfgsc_header_cells[$spreadsheet_id][$tab_id] = $header_cells;
				}
				else {
					$header_cells = $gfgsc_googlesheet->get_header_row($spreadsheet_id, $tab_id);
					$this->_gfgsc_header_cells[$spreadsheet_id][$tab_id] = $header_cells;
					$_SESSION['gs_header_cells_'.$spreadsheet_id."_".$tab_id] = $header_cells;
				}
			}
			
			$header_cells = apply_filters( "gcgf_header_row_cells", $header_cells, $entry, $form, $feed_id );
			
			foreach( $mapping_enabled_field as $field_key => $enabled ) {
					
				if( $enabled == 1 && isset( $mapping_cells[$field_key] ) && $mapping_cells[$field_key] != "" ) {					
					$field_id = $field_key;
					$field_id = str_replace("_", ".", $field_key);
					
					$field_value = $this->get_field_value( $form, $entry, $field_id );
					$field_name = $mapping_cells[$field_key];
					
					$entry_cells[$field_name] =  $field_value;
				}
			}
			
			if( isset ( $settings['gsheet_mergeTagsMap'] ) ) {				
				$mapping_merge_tags = $settings['gsheet_mergeTagsMap'];
				if( $mapping_merge_tags && !empty( $mapping_merge_tags ) ) {
					foreach( $mapping_merge_tags as $merge_tag ) {
						$column_name = $merge_tag['custom_key'];
						$value = $merge_tag['value'];
						$custom_value = $merge_tag['custom_value'];	
						
						
						if( $custom_value ) {
							$entry_cells[$column_name] =  GFCommon::replace_variables( $custom_value, $form, $entry );
						}
						else if( $value ) {
							$entry_cells[$column_name] =  $this->get_field_value( $form, $entry, $value );
						}
						// $entry_cells[$column_name] =  $this->get_field_value( $form, $entry, $field_value );
					}
				}
			}
			
			if( $entry_cells && $header_cells && $tab_title ) {
				
				foreach( $header_cells as $index => $cellName ) {
					
					if( isset( $entry_cells[$cellName] ) ) {
						$send_row_data[$index] = $entry_cells[$cellName];
					}
				}
				
				foreach( $header_cells as $index => $cellName ) {
					if( ! isset( $send_row_data[$index] ) ) {
						$send_row_data[$index] = "";
					}
				}
			}			
		}
		
		catch(Exception $e) {			
			$this->log_debug( __METHOD__ . "(): Error while adding the entry to sheet: \n " . $e->getMessage() );
			GravityForms_Gs_Connector_Utility::gfgs_debug_log( __METHOD__ . " Error while adding the entry to sheet: \n " . $e->getMessage() );
			return array();
		}
		
		$send_row_data = apply_filters( "gcgf_submit_data_to_google_sheet", $send_row_data, $entry, $form, $feed_id );
		
		return $send_row_data;
	}
	
	
	/** 
	* Gforms_Gsheet_Connector_Feeds::submit_with_deprecated_method
	* Submit with old method if new settings are not configured
	* @since 4.0 
	* @param array $entry
	* @param array $form
	**/
	public function submit_with_deprecated_method( $entry, $form ) {

         $GFGS_Connector_Service = new GFGS_Connector_Service();

         $license_validation = get_option( "gfgs_license_status" );

         $expiration = $GFGS_Connector_Service->check_license_expiration();
         if ( $expiration || $license_validation === "invalid" ) {
            return;
         }

         $form_id = $form['id'];
         $get_existing_data = get_post_meta( $form_id, 'gfgs_settings' );
		
		if( ! $get_existing_data || empty($get_existing_data) ) { return; }
		
         $data_value = array();
         $form_fields = get_post_meta( $form_id, 'gravity_form_fields', true );
		
         $sheet_name = $get_existing_data[0]['sheet-name'];
         $sheet_tab_name = $get_existing_data[0]['sheet-tab-name'];

         $sheetId_data = get_option( 'gfgs_sheetId' );

         $sheet_id = "";
         if ( !empty( $sheetId_data ) && array_key_exists( $sheet_name, $sheetId_data ) ) {
            $sheet_details = $sheetId_data[$sheet_name];
            $sheet_id = $sheet_details['id'];
            $tab_id = $sheet_details['tabId'][$sheet_tab_name];

            if ( (!empty( $sheet_name ) ) && (!empty( $sheet_tab_name ) ) ) {
               try {
                  include_once( GRAVITY_GOOGLESHEET_PRO_ROOT . "/lib/google-sheets.php" );
                  $doc = new GFGSC_googlesheet();
                  $doc->auth();
                  $doc->setSpreadsheetId( $sheet_id );
                  $doc->setWorkTabId( $tab_id );
                  $form_meta = RGFormsModel::get_form_meta( $form_id );
                  $data_meta = $form_meta['fields'];
                  $meta_inputs = array();
				  
				  
				  
                  foreach ( $data_meta as $meta_data ) {
                     $field_id = $meta_data->id;
                     $field_name = $meta_data->label;

                     $custom_name = $form_fields[$field_id];

                     if ( isset( $meta_data->inputs ) && array_key_exists( $field_id, $form_fields ) ) {
                        $meta_inputs = $meta_data->inputs;
                        $field = GFFormsModel::get_field( $form, $field_id );
                        $field_value = is_object( $field ) ? $field->get_value_export( $entry ) : '';
                        $data_value[$custom_name] = $field_value;
                     } else {
                        $data_value[$custom_name] = $entry[$field_id];
                     }
                     // add meta inputs
                     if ( !empty( $meta_inputs ) ) {
                        foreach ( $meta_inputs as $meta ) {
                           $field_id = $meta['id'];
                           $field_name = $meta['label'];
                           if ( array_key_exists( $field_id, $form_fields ) ) {
                              $custom_name = $form_fields[$field_id];
                              $data_value[$custom_name] = $entry[$field_id];
                           }
                        }
                     }
                  }
				  
                  $doc->add_row( $data_value );
               } 
			   catch ( Exception $e ) {
                  $data['ERROR_MSG'] = $e->getMessage();
                  $data['TRACE_STK'] = $e->getTraceAsString();
                  GravityForms_Gs_Connector_Utility::gfgs_debug_log( $data_value );
               }
            }
         }
      }
	
	
	/** 
	* Gforms_Gsheet_Connector_Feeds::form_settings_fields
	* Set Form settings fields
	* @since 4.0 
	* @param array $form
	* @retun array $field
	**/
	public function feed_settings_fields() {
		
		$all_sheet_data = get_option( 'gfgs_sheetId' );
		
		if( ! $all_sheet_data ) {
			do_action("sync_with_google_account");
			$sheet_data = get_option( 'gfgs_feeds' );
			$all_sheet_data = get_option( 'gfgs_sheetId' );
		}
		
		// if( ! $all_sheet_data ) {
		// 	$fields = array(
		// 		array(
		// 			'title' => esc_html__( 'GsheetConnector Gravity Forms Feed Settings', 'gsheetconnector-gravityforms' ),
		// 			'fields' => array(
		// 				array(
		// 					'name' => 'gs_sheet_empty_error',
		// 					'type'    => 'empty_error',
		// 				),
		// 			)
		// 		)
		// 	);
			
		// }
		
		//else { 
			$fields = array(
				array(
					'title' => esc_html__( 'GSheetConnector Gravityforms Feed Settings' ),
					'fields' => array(					
						array(
						  'name' => 'feedName',
						  'label' => esc_html__( 'Feed Name', 'gsheetconnector-gravityforms' ),
						  'type' => 'text',
						  'required' => true,
						  'class' => 'medium',
						  'tooltip' => esc_html__( 'Enter a feed name to uniquely identify this setup.', 'gsheetconnector-gravityforms' ) 
						),
						array(
							'name' => 'gs_sheet_integration',
							'label' => esc_html__( 'Integration Mode:', 'gsheetconnector-gravityforms' )." ".gs_gform_tooltip('integration_mode', '', true),
							'type'    => 'radio',
							'default_value'    => 'automatic',
							'horizontal' => true,
							"choices" => array(
								array(
									"label" => esc_html__( 'Automatically select', 'gsheetconnector-gravityforms' ),
									"value"  => "automatic",	
									"name"  => "automatic_integration",
									'onclick' => "
										if(this.checked){
											jQuery('#gform_setting_gs_sheet_select').show(); 
											jQuery('#gform_setting_gs_sheet_manuals').hide();
											jQuery('#gform_setting_gs_sheet_create').show();
										}",
								),
								array(
									"label" => esc_html__( 'Manually add sheet info', 'gsheetconnector-gravityforms' ),
									"value"  => "manual",
									"name"  => "manual_integration",
									'onclick' => "
										if(this.checked){
											jQuery('#gform_setting_gs_sheet_select').hide(); 
											jQuery('#gform_setting_gs_sheet_manuals').show();
											jQuery('#gform_setting_gs_sheet_create').hide();
										}",
								),							
							)
						),
						array(
							'name' => 'gs_sheet_create',
							'label' => esc_html__( 'Create Google Spreadsheet:', 'gsheetconnector-gravityforms' ),
							'type'    => 'create_new_sheets',
						),

						array(
							'name' => 'gs_sheet_select',
							'label' => esc_html__( 'Select Google Spreadsheet:', 'gsheetconnector-gravityforms' ),
							'type'    => 'sheets_selection',
						),
						array(
							'name' => 'gs_sheet_manuals',
							'label' => esc_html__( 'Google Sheet:', 'gsheetconnector-gravityforms' ),
							'type'    => 'sheets_info',
						),
						array(
							'name' => 'gsheet_sync_link',
							'label' => esc_html__( 'Note:', 'gsheetconnector-gravityforms' )."&nbsp;".gs_gform_tooltip( 'fetch_google_sheet', '', true ),
							'type'    => 'display_sync_link',
						),
						array(
							'name' => 'gsheet_field_maps',
							'label' => esc_html__( 'Field List:', 'gsheetconnector-gravityforms' )."&nbsp;".gs_gform_tooltip( 'field_list', '', true ),
							'type'    => 'map_form_fields',
						),
						array(
							'name'      => 'gsheet_mergeTagsMap',
							'type'      => 'generic_map',
							'label'     => esc_html__( 'Custom Tags:', 'gsheetconnector-gravityforms' )."&nbsp;".gs_gform_tooltip( 'custom_tags', '', true ),
							//'enable_custom_key' => true,
							'merge_tags' => true,
							'key_field' => array(
								'title' => 'Column Name',
								'type'  => 'text',
								/*'enable_custom_key' => false,
								'choices' => $this->get_merge_tags_fields_choices(),*/
								'class' => ' merge-tag-support mt-position-right mt-hide_all_fields ui-autocomplete-input '
							),
							'value_field' => array(
								'title' => 'Merge Tag / Formulas ',
								'text'  => 'text',
								'class' => ' merge-tag-support mt-position-right mt-hide_all_fields ui-autocomplete-input '
							),
						),
						array(
							'name' => 'gsheet_header_columns',
							'label' => esc_html__( 'Header Titles:', 'gsheetconnector-gravityforms' )."&nbsp;".gs_gform_tooltip( 'gsheet_header_titles', '', true ),
							'type'    => 'gsheet_header_columns',
						),
						
						array(
							'name' => 'gsheet_frozen_header',
							//'label' => esc_html__( 'Header:', 'gsheetconnector-gravityforms' )."&nbsp;".gs_gform_tooltip( 'gsheet_headers', '', true ),
							'type'    => 'checkbox',
							"choices" => array(
								array(
									//"label" => esc_html__( 'Freeze Header', 'gsheetconnector-gravityforms' ),
									"name"  => "gsheet_freeze_header",								
								),												
							)
						),
						//_gform_setting_gsheet_freeze_header - hidden

						array(
							'name' => 'gsheet_freeze_header_toggle',
							'label' => esc_html__( 'Header:', 'gsheetconnector-gravityforms' )."&nbsp;".gs_gform_tooltip( 'gsheet_headers', '', true ),
							'type'    => 'toggle',
							"choices" => array(
								array(
									"label" => esc_html__( 'Freeze Header', 'gsheetconnector-gravityforms' ),
									"name"  => "gsheet_freeze_header",	
								),												
							),
							'onchange' => "
								if(jQuery(this).prop('checked')){
									jQuery('input[name=_gform_setting_gsheet_freeze_header]').val(1);
									jQuery(this).val(1);
									jQuery('#gsheet_freeze_header').prop('checked', true);
								}
								else {
									jQuery('input[name=_gform_setting_gsheet_freeze_header]').val(0);
									jQuery(this).val(0);
									jQuery('#gsheet_freeze_header').prop('checked', false);

								}
							",
						),

						//_gform_setting_gsheet_alternate_colors_enabled - hidden
						array(
							'name' => 'gsheet_alternate_colors_enabled_toggle',
							'label' => esc_html__( 'Colors:', 'gsheetconnector-gravityforms' )."&nbsp;".gs_gform_tooltip( 'gsheet_colors', '', true ),
							'type'    => 'toggle',
							'onchange' => "
								if(jQuery(this).prop('checked')){
									jQuery('#gsheet_alternate_colors_enabled').prop('checked', true);
									jQuery('.alt-color-fields').show();
									jQuery('input[name=_gform_setting_gsheet_alternate_colors_enabled]').val(1);
									jQuery(this).val(1);
								}
								else {
									jQuery('#gsheet_alternate_colors_enabled').prop('checked', false);
									jQuery('.alt-color-fields').hide();
									jQuery('input[name=_gform_setting_gsheet_alternate_colors_enabled]').val(0);
									jQuery(this).val(0);
								}
							",
						),

						array(
							'name' => 'gsheet_alternate_colors',
							//'label' => esc_html__( 'Colors:', 'gsheetconnector-gravityforms' )."&nbsp;".gs_gform_tooltip( 'gsheet_colors', '', true ),
							'type'    => 'gsheet_alternate_colors',
						),

						//_gform_setting_gsheet_sort_column_enabled - hidden

						array(
							'name' => 'gsheet_sort_column_enabled_toggle',
							'label' => esc_html__( 'Sheet Sorting:', 'gsheetconnector-gravityforms' )."&nbsp;".gs_gform_tooltip( 'gsheet_sorting', '', true ),
							'type'    => 'toggle',

							'onchange' => "
								if(jQuery(this).prop('checked')){
									jQuery('#gsheet_sort_column_enabled').prop('checked', true);
									jQuery('.sort-col-text-field').show();
									jQuery('input[name=_gform_setting_gsheet_sort_column_enabled]').val(1);
									jQuery(this).val(1);
								}
								else {
									jQuery('#gsheet_sort_column_enabled').prop('checked', false);
									jQuery('.sort-col-text-field').hide();
									jQuery('input[name=_gform_setting_gsheet_sort_column_enabled]').val(0);
									jQuery(this).val(0);
								}
							",
						),

						array(
							'name' => 'gsheet_sort_column',
							//'label' => esc_html__( 'Sheet Sorting:', 'gsheetconnector-gravityforms' )."&nbsp;".gs_gform_tooltip( 'gsheet_sorting', '', true ),
							'type'    => 'gsheet_sorting'
						),

						array(
							'name' => 'feed_condition_conditional_logic_toggle',
							'label' => esc_html__( 'Condition:', 'gsheetconnector-gravityforms' )."&nbsp;".gs_gform_tooltip( 'gsheet_sorting', '', true ),
							'type'    => 'toggle',
							'onchange' => "
								if(jQuery(this).prop('checked')){
									jQuery('#feed_condition_conditional_logic').prop('checked', true);
									
									jQuery('input[name=_gform_setting_feed_condition_conditional_logic]').val(1);
									jQuery(this).val(1);
									jQuery('#feed_condition_conditional_logic_container').css('dispaly','block');
									ToggleConditionalLogic( false, 'feed_condition' );
								}
								else {
									jQuery('#feed_condition_conditional_logic').prop('checked', false);
									
									jQuery('input[name=_gform_setting_feed_condition_conditional_logic]').val(0);
									jQuery(this).val(0);
									jQuery('#feed_condition_conditional_logic_container').css('dispaly','none');
									ToggleConditionalLogic( false, 'feed_condition' );
								}
							",
						),
						//_gform_setting_feed_condition_conditional_logic - hidden
						
						array(
							'name'           => 'condition',
							//'label'          => esc_html__( 'Condition', 'gsheetconnector-gravityforms' ),
							'type'           => 'feed_condition',
							//'checkbox_label' => esc_html__( 'Enable Condition', 'gsheetconnector-gravityforms' ),
							'instructions'   => esc_html__( 'Process this feed if', 'gsheetconnector-gravityforms' ),
						),
						
						array(
							'name' => 'gsheet_sync_entries',
							'label' => esc_html__( 'Sync Entries:', 'gsheetconnector-gravityforms' )."&nbsp;".gs_gform_tooltip( 'sync_entries', '', true ),
							'type'    => 'display_sync_entries',
						),
					),
				)
			);
		//}
		return $fields;
	}
	
	
	/** 
	* Gforms_Gsheet_Connector_Feeds::settings_display_sync_entries
	* Get Spreadsheet and tab
	* @since 4.0 
	* @param array $form
	* @param int $feed_id
	* @return array $form_settings
	**/
	function get_google_sheet_settings($form, $feed_id) {
		
		$settings = $this->get_feed( $feed_id );		
		$posted_settings = $this->get_posted_settings();
		if( $posted_settings ) {
			$settings = $posted_settings;
		}
		
		if( ! $settings ) {
			return false;
		}
		
		$gfgsc_googlesheet = $this->get_gfgsc_googlesheet();
		
		if( ! $posted_settings  ) {
			$settings = $settings['meta'];
		}
		
		if( isset ( $settings['gs_sheet_select_name'] ) && $settings['gs_sheet_select_name'] == "gs-select-sheet" ) {
			return false;
		}
		
		$connection_mode = $settings['gs_sheet_integration'];		
		if( $connection_mode == "automatic" ) {
			$spreadsheet_id = $settings['gs_sheet_select_name'];
			$tab_id = $settings['gs_sheet_select_tab'];
			$tab_title = $gfgsc_googlesheet->get_sheet_name($spreadsheet_id, $tab_id);
			$spreadsheet_title = $gfgsc_googlesheet->get_spreadsheet_name($spreadsheet_id);
		}
		else {
			$spreadsheet_id = $settings['gs_sheet_manuals_sheet_id'];
			$tab_id = $settings['gs_sheet_manuals_sheet_tab_id'];
			$tab_title = $settings['gs_sheet_manuals_sheet_tab_name'];
			$spreadsheet_title = $settings['gs_sheet_manuals_sheet_name'];
		}
		
		$sheet_info = array(
			"spreadsheet_id" => $spreadsheet_id,
			"tab_id" => $tab_id,
			"tab_title" => $tab_title,
			"spreadsheet_title" => $spreadsheet_title,
		);
		$sheet_info = apply_filters( "gcgf_filter_sheet_info", $sheet_info, $form, $feed_id );
		return $sheet_info;
	}
	
	/** 
	* Gforms_Gsheet_Connector_Feeds::settings_empty_error
	* Show warning if no google account connected.
	* @since 4.0 
	* @param array $field
	**/
	public function settings_empty_error( $field ) {
		
		$anchor_link = admin_url('admin.php?page=gf_googlesheet');
		echo '<p class="gs-sync-row error">Configure your google account from <a href='.$anchor_link.'>here</a> to view settings.</p>';
	}
	
	
	/** 
	* Gforms_Gsheet_Connector_Feeds::settings_sheets_selection
	* Auto Select sheet settings field 
	* @since 4.0 
	* @param array $field
	**/
	public function settings_sheets_selection( $field ) {
		
		$field_name = $field['name'];
		$form = $this->get_current_form();
		$settings = $this->get_feed( $this->get_current_feed_id() );
		
		$sheet_data = get_option( 'gfgs_feeds' );
		$all_sheet_data = get_option( 'gfgs_sheetId' );
		
		$spreadsheet_names = array_keys($all_sheet_data);		
		$spreadsheet_name_option = array();	
		$i = 0;
		
		$default_select_sheet_data = array( );
		$default_tabs = array( "Select Sheet First" => "" );
		$default_select_sheet_data["Select Spreadsheet"] = array("id" => "gs-select-sheet", "tabId" => $default_tabs );
		$all_sheet_data = array_merge( $default_select_sheet_data, $all_sheet_data );
		
		foreach( $all_sheet_data as $spreadsheet => $spreadsheet_info ) {
			if( ! $spreadsheet_info['tabId'] || ! $spreadsheet_info['id'] ) {
				continue;
			}
			if( $i == 0 ) {
				$default_sheet = $spreadsheet_info['id'];
				$i++;
			}
			$tab_id = $spreadsheet_info['id'];
			$spreadsheet_name_option[] = array( 'label' => $spreadsheet, 'value' => $tab_id );
		}
		if(empty($all_sheet_data))
		{
			$spreadsheet_name_option[] = array( 'label' => "Select", 'value' => "" );
		}
		//$spreadsheet_name_option[] = array( 'label' => "Create New", 'value' => "create_new" );

		/***************/
		$spreadsheet_ids = wp_list_pluck( $all_sheet_data, 'id');
		
		$default_sheet_selected = true;
		$selected_sheet = $default_sheet;
		$selected_tab = 0;
		
		if( $settings && isset( $settings['meta'] ) ) {
			
			$meta = $settings['meta'];
			if( isset ( $meta [ $field_name.'_name' ] ) ) {				
				$selected_sheet = $meta [ $field_name.'_name' ];
			}
			if( isset ( $meta [ $field_name.'_tab' ] ) ) {				
				$selected_tab = $meta [ $field_name.'_tab' ];
			}			
			$default_sheet_selected = false;
			
			
			if( ! in_array( $selected_sheet, $spreadsheet_ids ) ) {
				$selected_sheet = $default_sheet;
				$default_sheet_selected = true;
				$selected_tab = 0;
			}
		}
				
		$spreadsheet_tabs = array();
		$opt_choices = array( 'label' => "select", 'value' => "0" );
		
		$choices = array();
		if ( $selected_sheet !== "" ) {
			
			foreach( $all_sheet_data as $key => $spreadsheet ) {
				
				if( ! $spreadsheet['tabId'] || ! $spreadsheet['id'] ) {
					continue;
				}
				
				$choice = array("label" => $key);
				$temp_store = array();
				
				$tabs = $spreadsheet['tabId'];
				
				foreach( $tabs as $tab_title => $tab_id ) {
					$choice['choices'][] = array( 'label' => $tab_title, 'value' => $tab_id );
					$temp_store[] = array( 'label' => $tab_title, 'value' => $tab_id );
				}
				
				$choices[] = $choice;
				
				if( $selected_sheet == $spreadsheet['id'] ) {
					$opt_choices = $temp_store;
				}
			}
		}
		
		
		/*FIELD*/
		$select_field = array(
			'name' => $field_name.'_name',
			'label' => esc_html__( 'Select Google Sheet:', 'gsheetconnector-gravityforms' ),
			'type'    => 'select',
			'choices'    => $spreadsheet_name_option,
			'onchange'    => "
				if(this.value=='create_new'){
					jQuery('.sheet-tab-name').hide();
					jQuery('.sheet-url').hide();
					jQuery('.create-ss-wrapper').show();
				}
				else{
					jQuery('.sheet-tab-name').show();
					jQuery('.sheet-url').show();
					jQuery('.create-ss-wrapper').hide();
					
				}",
		);		
		$sheet_select_field = $this->settings_select( $select_field, false );
		/*FIELD END*/
		
		/*FIELD*/
		$select_field = array(
			'name' => $field_name.'_tab',
			'label' => esc_html__( 'Select Tab:', 'gsheetconnector-gravityforms' ),
			'type'    => 'select',
			'choices'    => $opt_choices,
		);		
		$tab_select_field = $this->settings_select( $select_field, false );
		/*FIELD END*/
		
		
		/*FIELD*/
		$text_field = array(
			'name' => $field_name.'_create_sheet',
			'label' => esc_html__( 'Create New Sheet', 'gsheetconnector-gravityforms' ),
			'type'    => 'text',
			'value'    => '',
		);		
		$create_sheet_field = $this->settings_text( $text_field, false );
		/*FIELD END*/
		
		?>

		<div class="gf-gs-fields">			
			<p>
				<label>
					<?php echo esc_html( __( 'Google Sheet Name', 'gsheetconnector-gravityforms' ) ); 
						echo " ".gs_gform_tooltip('google_sheet_name', '', true) ?>
				</label>
				<?php echo $sheet_select_field; ?>
				<span class="gform-settings-validation__error" id="error-sheetName"></span>
				<span class="loading-sign">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
			
			</p>

			<div class="create-ss-wrapper" style="display: none";>
				<label>
					<?php echo esc_html( __( 'Create Spreadsheet', 'gsheetconnector-gravityforms' ) );
						echo " ".gs_gform_tooltip('create_spreadsheet', '', true) ?>
				</label>
				<?php echo $create_sheet_field; ?>
				<a id="gfgs-create-sheet" style="display:none" href="javascript:void(0);"><?php echo esc_html( __( 'Create', 'gsheetconnector-gravityforms' ) ); ?> </a>
				<span class="clear-loading-sign">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
			</div>	
			
			<p class="sheet-tab-name">
				<label>
					<?php echo esc_html( __( 'Google Sheet Tab Name', 'gsheetconnector-gravityforms' ) );
						echo " ".gs_gform_tooltip('google_sheet_tab_name', '', true) ?>
				</label>
				<?php echo $tab_select_field; ?>
				<!-- <input type="hidden" value='<?php //echo json_encode($all_sheet_data); ?>' id="gs_sheet_select_sheets_list"> -->
				<textarea id="gs_sheet_select_sheets_list" style="display:none">
	  				<?php echo json_encode($all_sheet_data); ?>
				</textarea>
			<span class="gform-settings-validation__error" id="error-tabName"></span>	
			</p>

			
			<p class="sheet-url" id="sheet-url">
				<?php 
				$sheet_id = $selected_sheet;
				$tab_id = (isset($selected_tab) && $selected_tab!="") ?$selected_tab : "0" ;
				
				if ( $sheet_id != "" && $tab_id!="" ) { ?>
					<label>
						<?php echo __( 'Google Sheet URL', 'gsheetconnector-gravityforms' );
							echo " ".gs_gform_tooltip('google_sheet_url', '', true) ?>
					</label>
					<a class="gr_sheet_url" href="https://docs.google.com/spreadsheets/d/<?php echo $sheet_id; ?>/edit#gid=<?php echo $tab_id; ?>" target="_blank">Sheet URL</a>
				<?php }  ?>
               </p>
		</div>
		
		<?php
	}
	
	
	/** 
	* Gforms_Gsheet_Connector_Feeds::settings_sheets_info
	* Manual Fields for sheet set up
	* @since 4.0 
	* @param array $field
	**/
	public function settings_sheets_info( $field ) {
		
		$field_name = $field['name'];
		
		/*FIELD*/
		$text_field = array(
			'name' => $field_name.'_sheet_name',
			'label' => esc_html__( 'Google Sheet Name', 'gsheetconnector-gravityforms' ),
			'type'    => 'text',
			'value'    => '',
		);		
		$sheet_name_text_field = $this->settings_text( $text_field, false );
		/*FIELD END*/
		
		/*FIELD*/
		$text_field = array(
			'name' => $field_name.'_sheet_id',
			'label' => esc_html__( 'Google Sheet Id', 'gsheetconnector-gravityforms' ),
			'type'    => 'text',
			'value'    => '',
		);		
		$sheet_id_text_field = $this->settings_text( $text_field, false );
		/*FIELD END*/
		
		/*FIELD*/
		$text_field = array(
			'name' => $field_name.'_sheet_tab_name',
			'label' => esc_html__( 'Google Sheet Tab Name', 'gsheetconnector-gravityforms' ),
			'type'    => 'text',
			'value'    => '',
		);		
		$tab_name_text_field = $this->settings_text( $text_field, false );
		/*FIELD END*/
		
		/*FIELD*/
		$text_field = array(
			'name' => $field_name.'_sheet_tab_id',
			'label' => esc_html__( 'Google Sheet Tab Id', 'gsheetconnector-gravityforms' ),
			'type'    => 'text',
			'value'    => '',
		);		
		$tab_id_text_field = $this->settings_text( $text_field, false );
		/*FIELD END*/
		
		?>
		
		<div class="gf-gs-fields manual-fields">
			
			<p>
				<label>
					<?php echo esc_html( __( 'Google Sheet Name', 'gsheetconnector-gravityforms' ) ); 
						echo " ".gs_gform_tooltip('google_manual_sheet_name', '', true) ?>
				</label>
				<?php echo $sheet_name_text_field ?>
				<span class="gform-settings-validation__error" id="errorman-sheetName"></span>

				<!-- <a href="" class="gs-name help-link"><?php //echo esc_html( __( 'Google Sheet Name ?', 'gsheetconnector-gravityforms' ) ); ?><span class='hover-data'><?php //echo esc_html( __( 'Go to your google account and click on"Google apps" icon and than click "Sheets". Select the name of the appropriate sheet you want to link your contact form or create new sheet.', 'gsheetconnector-gravityforms' ) ); ?> </span></a> -->
			</p>
			
			<p>
				<label>
					<?php echo esc_html( __( 'Google Sheet ID', 'gsheetconnector-gravityforms' ) );
						echo " ".gs_gform_tooltip('google_manual_sheet_id', '', true) ?>
				</label>
				<?php echo $sheet_id_text_field ?>
				<span class="gform-settings-validation__error" id="errorman-sheetId"></span>
				<!-- <a href="" class="gs-name help-link"><?php //echo esc_html( __( 'Google Sheet Name ?', 'gsheetconnector-gravityforms' ) ); ?><span class='hover-data'><?php //echo esc_html( __( 'Go to your google account and click on"Google apps" icon and than click "Sheets". Select the name of the appropriate sheet you want to link your contact form or create new sheet.', 'gsheetconnector-gravityforms' ) ); ?> </span></a> -->
			</p>
			
			<p>
				<label>
					<?php echo esc_html( __( 'Google Sheet Tab Name', 'gsheetconnector-gravityforms' ) );
						echo " ".gs_gform_tooltip('google_manual_sheet_tab_name', '', true) ?>
				</label>
				<?php echo $tab_name_text_field ?>
				<span class="gform-settings-validation__error" id="errorman-tabName"></span>
				<!-- <a href="" class="gs-name help-link"><?php //echo esc_html( __( 'Google Sheet Name ?', 'gsheetconnector-gravityforms' ) ); ?><span class='hover-data'><?php //echo esc_html( __( 'Go to your google account and click on"Google apps" icon and than click "Sheets". Select the name of the appropriate sheet you want to link your contact form or create new sheet.', 'gsheetconnector-gravityforms' ) ); ?> </span></a> -->
			</p>
			
			<p>
				<label>
					<?php echo esc_html( __( 'Google Sheet Tab ID', 'gsheetconnector-gravityforms' ) );
						echo " ".gs_gform_tooltip('google_manual_sheet_tab_id', '', true) ?>
				</label>
				<?php echo $tab_id_text_field ?>
				<span class="gform-settings-validation__error" id="errorman-tabId"></span>
				<!-- <a href="" class="gs-name help-link"><?php //echo esc_html( __( 'Google Sheet Name ?', 'gsheetconnector-gravityforms' ) ); ?><span class='hover-data'><?php //echo esc_html( __( 'Go to your google account and click on"Google apps" icon and than click "Sheets". Select the name of the appropriate sheet you want to link your contact form or create new sheet.', 'gsheetconnector-gravityforms' ) ); ?> </span></a> -->
			</p>

			<p class="sheet_url" id="sheet_url"></p>
			
			
		</div>
		
		<?php
	}
	
	
	/** 
	* Gforms_Gsheet_Connector_Feeds::settings_display_sync_link
	* Show Sync Google sheets link
	* @since 4.0 
	* @param array $field
	**/
	public function settings_display_sync_link( $field ) {
		?>
		
		<p class="gs-sync-row" style="margin-left: -12%">
            <?php echo __( 'Not showing Sheet Name, Tab Name and Sheet URL Link ? <a id="gfgs-sync" class="gfgs-sync" data-init="no">Click here </a> to fetch it.', 'gsheetconnector-gravityforms' ); ?>
            <span class="loading-sign">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
			<input type="hidden" name="gf-ajax-nonce" id="gf-ajax-nonce" value="<?php echo wp_create_nonce( 'gf-ajax-nonce' ); ?>" />
		</p>
		</br>
		
		<?php	//$this->get_google_sheet_settings( $this->get_current_form(), $this->get_current_feed_id() );
	}
	
	
	/** 
	* Gforms_Gsheet_Connector_Feeds::settings_display_sync_entries
	* Show Sync entries sync link
	* @since 4.0 
	* @param array $field
	**/
	public function settings_display_sync_entries( $field ) {
		
		$form = $this->get_current_form();
		$feed_id = $this->get_current_feed_id();
		$form_id = $form['id'];
		?>

		<input type="hidden" name="gf-ajax-sync-entries-nonce" id="gf-ajax-sync-entries-nonce" value="<?php echo wp_create_nonce( 'gf-ajax-sync-entries-nonce' ); ?>" />
		
		<p class="gs-sync-row">
            <?php 
			if( $feed_id > 0 ) {
				
				$link = '<a id="gfgs-entires-sync-launch" class="gfgs-fetch" data-form_id='.$form_id.' data-feed_id='.$feed_id.'>';
				$link .= __( 'Click Here to Sync Entries.', 'gsheetconnector-gravityforms' );
				$link .= '</a>';

				echo sprintf( __('%s ', 'gsheetconnector-gravityforms'), $link );
				?>
				
				<div id="syncMoal" class="modal">

					<!-- Modal content -->
					<div class="modal-content">
						
						<div class="modal-header">
							<p><?php _e( "Sync All Entries Options", 'gsheetconnector-gravityforms' ); ?></p>
							<span class="close">&times;</span>
						</div>
						
						<div>
							<p><?php _e( "Select an option below.", 'gsheetconnector-gravityforms' ); ?></p>
							<div class="sync-options">
								<div class="sync-option sync-all">
									<input type="radio" name="sync-type" class="sync-type" id="sync-all" value="sync-all">
									<label for="sync-all"><?php _e( "Sync All Entries with this feed", 'gsheetconnector-gravityforms' ); ?></label>
									<?php gs_gform_tooltip("gsheet_sync_all", '', false); ?>
								</div>
								<div class="sync-option sync-pending">
									<input type="radio" name="sync-type" class="sync-type" id="sync-pending" value="sync-pending">
									<label for="sync-pending"><?php _e( "Sync only pending entries", 'gsheetconnector-gravityforms' ); ?></label>
									<?php gs_gform_tooltip('gsheet_sync_pending', '', false); ?>
								</div>
								
							</div>
						</div>
						
						<div class="sync-submission">
							<?php 
								$link = '<a id="gfgs-entires-sync" class="btn gsheet-btn button-primary" data-form_id='.$form_id.' data-feed_id='.$feed_id.'>';
								$link .= __( 'Start Sync', 'gsheetconnector-gravityforms' );
								$link .= '</a>';
								echo $link;
							?>
							<span class="loading-sign">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
							<span class="result" style='display: none;' data-default_text="<?php _e( "Starting Synchronizing..", 'gsheetconnector-gravityforms' ); ?>"><?php _e( "Starting Synchronizing..", 'gsheetconnector-gravityforms' ); ?></span>
						</span>
					</div>

				</div>
			</div>
				
				<?php
			}
			else {
				echo __( 'Save this feed to view sync all existing entries option.', 'gsheetconnector-gravityforms' ); 
			}
			?>
            
		</p>		
		
		<?php
	}
	
	
	/** 
	* Gforms_Gsheet_Connector_Feeds::settings_map_form_fields
	* Fields List for Mapping Header and Field
	* @since 4.0 
	* @param array $field
	**/
	public function settings_map_form_fields( $field ) {
		
		$parent_field_name = $field['name'];
		$form = $this->get_current_form();
		
		$fields = $form['fields'];
		$fields_inputs = array( "name", "address", "consent", "product" );
		
		echo '<table class="gf-field-list gsheet-table two-col">';
			$field_list = $this->get_form_field_list($form);

			?>
			<?php
			$settings = $this->get_feed( $this->get_current_feed_id() );
			$feed = isset($settings['meta']['gsheet_field_maps_enable'])?$settings['meta']['gsheet_field_maps_enable']:array();

			$checkAll = '<span class="gform-settings-input__container">
						<div id="checkall-div" class="gform-settings-choice gform-settings-field gform-settings-field__toggle">
							<input type="hidden" name="checkall" value="0">
							<input type="checkbox" id="checkall" name="checkall" class="checkbox-all-field">
							<label class="gform-field__toggle-container" for="checkall">
						<span class="gform-field__toggle-switch"></span
						></label><span class="lbl_tog_field">Check All</span>
						</div>
					</span>';
					?>
			<tr><td><?php echo $checkAll; ?></td></tr>

			<tr>
				<td><!-- <label><span><input type="checkbox" class="entry_id_chk" checked disabled>Entry ID</span></label></td>
				<td><input type="text" name="entry_id" value="Entry ID" class="gaddon-text" disabled> -->
				<div class="gform-settings-field gform-settings-field__toggle">
					<span class="gform-settings-input__container"><input type="checkbox" name="entry_id" id="entry_id" value="1" disabled="1"><label class="gform-field__toggle-container" for="entry_id"><span class="gform-field__toggle-switch"></span></label><span class="lbl_tog_field">Entry ID</span></span>
				</div>
				</td>
			</tr>
			
			
			<?php
			foreach( $field_list as $field ) {
				
				 // echo "<pre>";
				 // print_r($field);
				
				$field_name = $field['field_name'];
				$field_id = $field['field_id'];

				$checked = (isset($feed[$field_id]) && $feed[$field_id] == "1") ? "checked" : ""; 
				
				$checkbox_name = $parent_field_name.'_enable';
				$hidden_name = $parent_field_name.'_field_'.$field_id;
				$default_value = $field_name;
				
				/*FIELD*/
				$column_name_text = array(
					'name' => $parent_field_name."_header_cell[$field_id]",
					'type'    => 'text',
					'default_value'    => $default_value,
							"class" => "gaddon-text",
				);		
				$create_sheet_field = $this->settings_text( $column_name_text, false );
				/*FIELD END*/
				
				/*FIELD*/
				$enable_checkbox_field = array(
					'name' => $checkbox_name,
					'type'    => 'checkbox',
					"choices" => array(
						array(
							"label" => $field_name,
							"value"  => "1",	
							"name"  => $checkbox_name."[$field_id]",
							"class" => "gaddon-checkbox",
						),						
					),
				);		
				//$checkbox_field = $this->settings_checkbox( $enable_checkbox_field, false );

				/*FIELD END*/

				//$checked
				$checkbox_field = '<span class="gform-settings-input__container">
						<div id="gform-settings-checkbox-choice-gsheet_field_maps_enable'.$field_id.'" class="gform-settings-choice gform-settings-field gform-settings-field__toggle">
							<input type="hidden" name="_gform_setting_gsheet_field_maps_enable['.$field_id.']" value="'.(isset($feed[$field_id]) ? $feed[$field_id] : 0).'">
							<input type="checkbox" id="gsheet_field_maps_enable'.$field_id.'" name="gsheet_field_maps_enable['.$field_id.']" class="gaddon-checkbox" '.$checked.' data-id='.$field_id.'>
							<label class="gform-field__toggle-container" for="gsheet_field_maps_enable'.$field_id.'">
						<span class="gform-field__toggle-switch"></span
						></label><span class="lbl_tog_field">'.$field_name.'</span>
						</div>
					</span>';
				?>
				<tr>
					<td style="width:30%!important; float: left!important;"><?php echo $checkbox_field; ?> </td>
					<td style="width:60%!important; float: left!important;" class="row_grvt" data-id="gsheet_field_maps_enable<?php echo $field_id ?>"><?php echo $create_sheet_field; ?></td>
				</tr>
				<?php
			}
			
		echo '</table>';
	}
	
	
	/** 
	* Gforms_Gsheet_Connector_Feeds::settings_gsheet_sorting
	* Sheet sorting fields
	* @since 4.0 
	* @param array $field
	**/
	public function settings_gsheet_sorting( $field ) {
		
		$field_name = $field['name'];
		
		$enabled_field = array(
			'name'       => $field_name . '_checkbox',
			'type'       => 'checkbox',
			'horizontal' => true,
			'choices'    => array(
				array(
					//'label'    => esc_html__( 'Enabled', 'gsheetconnector-gravityforms' ),
					'name'     => $field['name'] . '_enabled',
					'value'    => '1',
					'onchange' => "
						if(jQuery(this).prop('checked')){
							jQuery('.sort-col-text-field').show();
						}
						else {
							jQuery('.sort-col-text-field').hide();
						}
						",
				),
			)
		);
		
		$settings = $this->get_feed( $this->get_current_feed_id() );
		$settings = $settings && isset( $settings['meta'] ) && $settings['meta'] ? $settings['meta'] : array();
		
		echo $html = $this->settings_checkbox( $enabled_field, false );
		
		
		$style = "style='display: none'";
		
		if( isset($settings['gsheet_sort_column_enabled']) && $settings['gsheet_sort_column_enabled'] == 1 ) {
			$style = "";
		}
		
		/*FIELD*/
		$text_field = array(
			'name' => $field_name.'_name',
			'label' => esc_html__( 'Sort Column Name:', 'gsheetconnector-gravityforms' )."&nbsp;".gs_gform_tooltip( 'gsheet_sort_column_name', '', true ),
			'type'    => 'text',
			'value'    => '',
		);
		
		$select_field = array(
			'name' => $field_name.'_order',
			'label' => esc_html__( 'Order:', 'gsheetconnector-gravityforms' )."&nbsp;".gs_gform_tooltip( 'gsheet_sort_order', '', true ),
			'type'    => 'select',
			'choices'    => array(
				array(
					'label'    => esc_html__( 'Ascending', 'gsheetconnector-gravityforms' ),
					'value'    => 'ASCENDING',					
				),
				array(
					'label'    => esc_html__( 'Descending', 'gsheetconnector-gravityforms' ),
					'value'    => 'DESCENDING',					
				),
				
			)
		);
		
		echo "<table class='sort-col-text-field gsheet-table two-col' $style>";
			echo "<tr>";
				echo "<td><label>".$text_field['label']."</label></td>";
				echo "<td>".$this->settings_text( $text_field, false )."</td>";
			echo "</tr>";
			
			echo "<tr>";
				echo "<td><label>".$select_field['label']."</label></td>";
				echo "<td>".$this->settings_select( $select_field, false )."</td>";
			echo "</tr>";
			
			
		echo "</table>";
	}
	
	
	/** 
	* Gforms_Gsheet_Connector_Feeds::settings_gsheet_alternate_colors
	* Manual Fields for Alternate colors
	* @since 4.0 
	* @param array $field
	**/
	public function settings_gsheet_alternate_colors( $field ) {
		
		$field_name = $field['name'];
		
		$enabled_field = array(
			'name'       => $field_name . '_checkbox',
			'type'       => 'checkbox',
			'horizontal' => true,
			'choices'    => array(
				array(
					//'label'    => esc_html__( 'Enabled', 'gsheetconnector-gravityforms' ),
					'name'     => $field['name'] . '_enabled',
					'value'    => '1',
					'onchange' => "
						if(jQuery(this).prop('checked')){
							jQuery('.alt-color-fields').show();
						}
						else {
							jQuery('.alt-color-fields').hide();
						}
						",
				),
			)
		);
		
		$settings = $this->get_feed( $this->get_current_feed_id() );
		$settings = $settings && isset( $settings['meta'] ) && $settings['meta'] ? $settings['meta'] : array();

		echo $html = $this->settings_checkbox( $enabled_field, false );
		
		
		$style = "style='display: none'";
		
		if( isset($settings['gsheet_alternate_colors_enabled']) && $settings['gsheet_alternate_colors_enabled'] == 1 ) {
			$style = "";
		}
		
		/*FIELD*/

		$header_color_field = array(
			'name' => $field_name.'_header_color',
			'label' => esc_html__( 'Header Color:', 'gsheetconnector-gravityforms' ),
			'type'    => 'text',
			'value'    => '',
			'default_value'    => '#ffffff',
		);
		
		$odd_color_field = array(
			'name' => $field_name.'_odd_color',
			'label' => esc_html__( 'Odd Color:', 'gsheetconnector-gravityforms' ),
			'type'    => 'text',
			'value'    => '',
			'default_value'    => '#ffffff',
		);
		
		$even_color_field = array(
			'name' => $field_name.'_even_color',
			'label' => esc_html__( 'Even Color:', 'gsheetconnector-gravityforms' ),
			'type'    => 'text',
			'value'    => '',
			'default_value'    => '#ffffff',
		);
		
		
		
		echo "<table class='alt-color-fields gsheet-table three-cols' $style>";
			echo "<tr class='inline-colors'>";
				echo "<td><label>".$header_color_field['label']."</label>";
				echo "<div>".$this->settings_text( $header_color_field, false )."</div></td>";
				
				echo "<td><label>".$odd_color_field['label']."</label>";
				echo "<div>".$this->settings_text( $odd_color_field, false )."</div></td>";
				
				echo "<td><label>".$even_color_field['label']."</label>";
				echo "<div>".$this->settings_text( $even_color_field, false )."</div></td>";
				
			echo "</tr>";
			
		echo "</table>";
	}
	
	/** 
	* Gforms_Gsheet_Connector_Feeds::settings_gsheet_header_columns
	* Manual Fields for Alternate colors
	* @since 4.0 
	* @param array $field
	**/
	public function settings_gsheet_header_columns( $field ) {
		
		$field_name = $field['name'];
		
		$hidden_field_args = array(
			'name' => $field_name,
			'label' => esc_html__( 'Columns Ordering:', 'gsheetconnector-gravityforms' ),
			'type'    => 'hidden'
		);		
		$hidden_field = $this->settings_hidden( $hidden_field_args, false );
		
		/* Show Hide manager */
		// $cb_field = array(
		// 	'name' => $field_name.'_show',
		// 	'type'    => 'checkbox',
		// 	'choices'    => array(
		// 		array(
		// 			"label" => esc_html__( 'Show Header Row Management:', 'gsheetconnector-gravityforms' ),
		// 			"value"  => "1",	
		// 			"name"  => $field_name.'_toggle_manager',
		// 			'default_value' => 1,
		// 		),						
		// 	),

		// 	'onchange'    => "
		// 		if(this.checked){
		// 			jQuery('.columns_manager').show();
		// 			jQuery('.columns_manager_update').show();
		// 			jQuery('.fixed_entry_id').show();
		// 		}
		// 		else{
		// 			jQuery('.columns_manager').hide();
		// 			jQuery('.columns_manager_update').hide();
		// 			jQuery('.fixed_entry_id').hide();
		// 		}",
		// );		
		//$header_management_field = $this->settings_checkbox( $cb_field, false );
		
		/* Update or do not update field */
		// $update_header_row_field = array(
		// 	'name' => $field_name.'_update',
		// 	'type'    => 'checkbox',
		// 	"choices" => array(
		// 		array(
		// 			"label" => esc_html__( 'Update header row upon saving this feed', 'gsheetconnector-gravityforms' ),
		// 			"value"  => "1",	
		// 			"name"  => $field_name.'_update_header',
		// 		),						
		// 	)
		// );		
		//  $update_header_row_field = $this->settings_checkbox( $update_header_row_field, false );
		
		$settings = $this->get_feed( $this->get_current_feed_id() );
		$meta = $settings && isset( $settings['meta'] ) && $settings['meta'] ? $settings['meta'] : array();
		
		$hidden_style = "style='display: none;'";
		
		if( isset( $meta[$field_name.'_toggle_manager'] ) && $meta[$field_name.'_toggle_manager'] == 1 ) {
			$hidden_style = "";
		}
		
		// echo "<div class='manage-header'>
		// 	<div class='columns_manager_field'>$hidden_field</div>
		// 	<div class='columns_manager_field'>$header_management_field</div>
		// 	<div class='fixed_entry_id'>Entry ID</div>
		// 	<div class='columns_manager' $hidden_style><ul></ul></div>
		// 	<div class='columns_manager_update' $hidden_style><ul></ul>$update_header_row_field</div>
		// </div>";

		echo "<div class='manage-header'>
			<div class='columns_manager_field'>$hidden_field</div>
			<div class='columns_manager_field'></div>
			<div class='fixed_entry_id'>Entry ID</div>
			<div class='columns_manager' $hidden_style><ul></ul></div>
			<div class='columns_manager_update' $hidden_style><ul></ul></div>
		</div>";
		
		
		
	}


	/** 
	* Gforms_Gsheet_Connector_Feeds::settings_gsheet_header_columns
	* Manual Fields for Alternate colors
	* @since 4.0 
	* @param array $field
	**/
	public function settings_create_new_sheets() {
		echo '<div class="gf-gs-fields">			
			<div>
				<a id="create_new" class="create_new gr_sheet_url">Create New Sheet</a>
				<div class="new_sheet_sec" style="display:none;">
					<input type="text" name="create_new_shee_name" id="create_new_shee_name" class="create_new_shee_name" style="width:25%" />
					<span class="loading-sign-newsheet">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
					<a id="save_create_new_sheet" class="save_create_new_sheet gr_sheet_url">Save </a>
					<a id="cancel_new_sheet" class="cancel_new_sheet gr_sheet_url" style="margin-left:5px">Cancel </a>
				</div>
			</div>
		</div>';
	}
	
	
	/** 
	* Gforms_Gsheet_Connector_Feeds::get_form_field_list
	* Fetch all form fields and format them in array
	* @since 4.0 
	* @param array $form
	* @return array $field_list
	**/
	public function get_form_field_list($form) {
		$fields = $form['fields'];
		$fields_inputs = array( "name", "address", "consent", "product" );
		
		$field_list = array();
		
		foreach( $fields as $field ) {
				
			$field_name = $field->label;
			$field_id = $field->id;
			
			$type = $field->type;
			
			$field_list[] = array(
               "field_id" => $field_id,
               "field_name" => $field_name
            );
			
			if ( in_array( $type, $fields_inputs ) ) {
				$inputs = $field->inputs;
				foreach ( $inputs as $key => $value ) {
					if ( isset( $value['isHidden'] ) && $value['isHidden'] == 1 ) {
						continue;
					}
					$field_id = str_replace(".", "_", $value['id']);
					$field_name = $value['label'];
					$field_list[] = array(
						"field_id" => $field_id,
						"field_name" => $field_name
					);
				}
			}
			
		}
		
		$field_list = apply_filters( "gcgf_form_field_list", $field_list, $form );
		return $field_list;
	}
	
	
	/** 
	* Gforms_Gsheet_Connector_Feeds::get_merge_tags_fields_choices
	* Merge Tags fields as choices
	* @since 4.0 
	* @return array $choices
	**/
	public function get_merge_tags_fields_choices() {
		
		$form = $this->get_current_form();
		$merge_tags = GFCommon::get_merge_tags( $form['fields'], '', false );
		
		$choices = array();
		
		foreach( $merge_tags as $key => $merge_tag ) {
			
			$choice = array();
			
			if( isset( $merge_tag['tags'] ) && $merge_tag['tags'] ) {
				
				$group_label = "Default";
				if( isset( $merge_tag['label'] ) && $merge_tag['label'] ) {
					$group_label = $merge_tag['label'];
				}
				
				$choice = array("label" => $group_label);
				
				foreach( $merge_tag['tags'] as $tag ) {
					$choice['choices'][] = array( 'label' => $tag['label'], 'value' => $tag['tag'] );
				}
				
				$choices[] = $choice;
			}
		}
		$choices = apply_filters( "gcgf_merge_tag_choices", $choices );
		return $choices;
	}
	
	
	/** 
	* Gforms_Gsheet_Connector_Feeds::maybe_save_form_settings
	* Saved with parent and create the sheet as needed and assign for auto selecting sheet.
	* @since 4.0 
	* @param int $feed_id
	* @param array $form_id
	**/
	public function save_feed_settings($feed_id, $form_id, $values) {
		
		$feed_id = parent::save_feed_settings($feed_id, $form_id, $values);

		$license_validation = get_option( "gfgs_license_status" );
		$GFGS_Connector_Service = new GFGS_Connector_Service();
		$expiration = $GFGS_Connector_Service->check_license_expiration();
			if ( $expiration || $license_validation === "invalid" ) {
			return;
		}
		
		if ( $this->is_save_postback() ) {
			
			$form = GFAPI::get_form( $form_id );
			$old_settings = $this->get_feed( $feed_id );
			$old_meta = isset($old_settings['meta']) ? $old_settings['meta'] : "";
			
			if ( ! $this->current_user_can_any( $this->_capabilities_form_settings ) ) {
				return $feed_id;
			}
			
			$posted_settings = $this->get_posted_settings();
			
			global $_gaddon_posted_settings;
			
			$_gaddon_posted_settings = $posted_settings;
			
			$override_sheet_info = false;			
			$gfgsc_googlesheet = $this->get_gfgsc_googlesheet();
			
			$google_sheet_settings = $this->get_google_sheet_settings($form, $feed_id);
			$spreadsheet_id = $google_sheet_settings['spreadsheet_id'];
			$tab_id = $google_sheet_settings['tab_id'];

			if(isset($_POST['create_new_shee_name']) && $_POST['create_new_shee_name']!=""){
				$values['gs_sheet_select_name'] = $spreadsheet_id;
				$values['gs_sheet_select_tab'] = $tab_id;
			}
		

			
			if( isset ( $posted_settings['gs_sheet_select_name'] ) && $posted_settings['gs_sheet_select_name'] == "gs-select-sheet" ) {
				return;
			}
			
			//if( isset ( $posted_settings['gs_sheet_integration'] ) && $posted_settings['gs_sheet_integration'] == "automatic" ) {
				// if( isset ( $posted_settings['gs_sheet_select_name'] ) && $posted_settings['gs_sheet_select_name'] == "create_new" ) {
					
				// 	$sheet_title = $posted_settings['gs_sheet_select_create_sheet'];
				// 	$sheet_title = $sheet_title ? $sheet_title : GRAVITY_GOOGLESHEET_PRO_SHORT_NAME." ".$form['title'];
					
				// 	$sheet_title = apply_filters( "gcgf_create_sheet_title", $sheet_title, $form, $feed_id );
					
				// 	$spreadsheet = $gfgsc_googlesheet->gsheet_create_google_sheet($sheet_title);
					
				// 	if( $spreadsheet && $spreadsheet['result'] ) {
						
				// 		$spreadsheet_id = $spreadsheet['spreadsheet']['spreadsheet_id'];
				// 		$tab_id = 0;
						
				// 		$_gaddon_posted_settings['gs_sheet_select_name'] = $posted_settings['gs_sheet_select_name'] = $_POST['gs_sheet_select_name'] = $values['gs_sheet_select_name'] = $spreadsheet_id;
				// 		$_gaddon_posted_settings['gs_sheet_select_tab'] = $posted_settings['gs_sheet_select_tab'] = $_POST['gs_sheet_select_tab'] = $values['gs_sheet_select_tab'] = $tab_id;
				// 		// $_gaddon_posted_settings['gs_sheet_select_create_sheet'] = $posted_settings['gs_sheet_select_create_sheet'] = $_POST['gs_sheet_select_create_sheet'] = $values['gs_sheet_select_create_sheet'] = "";

				// 		$this->add_row_header( $spreadsheet_id, "0", $values, true );
					
				// 		$settings = $values;
				// 		//parent::save_feed_settings( $feed_id, $form_id, $values );
						
						
				// 	}
					
				// }
			//}
			
			$header_cells = $gfgsc_googlesheet->get_header_row($spreadsheet_id, $tab_id);			
			
			//if( $posted_settings['gsheet_header_columns_update_header'] && $posted_settings['gsheet_header_columns_update_header'] == 1 ) {
				if( ! $override_sheet_info ) {
					$this->add_row_header( $spreadsheet_id, $tab_id, $posted_settings );
				}
				
				// $posted_settings['gsheet_header_columns_update_header'] = 0;
				// $_gaddon_posted_settings['gsheet_header_columns_update_header'] = "0";
				// $_POST['gsheet_header_columns_update_header'] = "0";	
				// $values['gsheet_header_columns_update_header'] = "0";
				//parent::save_feed_settings( $feed_id, $form_id, $values );
			//}			
			//else if( ! $header_cells || empty ( $header_cells ) ) {
				// if( ! $override_sheet_info ) {
				// 	$this->add_row_header( $spreadsheet_id, $tab_id, $posted_settings, true );
				// }
			//}
			
			if( isset ( $posted_settings['gsheet_freeze_header'] ) ) {
				$gfgsc_googlesheet->freeze_row( $spreadsheet_id, $tab_id, $posted_settings['gsheet_freeze_header'] );				
			}
			
			$this->sort_sheet_by_column($form, $feed_id);
				
			if( isset ( $posted_settings['gsheet_alternate_colors_enabled'] ) ) {
				
				$enabled = $posted_settings['gsheet_alternate_colors_enabled'];
				if( $enabled ) {						
					$header_color = $posted_settings['gsheet_alternate_colors_header_color'];
					$odd_color = $posted_settings['gsheet_alternate_colors_odd_color'];
					$even_color = $posted_settings['gsheet_alternate_colors_even_color'];
					
					$header_color = apply_filters( "gcgf_header_color", $header_color, $feed_id, $spreadsheet_id, $tab_id);
					$odd_color = apply_filters( "gcgf_odd_color", $odd_color, $feed_id, $spreadsheet_id, $tab_id);
					$even_color = apply_filters( "gcgf_even_color", $even_color, $feed_id, $spreadsheet_id, $tab_id);
					
					$gfgsc_googlesheet->set_alternate_colors( $spreadsheet_id, $tab_id, $header_color, $odd_color, $even_color );
				}
				else { 
					$gfgsc_googlesheet->remove_alternate_colors( $spreadsheet_id, $tab_id );
				}
			}else{
				$gfgsc_googlesheet->set_alternate_colors( $spreadsheet_id, $tab_id, "#ffffff", "#ffffff", "#ffffff" );
			}
			
		}

		parent::save_feed_settings( $feed_id, $form_id, $values );
		
		//update_post_meta( $form_id, 'gfgs_settings', "" );
		update_post_meta( $form_id, 'gfgs_settings', $_gaddon_posted_settings );
		return $feed_id;
	}
	
			
	/** 
	* Gforms_Gsheet_Connector_Feeds::sort_sheet_by_column
	* Sort Sheet by column Index
	* @since 4.0 
	* @param array $form
	* @param int $feed_id
	* @param array $perform
	**/
	public function sort_sheet_by_column( $form, $feed_id ) {
	
		$settings = $this->get_feed( $feed_id );
		
		if( ! $settings ) {
			return;
		}
		
		$settings = $settings && isset( $settings['meta'] ) && $settings['meta'] ? $settings['meta'] : array();
		
		if( ! isset( $settings['gsheet_sort_column_enabled'] ) || ! $settings['gsheet_sort_column_enabled'] ) {
			return;
		}
		
		$gsheet_sort_column_enabled = $settings['gsheet_sort_column_enabled'];
		if( ! $gsheet_sort_column_enabled || $gsheet_sort_column_enabled == 0 ) {
			return;
		}
		
		$gsheet_sort_column_name = $settings['gsheet_sort_column_name'];
		if( ! $gsheet_sort_column_name || $gsheet_sort_column_name == "" ) {
			return;
		}
		
		
		$google_sheet_settings = $this->get_google_sheet_settings($form, $feed_id);
		
		if( ! $google_sheet_settings ) {
			return;
		}
		
		$spreadsheet_id = $google_sheet_settings['spreadsheet_id'];
		$tab_id = $google_sheet_settings['tab_id'];
		
		$index_column_name = $gsheet_sort_column_name;
		
		$column_index = false;
		$sort_order = $settings['gsheet_sort_column_order'] ? $settings['gsheet_sort_column_order'] : "ASCENDING";
		
		
		$gfgsc_googlesheet = $this->get_gfgsc_googlesheet();
		
		$header_cells = $gfgsc_googlesheet->get_header_row( $spreadsheet_id, $tab_id );
		
		foreach( $header_cells as $index => $cellName ) {			
			if( $cellName == $index_column_name ) {
				$column_index = $index;
			}
		}
		
		$column_index = apply_filters( "gcgf_column_index", $column_index, $form, $feed_id, $settings, $spreadsheet_id, $tab_id );
		
		if( $column_index !== false && is_numeric($column_index) ) {			
			$gfgsc_googlesheet->sort_sheet_by_column( $spreadsheet_id, $tab_id, $column_index, $sort_order );				
		}		
	}
	
	
	/** 
	* Gforms_Gsheet_Connector_Feeds::feed_list_columns
	* Future usage if converting to Feeds.
	* @since 4.0 
	* @return array $columns
	**/
	public function feed_list_columns() {
		return array(
			'feedName'  => esc_html__( 'Name', 'gsheetconnector-gravityforms' )
		);
	}
	
	
	/** 
	* Gforms_Gsheet_Connector_Feeds::add_row_header
	* Adding the row Header with selected fields
	* @since 4.0 
	* @param string $spreadsheet_id
	* @param string $tab_id
	* @param array $form
	**/
	public function add_row_header( $spreadsheet_id, $tab_id, $settings, $force = false ) {
		
		if( ! $settings ) {
			return;
		}
		
		// $settings = $settings['meta'];
		$row_header = array();
		$row_header[] = "Entry ID";
		
		if( isset( $settings['gsheet_header_columns'] ) && $settings['gsheet_header_columns'] ) {
			//if( $force || ( isset( $settings['gsheet_header_columns_update_header'] ) && $settings['gsheet_header_columns_update_header'] == 1) ) {
				$ordered_columns = $settings['gsheet_header_columns'];
				foreach( $ordered_columns as $column ) {
					if( $column['column_name'] != "" ) {
						$row_header[] = $column['column_name'];
					}
				}
			//}			
		}
		else {
			$mapping_enabled_field = $settings['gsheet_field_maps_enable'];
			$mapping_cells = $settings['gsheet_field_maps_header_cell'];
			
			$parent_field_name = "gsheet_field_maps";
						
			foreach( $mapping_enabled_field as $field_key => $enabled ) {
				
				if( $enabled == 1 && isset( $mapping_cells[$field_key] ) && $mapping_cells[$field_key] != "" ) {					
					$field_id = $field_key;
					$field_id = str_replace("_", ".", $field_key);
					
					$field_name = $mapping_cells[$field_key];
					
					$row_header[] =  $field_name;
				}
				
			}
			
			$mapping_merge_tags = $settings['gsheet_mergeTagsMap'];
			if( $mapping_merge_tags && !empty( $mapping_merge_tags ) ) {
				foreach( $mapping_merge_tags as $merge_tag ) {
					$field_name = $merge_tag['custom_key'];
					$row_header[] =  $field_name;
				}
			}		
		}
		
		$row_header = apply_filters( "gcgf_row_header", $row_header, $settings, $spreadsheet_id, $tab_id );
	
		if( $row_header ) {
			$gfgsc_googlesheet = $this->get_gfgsc_googlesheet();
			$tab_title = $gfgsc_googlesheet->get_sheet_name( $spreadsheet_id, $tab_id );
			if( $tab_title ) {
				$gfgsc_googlesheet->add_row_to_sheet( $spreadsheet_id, $tab_title, $row_header, false, true );
			}
		}
	}
	
	
	/** 
	* Gforms_Gsheet_Connector_Feeds::sync_all_form_entries
	* Send entries to google sheet in bunch
	* @since 4.0 
	**/
	public function sync_all_form_entries() {
		
		check_ajax_referer( 'gf-ajax-sync-entries-nonce', 'security' );
		
		if ( isset( $_POST['form_id'] ) && $_POST['form_id'] != '' ) {
			
			$form_id = sanitize_text_field( $_POST['form_id'] );
			$feed_id = sanitize_text_field( $_POST['feed_id'] );
			
			$search_criteria = array(
				'status'        => 'active'
			);
			
			$temp = false;
			$pending_only = false;
			if( isset ( $_POST['sync_type'] ) && $_POST['sync_type'] == "sync-pending" ) {
				$pending_only = true;
			}
			
			$page = isset( $_POST['page'] ) && $_POST['page'] ? sanitize_text_field( $_POST['page'] ) : 0;	
			$post_processed = isset( $_POST ['processed'] ) ? sanitize_text_field( $_POST ['processed'] ) : 0;
			$total_entries = isset( $_POST['total_entries'] ) && $_POST['total_entries'] ? sanitize_text_field( $_POST['total_entries'] ) : 0;
			
			// $page = 10;
			$per_page = 50;
			$offset = $per_page * ( $page - 1 );
			
			$form_ids = array( $form_id );
			$form = GFAPI::get_form( $form_id );
			if( ! $total_entries ) {
				$total_entries = GFAPI::count_entries( $form_ids, $search_criteria );
			}
			
			$form_ids = array( $form_id );			
			
			$paging = array( 'offset' => $offset, 'page_size' => $per_page );
			$sorting = array( 'key' => 'id', 'direction' => 'ASC' );
			
			$processed = $post_processed;
			/* Fetch entries */
			$entries = GFAPI::get_entries( $form_ids, $search_criteria, $sorting, $paging );
			
			$feed = $this->get_feed( $feed_id );
			$feed_data = $feed['meta'];			
			$is_condition_enabled = rgar( $feed_data, 'feed_condition_conditional_logic' );
			$logic = rgars( $feed_data, 'feed_condition_conditional_logic_object/conditionalLogic' );
			
			$post_entries = array();
			$processed_entries = array();

			$ids = array();
			//Finding google sheet Entry ID list
			if( $pending_only ) {
				$google_sheet_settings = $this->get_google_sheet_settings($form, $feed_id);
		
				if( $google_sheet_settings ) {
				
					$spreadsheet_id = $google_sheet_settings['spreadsheet_id'];
					$tab_id = $google_sheet_settings['tab_id'];
					$tab_title = $google_sheet_settings['tab_title'];
					

					$gfgsc_googlesheet = $this->get_gfgsc_googlesheet();
					$allEntries = $gfgsc_googlesheet->getAllEntriesValues( $spreadsheet_id, $tab_title );
					
					if(!empty($allEntries)){
						$searchPostionEntryId = $allEntries[0];
						$postionEntryId=array_search('Entry ID', $allEntries[0]);
						if(isset($postionEntryId)){
							array_shift($allEntries);//remove Entry Id title from
							$ids = array_column($allEntries, $postionEntryId);
						}
					}
				}
			}
			
			//Finding google sheet Entry ID list

			if( $entries ) {
				
				foreach( $entries as $entry ) {	
					
					$process_entry = apply_filters( "gcgf_process_entry", true, $entry, $form, $feed_id );
					
					if( ! $process_entry ) {
						continue;
					}
					
					//if( $pending_only ) {

						// $meta_key = 'synced_with_feed_'.$feed_id;
						// $is_pending = gform_get_meta( $entry['id'], $meta_key );
						
						// if( $is_pending && $is_pending == 1 ) {
						// 	continue;
						// }
					//}
					if( ! $is_condition_enabled || empty( $logic ) ) {
						if( $pending_only ) {
							if(in_array($entry['id'], $ids)){
								continue;
							}
						}
						$post_entries[] = $this->get_data_to_submit( $entry, $form, $feed_id, true );
						$processed_entries[] = $entry;
						$processed++;
						gform_update_meta( $entry['id'], 'synced_with_feed_'.$feed_id, 1 );
						
					}
					else {
						if( $pending_only ) {
							if(in_array($entry['id'], $ids)){
								continue;
							}
						}
						$check = GFCommon::evaluate_conditional_logic( $logic, $form, $entry );
						if( $check ) {
							$post_entries[] = $this->get_data_to_submit( $entry, $form, $feed_id, true );
							$processed_entries[] = $entry;
							$processed++;
							gform_update_meta( $entry['id'], 'synced_with_feed_'.$feed_id, 1 );
						}
					}
				}
			}
			
			
			$post_entries = apply_filters( "gcgf_post_entries", $post_entries, $processed_entries, $form, $feed_id, $page );
			if( $post_entries ) {
				$google_sheet_settings = $this->get_google_sheet_settings($form, $feed_id);
				
				if( $google_sheet_settings ) {
				
					$spreadsheet_id = $google_sheet_settings['spreadsheet_id'];
					$tab_id = $google_sheet_settings['tab_id'];
					$tab_title = $google_sheet_settings['tab_title'];
					
					$gfgsc_googlesheet = $this->get_gfgsc_googlesheet();
					$gfgsc_googlesheet = $gfgsc_googlesheet->add_bulk_rows_to_sheet( $spreadsheet_id, $tab_title, $post_entries, $processed_entries );
					$this->sort_sheet_by_column($form, $feed_id);
				}
			}
			
			$process_further = 1;
			$fetched_entries = ($offset + $per_page);
			if( $total_entries <= $fetched_entries ) {
				$process_further = 0;
				$fetched_entries = $total_entries;
                                if( isset( $spreadsheet_id ) && isset( $tab_id ) ) :
                                    unset( $_SESSION['gs_header_cells_'.$spreadsheet_id."_".$tab_id] );
                                endif;				
			}
			
			$text = $entries ? sprintf( __('Processed %d of %d entries. Sent %d entries.', 'gsheetconnector-gravityforms'), $fetched_entries, $total_entries, $processed ) : sprintf( __('No Entries Found', 'gsheetconnector-gravityforms') );
			
			if( ! $entries && $pending_only ) {
				$text = sprintf( __('No Pending Entries Found.', 'gsheetconnector-gravityforms') );
			}
			else if( $entries && $pending_only ) {
				$text .= sprintf( __(' %d pending entries found.', 'gsheetconnector-gravityforms'), $processed );
			}
			
			echo json_encode( 
				array(
					"processed" => $processed,
					"processed_page" => $page,
					"next_page" => $page + 1,
					"total_entries" => $total_entries,
					"process_further" => $process_further,
					"temp" => json_encode($temp),
					"text" => $text,					
				) 
			);
		}
		
		exit;
	}
	
	public function run_on_upgrade() {
      $plugin_options = get_site_option('gfgs_info');
      $gfgs_upgraded_4_0 = get_site_option('gfgs_upgraded_4_0', false);
      $all_sheet_data = get_option( 'gfgs_sheetId' );
	 
  	  global $wpdb;
	  $table = $wpdb->prefix . 'gf_addon_feed';
	  
	  if( isset( $_GET['force_upgrade'] ) || ( ! $gfgs_upgraded_4_0 && $plugin_options['version'] != "4.1" ) ) {
		  
		  if( class_exists( "GFAPI" ) ) {
			
			$forms = GFAPI::get_forms();
			
			if( $forms ) {
				foreach( $forms as $form ) {
					
					$upgrade_meta_script = array();
					
					$form_id = $form['id'];
					$sheet_meta = get_post_meta($form_id, 'gfgs_settings', true );
					$field_meta = get_post_meta($form_id, 'gravity_form_fields', true );
					$current_form_feeds = $this->get_feeds_by_slug("gsheetconnectorgravityforms", $form_id );
					
					$form_feed_upgraded = false;
					
					if( ! isset( $sheet_meta['sheet-name'] ) || $sheet_meta['sheet-name'] == "" ) {
						continue;
					}
					
					if( ! isset( $all_sheet_data [ $sheet_meta['sheet-name'] ] ) || ! $all_sheet_data [ $sheet_meta['sheet-name'] ]  ) {
						continue;
					}
							
					$is_prefilled = isset($sheet_meta['manual-field']) && $sheet_meta['manual-field'] != "on" ? true : false;
					
					$selected_google_sheet = $all_sheet_data [ $sheet_meta['sheet-name'] ];			
					$input_sheet_name = $sheet_meta['sheet-name'];
					$input_tab_name = $sheet_meta['sheet-tab-name'];
					$input_sheet_id = $sheet_meta['sheet-id'];
					$input_tab_id = $sheet_meta['tab-id'];
					
					if( $current_form_feeds ) {
						
						foreach( $current_form_feeds as $feed ) {
						
							$meta = $feed['meta'];
							$feed_id = $feed['id'];
							
							if( isset( $meta ) && $meta && isset( $meta['sheet_details'] ) ) {
								
								$upgrade_meta_script['feedName'] = $meta['feedName'];
								
								if( $is_prefilled ) {
									$upgrade_meta_script['gs_sheet_integration'] = "automatic";
									$upgrade_meta_script['gs_sheet_select_name'] = $selected_google_sheet['id'];
									$upgrade_meta_script['gs_sheet_select_tab'] = $selected_google_sheet['tabId'][$input_tab_name];
								}
								
								else {
									$upgrade_meta_script['gs_sheet_integration'] = "manual";
									$upgrade_meta_script['gs_sheet_manuals_sheet_name'] = $input_sheet_name;
									$upgrade_meta_script['gs_sheet_manuals_sheet_id'] = $input_sheet_id;
									$upgrade_meta_script['gs_sheet_manuals_sheet_tab_name'] = $input_tab_name;
									$upgrade_meta_script['gs_sheet_manuals_sheet_tab_id'] = $input_tab_id;
								}
								
								if( $field_meta ) {
									$gsheet_field_maps_enable = array();
									$gsheet_field_maps_header_cell = array();
									
									foreach( $field_meta as $field_id => $column_name ) {
										$key = str_replace( ".", "_", $field_id );
										
										$gsheet_field_maps_enable[$key] = 1;
										$gsheet_field_maps_header_cell[$key] = $column_name;
									}
									
									$upgrade_meta_script['gsheet_field_maps_enable'] = $gsheet_field_maps_enable;
									$upgrade_meta_script['gsheet_field_maps_header_cell'] = $gsheet_field_maps_header_cell;
								}
								$form_feed_upgraded = $this->update_feed_meta( $feed_id, $upgrade_meta_script );
							}
						}
					}
					
					if( $form_feed_upgraded || $_GET['force_upgrade'] == 335383 ) {
						$sheet_meta = delete_post_meta($form_id, 'gfgs_settings' );
						$field_meta = delete_post_meta($form_id, 'gravity_form_fields' );
					}
				}
			}
		}
		
		update_site_option('gfgs_upgraded_4_0', 1);
		
	  }
	  
	  
   }

}




/**
 * Obtains and returns an instance of the Gforms_Gsheet_Connector_Feeds class
 *
 * @since 4.0
 * @access public
 *
 * @uses Gforms_Gsheet_Connector_Feeds::get_instance()
 *
 * @return object Gforms_Gsheet_Connector_Feeds
 */
function gravityforms_gsheetconnector() {
	return Gforms_Gsheet_Connector_Feeds::get_instance();
}

if( ! function_exists('gs_gform_tooltip') ) {
	function gs_gform_tooltip( $name, $css_class = '', $return = false ) {
		global $__gf_tooltips; //declared as global to improve WPML performance

		$css_class     = empty( $css_class ) ? 'tooltip' : $css_class;
		/**
		 * Filters the tooltips available
		 *
		 * @param array $__gf_tooltips Array containing the available tooltips
		 */
		$__gf_tooltips = apply_filters( 'gform_tooltips', $__gf_tooltips );

		//AC: the $name parameter is a key when it has only one word. Maybe try to improve this later.
		$parameter_is_key = count( explode( ' ', $name ) ) == 1;

		$tooltip_text  = $parameter_is_key ? rgar( $__gf_tooltips, $name ) : $name;
		$tooltip_class = isset( $__gf_tooltips[ $name ] ) ? "tooltip_{$name}" : '';

		if ( empty( $tooltip_text ) ) {
			return '';
		}
		$tooltip = sprintf(
			'<button onclick="return false;" onkeypress="return false;" class="gf_tooltip %s" %s aria-label="%s">
				<i class="gform-icon gform-icon--question-mark" aria-hidden="true"></i>
			</button>',
			esc_attr( $css_class ),
			esc_attr( $tooltip_class ),
			esc_attr( $tooltip_text )
		);

		if ( $return ) {
			return $tooltip;
		} else {
			echo $tooltip;
		}
	}
}