<?php

/**
 * Plugin Name: Gravity Forms GSheetConnector Pro
 * Plugin URI: https://www.gsheetconnector.com/
 * Description: Send your gravityform  data to your Google Sheets spreadsheet.
 * Requires at least: 4.9
 * Requires PHP:      5.5 
 * Author: GSheetConnector
 * Author URI: https://www.gsheetconnector.com/
 * Version: 4.3.4 
 * Text Domain: gsheetconnector-gravityforms
 */
// Exit if accessed directly.
if (!defined('ABSPATH')) {
   exit;
}

define('GRAVITY_GOOGLESHEET_PRO_VERSION', '4.3.4');
define('GRAVITY_GOOGLESHEET_PRO_DB_VERSION', '4.3.4');
define('GRAVITY_GOOGLESHEET_PRO_ROOT', dirname(__FILE__));
define('GRAVITY_GOOGLESHEET_PRO_URL', plugins_url('/', __FILE__));
define('GRAVITY_GOOGLESHEET_PRO_BASE_FILE', basename(dirname(__FILE__)) . '/gsheetconnector-gravityforms.php');
define('GRAVITY_GOOGLESHEET_PRO_BASE_NAME', plugin_basename(__FILE__));
define('GRAVITY_GOOGLESHEET_PRO_PATH', plugin_dir_path(__FILE__)); //use for include files to other files
define('GRAVITY_GOOGLESHEET_PRO_PRODUCT_NAME', 'GravityForms Google Sheet Connector Pro');
define('GRAVITY_GOOGLESHEET_PRO_SHORT_NAME', 'GSheet Connector Pro');
define('GRAVITY_GOOGLESHEET_PRO_STORE_URL', 'https://gsheetconnector.com');

load_plugin_textdomain('gsheetconnector-gravityforms', false, basename(dirname(__FILE__)) . '/languages');

if (!class_exists('GravityForms_Gs_Connector_Utility')) {
   include( GRAVITY_GOOGLESHEET_PRO_ROOT . '/includes/class-gravityforms-utility.php' );
}

class Gforms_Gsheet_Connector_Init {

   public function __construct() {

      //run on activation of plugin
      register_activation_hook(__FILE__, array($this, 'gsheetconnector_gform_activate'));

      //run on deactivation of plugin
      register_deactivation_hook(__FILE__, array($this, 'gsheetconnector_gform_deactivate'));

      //run on uninstall
      register_uninstall_hook(__FILE__, array('Gforms_Gsheet_Connector_Init', 'gsheetconnector_gform_uninstall'));

      // validate is Gravityforms plugin exist
      add_action('admin_init', array($this, 'validate_parent_plugin_exists'));

      // register admin menu under "Forms" > "Entries"
      add_action('gform_addon_navigation', array($this, 'get_parent_menu'), 10, 1);

      // load the classes
      add_action('init', array($this, 'load_all_classes'), 10, 1);

      // load the js and css files
      add_action('init', array($this, 'load_css_and_js_files'));
      
      // add custom interval for checking expiration of the License
      add_filter('cron_schedules', array($this, 'custom_cron_interval'));
      
      // run upgradation
      add_action( 'admin_init', array( $this, 'run_on_upgrade' ) );

      // Setting option
      add_filter('plugin_action_links_' . GRAVITY_GOOGLESHEET_PRO_BASE_NAME, array($this, 'grvt_connector_pro_plugin_action_links'));

      // Display widget to dashboard
      add_action('wp_dashboard_setup', array($this, 'add_grforms_gs_connector_summary_widget'));
   }

   /**
    * Do things on plugin activation
    * @since 1.0
    */
   public function gsheetconnector_gform_activate($network_wide) {
      global $wpdb;
      $this->run_on_activation();
      if (function_exists('is_multisite') && is_multisite()) {
         // check if it is a network activation - if so, run the activation function for each blog id
         if ($network_wide) {
            // Get all blog ids
            $blogids = $wpdb->get_col("SELECT blog_id FROM {$wpdb->base_prefix}blogs");
            foreach ($blogids as $blog_id) {
               switch_to_blog($blog_id);
               $this->run_for_site();
               restore_current_blog();
            }
            return;
         }
      }

      // for non-network sites only
      $this->run_for_site();
   }

   public function gsheetconnector_gform_deactivate($network_wide) {
      
   }

   /**
    *  Runs on plugin uninstall.
    *  a static class method or function can be used in an uninstall hook
    *
    *  @since 1.0
    */
   public static function gsheetconnector_gform_uninstall() {
      global $wpdb;
      Gforms_Gsheet_Connector_Init::run_on_uninstall();
      if (function_exists('is_multisite') && is_multisite()) {
         //Get all blog ids; foreach of them call the uninstall procedure
         $blog_ids = $wpdb->get_col("SELECT blog_id FROM {$wpdb->base_prefix}blogs");

         //Get all blog ids; foreach them and call the install procedure on each of them if the plugin table is found
         foreach ($blog_ids as $blog_id) {
            switch_to_blog($blog_id);
            Gforms_Gsheet_Connector_Init::delete_for_site();
            restore_current_blog();
         }
         return;
      }
      Gforms_Gsheet_Connector_Init::delete_for_site();
   }

   /**
    * Validate parent Plugin gravityforms exist and activated
    * @access public
    * @since 1.0
    */
   public function validate_parent_plugin_exists() {
      $plugin = plugin_basename(__FILE__);
      if ((!is_plugin_active('gravityforms/gravityforms.php'))) {
         add_action('admin_notices', array($this, 'gform_missing_notice'));
         add_action('network_admin_notices', array($this, 'gform_missing_notice'));
         deactivate_plugins($plugin);
         if (isset($_GET['activate'])) {
            // Do not sanitize it because we are destroying the variables from URL
            unset($_GET['activate']);
         }
      }
   }

   /**
    * If Gravityforms plugin is not installed or activated then throw the error
    *
    * @access public
    * @return mixed error_message, an array containing the error message
    *
    * @since 1.0 initial version
    */
   public function gform_missing_notice() {
      $plugin_error = GravityForms_Gs_Connector_Utility::instance()->admin_notice(array(
         'type' => 'error',
         'message' => 'GSheetConnector GravityForms Pro Add-on requires Gravityforms plugin to be installed and activated.'
      ));
      echo $plugin_error;
   }

   public function get_parent_menu($addon_menus) {
      $current_role = GravityForms_Gs_Connector_Utility::instance()->get_current_user_role();
      $gs_roles = get_option('gfgs_page_roles_setting');
      if (( is_array($gs_roles) && array_key_exists($current_role, $gs_roles) ) || $current_role === "administrator") {
         $addon_menus[] = array(
            'permission' => 'gravityforms_edit_forms',
            'label' => 'Google Sheet',
            'name' => 'gf_googlesheet',
            'callback' => array($this, 'add_googlesheet_menu')
         );
      }
      return $addon_menus;
   }

   public function add_googlesheet_menu() {

      require_once plugin_dir_path(__FILE__) . 'includes/pages/google-sheet-settings.php';
   }

   /**
    * Create/Register menu items for the plugin.
    * @since 1.0
    */
   public function load_all_classes() {
      if (!class_exists('Gsheet_License_Settings')) {
         include( GRAVITY_GOOGLESHEET_PRO_PATH . 'includes/class-gs-license-settings.php' );
      }
      if (!class_exists('GFGS_License_Service')) {
         include ( GRAVITY_GOOGLESHEET_PRO_PATH . 'includes/class-gs-license-service.php' );
      }

      if (!class_exists('GSheet_Settings')) {
         include( GRAVITY_GOOGLESHEET_PRO_PATH . 'includes/class-gs-settings.php' );
      }
   }

   public function load_css_and_js_files() {
      add_action('admin_print_styles', array($this, 'add_css_files'));
      add_action('admin_print_scripts', array($this, 'add_js_files'));
   }

   /**
    * enqueue CSS files
    * @since 1.0
    */
   public function add_css_files() {
      if (is_admin() && ( isset($_GET['page']) && ( ( $_GET['page'] == 'gf_googlesheet' ) || ( $_GET['page'] == 'gf_edit_forms' ) ) )) {
         wp_enqueue_style('gfgs-connector-css', GRAVITY_GOOGLESHEET_PRO_URL . 'assets/css/gravity-form-style.css', GRAVITY_GOOGLESHEET_PRO_VERSION, true);
      }
   }

   public function add_js_files() {
      if (is_admin() && ( isset($_GET['page']) && (( $_GET['page'] == 'gf_googlesheet' ) || ( $_GET['page'] == 'gf_edit_forms' ) ) )) {
         wp_enqueue_script('gfgs-connector-js', GRAVITY_GOOGLESHEET_PRO_URL . 'assets/js/gfgs-connector.js', GRAVITY_GOOGLESHEET_PRO_VERSION, true);
      }
   }
   
   /**
    * Custom cron interval
    * @since 1.0
    */
   public function custom_cron_interval($interval)
   {
      $interval['gfgs_weekly'] = array('interval' => 604800, 'display' => __('weekly', 'gsheetconnector-gravityforms'));
      return $interval;
   }

   /**
    * called on upgrade. 
    * checks the current version and applies the necessary upgrades from that version onwards
    * @since 1.0
    */
   public function run_on_upgrade() {
      $plugin_options = get_site_option('gfgs_info');
      
      // update the version value
      $google_sheet_info = array(
         'version' => GRAVITY_GOOGLESHEET_PRO_ROOT,
         'db_version' => GRAVITY_GOOGLESHEET_PRO_DB_VERSION
      );
      update_site_option('gfgs_info', $google_sheet_info);
   }

   /**
    * Called on activation.
    * Creates the site_options (required for all the sites in a multi-site setup)
    * If the current version doesn't match the new version, runs the upgrade
    * @since 1.0
    */
   private function run_on_activation() {

      $plugin_options = get_site_option('gfgs_info');
      if (false === $plugin_options) {
         $google_sheet_info = array(
            'version' => GRAVITY_GOOGLESHEET_PRO_VERSION,
            'db_version' => GRAVITY_GOOGLESHEET_PRO_DB_VERSION
         );
         update_site_option('google_sheet_info', $google_sheet_info);
      } else if ( GRAVITY_GOOGLESHEET_PRO_DB_VERSION != $plugin_options['version']) {
         $this->run_on_upgrade();
      }
      
      if ( ! wp_next_scheduled('gfgs_check_expiration') ) {
         wp_schedule_event(time(), 'gfgs_weekly', 'gfgs_check_expiration');
      }
   }

   private function run_for_site() {

      if (!get_option('gfgs_access_code')) {
         update_option('gfgs_access_code', '');
      }
      if (!get_option('gfgs_verify')) {
         update_option('gfgs_verify', 'invalid');
      }
      if (!get_option('gfgs_token')) {
         update_option('gfgs_token', '');
      }
      if (!get_option('gfgs_feeds')) {
         update_option('gfgs_feeds', '');
      }
      if (!get_option('gfgs_sheetId')) {
         update_option('gfgs_sheetId', '');
      }
      if (!get_option('gfgs_page_roles_setting')) {
         update_option("gfgs_page_roles_setting", array());
      }
      if (!get_option('gfgs_tab_roles_setting')) {
         update_option("gfgs_tab_roles_setting", array());
      }
   }
   
   /**
    * Called on uninstall - deletes site specific options
    *
    * @since 1.5
    */
   private static function delete_for_site() {

      // deactivate the license
      $license = trim( get_option('gfgs_license_key') );

      // data to send in our API request
      $api_params = array(
          'edd_action' => 'deactivate_license',
          'license' => $license,
          'item_name' => urlencode(GRAVITY_GOOGLESHEET_PRO_PRODUCT_NAME), // the name of our product in EDD
          'url' => home_url()
      );

      // Call the custom API.
      $response = wp_remote_post( GRAVITY_GOOGLESHEET_PRO_PRODUCT_NAME, array('timeout' => 15, 'body' => $api_params ) );

      delete_option('gfgs_license_status');
      delete_option('gfgs_license_key');
      delete_option('gfgs_sheetId');
      delete_option('gfgs_feeds');
      delete_option('gfgs_access_code');
      delete_option('gfgs_verify');
      delete_option('gfgs_token');
      delete_option('gfgs_feeds');
      delete_option('gfgs_sheetId');
      delete_option('gfgs_page_roles_setting');
      delete_option('gfgs_tab_roles_setting');
      delete_option('gfgs-lexpiration');
      delete_option('gfgs_renew_notice_interval');

      delete_post_meta_by_key('gravity_form_fields');
      delete_post_meta_by_key('gfgs_settings');
   }
   
   /**
    * Called on uninstall - deletes site_options
    * @since 1.0
    */
   private static function run_on_uninstall() {
      if (!defined('ABSPATH') && !defined('WP_UNINSTALL_PLUGIN'))
         exit();

      delete_site_option('gfgs_info');
   }
   
   /**
    * Plugin Update notifier
    */
   public function gfgs_plugin_updater() {
      if (!class_exists('GFGS_Plugin_Updater')) {
         include( GRAVITY_GOOGLESHEET_PRO_PATH . "includes/class-gs-plugin-updater.php" );

         // setup the plugin updater
         $edd_updater = new GFGS_Plugin_Updater(GRAVITY_GOOGLESHEET_PRO_STORE_URL, __FILE__, array(
             'version' => GRAVITY_GOOGLESHEET_PRO_VERSION, // current version number
             'license' => trim(get_option('gfgs_license_key')), // license key (used get_option above to retrieve from DB)
             'item_name' => GRAVITY_GOOGLESHEET_PRO_PRODUCT_NAME, // name of this plugin
             'author' => 'WesternDeal' // author of this plugin
                 )
         );
      }
   }

   /**
    * Add custom link for the plugin beside activate/deactivate links
    * @param array $links Array of links to display below our plugin listing.
    * @return array Amended array of links.    * 
    * @since 1.5
    */
   public function grvt_connector_pro_plugin_action_links($links) {
      // We shouldn't encourage editing our plugin directly.
      unset($links['edit']);

      // Add our custom links to the returned array value.
      return array_merge(array(
          '<a href="' . admin_url('admin.php?page=gf_googlesheet') . '">' . __('Settings', 'gsheetconnector-gravityforms') . '</a>'
              ), $links);
   }

    /**
    * Add widget to the dashboard
    * @since 1.0
    */
   public function add_grforms_gs_connector_summary_widget() {
      wp_add_dashboard_widget('gravity_dashboard', __('GSheetConnector Gravity Forms', 'gsheetconnector-gravityforms')."<img style='width:60px' src='".GRAVITY_GOOGLESHEET_PRO_URL."assets/image/GravityGSheet-Connector-logo.png'>", array($this, 'grforms_gs_connector_summary_dashboard'));
   }

   /**
    * Display widget contents
    * @since 1.0
    */
   public function grforms_gs_connector_summary_dashboard() {
      include_once( GRAVITY_GOOGLESHEET_PRO_ROOT . '/includes/pages/gravity-dashboard-widget.php' );
   }

}


add_action( 'gform_loaded', 'load_gsheetconnector_gforms', 60 );
function load_gsheetconnector_gforms() {
	
	if (  method_exists( 'GFForms', 'include_feed_addon_framework' ) && method_exists( 'GFForms', 'include_addon_framework' ) ) {
		
		// if ( is_plugin_active( 'gsheetconnector-gravity-forms/gsheetconnector-gravityforms.php' ) ) {
		// 	add_action( 'admin_notices', 'gsheetconnector_gravityforms_free_version_notice' ); 
			
		// 	require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
		// 	deactivate_plugins('gsheetconnector-gravity-forms/gsheetconnector-gravityforms.php');
		// } 
		
		// else {
			
			/*
			 * include utility classes
			 */
			
			
			if (!class_exists('GFGS_Connector_Service')) {
			   include( GRAVITY_GOOGLESHEET_PRO_ROOT . '/includes/class-gravityform-gs-service.php' );
			}

			if (!class_exists('Gforms_Gsheet_Connector')) {
			   // include( GRAVITY_GOOGLESHEET_PRO_PATH . 'class-gf-gsheetgravityforms.php' );
			   // GFAddOn::register('Gforms_Gsheet_Connector');
			}

			if (!class_exists('Gforms_Gsheet_Connector_Feeds')) {
			   include( GRAVITY_GOOGLESHEET_PRO_PATH . 'gf-gs-feed-addon.php' );
			   GFAddOn::register('Gforms_Gsheet_Connector_Feeds');
			   Gforms_Gsheet_Connector_Feeds::get_instance();
			}
			
			//Include Library Files
			require_once GRAVITY_GOOGLESHEET_PRO_ROOT . '/lib/vendor/autoload.php';

			include_once( GRAVITY_GOOGLESHEET_PRO_ROOT . '/lib/google-sheets.php');

			include_once( GRAVITY_GOOGLESHEET_PRO_ROOT . '/gsheet-operations.php');
			
			$init = new Gforms_Gsheet_Connector_Init();
			$init->gfgs_plugin_updater();
		//}
	}
	// else {
	// 	add_action( 'admin_notices', 'gsheetconnector_gravityforms_required_notice' );
	// }
}


//$init = new Gforms_Gsheet_Connector_Init();

//add_action('admin_init', 'gsheetconnector_gravityforms_required_plugin_check');
// function gsheetconnector_gravityforms_required_plugin_check() {
// 	if ( ! method_exists( 'GFForms', 'include_feed_addon_framework' ) || ! method_exists( 'GFForms', 'include_addon_framework' ) ) {
// 		add_action( 'admin_notices', 'gsheetconnector_gravityforms_required_notice' );
// 	}
	
// 	$upgraded = get_site_option( "gfgs_upgraded_40_reconnect", false );
// 	if( ! $upgraded || $upgraded != 1 ) {
// 		// add_action( 'admin_notices', 'gsheetconnector_reconnect_notice' );
// 	}
	
// 	// add_action( 'admin_notices', 'gsheetconnector_reconnect_notice' );
// }

// function gsheetconnector_gravityforms_required_notice() {
// 	$class = 'notice notice-error';
// 	$message = esc_html__( "GravityForms plugin need to be active to send entry to google sheet.", "gsheetconnector-gravityforms" );	 
// 	printf( '<div class="%1$s"><p>%2$s</p></div>', esc_attr( $class ), esc_html( $message ) ); 
// }
function gsheetconnector_gravityforms_free_version_notice() {
	$class = 'notice notice-error is-dismissible';
	$message = esc_html__( "Deactivated GSheetConnector Gravity Forms (Free Version) to activate GSheetConnector Gravity Forms Pro.", "gsheetconnector-gravityforms" );	 
	printf( '<div class="%1$s"><p>%2$s</p></div>', esc_attr( $class ), esc_html( $message ) ); 
}

function gsheetconnector_reconnect_notice() {	
	$class = 'notice notice-error';
	$message = esc_html__( "Reconnect your google account to access new features with google sheet..", "gsheetconnector-gravityforms" );	 
	printf( '<div class="%1$s"><p>%2$s</p></div>', esc_attr( $class ), esc_html( $message ) ); 
}

//add_filter('plugin_action_links_' . GRAVITY_GOOGLESHEET_PRO_BASE_NAME, array($init, 'grvt_connector_pro_plugin_action_links'));