<?php

/**
 * Service class for Google Sheet Connector
 * @since 1.0
 */
if (!defined('ABSPATH')) {
   exit; // Exit if accessed directly
}

/**
 * Gs_Connector_Service Class
 *
 * @since 1.0
 */
class GFGS_Connector_Service {

   protected $_short_title = 'Googlesheet';

   /**
    *  Set things up.
    *  @since 1.0
    */
   public function __construct() {


      add_action('wp_ajax_verify_code_integation', array($this, 'verify_code_integation'));
      add_action('wp_ajax_deactivate_gs_code_integation', array($this, 'deactivate_gs_code_integation'));
      add_action('wp_ajax_gfgs_clear_log', array($this, 'gfgs_clear_logs'));
      add_action( 'wp_ajax_update_license_expiration', array( $this, 'update_license_expiration' ) );
      add_action( 'wp_ajax_hide_renew_box', array( $this, 'hide_renew_box' ) );
      add_action('admin_notices', array( $this, 'gsgf_admin_validation' ) );
      add_action('gfgs_check_expiration', array( $this, 'check_expiration' ) );
   }

   /**
    * AJAX function - verify_code_integation
    * @since 1.0
    */
   public function verify_code_integation() {
      // nonce check
      check_ajax_referer('gf-ajax-nonce', 'security');

      /* sanitize incoming data */
      $Code = sanitize_text_field($_POST["code"]);
      
      update_option('gfgs_access_code', $Code);

      if (get_option('gfgs_access_code') != '') {
         include_once( GRAVITY_GOOGLESHEET_PRO_ROOT . '/lib/google-sheets.php');
         GFGSC_googlesheet::preauth(get_option('gfgs_access_code'));
         //update_option('gfgs_verify', 'valid');//resolved - google sheet permission issues 
		 
		 
		 $google_sheet = new GFGSC_googlesheet();
		 $google_sheet->auth();				 
		 $email = $google_sheet->gsheet_get_google_account_email();
		 update_option('gfgs_email_account', $email);
		 
		 
		 update_option('gfgs_upgraded_40_reconnect', 1);
      //resolved - google sheet permission issues -START
      if(get_option('gfgs_verify') == "valid"){
          do_action("sync_with_google_account"); 
      }
      //resolved - google sheet permission issues -END
      
         // After validation fetch sheetname and tabs from the user account 
         wp_send_json_success();
      } else {
         update_option('gfgs_verify', 'invalid');
         wp_send_json_error();
      }
   }


   /**
    * AJAX function - verify_code_integation
    * @since 1.0
    */
   public static function verify_code_integation_new($Code = "") {

      update_option('gfgs_access_code', $Code);

      if (get_option('gfgs_access_code') != '') {
         include_once( GRAVITY_GOOGLESHEET_PRO_ROOT . '/lib/google-sheets.php');
         GFGSC_googlesheet::preauth(get_option('gfgs_access_code'));
         //update_option('gfgs_verify', 'valid');//resolved - google sheet permission issues 
       
       
       $google_sheet = new GFGSC_googlesheet();
       $google_sheet->auth();           
       $email = $google_sheet->gsheet_get_google_account_email();
       update_option('gfgs_email_account', $email);
       
       
       update_option('gfgs_upgraded_40_reconnect', 1);
      //resolved - google sheet permission issues -START
      // if(get_option('gfgs_verify') == "valid"){
      //     do_action("sync_with_google_account"); 
      // }
      //resolved - google sheet permission issues -END
      
         // After validation fetch sheetname and tabs from the user account 
         
      } else {
         update_option('gfgs_verify', 'invalid');
      }
   }


   /**
    * AJAX function - deactivate activation
    * @since 1.0
    */
   public function deactivate_gs_code_integation() {
      // nonce check
      check_ajax_referer('gf-ajax-nonce', 'security');

      if (get_option('gfgs_token') !== '') {
         delete_option('gfgs_feeds');
         delete_option('gfgs_sheetId');
         delete_option('gfgs_token');
         delete_option('gfgs_access_code');
         delete_option('gfgs_verify');
         delete_option('gfgs_email_account');
         wp_send_json_success();
      } else {
         wp_send_json_error();
      }
   }

   /**
    * AJAX function - clear log file
    * @since 1.0
    */
   public function gfgs_clear_logs() {

      // nonce check
      check_ajax_referer('gf-ajax-nonce', 'security');

      $handle = fopen(GRAVITY_GOOGLESHEET_PRO_PATH . 'logs/log.txt', 'w');
      fclose($handle);

      wp_send_json_success();
   }
   
   /**
    * AJAX function - update license expiration
    * @since 1.0
    */
   public function update_license_expiration() {
      // check nonce
      check_ajax_referer( 'gfgs_ajax_nonce', 'security' );
      
      $license_key = get_option('gfgs_license_key');
      
      // data to send in our API request
      $api_params = array(
         'edd_action' => 'activate_license',
         'license' => $license_key,
         'item_name' => urlencode( GRAVITY_GOOGLESHEET_PRO_PRODUCT_NAME ), // the name of our product in EDD
         'url' => home_url()
      );

      // Call the custom API.
      $response = wp_remote_post( GRAVITY_GOOGLESHEET_PRO_STORE_URL, array('timeout' => 15, 'body' => $api_params ) );

      // make sure the response came back okay
      if (is_wp_error($response)) {
         GravityForms_Gs_Connector_Utility::instance()->logger($response);
         return false;
      }

      // decode the license data
      $license_data = json_decode(wp_remote_retrieve_body($response));
      
      if( $license_data->license === "valid" ) {
         update_option( "gfgs-lexpiration", $license_data->expires );
         delete_option('gfgs_renew_notice_interval');
         wp_send_json_success();
      }
      wp_send_json_error();
   }
   
   public function hide_renew_box() {
      // check nonce
      check_ajax_referer( 'gfgs_ajax_nonce', 'security' );
      $time_interval = date( 'Y-m-d H:i:s', strtotime( '+7 day' ) );
      update_option( 'gfgs_renew_notice_interval', $time_interval );
      wp_send_json_success();
   }
   
   public function gsgf_admin_validation() {
      $expiration = $this->check_license_expiration();
      
      if( ! $expiration ) {
         return;
      }
      
      $interval = get_option('gfgs_renew_notice_interval');
      $interval_timestamp = "";
      $current_date = date("Y-m-d H:i:s");
      $current_timestamp = strtotime( $current_date );
      if ( ! empty( $interval ) ) {
         $interval_timestamp = strtotime( $interval );          
      }
      if ( $expiration && ( ( empty( $interval ) ) || ( $current_timestamp > $interval_timestamp ) ) ) {
         $ajax_nonce    = wp_create_nonce( "gfgs_ajax_nonce" );
         $renew_text    = '<div>';
         $renew_text   .= '<span>Hey, your <b>GSheetConnector GravityForms Pro</b> license has Expired.';
         $renew_text   .= '<ul class="renew-list">';
         $renew_text   .= '<li><a href="https://www.gsheetconnector.com/your-account" target="_blank">Renew Now</a></li>';
         $renew_text   .= '<li><a href="javascript:void(0);" class="update-renewal">Already Renewed</a></li>';
         $renew_text   .= '<li><a href="javascript:void(0);" class="hide-renew-box">Dismiss</a></li>';
         $renew_text   .= '</ul>';
         $renew_text   .= '<input type="hidden" name="gsgf_ajax_nonce" id="gsgf_ajax_nonce" value="' . $ajax_nonce . '" /></div>';        
         
         $plugin_error = GravityForms_Gs_Connector_Utility::instance()->admin_notice(array(
          'type' => 'renew',
          'message' => $renew_text
         ) );
         echo $plugin_error;
      }
   }
   
   public function check_license_expiration() {
      $expiration = get_option( 'gfgs-lexpiration');
      if ( ! empty( $expiration ) && $expiration !== "lifetime" ) {
        $current_date = date("Y-m-d H:i:s");
        $current_timestamp = strtotime( $current_date );
        $expiration_timestamp = strtotime( $expiration );
        if( $current_timestamp > $expiration_timestamp ) {
           return true;
        }
      } 
      return false;
   }
   
   public function check_expiration() {
      
      $license_key = get_option('gfgs_license_key');
      
      // data to send in our API request
      $api_params = array(
         'edd_action' => 'activate_license',
         'license' => $license_key,
         'item_name' => urlencode( GRAVITY_GOOGLESHEET_PRO_PRODUCT_NAME ), // the name of our product in EDD
         'url' => home_url()
      );

      // Call the custom API.
      $response = wp_remote_post( GRAVITY_GOOGLESHEET_PRO_STORE_URL, array('timeout' => 15, 'body' => $api_params ) );

      // make sure the response came back okay
      if (is_wp_error($response)) {
         GravityForms_Gs_Connector_Utility::instance()->logger($response);
         return false;
      }

      // decode the license data
      $license_data = json_decode(wp_remote_retrieve_body($response));
      
      if( $license_data->license === "invalid" ) {
         update_option( "gfgs_license_status", "invalid" );
         wp_send_json_success();
      }
   }

   /**
    * Function - fetch contant form list that is connected with google sheet
    * @since 1.0
    */
   public function get_forms_connected_to_sheet() {
      global $wpdb;
      $query = $wpdb->get_results('SELECT * FROM `wp_gf_form` AS gf JOIN `wp_postmeta` AS pm ON gf.id=pm.post_id WHERE pm.meta_key = "gfgs_settings"');
      return $query;
   }

}

$GFGS_Connector_Service = new GFGS_Connector_Service();
