<?php
/**
 * Settings class for Google Sheet settings
 * @since 1.1
 */
// Exit if accessed directly
if (!defined('ABSPATH')) {
   exit;
}

/**
 * GS_License_Settings Class
 * @since 1.1
 */
class GSheet_Settings {

   /**
    * @var string group name
    */
   protected $gs_group_name = 'gfgs-settings';

   /**
    * @var string roles that can access Google Sheet page
    */
   protected $gs_page_roles_setting_option_name = 'gfgs_page_roles_setting';

   /**
    * @var string roles that can access Google Sheet tab at contact form settings
    */
   protected $gs_tab_roles_setting_option_name = 'gfgs_tab_roles_setting';

   public function __construct() {
      add_action('admin_init', array($this, 'init_settings'));
   }

   // White list our options using the Settings API
   public function init_settings() {
      register_setting('gfgs-settings', $this->gs_page_roles_setting_option_name, array($this, 'validate_gs_access_roles'));
      register_setting('gfgs-settings', $this->gs_tab_roles_setting_option_name, array($this, 'validate_gs_access_roles'));
   }

   public function validate_gs_access_roles($selected_roles) {

      $roles = array();
      $system_roles = GravityForms_Gs_Connector_Utility::instance()->get_system_roles();

      if ( $selected_roles && count( $selected_roles ) > 0 ) {
         foreach ( $system_roles as $role => $display_name ) {
            if ( is_array( $selected_roles ) && in_array( esc_attr( $role ), $selected_roles ) ) { // preselect specified role
               $roles[$role] = $display_name;
            }
         }
      }
      return $roles;
   }

   public function add_gs_setting_page() {
      $page_roles = get_option($this->gs_page_roles_setting_option_name);
      $tab_roles = get_option($this->gs_tab_roles_setting_option_name);
      ?>
      <form id="gs_settings_form" method="post" action="options.php">
         <?php
         settings_fields($this->gs_group_name); // adds nonce for current settings page
         ?>
         <div>
            <div class="gfgs-card">
               <div><label><?php echo __('Roles that can access Google Sheet Page', 'gsheetconnector-gravityforms'); ?></label></div>
               <?php
               GravityForms_Gs_Connector_Utility::instance()->gfgs_checkbox_roles_multi(
                       $this->gs_page_roles_setting_option_name
                       . '[]', $page_roles);
               ?>

               <br/>
               <div><label><?php echo __('Roles that can access Google Sheet Tab at GravityForms', 'gsheetconnector-gravityforms'); ?></label></div>
               <?php
               GravityForms_Gs_Connector_Utility::instance()->gfgs_checkbox_roles_multi(
                       $this->gs_tab_roles_setting_option_name . '[]', $tab_roles);
               ?>
               <br/>
               <div class="select-info">
                  <input type="submit" class="button button-primary button-large" name="gfgs_settings" value="<?php echo __("Save", "gsheetconnector-gravityforms"); ?>"/>
               </div>
            </div>
         </div>
      </form>
      <?php
   }

}

$gs_settings = new GSheet_Settings();
