<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       www.redefiningtheweb.com
 * @since      1.0.0
 *
 * @package    Rtwgftpdf_Gravity_Form_To_Pdf
 * @subpackage Rtwgftpdf_Gravity_Form_To_Pdf/admin
 */
/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Rtwgftpdf_Gravity_Form_To_Pdf
 * @subpackage Rtwgftpdf_Gravity_Form_To_Pdf/admin
 * @author     RedefiningTheWeb <developer@redefiningtheweb.com>
 */

class Rtwgftpdf_Gravity_Form_To_Pdf_Admin {
	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $rtwgftpdf_plugin_name    The ID of this plugin.
	 */

	private $rtwgftpdf_plugin_name;
	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $rtwgftpdf_version    The current version of this plugin.
	 */

	private $rtwgftpdf_version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $rtwgftpdf_plugin_name       The name of this plugin.
	 * @param      string    $rtwgftpdf_version    The version of this plugin.
	 */

	public function __construct( $rtwgftpdf_plugin_name, $rtwgftpdf_version ) {
		$this->rtwgftpdf_plugin_name = $rtwgftpdf_plugin_name;
		$this->rtwgftpdf_version = $rtwgftpdf_version;
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */

	public function rtwgftpdf_enqueue_styles() {
		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the rtwgftpdf_run() function
		 * defined in Gravity_Form_To_Pdf_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Gravity_Form_To_Pdf_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( 'wp-color-picker' ); 
        // Include our custom jQuery file with WordPress Color Picker dependency
		wp_enqueue_style( $this->rtwgftpdf_plugin_name, plugin_dir_url( __FILE__ ) . 'css/rtwgftpdf-gravity-form-to-pdf-admin.css', array(), $this->rtwgftpdf_version, 'all' );
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */

	public function rtwgftpdf_enqueue_scripts() {
		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the rtwgftpdf_run() function
		 * defined in Gravity_Form_To_Pdf_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Gravity_Form_To_Pdf_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->rtwgftpdf_plugin_name, plugins_url( 'js/rtwgftpdf-gravity-form-to-pdf-admin.js', __FILE__ ), array( 'wp-color-picker' ), $this->rtwgftpdf_version, false );

		wp_enqueue_script( 'jquery.validate', RTWGFTPDF_URL . 'assets/jquery.validate/jquery.validate.js', array( 'jquery' ), $this->rtwgftpdf_version, false );

		$rtwgftpdf_screen = get_current_screen();

		if($rtwgftpdf_screen->id == 'toplevel_page_rtwgftpdf')
		{
			wp_enqueue_script('media-upload');

			wp_enqueue_script('thickbox');

			wp_enqueue_style('thickbox');
		}

		if ( RGForms::is_gravity_page()) {
			if( !isset($_GET['subview']) && $_GET['page'] == 'gf_edit_forms' && isset($_GET['id']) )
			{
				wp_enqueue_script( 'rtwgftpdf_gravity_script', plugin_dir_url( __FILE__ ) . 'js/rtwgftpdf-admin-gravity-form.js', array( 'jquery' ), $this->rtwgftpdf_version, false );
			}
		}

		$rtwgftpdf_ajax_nonce = wp_create_nonce( "rtwgftpdf-ajax-seurity" );
		wp_localize_script( $this->rtwgftpdf_plugin_name, 'rtwgftpdf_ajax', array( 'ajax_url' => esc_url(admin_url('admin-ajax.php')),
			'rtwgftpdf_nonce' => $rtwgftpdf_ajax_nonce));
		wp_enqueue_script( $this->rtwgftpdf_plugin_name );

		// wp_enqueue_script( "blockUI", plugins_url( 'woocommerce/assets/js/jquery-blockui/jquery.blockUI.min.js' ), array( 'jquery' ), $this->rtwgftpdf_version, false );
	}

	/**
	 * Function to add Menu Page.
	 *
	 * @since    1.0.0
	 */

	public function rtwgftpdf_add_menu_page(){
		add_menu_page( esc_html('Gravity Form to PDF'), esc_html('Gravity Form to PDF'), 'manage_options', 'rtwgftpdf',array($this,'rtwgftpdf_add_menu_page_html'));
	}

	/**
	 * Function to add Menu Page html.
	 *
	 * @since    1.0.0
	 */

	public function rtwgftpdf_add_menu_page_html()
	{
		error_reporting(0);
		include_once(RTWGFTPDF_DIR.'admin/partials/rtwgftpdf-gravity-form-to-pdf-admin-display.php');
	}

	/**
	 * Function to register admin settings.
	 *
	 * @since    1.0.0
	 */

	public function rtwgftpdf_save_admin_setting()
	{
		register_setting('rtwgftpdf_header_setting','rtwgftpdf_header_setting_opt');

		register_setting('rtwgftpdf_footer_setting','rtwgftpdf_footer_setting_opt');

		register_setting('rtwgftpdf_basic_setting','rtwgftpdf_basic_setting_opt');

		register_setting('rtwgftpdf_css_setting','rtwgftpdf_css_setting_opt');

		register_setting('rtwgftpdf_watermark_setting','rtwgftpdf_watermark_setting_opt');

		register_setting('rtwgftpdf_google_spreadsheet','rtwgftpdf_google_spreadsheet_opt');

		$rtwgftpdf_forms_count = RGFormsModel::get_forms( null, 'title' );
		foreach ($rtwgftpdf_forms_count as $key => $value) {
			register_setting('rtwgftpdf_editor_format_'.$value->id, 'rtwgftpdf_editor_format_opt_'.$value->id );
		}
	}

	/**
	 * Function to start clear header settings.
	 *
	 * @since    1.0.0
	 */

	function rtwgftpdf_start_ob() 
	{
		if(isset($_POST['action']) && $_POST['action'] == 'bulk_pdf')
		{
			ob_start();
		}
		elseif(isset($_POST['action']) && $_POST['action'] == 'bulk_csv')
		{
			ob_start();
		}
	}

	/**
	 * Function to Add Submenu in Gravity Forms Setting.
	 *
	 * @since    1.0.0
	 */

	function rtwgftpdf_register_submenu_page($rtwgftpdf_tabs, $rtwgftpdf_form_id)
	{
		$rtwgftpdf_basic_setting 	= get_option('rtwgftpdf_basic_setting_opt',array());
		$rtwgft_selected_forms = isset($rtwgftpdf_basic_setting['rtwwdpd_selected_forms'])? $rtwgftpdf_basic_setting['rtwwdpd_selected_forms'] : array();

		if(isset($rtwgftpdf_basic_setting['rtwwdpd_selected_forms']))
		{
			if(in_array($rtwgftpdf_form_id, $rtwgft_selected_forms))
			{
				$rtwgftpdf_tabs[] = [
					'name'  => 'rtwgftpdf_',
					'label' => esc_html__('PDF Format', 'rtwgftpdf-gravity-form-to-pdf'),
				];
			}
		}
		return $rtwgftpdf_tabs;
	}

	/**
	 * Function to Add Submenu Page html.
	 *
	 * @since    1.0.0
	 */

	function rtwgftpdf_setting_display()
	{
		$rtwgftpdf_content = '';
		$rtwgftpdf_form_id = $_GET['id'];
		$rtwgftpdf_forms = RGFormsModel::get_form_meta( $rtwgftpdf_form_id );
		$rtwgftpdf_form_field = $rtwgftpdf_forms['fields'];
		$rtwgftpdf_form_fields = array();

		foreach($rtwgftpdf_form_field as $rtwpftpdf_key => $rtwgftpdf_val)
		{	
			if($rtwgftpdf_val['type'] != 'section' && $rtwgftpdf_val['type'] != 'html' && $rtwgftpdf_val['type'] != 'hidden' && $rtwgftpdf_val['type'] != 'CAPTCHA')
			{
				if($rtwgftpdf_val['type'] != 'page')
				{
					array_push($rtwgftpdf_form_fields, $rtwgftpdf_val['label']);
				}
				else
				{
					array_push($rtwgftpdf_form_fields, 'pagebreak');
				}
			}
		}

		$rtwgftpdf_html = '';
		$rtwgftpdf_page_name = 0;
		if(isset($forms['pagination']['pages'][0]))
		{
			$rtwgftpdf_html .='<p>{' . esc_html($forms['pagination']['pages'][$rtwgftpdf_page_name]) .'}</p>';
			$rtwgftpdf_page_name = 1;
		}

		foreach ($rtwgftpdf_form_fields as $rtwgftpdf_key => $rtwgftpdf_val) 
		{
			if($rtwgftpdf_val == 'pagebreak')
			{
				$rtwgftpdf_html .= '<p>{pagebreak}</p>';
				if(isset($forms['pagination']['pages'][0]) && $forms['pagination']['pages'][0] != '')
				{
					$rtwgftpdf_html .= '<p>{' . esc_html($rtwgftpdf_forms['pagination']['pages'][$rtwgftpdf_page_name]) .'}</p>';
					$rtwgftpdf_page_name = $rtwgftpdf_page_name + 1;
				}
			}
			else
			{
				$rtwgftpdf_html .= '<p> [' . esc_html($rtwgftpdf_val) .']' .'</p>';
			}
		}

		GFFormSettings::page_header();
		?>
		<form enctype="multipart/form-data" action="options.php" method="post">
			<?php settings_fields('rtwgftpdf_editor_format_'.$rtwgftpdf_form_id);?>
			<?php $rtwgftpdf_editor_format = get_option('rtwgftpdf_editor_format_opt_'.$rtwgftpdf_form_id);
			$rtwgftpdf_temp_select 		= isset( $rtwgftpdf_editor_format['rtw_template_select'] ) ? $rtwgftpdf_editor_format['rtw_template_select'] : '';
			$rtwgftpdf_bck_color = isset( $rtwgftpdf_editor_format['rtw_bck_color'] ) ? $rtwgftpdf_editor_format['rtw_bck_color'] : '';
			
			$rtwgftpdf_temp_one = RTWGFTPDF_URL.'/icons/template1.jpg'; 
			$rtwgftpdf_temp_two = RTWGFTPDF_URL.'/icons/template2.jpg'; 
			$rtwgftpdf_temp_three = RTWGFTPDF_URL.'/icons/template3.jpg'; 
			?>
			<table class="wp-list-table form-table">
				<tbody>
					<thead>
						<h1>
							<i class="fa fa-file-pdf-o"></i>
							<?php esc_html_e('Gravity Form to PDF', 'rtwgftpdf-gravity-form-to-pdf'); ?>
						</h1>
					</thead>
					<tr>
						<td>
							<label><b><?php esc_html_e('Choose Template : ', 'rtwgftpdf-gravity-form-to-pdf'); ?></b></label>
							<select id="rtw_select_temp" name="rtwgftpdf_editor_format_opt_<?php echo esc_attr($rtwgftpdf_form_id) ?>[rtw_template_select]">
								<option value="rtw_none" <?php selected( $rtwgftpdf_temp_select, 'rtw_none'); ?>> 
									<?php esc_html_e('Custom', 'rtwgftpdf-gravity-form-to-pdf'); ?></option>
									<option value="temp_one" <?php selected( $rtwgftpdf_temp_select, 'temp_one'); ?>> 
										<?php esc_html_e('Template 1', 'rtwgftpdf-gravity-form-to-pdf'); ?> 
									</option>
									<option value="temp_two" <?php selected( $rtwgftpdf_temp_select, 'temp_two'); ?>> 
										<?php esc_html_e('Template 2', 'rtwgftpdf-gravity-form-to-pdf'); ?> 
									</option>
									<option value="temp_three" <?php selected( $rtwgftpdf_temp_select, 'temp_three'); ?>> 
										<?php esc_html_e('Template 3', 'rtwgftpdf-gravity-form-to-pdf'); ?> 
									</option>
								</select>
								<div class="rtw_cel_color">
									<img height="150" width="130" id="rtw_temp_one" src="<?php echo esc_url( $rtwgftpdf_temp_one); ?>">
									<img height="150" width="130" id="rtw_temp_two" src="<?php echo esc_url( $rtwgftpdf_temp_two); ?>">
									<img height="150" width="130" id="rtw_temp_three" src="<?php echo esc_url( $rtwgftpdf_temp_three); ?>">
								</div>
							</td>
						</tr>
						<tr  class="rtw_cel_color">
							<td>
								<label><b><?php esc_html_e('Select Field Background color :', 'rtwgftpdf-gravity-form-to-pdf'); ?></b></label>
								<div class="wp-picker-container">
									<input class="color-field" type="text" name="rtwgftpdf_editor_format_opt_<?php echo esc_attr($rtwgftpdf_form_id) ?>[rtw_bck_color]" value="<?php echo esc_attr($rtwgftpdf_bck_color); ?>" />
								</div>
							</td>
						</tr>
						<tr class="rtw_wp_editor">
							<td>
								<?php
								esc_html_e('Use ','rtwgftpdf-gravity-form-to-pdf');
								foreach ($rtwgftpdf_form_fields as $rtwgftpdf_key => $rtwgftpdf_value) 
								{
									if($rtwgftpdf_value == 'pagebreak')
									{
										printf( ' {%s} ,', esc_html( $rtwgftpdf_value ) );
									}
									else
									{
										printf( ' [%s] ,', esc_html( $rtwgftpdf_value ) );
									}
								}
								esc_html_e('for field\'s value', 'rtwgftpdf-gravity-form-to-pdf');
								?>
							</td>
						</tr>
						<?php 
						if(isset($rtwgftpdf_forms['pagination']['pages']) && !empty($rtwgftpdf_forms['pagination']['pages']))
						{ 
							?>
							<tr class="rtw_wp_editor">
								<td>
									<?php 
									esc_html_e('And ', 'rtwgftpdf-gravity-form-to-pdf');
									foreach ($rtwgftpdf_forms['pagination']['pages'] as $rtwgftpdf_key => $rtwgftpdf_value) 
									{
										printf( ' {%s} ,', esc_html( $rtwgftpdf_value ) );
									}
									esc_html_e('for page names.','rtwgftpdf-gravity-form-to-pdf');
									?>
								</td>
							</tr>
							<?php 
						}
						?>
					<tr class="rtw_wp_editor">
						<td>
							<?php
							if( isset( $rtwgftpdf_editor_format['editor'][$rtwgftpdf_form_id] ) && $rtwgftpdf_editor_format['editor'][$rtwgftpdf_form_id] != '' )
							{	
								$rtwgftpdf_content = isset( $rtwgftpdf_editor_format['editor'][$rtwgftpdf_form_id] ) ? $rtwgftpdf_editor_format['editor'][$rtwgftpdf_form_id] : '';
							}
							else
							{
								$rtwgftpdf_content = $rtwgftpdf_html;
							}

							$rtwgftpdf_setting = array(
								'wpautop' => false,
								'media_buttons' => true,
								'textarea_name' => 'rtwgftpdf_editor_format_opt_'.$rtwgftpdf_form_id.'[editor]['.$rtwgftpdf_form_id.']',
								'textarea_rows' => 12
							);

							wp_editor( stripcslashes($rtwgftpdf_content), 'rtwgftpdfeditor', $rtwgftpdf_setting );
							?>
						</td>
					</tr>
				</tbody>
			</table>
			<div class="rtw-popup-wrapper">
				<div class="rtw-popup-content">
					<img class="rtw_temp_one" height="500" width="300" src="<?php echo esc_url( $rtwgftpdf_temp_one); ?>">
					<span class="rtw-popup-close-popup">X</span>
				</div>
			</div>
			<div class="rtw-popup-wrapper2">
				<div class="rtw-popup-content2">
					<img class="rtw_temp_two" height="500" width="300" src="<?php echo esc_url( $rtwgftpdf_temp_two); ?>">
					<span class="rtw-popup-close-popup2">X</span>
				</div>
			</div>
			<div class="rtw-popup-wrapper3">
				<div class="rtw-popup-content3">
					<img class="rtw_temp_three" height="500" width="300" src="<?php echo esc_url( $rtwgftpdf_temp_three); ?>">
					<span class="rtw-popup-close-popup3">X</span>
				</div>
			</div>
			<p class="submit">
				<input type="submit" id="rtwgftpdfeditor" name="rtwgftpdf_submit" value="<?php esc_attr_e('Save Format','rtwgftpdf-gravity-form-to-pdf');?>" class="button-primary"/>
				<input type="submit" id="rtw_preview_pdf" name="rtw_preview_pdf" data-html="<?php echo esc_attr($rtwgftpdf_content); ?>" value="<?php esc_attr_e('Preview PDF','rtwgftpdf-gravity-form-to-pdf');?>" class="button-primary"/>
			</p>
		</form>
		<?php
		GFFormSettings::page_footer();
	}

	/**
	 * Function to register settings for bulk PDF.
	 *
	 * @since    1.0.0
	 */

	function rtwgftpdf_entry_list_bulk_actions( $rtwgftpdf_display)
	{
		$rtwgftpdf_display['bulk_pdf'] = esc_html__( 'Generate Bulk PDF','rtwgftpdf-gravity-form-to-pdf');
		$rtwgftpdf_display['bulk_excel'] = esc_html__('Create Excel','rtwgftpdf-gravity-form-to-pdf');
		$rtwgftpdf_display['bulk_csv'] = esc_html__('Create CSV','rtwgftpdf-gravity-form-to-pdf');
		return $rtwgftpdf_display;
	}

	/**
	 * Function to register settings for creating pdf from entries page.
	 *
	 * @since    1.0.0
	 */

	function rtwgftpdf_entries( $rtwgftpdf_form_id, $rtwgftpdf_field_id, $rtwgftpdf_value, $rtwgftpdf_entry, $rtwgftpdf_query_string )
	{
		$rtwgftpdf_basic_setting 	= get_option('rtwgftpdf_basic_setting_opt',array());
		$rtwgft_selected_forms = isset($rtwgftpdf_basic_setting['rtwwdpd_selected_forms'])? $rtwgftpdf_basic_setting['rtwwdpd_selected_forms'] : array();

		if(isset($rtwgftpdf_basic_setting['rtwwdpd_selected_forms']))
		{
			if(in_array($rtwgftpdf_form_id, $rtwgft_selected_forms))
			{
				$pdf_name = isset($rtwgftpdf_basic_setting['pdf_name']) ? $rtwgftpdf_basic_setting['pdf_name'] : 'rtwgftpdf_';

				$rtwgftpdf_file_path = RTWGFTPDF_CONTENT_URL . '/'. $pdf_name . esc_html($rtwgftpdf_entry['id']) . '.pdf';
				?>
				<span class="edit">
					<a href="<?php echo esc_url($rtwgftpdf_file_path); ?>" target="_blank">
						<?php esc_html_e('View PDF','rtwgftpdf-gravity-form-to-pdf')?>
					</a>
				</span>
				<?php
			}
		}
		else
		{
			$pdf_name = isset($rtwgftpdf_basic_setting['pdf_name']) ? $rtwgftpdf_basic_setting['pdf_name'] : 'rtwgftpdf_';

			$rtwgftpdf_file_path = RTWGFTPDF_CONTENT_URL . '/'. $pdf_name . esc_html($rtwgftpdf_entry['id']) . '.pdf';
			?>
			<span class="edit">
				<a href="<?php echo esc_url($rtwgftpdf_file_path); ?>" target="_blank">
					<?php esc_html_e('View PDF','rtwgftpdf-gravity-form-to-pdf')?>
				</a>
			</span>
			<?php
		}
	}

	/**
	 * Function to creating zip to bulk pdf.
	 *
	 * @since    1.0.0
	 */

	function rtwgftpdf_bulk_actions()
	{
		if(isset($_POST['action']))
		{
			$rtwgftpdf_basic_setting 	= get_option('rtwgftpdf_basic_setting_opt',array());

			$pdf_name = isset($rtwgftpdf_basic_setting['pdf_name']) ? $rtwgftpdf_basic_setting['pdf_name'] : 'rtwgftpdf_';

			$rtwgftpdf_bulk_action = $_POST['action'];
			///////// version 1.1.0 ///////////
			$rtwgftpdf_entries = isset( $_POST['entry'] ) ? $_POST['entry'] : '';

			$rtwgftpdf_form_id = 1;
			if(isset($_GET['id']))
			{
				$rtwgftpdf_form_id = $_GET['id'];
			}

			///////// version 1.1.0 ///////////
			if($rtwgftpdf_bulk_action === 'bulk_excel')
			{
				include(RTWGFTPDF_DIR.'/admin/partials/rtwgftpdf_excel/rtwgftpdf_excel.php');
			}
			////////////////////////////////////
			///////// version 1.2.0 ////////////
			elseif($rtwgftpdf_bulk_action === 'bulk_csv')
			{
				include(RTWGFTPDF_DIR.'/admin/partials/rtwgftpdf_csv/rtwgftpdf_csv.php');
			}
			/////////////////////////////////////
			elseif($rtwgftpdf_bulk_action === 'bulk_pdf')
			{
				$rtwgftpdf_output = ob_get_contents();
				ob_end_clean();
				if(class_exists('ZipArchive'))
				{
					$rtwgftpdf_zip = new ZipArchive;
					$rtwgftpdf_archive_file_name = RTWGFTPDF_CONTENT_DIR.'/rtwgftpdf_'.date("Y-m-d_G-i-s").".zip";
					if ($rtwgftpdf_zip->open($rtwgftpdf_archive_file_name, ZipArchive::CREATE) === TRUE)
					{
						$rtwgftpdf_lead_entries = array();
						if(isset($_POST['all_entries']) && $_POST['all_entries'] == 1)
						{
							$rtwgftpdf_lead_entries = GFAPI::get_entries($rtwgftpdf_form_id, array(), null, array( 'offset' => 0, 'page_size' => 'aa' ));

							foreach ($rtwgftpdf_lead_entries as $value) {
								$rtwgftpdf_file = RTWGFTPDF_CONTENT_DIR . '/'. $pdf_name  . esc_html($value['id']) . '.pdf';

								$rtwgftpdf_zip->addFile($rtwgftpdf_file, ('zip_rtwgf/'. $pdf_name. $value['id'] . '.pdf'));
							}
						}
						else{
							$rtwgftpdf_page_size = isset( $_POST['paged'] ) ? $_POST['paged'] : 0;
							$rtwgftpdf_lead_entries = GFAPI::get_entries( $rtwgftpdf_form_id, array(), null, array( 'offset' => 0, 'page_size' => 'aa' ) );

							foreach ($rtwgftpdf_lead_entries as $value) {
								$i = 0;
								if( in_array( $value['id'], $_POST['entry'] ) )
								{
									$rtwgftpdf_file = RTWGFTPDF_CONTENT_DIR . '/'. $pdf_name  . esc_html($value['id']) . '.pdf';

									$rtwgftpdf_zip->addFile($rtwgftpdf_file, ('zip_rtwgf/'. $pdf_name . $value['id'] . '.pdf'));
								}
							}
						}

						$rtwgftpdf_zip->close();
						header("Content-type: application/zip"); 
						header("Content-Disposition: attachment; filename=".$rtwgftpdf_archive_file_name);
						header("Content-length: " . filesize($rtwgftpdf_archive_file_name));
						header("Pragma: no-cache"); 
						header("Expires: 0"); 
						readfile($rtwgftpdf_archive_file_name);
						unlink($rtwgftpdf_archive_file_name);
					}
				}
			}
		}
	}

	/**
	 * Function for copy paste restriction setting for text fields.
	 *
	 * @since    1.0.0
	 */

	function rtwgftpdf_standard_settings( $rtwgftpdf_position , $rtwgftpdf_form_id) 
	{
		if( $rtwgftpdf_position  == 25 ) {
			?>
			<li class="encrypt_setting field_setting">
				<label for="rtwgftpdf_disable_copy_paste" class="section_label">
					<?php esc_html_e( 'Copy Paste Restriction', 'rtwgftpdf-gravity-form-to-pdf' ); ?>
					<?php gform_tooltip( 'rtwgftpdf_disable_copy_paste' ) ?>
				</label>
				<select id="rtwgftpdf_disable_copy_paste">
					<option value="">
						<?php esc_html_e( 'Select', 'rtwgftpdf-gravity-form-to-pdf' ); ?>
					</option>

					<option value="enable">
						<?php esc_html_e( 'Enable', 'rtwgftpdf-gravity-form-to-pdf' ); ?>
					</option>

					<option value="disable">
						<?php esc_html_e( 'Disable', 'rtwgftpdf-gravity-form-to-pdf' ); ?>
					</option>
				</select>
			</li>
			<?php
		}
	}

	/**
	 * Function to tooltip to the Generate Bulk PDF setting.
	 *
	 * @since    1.0.0
	 */

	function rtwgftpdf_encryption_tooltips( $rtwgftpdf_tooltips ) 
	{
		$rtwgftpdf_tooltips['rtwgftpdf_disable_copy_paste'] = "<h6>". esc_html__('Copy Paste Restriction','rtwgftpdf-gravity-form-to-pdf')."</h6>". esc_html__('Give Copy Paste restriction to this field by selecting enable.','rtwgftpdf-gravity-form-to-pdf');
		return $rtwgftpdf_tooltips;
	}

	function rtwgftpdf_verify_purchase_code( )
	{
		if (!wp_verify_nonce($_POST['security_check'], 'rtwgftpdf-ajax-seurity')){
			return;
		}
		$rtwgftpdf_purchase_code = sanitize_text_field( $_POST['purchase_code'] );

		$rtwgftpdf_site_url 	= get_site_url();
		$rtwgftpdf_admin_email 	= get_option('admin_email');
		$wp_get_current_user 	= get_user_meta( get_current_user_id() );
		
		if( is_array($wp_get_current_user) && !empty( $wp_get_current_user ) )
		{
			if( isset( $wp_get_current_user['first_name'][0]))
			{
				$rtwgftpdf_admin_name = $wp_get_current_user['first_name'][0] . ' '. $wp_get_current_user['last_name'][0];
			}
		}
		else{
			$wp_get_current_user 	= wp_get_current_user();
			$rtwgftpdf_admin_name 	= $wp_get_current_user->data->user_nicename;
		}
		$rtwgftpdf_plugin_name 	= 'WordPress Gravity Forms PDF, Excel & CSV';
		$plugin_text_domain 	= 'rtwgftpdf-gravity-form-to-pdf';
		$rtwgftpdf_site_domain 	= preg_replace( "(^https?://)", "", $rtwgftpdf_site_url );


		$rtwgftpdf_post_array = array( 
								'site_domain' 	=> $rtwgftpdf_site_domain,
								'admin_email' 	=> $rtwgftpdf_admin_email,
								'admin_name' 	=> $rtwgftpdf_admin_name,
								'plugin_name' 	=> $rtwgftpdf_plugin_name,
								'text_domain' 	=> $plugin_text_domain,
								'purchase_code' => $rtwgftpdf_purchase_code,
								'plugin_id' 	=> '23642805'
							);

		$args = array(
					'method' => 'POST',
					'headers'  => array(
						'Content-type: application/x-www-form-urlencoded'
					),
					'sslverify' => false,
					'body' => $rtwgftpdf_post_array
				);
				
		$response = wp_remote_post( 'https://demo.redefiningtheweb.com/license-verification/license-verification.php', $args );

		$response_body = json_decode( $response['body'] );
		
		$response_status = $response_body->result;
		$response_message = $response_body->message;

		if( $response_status ){
			$rtwgftpdf_update_array = array( 'purchase_code' => 'rtwgftpdf_'.$rtwgftpdf_purchase_code, 'status' => true );

			update_option( 'rtwgftpdf_verification_done', $rtwgftpdf_update_array );

			$rtwgftpdf_result = array( 'status' => true,
								'message' => $response_message );

			echo json_encode( $rtwgftpdf_result );
			wp_die();
		}else{
			$rtwgftpdf_result = array( 'status' => false,
								'message' => $response_message );

			echo json_encode( $rtwgftpdf_result );
			wp_die();
		}
	}

	/*
	* Function to remove purchase code
	*/

	function rtwgftpdf_delete_purchase_code()
	{
		$rtwgftpdf_site_url = get_site_url();
		$rtwgftpdf_admin_email = get_option('admin_email');
		$wp_get_current_user = get_user_meta( get_current_user_id() );

		if( is_array($wp_get_current_user) && !empty( $wp_get_current_user ) )
		{
			if( isset( $wp_get_current_user['first_name'][0]) )
			{
				$rtwgftpdf_admin_name = $wp_get_current_user['first_name'][0] . ' '. $wp_get_current_user['last_name'][0];
			}
		}
		else{
			$wp_get_current_user = wp_get_current_user();
			$rtwgftpdf_admin_name = $wp_get_current_user->data->user_nicename;
		}
		$rtwgftpdf_plugin_name = 'WordPress Gravity Forms PDF, Excel & CSV';
		$plugin_text_domain = 'rtwgftpdf-gravity-form-to-pdf';
		$rtwgftpdf_site_domain = preg_replace( "(^https?://)", "", $rtwgftpdf_site_url );
		$rtwgftpdf_purchase_code = get_option( 'rtwgftpdf_verification_done', array() );

		$rtwgftpdf_post_array = array(
			'site_domain' => $rtwgftpdf_site_domain,
			'admin_email' => $rtwgftpdf_admin_email,
			'admin_name' => $rtwgftpdf_admin_name,
			'plugin_name' => $rtwgftpdf_plugin_name,
			'text_domain' => $plugin_text_domain,
			'purchase_code' => $rtwgftpdf_purchase_code['purchase_code'],
			'plugin_id' => 24165502
		);

		$args = array(
				'method' => 'POST',
				'headers' => array(
				'Content-type: application/x-www-form-urlencoded'
			),
				'sslverify' => false,
				'body' => $rtwgftpdf_post_array
			);

		$response = wp_remote_post( 'https://demo.redefiningtheweb.com/license-verification/license-remove.php', $args );
		delete_option('rtwgftpdf_verification_done');
		wp_redirect( esc_url( admin_url( 'admin.php?page=rtwgftpdf' ) ) );
		exit;
	}

	/**
	* Functuion to set option for google sheets api
	* @since 1.1.0
	*/
	function rtwgftpdf_google_authenticate_callback()
	{
		if (!wp_verify_nonce($_POST['security_check'], 'rtwgftpdf-ajax-seurity'))
		{
			return;
		}
		
		$rtwgftpdf_google_cal_option = array(
			'rtwgftpdf_google_client_id' => sanitize_text_field( $_POST['client_id'] ),
			'rtwgftpdf_client_secret' => sanitize_text_field( $_POST['client_secret'] ),
			'rtwgftpdf_redirect_url' => sanitize_text_field( $_POST['redirect_url'] )
		);

		update_option( 'rtwgftpdf_google_sheet_option', $rtwgftpdf_google_cal_option );

		$this->rtwgftpdf_getClient();
	}

	function rtwgftpdf_getClient()
	{
		require_once RTWGFTPDF_DIR . 'assets/googlesheets/vendor/autoload.php';
		$rtwgftpdf_google_cal = get_option('rtwgftpdf_google_sheet_option', array());

		$client = new Google_Client();
		$client->setApplicationName("Gravity Form to PDF");
		$client->setScopes(Google_Service_Sheets::SPREADSHEETS);
		$client->setClientId(isset( $rtwgftpdf_google_cal['rtwgftpdf_google_client_id'] ) ? $rtwgftpdf_google_cal['rtwgftpdf_google_client_id'] : '');
		$client->setClientSecret(isset( $rtwgftpdf_google_cal['rtwgftpdf_client_secret'] ) ? $rtwgftpdf_google_cal['rtwgftpdf_client_secret'] : '');
		$client->setRedirectUri(isset( $rtwgftpdf_google_cal['rtwgftpdf_redirect_url'] ) ? $rtwgftpdf_google_cal['rtwgftpdf_redirect_url'] : '');
		$client->setAccessType('offline');
		$client->setPrompt('select_account consent');
		$client->setIncludeGrantedScopes(true);
		$auth_url = $client->createAuthUrl();

		echo json_encode($auth_url);
		die;
	}

	function rtwgftpdf_get_tokens()
	{
		ini_set('display_errors', 1); ini_set('display_startup_errors', 1); error_reporting(E_ALL);
		$rtwgftpdf_google_sheet = get_option('rtwgftpdf_google_sheet_option', array());
        require RTWGFTPDF_DIR . '/assets/googlesheets/vendor/autoload.php';
		$client = new Google_Client();
		$client->setScopes( Google_Service_Sheets::SPREADSHEETS );
		$client->setClientId( isset( $rtwgftpdf_google_sheet['rtwgftpdf_google_client_id'] ) ? $rtwgftpdf_google_sheet['rtwgftpdf_google_client_id'] : '' );
		$client->setClientSecret( isset( $rtwgftpdf_google_sheet['rtwgftpdf_client_secret'] ) ? $rtwgftpdf_google_sheet['rtwgftpdf_client_secret'] : '' );
		$client->setRedirectUri( isset( $rtwgftpdf_google_sheet['rtwgftpdf_redirect_url'] ) ? $rtwgftpdf_google_sheet['rtwgftpdf_redirect_url'] : '' );
		$client->setAccessType('offline');
    	$client->setPrompt('select_account consent');
     
        $client->setIncludeGrantedScopes(true);   // incremental auth
        if(empty($Authcode))
        {
            $Authcode = get_option('rtwgftpdf_authentication_code');
        }
        $response = $client->authenticate($Authcode);

        $access_token = $client->getAccessToken();
        $RefreshToken = $client->getRefreshToken();

        $status = update_option( 'rtwgftpdf_access_token', json_encode( $access_token ) );
        $status = update_option( 'rtwgftpdf_refresh_token', $RefreshToken );
       
        if($client->isAccessTokenExpired())
        {
        	$RefreshToken = get_option( 'rtwgftpdf_refresh_token' );
	        $response = $client->refreshToken($RefreshToken);
	        $access_token = $client->getAccessToken();
	        $RefreshToken = $client->getRefreshToken();
	        update_option('rtwgftpdf_access_token',json_encode($access_token));
	        if($RefreshToken != '')
	        {
	            update_option('rtwgftpdf_refresh_token',$RefreshToken);
	        }
	    }
	}
}