<?php
/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       www.redefiningtheweb.com
 * @since      1.0.0
 *
 * @package    Rtwgftpdf_Gravity_Form_To_Pdf
 * @subpackage Rtwgftpdf_Gravity_Form_To_Pdf/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin
 *
 * @since      1.0.0
 * @package    Rtwgftpdf_Gravity_Form_To_Pdf
 * @subpackage Rtwgftpdf_Gravity_Form_To_Pdf/includes
 * @author     RedefiningTheWeb <developer@redefiningtheweb.com>
 */

class Rtwgftpdf_Gravity_Form_To_Pdf {
	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Rtwgftpdf_Gravity_Form_To_Pdf_Loader    $rtwgftpdf_loader    Maintains and registers all hooks for the plugin.
	 */

	protected $rtwgftpdf_loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $rtwgftpdf_plugin_name    The string used to uniquely identify this plugin.
	 */

	protected $rtwgftpdf_plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $rtwgftpdf_version    The current version of the plugin.
	 */

	protected $rtwgftpdf_version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */

	public function __construct() 
	{
		if ( defined( 'RTWGFTPDF_GRAVITY_FORM_TO_PDF_VERSION' ) ) 
		{
			$this->rtwgftpdf_version = RTWGFTPDF_GRAVITY_FORM_TO_PDF_VERSION;
		} else {
			$this->rtwgftpdf_version = '1.0.0';
		}

		$this->rtwgftpdf_plugin_name = 'gravity-form-to-pdf';

		$this->rtwgftpdf_load_dependencies();

		$this->rtwgftpdf_set_locale();

		if(is_admin())
		{
			$this->rtwgftpdf_define_admin_hooks();
		}

		$this->rtwgftpdf_define_public_hooks();
	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Rtwgftpdf_Gravity_Form_To_Pdf_Loader. Orchestrates the hooks of the plugin.
	 * - Rtwgftpdf_Gravity_Form_To_Pdf_i18n. Defines internationalization functionality.
	 * - Rtwgftpdf_Gravity_Form_To_Pdf_Admin. Defines all hooks for the admin area.
	 * - Rtwgftpdf_Gravity_Form_To_Pdf_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */

	private function rtwgftpdf_load_dependencies() 
	{
		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/rtwgftpdf-class-gravity-form-to-pdf-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/rtwgftpdf-class-gravity-form-to-pdf-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/rtwgftpdf-class-gravity-form-to-pdf-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/rtwgftpdf-class-gravity-form-to-pdf-public.php';

		$this->rtwgftpdf_loader = new Rtwgftpdf_Gravity_Form_To_Pdf_Loader();
	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Rtwgftpdf_Gravity_Form_To_Pdf_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */

	private function rtwgftpdf_set_locale() 
	{
		$rtwgftpdf_plugin_i18n = new Rtwgftpdf_Gravity_Form_To_Pdf_i18n();
		$this->rtwgftpdf_loader->rtwgftpdf_add_action( 'plugins_loaded', $rtwgftpdf_plugin_i18n, 'rtwgftpdf_load_plugin_textdomain' );
	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */

	private function rtwgftpdf_define_admin_hooks() 
	{
		$rtwgftpdf_plugin_admin = new Rtwgftpdf_Gravity_Form_To_Pdf_Admin( $this->rtwgftpdf_get_plugin_name(), $this->rtwgftpdf_get_version() );

		$this->rtwgftpdf_loader->rtwgftpdf_add_action( 'admin_enqueue_scripts', $rtwgftpdf_plugin_admin, 'rtwgftpdf_enqueue_styles' );

		$this->rtwgftpdf_loader->rtwgftpdf_add_action( 'admin_enqueue_scripts', $rtwgftpdf_plugin_admin, 'rtwgftpdf_enqueue_scripts' );

		$this->rtwgftpdf_loader->rtwgftpdf_add_action('admin_menu', $rtwgftpdf_plugin_admin, 'rtwgftpdf_add_menu_page');
		$rtwgftpdf_verification_done = get_option( 'rtwgftpdf_verification_done', array() );

		if( !empty( $rtwgftpdf_verification_done ) && $rtwgftpdf_verification_done['status'] == true && !empty($rtwgftpdf_verification_done['purchase_code']) )
		{
			$this->rtwgftpdf_loader->rtwgftpdf_add_action('admin_init', $rtwgftpdf_plugin_admin, 'rtwgftpdf_save_admin_setting');

			$this->rtwgftpdf_loader->rtwgftpdf_add_action('gform_form_settings_menu', $rtwgftpdf_plugin_admin, 'rtwgftpdf_register_submenu_page','', 2);

			$this->rtwgftpdf_loader->rtwgftpdf_add_action('gform_form_settings_page_rtwgftpdf_', $rtwgftpdf_plugin_admin, 'rtwgftpdf_setting_display');

			$this->rtwgftpdf_loader->rtwgftpdf_add_filter('gform_entry_list_bulk_actions', $rtwgftpdf_plugin_admin, 'rtwgftpdf_entry_list_bulk_actions', 10);

			$this->rtwgftpdf_loader->rtwgftpdf_add_action('gform_entries_first_column_actions', $rtwgftpdf_plugin_admin, 'rtwgftpdf_entries','', 5);

			$this->rtwgftpdf_loader->rtwgftpdf_add_filter('admin_init', $rtwgftpdf_plugin_admin, 'rtwgftpdf_bulk_actions', 10 );

			$this->rtwgftpdf_loader->rtwgftpdf_add_action( 'gform_field_standard_settings', $rtwgftpdf_plugin_admin, 'rtwgftpdf_standard_settings', 10, 2 );

			$this->rtwgftpdf_loader->rtwgftpdf_add_filter( 'gform_tooltips', $rtwgftpdf_plugin_admin, 'rtwgftpdf_encryption_tooltips' );
			//delete_purchase_code
			if(isset($_GET['rtwgftpdf_action']) && $_GET['rtwgftpdf_action'] == 'delete_purchase_code')
			{
				$this->rtwgftpdf_loader->rtwgftpdf_add_action( 'admin_init', $rtwgftpdf_plugin_admin, 'rtwgftpdf_delete_purchase_code' );
			}
		}
		if( isset( $_GET['code'] ) && !empty( $_GET['code'] ) )
		{
			update_option( 'rtwgftpdf_authentication_code', $_GET['code'] );
			
			$this->rtwgftpdf_loader->rtwgftpdf_add_action( 'init', $rtwgftpdf_plugin_admin, 'rtwgftpdf_get_tokens' );
		}
		$this->rtwgftpdf_loader->rtwgftpdf_add_action( 'wp_ajax_rtwgftpdf_google_authenticate', $rtwgftpdf_plugin_admin, 'rtwgftpdf_google_authenticate_callback' );

		$this->rtwgftpdf_loader->rtwgftpdf_add_action( 'wp_ajax_rtwgftpdf_verify_purchase_code', $rtwgftpdf_plugin_admin, 'rtwgftpdf_verify_purchase_code' );
		
	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */

	private function rtwgftpdf_define_public_hooks() 
	{
		$rtwgftpdf_verification_done = get_option( 'rtwgftpdf_verification_done', array() );

		if( !empty( $rtwgftpdf_verification_done ) && $rtwgftpdf_verification_done['status'] == true && !empty($rtwgftpdf_verification_done['purchase_code']) )
		{
			$rtwgftpdf_plugin_public = new Rtwgftpdf_Gravity_Form_To_Pdf_Public( $this->rtwgftpdf_get_plugin_name(), $this->rtwgftpdf_get_version() );

			$this->rtwgftpdf_loader->rtwgftpdf_add_action( 'wp_enqueue_scripts', $rtwgftpdf_plugin_public, 'rtwgftpdf_enqueue_styles' );

			$this->rtwgftpdf_loader->rtwgftpdf_add_action( 'wp_enqueue_scripts', $rtwgftpdf_plugin_public, 'rtwgftpdf_enqueue_scripts' );

			$this->rtwgftpdf_loader->rtwgftpdf_add_action( 'init', $rtwgftpdf_plugin_public, 'rtwgftpdf_dwnld_pdf' );

			$this->rtwgftpdf_loader->rtwgftpdf_add_action( 'init', $rtwgftpdf_plugin_public, 'rtwgftpdf_preview_pdf' );

			$this->rtwgftpdf_loader->rtwgftpdf_add_action( 'gform_confirmation', $rtwgftpdf_plugin_public, 'rtwgftpdf_after_confirmation_callback', 1, 4 );

			$this->rtwgftpdf_loader->rtwgftpdf_add_filter('gform_pre_send_email', $rtwgftpdf_plugin_public, 'rtwgftpdf_send_email_with_attachment','', 4);

			$this->rtwgftpdf_loader->rtwgftpdf_add_filter( 'gform_field_css_class', $rtwgftpdf_plugin_public, 'rtwgftpdf_field_class', 10, 3 );

			$this->rtwgftpdf_loader->rtwgftpdf_add_action( 'gform_entry_created', $rtwgftpdf_plugin_public, 'rtwgftpdf_after_submission_callback', 10, 2 );
			
			$this->rtwgftpdf_loader->rtwgftpdf_add_filter( 'gform_review_page', $rtwgftpdf_plugin_public, 'rtwgftpdf_review_page', 10, 3 );
			$this->rtwgftpdf_loader->rtwgftpdf_add_filter( 'gform_entry_detail', $rtwgftpdf_plugin_public, 'rtwgftpdf_update_after_entry', 10, 2 );

			$this->rtwgftpdf_loader->rtwgftpdf_add_filter( 'rtwgftpdf_remove_label', $rtwgftpdf_plugin_public, 'rtwgftpdf_remove_label_fxn',10,1);

			$this->rtwgftpdf_loader->rtwgftpdf_add_filter( 'gform_currencies', $rtwgftpdf_plugin_public, 'rtwgftpdf_currency_fxn',10,1);

			// add_filter( '', function( $currencies )
		}
	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */

	public function rtwgftpdf_run() 
	{
		$this->rtwgftpdf_loader->rtwgftpdf_run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */

	public function rtwgftpdf_get_plugin_name() 
	{
		return $this->rtwgftpdf_plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Gravity_Form_To_Pdf_Loader    Orchestrates the hooks of the plugin.
	 */

	public function rtwgftpdf_get_loader() 
	{
		return $this->rtwgftpdf_loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */

	public function rtwgftpdf_get_version() 
	{
		return $this->rtwgftpdf_version;
	}
}