<?php

/**
 * The public-specific functionality of the plugin.
 *
 * @link       www.redefiningtheweb.com
 * @since      1.0.0
 *
 * @package    Rtwgftpdf_Gravity_Form_To_Pdf
 * @subpackage Rtwgftpdf_Gravity_Form_To_Pdf/public
 */

/**
 * The public-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-specific stylesheet and JavaScript.
 *
 * @package    Rtwgftpdf_Gravity_Form_To_Pdf
 * @subpackage Rtwgftpdf_Gravity_Form_To_Pdf/public
 * @author     RedefiningTheWeb <developer@redefiningtheweb.com>
 */
class Rtwgftpdf_Gravity_Form_To_Pdf_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $rtwgftpdf_plugin_name    The ID of this plugin.
	 */
	private $rtwgftpdf_plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $rtwgftpdf_version    The current version of this plugin.
	 */
	private $rtwgftpdf_version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $rtwgftpdf_plugin_name       The name of this plugin.
	 * @param      string    $rtwgftpdf_version    The version of this plugin.
	 */
	public function __construct( $rtwgftpdf_plugin_name, $rtwgftpdf_version ) {

		$this->rtwgftpdf_plugin_name = $rtwgftpdf_plugin_name;
		$this->rtwgftpdf_version = $rtwgftpdf_version;
		$this->rtwgftpdf_pdf_path = '';
		$rtwgftpdf_basic_stng = get_option('rtwgftpdf_basic_setting_opt');
		if( !$rtwgftpdf_basic_stng )
		{
			$rtwgftpdf_basic_stng = array();
		}
		$rtwgftpdf_css_stng = get_option('rtwgftpdf_css_setting_opt');
		if( !$rtwgftpdf_css_stng )
		{
			$rtwgftpdf_css_stng = array();
		}
		$rtwgftpdf_header_stng = get_option('rtwgftpdf_header_setting_opt');
		if( !$rtwgftpdf_header_stng )
		{
			$rtwgftpdf_header_stng = array();
		}
		$rtwgftpdf_footer_stng = get_option('rtwgftpdf_footer_setting_opt');
		if( !$rtwgftpdf_footer_stng )
		{
			$rtwgftpdf_footer_stng = array();
		}
		$rtwgftpdf_watermark_stng = get_option('rtwgftpdf_watermark_setting_opt');
		if( !$rtwgftpdf_watermark_stng )
		{
			$rtwgftpdf_watermark_stng = array();
		}
		$this->rtwgftpdf_stng = array_merge($rtwgftpdf_basic_stng,$rtwgftpdf_css_stng,$rtwgftpdf_header_stng,$rtwgftpdf_footer_stng,$rtwgftpdf_watermark_stng);
	}

	/**
	 * Register the stylesheets for the public area.
	 *
	 * @since    1.0.0
	 */
	public function rtwgftpdf_enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the rtwgftpdf_run() function
		 * defined in Gravity_Form_To_Pdf_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Gravity_Form_To_Pdf_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->rtwgftpdf_plugin_name, plugin_dir_url( __FILE__ ) . 'css/rtwgftpdf-gravity-form-to-pdf-public.css', array(), $this->rtwgftpdf_version, 'all' );
	}

	/**
	 * Register the JavaScript for the public area.
	 *
	 * @since    1.0.0
	 */
	public function rtwgftpdf_enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the rtwgftpdf_run() function
		 * defined in Gravity_Form_To_Pdf_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Gravity_Form_To_Pdf_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->rtwgftpdf_plugin_name, plugin_dir_url( __FILE__ ) . 'js/rtwgftpdf-gravity-form-to-pdf-public.js', array( 'jquery' ), $this->rtwgftpdf_version, false );
	}

	/**
	 * Funtion to assign directory to the PDF.
	 *
	 * @since    1.0.0
	 */
	public function rtwgftpdf_dwnld_pdf(){
		if( isset( $_GET['rtwgftpdf_generate_pdf'] ) && isset( $_GET['rtwgftpdf_pdf_file'] ) && !empty( $_GET['rtwgftpdf_pdf_file'] ) )
		{
			$rtwgftpdf_file_path = RTWGFTPDF_CONTENT_DIR . '/' . sanitize_text_field($_GET['rtwgftpdf_pdf_file']);
			$rtwgftpdf_file_name = $_GET['rtwgftpdf_pdf_file'];
			header("Content-type:application/pdf");
			header("Content-Disposition:attachment;filename=$rtwgftpdf_file_name");
			readfile($rtwgftpdf_file_path);
			die();
		}
	}

	/**
	 * Function that runs on submit click of Gravity Forms using to know the type of fields.
	 *
	 * @since    1.0.0
	 */
	function rtwgftpdf_after_submission_callback( $rtwgftpdf_lead, $rtwgftpdf_form )
	{
		if(isset($rtwgftpdf_form['fields']) && !empty($rtwgftpdf_form['fields']))
		{
			$rtwgftpdf_editor_format_option = get_option('rtwgftpdf_editor_format_opt_'.$rtwgftpdf_form['id']);

			$rtwgftpdf_forms = $rtwgftpdf_lead['id'];
			$rtwgftpdf_form_title = $rtwgftpdf_form['title'];
			$rtwgftpdf_guest = array();
			foreach($rtwgftpdf_form['fields'] as $rtwgftpdf_key => $rtwgftpdf_val)
			{
				if($rtwgftpdf_val['type'] == 'address')
				{
					foreach ($rtwgftpdf_val['inputs'] as $rtwgftpdf_keys => $rtwgftpdf_value) {
						array_push($rtwgftpdf_guest, $rtwgftpdf_value['id']);
					}
				}
				elseif($rtwgftpdf_val['type'] == 'name')
				{
					foreach ($rtwgftpdf_val['inputs'] as $rtwgftpdf_keys => $rtwgftpdf_value) {
						array_push($rtwgftpdf_guest, $rtwgftpdf_value['id']);
					}
				}
				else
				{
					array_push($rtwgftpdf_guest, $rtwgftpdf_val['id']);
				}
			}

			$rtwgftpdf_guest_name = $rtwgftpdf_lead[$rtwgftpdf_guest[0]];
			if(isset($rtwgftpdf_guest[1]) && !empty($rtwgftpdf_guest[1]))
			{
				$rtwgftpdf_guest_email = $rtwgftpdf_lead[$rtwgftpdf_guest[1]];
			}
			else
			{
				$rtwgftpdf_guest_email = $rtwgftpdf_lead[$rtwgftpdf_guest[0]];
			}

			$rtwgftpdf_form_id = GFFormsModel::get_form_id($rtwgftpdf_form_title);
			$rtwgftpdf_editor_format = get_option('rtwgftpdf_editor_format_opt_'.$rtwgftpdf_form_id);
			$rtwgftpdf_editor_format = $rtwgftpdf_editor_format['editor'][$rtwgftpdf_form_id];

			$rtwgftpdf_form_field = $rtwgftpdf_form['fields'];
			$rtwgftpdf_form_field_for_temp = $rtwgftpdf_form['fields'];
			$rtwgftpdf_form_fields = array();
			if($rtwgftpdf_editor_format == '')
			{
				foreach($rtwgftpdf_form_field as $rtwpftpdf_key => $rtwgftpdf_val)
				{	
					if($rtwgftpdf_val['type'] != 'section' && $rtwgftpdf_val['type'] != 'html' && $rtwgftpdf_val['type'] != 'hidden' && $rtwgftpdf_val['type'] != 'CAPTCHA')
					{
						if($rtwgftpdf_val['type'] != 'page')
						{
							array_push($rtwgftpdf_form_fields, $rtwgftpdf_val['label']);
						}
						else
						{	
							if(trim($rtwgftpdf_val['cssClass']) != 'gform_review_page')
							{
								array_push($rtwgftpdf_form_fields, 'pagebreak');
							}
						}
					}
				}

				$rtwgftpdf_editor_html = '';
				$rtwgftpdf_edit_page_name = 0;
				if(isset($rtwgftpdf_form['pagination']['pages'][0]))
				{
					$rtwgftpdf_editor_html .='<p>{' . esc_html($rtwgftpdf_form['pagination']['pages'][$rtwgftpdf_edit_page_name]) .'}</p>';
					$rtwgftpdf_edit_page_name = 1;
				}

				foreach ($rtwgftpdf_form_fields as $rtwgftpdf_key => $rtwgftpdf_val) 
				{
					if($rtwgftpdf_val == 'pagebreak')
					{
						$rtwgftpdf_editor_html .= '<p>{pagebreak}</p>';
						$rtwgftpdf_editor_html .= '<p>{' . esc_html($rtwgftpdf_form['pagination']['pages'][$rtwgftpdf_edit_page_name]) .'}</p>';
						$rtwgftpdf_edit_page_name = $rtwgftpdf_edit_page_name + 1;
					}
					else
					{
						$rtwgftpdf_editor_html .= '<p> [' . esc_html($rtwgftpdf_val) .']' .'</p>';
					}
				}
				$rtwgftpdf_editor_format = $rtwgftpdf_editor_html;
			}
			if(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_one')
			{
				include( RTWGFTPDF_DIR .'/admin/templates/temp-one.php');
			}
			elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_two')
			{
				include( RTWGFTPDF_DIR .'/admin/templates/temp-two.php');
			}
			elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_three')
			{
				include( RTWGFTPDF_DIR .'/admin/templates/temp-three.php' );
			}

			$rtwgftpdf_frst_array = array();
			$rtwgftpdf_label_frst_empty = array();
			$rtwgftpdf_label_array = array();
			
			//////////  Getting Empty fields in label_frst_empty ////////
			foreach ($rtwgftpdf_form['fields'] as $rtwgftpdf_key => $rtwgftpdf_value)
			{
				if($rtwgftpdf_value['type'] != 'page' && $rtwgftpdf_value['type'] != 'section' && $rtwgftpdf_value['type'] != 'html' && $rtwgftpdf_value['type'] != 'hidden' && $rtwgftpdf_value['type'] != 'CAPTCHA')
				{
					if($rtwgftpdf_value['type'] != 'option' && $rtwgftpdf_value['type'] != 'checkbox' && $rtwgftpdf_value['type'] != 'address' && $rtwgftpdf_value['type'] != 'name' && $rtwgftpdf_value['type'] != 'consent' && $rtwgftpdf_value['type'] != 'product' && isset($rtwgftpdf_lead[$rtwgftpdf_value['id']]) && empty($rtwgftpdf_lead[$rtwgftpdf_value['id']]) )
					{
						array_push($rtwgftpdf_label_frst_empty, $rtwgftpdf_value['label']);
					}
					array_push($rtwgftpdf_frst_array, '['.$rtwgftpdf_value['label'].']');
					array_push($rtwgftpdf_label_array, $rtwgftpdf_value['label']);
				}
			}
			///////////   Simple Html DOM   ///////////
			$rtwgftpdf_verification_done = get_option( 'rtwgftpdf_verification_done', array() );

			if( !empty( $rtwgftpdf_verification_done ) && $rtwgftpdf_verification_done['status'] == true && !empty($rtwgftpdf_verification_done['purchase_code']) )
			{
				if( !class_exists('simple_html_dom') )
				{
					include_once( RTWGFTPDF_DIR .'/includes/simplehtmldom/simple_html_dom.php');
				}
				$rtwgftpdf_html = new simple_html_dom();

				if (isset($this->rtwgftpdf_stng ['emtpy_field'] ) && $this->rtwgftpdf_stng ['emtpy_field'] == 'No')
				{	
					if( isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] != 'temp_two' && $rtwgftpdf_editor_format_option['rtw_template_select'] != 'temp_three' )
					{
						if($rtwgftpdf_editor_format_option['rtw_template_select'] != 'temp_one')
						{
							$rtwgftpdf_html->load($rtwgftpdf_editor_format);
							foreach ($rtwgftpdf_label_frst_empty as $rtwgftpdf_key => $rtwgftpdf_value) {
								foreach($rtwgftpdf_html->find('p') as $rtwgftpdf_element)
								{
									if( stripos($rtwgftpdf_element->plaintext, '['.$rtwgftpdf_value.']') !== false )
									{
										$rtwgftpdf_element->outertext = '';
									}
								}
							}
							$rtwgftpdf_editor_format = $rtwgftpdf_html->save();
						}
					}
				}
				/////////   $thrd_array for page names   ///////////
				$rtwgftpdf_thrd_array = array();
				if(isset($rtwgftpdf_form['pagination']['pages']) && !empty($rtwgftpdf_form['pagination']['pages']))
				{
					foreach ($rtwgftpdf_form['pagination']['pages'] as $rtwgftpdf_key => $rtwgftpdf_value) 
					{
						array_push($rtwgftpdf_thrd_array, '{'.$rtwgftpdf_value.'}');
					}

					$rtwgftpdf_page_name = array();
					foreach ($rtwgftpdf_form['pagination']['pages'] as $rtwgftpdf_key => $rtwgftpdf_value) 
					{
						array_push($rtwgftpdf_page_name, $rtwgftpdf_value);
					}
					if (isset($this->rtwgftpdf_stng ['page_name'] ) && $this->rtwgftpdf_stng ['page_name'] == 'Yes') 
					{
						$rtwgftpdf_editor_format = str_replace('{pagebreak}', '<pagebreak>', $rtwgftpdf_editor_format);
						$rtwgftpdf_editor_format = str_replace($rtwgftpdf_thrd_array, $rtwgftpdf_page_name, $rtwgftpdf_editor_format);
					}
					else
					{
						$rtwgftpdf_html->load($rtwgftpdf_editor_format);
						foreach ($rtwgftpdf_thrd_array as $rtwgftpdf_key => $rtwgftpdf_value) {
							foreach($rtwgftpdf_html->find('[plaintext^='.$rtwgftpdf_value.']') as $rtwgftpdf_element)
							{
								$rtwgftpdf_element->outertext = '';
							}
						}
						foreach($rtwgftpdf_html->find('[plaintext^={pagebreak}]') as $rtwgftpdf_element)
						{
							$rtwgftpdf_element->outertext = '';
						}
						$rtwgftpdf_editor_format = $rtwgftpdf_html->save();
					}
				}
				$rtwgftpdf_scnd_array = array();
				$rtwgftpdf_field_value_array = array();
				foreach ($rtwgftpdf_form['fields'] as $rtwgftpdf_key => $rtwgftpdf_value) {
					if($rtwgftpdf_value['type'] != 'section' && $rtwgftpdf_value['type'] != 'page' && $rtwgftpdf_value['type'] != 'html' && $rtwgftpdf_value['type'] != 'hidden' && $rtwgftpdf_value['type'] != 'CAPTCHA')
					{
						$rtwgft_img_width 	= $this->rtwgftpdf_stng ['upload_img_width'];
						$rtwgft_img_height 	= $this->rtwgftpdf_stng ['upload_img_height'];

						if($rtwgftpdf_value['type'] == 'post_image')
						{
							if($rtwgftpdf_lead[$rtwgftpdf_value['id']] != '')
							{
								$rtwgftpdf_pro_pic_url = '';
								$rtwgftpdf_pro_pic ='';
								$rtwgftpdf_pro_pic = $rtwgftpdf_lead[$rtwgftpdf_value['id']];
								$rtwgftpdf_arr = explode("|", $rtwgftpdf_pro_pic);
								// $rtwgftpdf_pro_pic_url =
									// '<b>'. esc_html($rtwgftpdf_value['label']).' :        </b>';
								
								$rtwgftpdf_pro_pic_url = apply_filters('rtwgftpdf_remove_label',$rtwgftpdf_pro_pic_url);
								if( !empty($rtwgft_img_width) && !empty($rtwgft_img_height) )
								{
									$rtwgftpdf_pro_pic_url .=
									'<img width="'. $rtwgft_img_width .'px" height="'. $rtwgft_img_height .'px" id="rtwgftpdf_post_image" src="'.esc_url($rtwgftpdf_arr[0]).'" />';
								}
								else{
									$rtwgftpdf_pro_pic_url .=
									'<img id="rtwgftpdf_post_image" src="'.esc_url($rtwgftpdf_arr[0]).'" />';
								}

								if(isset( $rtwgftpdf_editor_format_option['rtw_template_select'] ) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_two' )
								{
									if( !empty($rtwgft_img_width) && !empty($rtwgft_img_height) )
									{
										$rtwgftpdf_pro_pic_url =
										// '<b>'. esc_html($rtwgftpdf_value['label']).' :        </b> 
										'<img width="'. $rtwgft_img_width .'px" height="'. $rtwgft_img_height .'px" id="rtwgftpdf_post_image" src="'.esc_url($rtwgftpdf_arr[0]).'" />';
									}
									else{
										$rtwgftpdf_pro_pic_url =
										// '<b>'. esc_html($rtwgftpdf_value['label']).' :        </b> 
										'<img id="rtwgftpdf_post_image" src="'.esc_url($rtwgftpdf_arr[0]).'" />';
									}
								}
								array_push($rtwgftpdf_scnd_array, $rtwgftpdf_pro_pic_url);
								array_push($rtwgftpdf_field_value_array, $rtwgftpdf_lead[$rtwgftpdf_value['id']]);
							}
							else
							{
								if (isset($this->rtwgftpdf_stng ['emtpy_field'] ) && $this->rtwgftpdf_stng ['emtpy_field'] == 'Yes') 
								{
									$rtwgftpdf_pro_pic_url = $rtwgftpdf_lead[$rtwgftpdf_value['id']];
									array_push($rtwgftpdf_scnd_array, $rtwgftpdf_pro_pic_url);
									array_push($rtwgftpdf_field_value_array, $rtwgftpdf_pro_pic_url);
								}
							}
						}
						elseif($rtwgftpdf_value['type'] == 'address')
						{
							$rtwgftpdf_address = '';
							$rtwgftpdf_address = '<b>'. esc_html($rtwgftpdf_value['label']).' </b><br>';
							if( isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_one' )
							{
								$rtwgftpdf_address = '<div class="rtw_label"><b>'. esc_html($rtwgftpdf_value['label']).' </b></div><br>';
							}
							if(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_three')
							{
								$rtwgftpdf_address = '';
							}
							if(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_two')
							{
								$rtwgftpdf_address = '';
							}
							$i = 1;

							$value_exists = false;
							
							foreach ($rtwgftpdf_value['inputs'] as $rtwgftpdf_keys => $rtwgftpdf_values) {
								if($rtwgftpdf_lead[$rtwgftpdf_values['id']] != '')
								{
									$value_exists = true;
							
									if(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_two')
									{
										$rtwgftpdf_address .='<div class="rtw_form_address'.esc_html($i).'">'. esc_html($rtwgftpdf_lead[$rtwgftpdf_values['id']]).'</div>';
									}
									elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_one')
									{
										$rtwgftpdf_address .='<div class="rtw_div_address">'.esc_html($rtwgftpdf_values['label']) .' : '. esc_html($rtwgftpdf_lead[$rtwgftpdf_values['id']]).'<br></div></div>';
									}
									elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_three')
									{
										$rtwgftpdf_address .='<div class="rtw_form_address'.esc_html($i).'">'. esc_html($rtwgftpdf_lead[$rtwgftpdf_values['id']]).'</div>';
									}
									else{
										$rtwgftpdf_address .= esc_html($rtwgftpdf_values['label']) .' : '. esc_html($rtwgftpdf_lead[$rtwgftpdf_values['id']]).'<br>';
									}
									array_push($rtwgftpdf_field_value_array, $rtwgftpdf_lead[$rtwgftpdf_values['id']]);
								}
								$i = '';
							}
							if(!$value_exists)
							{
								$rtwgftpdf_address = '';
							}
							array_push($rtwgftpdf_scnd_array, $rtwgftpdf_address);
						}
						elseif($rtwgftpdf_value['type'] == 'checkbox')
						{
							$rtwgftpdf_ckbox_value = '';
							$rtwgftpdf_ckbox_value .= '<b>'. esc_html($rtwgftpdf_value['label']).' </b><br>';
							if(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_one')
							{
								$rtwgftpdf_ckbox_value = '<div class="rtw_label"><b>'. esc_html($rtwgftpdf_value['label']).' </b></div><br>';
							}
							elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_two')
							{
								$rtwgftpdf_ckbox_value = '';
							}
								
							$rtwgftpdf_ckbox_value = apply_filters('rtwgftpdf_remove_label',$rtwgftpdf_ckbox_value);
							foreach ($rtwgftpdf_value['inputs'] as $rtwgftpdf_keys => $rtwgftpdf_values) {
								if($rtwgftpdf_lead[$rtwgftpdf_values['id']] != '')
								{
									if(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_two')
									{
										$rtwgftpdf_ckbox_value .='<div class="rtw_form_chkbox">'. esc_html($rtwgftpdf_lead[$rtwgftpdf_values['id']]).'</div>';
									}
									elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_one')
									{
										$rtwgftpdf_ckbox_value .= '<div class="rtw_div">'. esc_html($rtwgftpdf_lead[$rtwgftpdf_values['id']]).'</div><br>';
									}
									elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_three')
									{
										$rtwgftpdf_ckbox_value .= '<div class="rtw_div">'. esc_html($rtwgftpdf_lead[$rtwgftpdf_values['id']]).'</div><br>';
									}
									else{
										$rtwgftpdf_ckbox_value .= esc_html($rtwgftpdf_lead[$rtwgftpdf_values['id']]).'<br>';
									}
									
									array_push($rtwgftpdf_field_value_array, $rtwgftpdf_lead[$rtwgftpdf_values['id']]);
								}
							}
							array_push($rtwgftpdf_scnd_array, $rtwgftpdf_ckbox_value);
						}
						elseif($rtwgftpdf_value['type'] == 'name')
						{
							$rtwgftpdf_adv_name = '';
							$rtwgftpdf_adv_name .= '<b>'. esc_html($rtwgftpdf_value['label']).' </b>   <br>';
							if(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_two')
							{
								$rtwgftpdf_adv_name = '';
							}
							elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_three')
							{
								$rtwgftpdf_adv_name = '';
							}
							elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_one')
							{
								$rtwgftpdf_adv_name = '<div class="rtw_label"><b>'. esc_html($rtwgftpdf_value['label']).' </b></div><br>';
							}
							$name = '';
							foreach ($rtwgftpdf_value['inputs'] as $rtwgftpdf_keys => $rtwgftpdf_values) 
							{
								if($rtwgftpdf_lead[$rtwgftpdf_values['id']] != '')
								{
									if(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_two')
									{
										$rtwgftpdf_adv_name .='<div class="rtw_form_name">'. esc_html($rtwgftpdf_lead[$rtwgftpdf_values['id']]).'</div>';
									}
									elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_one')
									{
										$rtwgftpdf_adv_name .= '<div class="rtw_div">'. esc_html($rtwgftpdf_values['label']) .' : '. esc_html($rtwgftpdf_lead[$rtwgftpdf_values['id']]).'</div>';
									}
									elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_three')
									{
										$rtwgftpdf_adv_name .= '<div class="rtw_div">'. esc_html($rtwgftpdf_values['label']) .' : '. esc_html($rtwgftpdf_lead[$rtwgftpdf_values['id']]).'</div>';
									}
									else{
										$rtwgftpdf_adv_name .= esc_html($rtwgftpdf_values['label']) .' : '. esc_html($rtwgftpdf_lead[$rtwgftpdf_values['id']]).'<br>'; 
									}
									$name .= $rtwgftpdf_lead[$rtwgftpdf_values['id']].' ';

								}
							}
							if(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_one')
							{
								$rtwgftpdf_adv_name .= '<br>';
							}
							array_push($rtwgftpdf_scnd_array, $rtwgftpdf_adv_name);
							array_push($rtwgftpdf_field_value_array, $name);
						}
						elseif($rtwgftpdf_value['type'] == 'list')
						{
							if($rtwgftpdf_value['enableColumns'] == 1)
							{
								$rtwgftpdf_list_array ='';
								$rtwgftpdf_adv_list = '';
								$rtwgftpdf_adv_list .= '<b>'. esc_html($rtwgftpdf_value['label']).'</b><br>';
								if(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_two')
								{
									$rtwgftpdf_adv_list = '';
								}
								elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_one')
								{
									$rtwgftpdf_adv_list = '<div class="rtw_label"><b>'. esc_html($rtwgftpdf_value['label']).' </b></div><br>';
								}
								elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_three')
								{
									$rtwgftpdf_adv_list = '<div class="rtw_label"><b>'. esc_html($rtwgftpdf_value['label']).' </b></div><br>';
								}
								$rtwgftpdf_list_array = maybe_unserialize($rtwgftpdf_lead[$rtwgftpdf_value['id']]);
								foreach ($rtwgftpdf_value['choices'] as $rtwgftpdf_keys => $rtwgftpdf_values) 
								{
									if(is_array($rtwgftpdf_list_array) && !empty($rtwgftpdf_list_array))
									{
										foreach ($rtwgftpdf_list_array as $rtwgftpdf_kk => $rtwgftpdf_vv) {
											if(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_two')
											{
												$rtwgftpdf_adv_list .= '<div class="rtw_form_list">'.esc_html($rtwgftpdf_values['text']) .' : '. esc_html($rtwgftpdf_vv[$rtwgftpdf_values['text']]) . '</div>';
											}
											elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_one')
											{
												$rtwgftpdf_adv_list .= '<div class="rtw_div">'. esc_html($rtwgftpdf_values['text']) .' : '. esc_html($rtwgftpdf_vv[$rtwgftpdf_values['text']]) .'</div>';
											}
											elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_three')
											{
												$rtwgftpdf_adv_list .= '<div class="rtw_div">'. esc_html($rtwgftpdf_values['text']) .' : '. esc_html($rtwgftpdf_vv[$rtwgftpdf_values['text']]) .'</div>';
											}
											else{
												$rtwgftpdf_adv_list .= esc_html($rtwgftpdf_values['text']) .' : '. esc_html($rtwgftpdf_vv[$rtwgftpdf_values['text']]) . '<br>';
											}
										}
									}
								}
								array_push($rtwgftpdf_scnd_array, $rtwgftpdf_adv_list);
								array_push($rtwgftpdf_field_value_array, $rtwgftpdf_list_array);
							}
							else
							{	
								$rtwgftpdf_adv_list = '';
								$rtwgftpdf_list_array ='';
								$rtwgftpdf_adv_list .= '<b>'. esc_html($rtwgftpdf_value['label']).' </b><br>';
								if(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_two')
								{
									$rtwgftpdf_adv_list = '';
								}
								elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_one')
								{
									$rtwgftpdf_adv_list = '<div class="rtw_label"><b>'. esc_html($rtwgftpdf_value['label']).' </b></div><br>';
								}
								elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_three')
								{
									$rtwgftpdf_adv_list = '<div class="rtw_label"><b>'. esc_html($rtwgftpdf_value['label']).' </b></div><br>';
								}
								$rtwgftpdf_list_array = maybe_unserialize($rtwgftpdf_lead[$rtwgftpdf_value['id']]);

								if(!empty($rtwgftpdf_list_array))
								{
									$rtwgftpdf_adv_list .= esc_html($rtwgftpdf_list_array[0]);
									array_push($rtwgftpdf_scnd_array, $rtwgftpdf_adv_list);
								}
								else
								{
									array_push($rtwgftpdf_scnd_array, $rtwgftpdf_list_array);
								}
								array_push($rtwgftpdf_field_value_array, $rtwgftpdf_list_array);
							}
						}
						elseif($rtwgftpdf_value['type'] == 'consent')
						{
							$rtwgftpdf_adv_cnsnt = '';
							$rtwgftpdf_adv_cnsnt .= '<b>' .esc_html($rtwgftpdf_value['label']).' </b><br>';
							if(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_two')
							{
								$rtwgftpdf_adv_cnsnt = '';
							}
							elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_one')
							{
								$rtwgftpdf_adv_cnsnt = '<div class="rtw_label"><b>'. esc_html($rtwgftpdf_value['label']).' </b></div><br>';
							}
							elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_three')
							{
								$rtwgftpdf_adv_cnsnt = '<div class="rtw_label"><b>'. esc_html($rtwgftpdf_value['label']).' </b></div><br>';
							}
							foreach ($rtwgftpdf_value['inputs'] as $rtwgftpdf_keys => $rtwgftpdf_values) 
							{
								if($rtwgftpdf_values['label'] == 'Text')
								{
									
									if(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_two')
									{
										$rtwgftpdf_adv_cnsnt .= '<div class="rtw_form_consent">'. esc_html($rtwgftpdf_lead[$rtwgftpdf_values['id']]).'</div>';
									}else{
										$rtwgftpdf_adv_cnsnt .= esc_html($rtwgftpdf_lead[$rtwgftpdf_values['id']]).'<br>';
									}
								}
							}
							array_push($rtwgftpdf_scnd_array, $rtwgftpdf_adv_cnsnt);
							array_push($rtwgftpdf_field_value_array, $rtwgftpdf_lead[$rtwgftpdf_value['id']]);
						}
						elseif($rtwgftpdf_value['type'] == 'product')
						{
							$rtwgftpdf_adv_pro ='';
							$rtwgftpdf_adv_pro = '<b>'. esc_html($rtwgftpdf_value['label']). '</b><br>';
							if(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_two')
							{
								$rtwgftpdf_adv_pro ='';
							}
							elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_one')
							{
								$rtwgftpdf_adv_pro = '<div class="rtw_label"><b>'. esc_html($rtwgftpdf_value['label']).' </b></div><br>';
							}
							elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_three')
							{
								$rtwgftpdf_adv_pro = '<div class="rtw_label"><b>'. esc_html($rtwgftpdf_value['label']).' </b></div><br>';
							}
							if($rtwgftpdf_value['inputType'] == 'radio')
							{
								$rtwgftpdf_adv_price ='';
								$rtwgftpdf_adv_price = $rtwgftpdf_lead[$rtwgftpdf_value['id']];
								$rtwgftpdf_arr = explode("|", $rtwgftpdf_adv_price);
								if( strpos( $rtwgftpdf_adv_price, '|' ) !== false) {
									$rtwgftpdf_adv_pro .= esc_html($rtwgftpdf_arr[0]) .' : ';
									$rtwgftpdf_adv_pro .= esc_html($rtwgftpdf_arr[1]);
								}
								else{
									$rtwgftpdf_adv_pro .= esc_html($rtwgftpdf_arr[0]);
								}
								array_push($rtwgftpdf_scnd_array, $rtwgftpdf_adv_pro);
							}
							elseif($rtwgftpdf_value['inputType'] == 'price')
							{
								$rtwgftpdf_adv_pro .= esc_html($rtwgftpdf_lead[$rtwgftpdf_value['id']]);
								array_push($rtwgftpdf_scnd_array, $rtwgftpdf_adv_pro);
							}
							elseif($rtwgftpdf_value['inputType'] == 'select')
							{
								$rtwgftpdf_adv_price ='';
								$rtwgftpdf_adv_price = $rtwgftpdf_lead[$rtwgftpdf_value['id']];
								$rtwgftpdf_arr = explode("|", $rtwgftpdf_adv_price);
								$rtwgftpdf_adv_pro .= esc_html($rtwgftpdf_arr[0]).':'.esc_html($rtwgftpdf_arr[1]);
								array_push($rtwgftpdf_scnd_array, $rtwgftpdf_adv_pro);
							}
							else
							{
								$rtwgftpdf_adv_price = '<b>'. esc_html($rtwgftpdf_value['label']). ' </b><br>';
								foreach ($rtwgftpdf_value['inputs'] as $rtwgftpdf_keys => $rtwgftpdf_values) 
								{
									if($rtwgftpdf_lead[$rtwgftpdf_values['id']] != '')
									{
										if(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_two')
										{
											$rtwgftpdf_adv_price .='<div class="rtw_form_product">'. esc_html($rtwgftpdf_values['label']). ' = '.esc_html($rtwgftpdf_lead[$rtwgftpdf_values['id']]).'</div>';
										}else{
											$rtwgftpdf_adv_price .= esc_html($rtwgftpdf_values['label']). ' = '.esc_html($rtwgftpdf_lead[$rtwgftpdf_values['id']]).'<br>';
										}
									}
								}
								array_push($rtwgftpdf_scnd_array, $rtwgftpdf_adv_price);
							}
							array_push($rtwgftpdf_field_value_array, $rtwgftpdf_lead[$rtwgftpdf_values['id']]);
							
						}
						elseif($rtwgftpdf_value['type'] == 'quantity')
						{
							$rtwgftpdf_adv_quant = '<b>'. esc_html($rtwgftpdf_value['label']). ' :</b> ' . esc_html($rtwgftpdf_lead[$rtwgftpdf_value['id']]);
							if(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_two')
							{
								$rtwgftpdf_adv_quant = esc_html($rtwgftpdf_lead[$rtwgftpdf_value['id']]);
							}

							array_push($rtwgftpdf_scnd_array, $rtwgftpdf_adv_quant);
							array_push($rtwgftpdf_field_value_array, $rtwgftpdf_lead[$rtwgftpdf_value['id']]);
						}
						elseif($rtwgftpdf_value['type'] == 'option')
						{
							$rtwbma_currenciess = get_option('rtwgftpdf_currencies', array());
							
							if($rtwgftpdf_value['inputType'] == 'checkbox')
							{
								$rtwgftpdf_adv_chk = '<b>'. esc_html($rtwgftpdf_value['label']). ' </b><br>';
								if(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_two')
								{
									$rtwgftpdf_adv_chk = "";
								}
								foreach ($rtwgftpdf_value['inputs'] as $rtwgftpdf_keys => $rtwgftpdf_values) 
								{
									if($rtwgftpdf_lead[$rtwgftpdf_values['id']] != '')
									{
										$rtwgftpdf_adv_val = $rtwgftpdf_lead[$rtwgftpdf_values['id']];
										$rtwgftpdf_arr = explode("|", $rtwgftpdf_adv_val);
										/////////////////////////////////////////////
										$totals = number_format((float)$rtwgftpdf_arr[1], isset($rtwbma_currenciess[$rtwgftpdf_lead['currency']])?$rtwbma_currenciess[$rtwgftpdf_lead['currency']]['decimals'] : 2, isset($rtwbma_currenciess[$rtwgftpdf_lead['currency']])?$rtwbma_currenciess[$rtwgftpdf_lead['currency']]['thousand_separator'] : ',', isset($rtwbma_currenciess[$rtwgftpdf_lead['currency']])?$rtwbma_currenciess[$rtwgftpdf_lead['currency']]['decimal_separator'] : '.');

										$total_after_symbols = (isset($rtwbma_currenciess[$rtwgftpdf_lead['currency']])?$rtwbma_currenciess[$rtwgftpdf_lead['currency']]['symbol_left'] : '') . $totals . (isset($rtwbma_currenciess[$rtwgftpdf_lead['currency']])?$rtwbma_currenciess[$rtwgftpdf_lead['currency']]['symbol_right'] : ''); 

										////////////////////////////////////////////
										$rtwgftpdf_adv_chk .= esc_html($rtwgftpdf_values['label']). ' = '.esc_html($total_after_symbols).'<br>';
									}
								}
								array_push($rtwgftpdf_scnd_array, $rtwgftpdf_adv_chk);
							}
							else
							{
								$rtwgftpdf_adv_opt ='';
								$rtwgftpdf_adv_opt = '<b>'. esc_html($rtwgftpdf_value['label']). ' </b><br>';
								if(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_two')
								{
									$rtwgftpdf_adv_opt ='';
								}
								$rtwgftpdf_adv_opt = $rtwgftpdf_lead[$rtwgftpdf_value['id']];
								$rtwgftpdf_arr = explode("|", $rtwgftpdf_adv_opt);
								//////////////////////////////////////////////
								
								$totals = number_format((float)$rtwgftpdf_arr[1], isset($rtwbma_currenciess[$rtwgftpdf_lead['currency']])?$rtwbma_currenciess[$rtwgftpdf_lead['currency']]['decimals'] : 2, isset($rtwbma_currenciess[$rtwgftpdf_lead['currency']])?$rtwbma_currenciess[$rtwgftpdf_lead['currency']]['thousand_separator'] : ',', isset($rtwbma_currenciess[$rtwgftpdf_lead['currency']])?$rtwbma_currenciess[$rtwgftpdf_lead['currency']]['decimal_separator'] : '.');

								$total_after_symbols = (isset($rtwbma_currenciess[$rtwgftpdf_lead['currency']])?$rtwbma_currenciess[$rtwgftpdf_lead['currency']]['symbol_left'] : '') . $totals . (isset($rtwbma_currenciess[$rtwgftpdf_lead['currency']])?$rtwbma_currenciess[$rtwgftpdf_lead['currency']]['symbol_right'] : ''); 
								//////////////////////////////////////////////
								$rtwgftpdf_adv_opt = esc_html($rtwgftpdf_arr[0]).':'.esc_html($total_after_symbols);
								array_push($rtwgftpdf_scnd_array, $rtwgftpdf_adv_opt);
							}
							array_push($rtwgftpdf_field_value_array, $rtwgftpdf_lead[$rtwgftpdf_value['id']]);
						}
						elseif($rtwgftpdf_value['type'] == 'shipping')
						{
							if($rtwgftpdf_value['inputType'] == 'singleshipping')
							{
								$rtwgftpdf_adv_ship ='<b>'. esc_html($rtwgftpdf_value['label']). '</b> = ';
								
								$rtwgftpdf_adv_ship = apply_filters('rtwgftpdf_remove_label',$rtwgftpdf_adv_ship);

								$rtwgftpdf_adv_ship .= esc_html($rtwgftpdf_lead[$rtwgftpdf_value['id']]) .'<br>';
								
								if(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_two')
								{
									$rtwgftpdf_adv_ship = esc_html($rtwgftpdf_lead[$rtwgftpdf_value['id']]) .'<br>';
								}
								if(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_three')
								{
									$rtwgftpdf_adv_ship = '<div class="rtw_form_other_field">'.esc_html($rtwgftpdf_lead[$rtwgftpdf_value['id']]) .'</div>';
								}
								
								array_push($rtwgftpdf_scnd_array, $rtwgftpdf_adv_ship);
							}
							else
							{
								$rtwgftpdf_adv_shiped = '';
								$rtwgftpdf_adv_ship = '';
								$rtwgftpdf_adv_shiped .= '<b>'. esc_html($rtwgftpdf_value['label']) . ' :</b><br>';

								$rtwgftpdf_adv_shiped = apply_filters('rtwgftpdf_remove_label',$rtwgftpdf_adv_shiped);

								if(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_two')
								{
									$rtwgftpdf_adv_shiped = '';
									$rtwgftpdf_adv_ship = '';
								}
								$rtwgftpdf_adv_ship = $rtwgftpdf_lead[$rtwgftpdf_value['id']];
								$rtwgftpdf_arr = explode("|", $rtwgftpdf_adv_ship);
								$rtwgftpdf_adv_shiped .= esc_html($rtwgftpdf_arr[0]).' : '.esc_html($rtwgftpdf_arr[1]) ;

								if(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_three')
								{
									$rtwgftpdf_adv_ship = '<div class="rtw_form_other_field">'.esc_html( $rtwgftpdf_arr[0] ).' : '.esc_html( $rtwgftpdf_arr[1] ) .'</div>';
								}

								array_push($rtwgftpdf_scnd_array, $rtwgftpdf_adv_shiped);
							}
							array_push($rtwgftpdf_field_value_array, $rtwgftpdf_lead[$rtwgftpdf_value['id']]);
						}
						elseif($rtwgftpdf_value['type'] == 'total')
						{
							$rtwbma_currencies = get_option('rtwgftpdf_currencies', array());

							$total = number_format((float)$rtwgftpdf_lead[$rtwgftpdf_value['id']], isset($rtwbma_currencies[$rtwgftpdf_lead['currency']])?$rtwbma_currencies[$rtwgftpdf_lead['currency']]['decimals'] : 2, isset($rtwbma_currencies[$rtwgftpdf_lead['currency']])?$rtwbma_currencies[$rtwgftpdf_lead['currency']]['thousand_separator'] : ',', isset($rtwbma_currencies[$rtwgftpdf_lead['currency']])?$rtwbma_currencies[$rtwgftpdf_lead['currency']]['decimal_separator'] : '.');

							$total_after_symbol = (isset($rtwbma_currencies[$rtwgftpdf_lead['currency']])?$rtwbma_currencies[$rtwgftpdf_lead['currency']]['symbol_left'] : '') . $total . (isset($rtwbma_currencies[$rtwgftpdf_lead['currency']])?$rtwbma_currencies[$rtwgftpdf_lead['currency']]['symbol_right'] : ''); 
							
							$rtwgftpdf_adv_field = '';
							$rtwgftpdf_adv_field = '<b>'. esc_html($rtwgftpdf_value['label']). ' </b>   <br>';
							$rtwgftpdf_adv_field = apply_filters('rtwgftpdf_remove_label',$rtwgftpdf_adv_field);
							$rtwgftpdf_adv_field .= esc_html($total_after_symbol);
							if(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_one')
							{
								$rtwgftpdf_adv_field = '<div class="rtw_label"><b>'. esc_html($rtwgftpdf_value['label']).' </b></div><br>';

								$rtwgftpdf_adv_field .= '<div class="rtw_div">'. esc_html($total_after_symbol).'</div>';
							}
							elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_two')
							{
								$rtwgftpdf_adv_field = '<div class="rtw_form_other_field">' .esc_html($total_after_symbol).'</div>';
							}
							elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_three')
							{
								$rtwgftpdf_adv_field = '<div class="rtw_form_other_field">' .esc_html($total_after_symbol).'</div>';
							}
							array_push($rtwgftpdf_scnd_array, $rtwgftpdf_adv_field);
							array_push($rtwgftpdf_field_value_array, $total_after_symbol);
						}
						elseif($rtwgftpdf_value['type'] == 'number')
						{
							if($rtwgftpdf_value['numberFormat'] == 'currency')
							{
								$rtwbma_currencies = get_option('rtwgftpdf_currencies', array());
								
								$total = number_format((float)$rtwgftpdf_lead[$rtwgftpdf_value['id']], isset($rtwbma_currencies[$rtwgftpdf_lead['currency']])?$rtwbma_currencies[$rtwgftpdf_lead['currency']]['decimals'] : 2, isset($rtwbma_currencies[$rtwgftpdf_lead['currency']])?$rtwbma_currencies[$rtwgftpdf_lead['currency']]['thousand_separator'] : ',', isset($rtwbma_currencies[$rtwgftpdf_lead['currency']])?$rtwbma_currencies[$rtwgftpdf_lead['currency']]['decimal_separator'] : '.');

								
								if(!empty($rtwgftpdf_lead[$rtwgftpdf_value['id']]))
								{
									$total_after_symbol = (isset($rtwbma_currencies[$rtwgftpdf_lead['currency']])?$rtwbma_currencies[$rtwgftpdf_lead['currency']]['symbol_left'] : '') . $total . (isset($rtwbma_currencies[$rtwgftpdf_lead['currency']])?$rtwbma_currencies[$rtwgftpdf_lead['currency']]['symbol_right'] : ''); 
								}else{
									$total_after_symbol = '';
								}
							
								$rtwgftpdf_adv_field = '';
								$rtwgftpdf_adv_field = '<b>'. esc_html($rtwgftpdf_value['label']). ' </b>   <br>';
								$rtwgftpdf_adv_field = apply_filters('rtwgftpdf_remove_label',$rtwgftpdf_adv_field);
								$rtwgftpdf_adv_field .= esc_html($total_after_symbol);
								if(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_one')
								{
									$rtwgftpdf_adv_field = '<div class="rtw_label"><b>'. esc_html($rtwgftpdf_value['label']).' </b></div><br>';
	
									$rtwgftpdf_adv_field .= '<div class="rtw_div">'. esc_html($total_after_symbol).'</div>';
								}
								elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_two')
								{
									$rtwgftpdf_adv_field = '<div class="rtw_form_other_field">' .esc_html($total_after_symbol).'</div>';
								}
								elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_three')
								{
									$rtwgftpdf_adv_field = '<div class="rtw_form_other_field">' .esc_html($total_after_symbol).'</div>';
								}
								array_push($rtwgftpdf_scnd_array, $rtwgftpdf_adv_field);
								array_push($rtwgftpdf_field_value_array, $total_after_symbol);
							}
							elseif($rtwgftpdf_value['numberFormat'] == 'decimal_dot')
							{
								if(!empty($rtwgftpdf_lead[$rtwgftpdf_value['id']]))
								{
									$number_decimal = number_format((float)$rtwgftpdf_lead[$rtwgftpdf_value['id']], 2);
								}else{
									$number_decimal = $rtwgftpdf_lead[$rtwgftpdf_value['id']];
								}
								
								$rtwgftpdf_adv_field = '';
								$rtwgftpdf_adv_field = '<b>'. esc_html($rtwgftpdf_value['label']). ' </b>   <br>';
								$rtwgftpdf_adv_field = apply_filters('rtwgftpdf_remove_label',$rtwgftpdf_adv_field);
								$rtwgftpdf_adv_field .= esc_html($number_decimal);
								if(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_one')
								{
									$rtwgftpdf_adv_field = '<div class="rtw_label"><b>'. esc_html($rtwgftpdf_value['label']).' </b></div><br>';
	
									$rtwgftpdf_adv_field .= '<div class="rtw_div">'. esc_html($number_decimal).'</div>';
								}
								elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_two')
								{
									$rtwgftpdf_adv_field = '<div class="rtw_form_other_field">' .esc_html($number_decimal).'</div>';
								}
								elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_three')
								{
									$rtwgftpdf_adv_field = '<div class="rtw_form_other_field">' .esc_html($number_decimal).'</div>';
								}
								array_push($rtwgftpdf_scnd_array, $rtwgftpdf_adv_field);
								array_push($rtwgftpdf_field_value_array, $number_decimal);
							}
							elseif($rtwgftpdf_value['numberFormat'] == 'decimal_comma')
							{
								if(!empty($rtwgftpdf_lead[$rtwgftpdf_value['id']]))
								{
									$number_decimal = number_format((float)$rtwgftpdf_lead[$rtwgftpdf_value['id']], 2, ",", '.');
								}else{
									$number_decimal = $rtwgftpdf_lead[$rtwgftpdf_value['id']];
								}
								
								$rtwgftpdf_adv_field = '';
								$rtwgftpdf_adv_field = '<b>'. esc_html($rtwgftpdf_value['label']). ' </b>   <br>';
								$rtwgftpdf_adv_field = apply_filters('rtwgftpdf_remove_label',$rtwgftpdf_adv_field);
								$rtwgftpdf_adv_field .= esc_html($number_decimal);
								if(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_one')
								{
									$rtwgftpdf_adv_field = '<div class="rtw_label"><b>'. esc_html($rtwgftpdf_value['label']).' </b></div><br>';
	
									$rtwgftpdf_adv_field .= '<div class="rtw_div">'. esc_html($number_decimal).'</div>';
								}
								elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_two')
								{
									$rtwgftpdf_adv_field = '<div class="rtw_form_other_field">' .esc_html($number_decimal).'</div>';
								}
								elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_three')
								{
									$rtwgftpdf_adv_field = '<div class="rtw_form_other_field">' .esc_html($number_decimal).'</div>';
								}
								array_push($rtwgftpdf_scnd_array, $rtwgftpdf_adv_field);
								array_push($rtwgftpdf_field_value_array, $number_decimal);
							}
							else
							{
								$rtwgftpdf_adv_field = '';
								$rtwgftpdf_adv_field = '<b>'. esc_html($rtwgftpdf_value['label']). ' </b>   <br>';
								$rtwgftpdf_adv_field = apply_filters('rtwgftpdf_remove_label',$rtwgftpdf_adv_field);
								$rtwgftpdf_adv_field .= esc_html($rtwgftpdf_lead[$rtwgftpdf_value['id']]);
								if(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_one')
								{
									$rtwgftpdf_adv_field = '<div class="rtw_label"><b>'. esc_html($rtwgftpdf_value['label']).' </b></div><br>';
	
									$rtwgftpdf_adv_field .= '<div class="rtw_div">'. esc_html($rtwgftpdf_lead[$rtwgftpdf_value['id']]).'</div>';
								}
								elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_two')
								{
									$rtwgftpdf_adv_field = '<div class="rtw_form_other_field">' .esc_html($rtwgftpdf_lead[$rtwgftpdf_value['id']]).'</div>';
								}
								elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_three')
								{
									$rtwgftpdf_adv_field = '<div class="rtw_form_other_field">' .esc_html($rtwgftpdf_lead[$rtwgftpdf_value['id']]).'</div>';
								}
								array_push($rtwgftpdf_scnd_array, $rtwgftpdf_adv_field);
								array_push($rtwgftpdf_field_value_array, $rtwgftpdf_lead[$rtwgftpdf_value['id']]);
							}
						}
						elseif($rtwgftpdf_value['type'] == 'date')
						{
							$date_info = GFcommon::parse_date( $rtwgftpdf_lead[$rtwgftpdf_value['id']], $rtwgftpdf_value['dateFormat'] );
							$field_val = $this->get_date_array_by_format( array( $date_info['month'], $date_info['day'], $date_info['year'] ), $rtwgftpdf_value['dateFormat'] );

							$rtwgftpdf_adv_field = '';
							$rtwgftpdf_adv_field = '<b>'. esc_html($rtwgftpdf_value['label']). ' </b>   <br>';
							$rtwgftpdf_adv_field = apply_filters('rtwgftpdf_remove_label',$rtwgftpdf_adv_field);
							$rtwgftpdf_adv_field .= esc_html($field_val);
							if(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_one')
							{
								$rtwgftpdf_adv_field = '<div class="rtw_label"><b>'. esc_html($rtwgftpdf_value['label']).' </b></div><br>';

								$rtwgftpdf_adv_field .= '<div class="rtw_div">'. esc_html($field_val).'</div>';
							}
							elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_two')
							{
								$rtwgftpdf_adv_field = '<div class="rtw_form_other_field">' .esc_html($field_val).'</div>';
							}
							elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_three')
							{
								$rtwgftpdf_adv_field = '<div class="rtw_form_other_field">' .esc_html($field_val).'</div>';
							}
							array_push($rtwgftpdf_scnd_array, $rtwgftpdf_adv_field);
							array_push($rtwgftpdf_field_value_array, $field_val);
						}
						elseif($rtwgftpdf_value['type'] == 'signature')
						{
							if($rtwgftpdf_lead[$rtwgftpdf_value['id']] != '')
							{
								$rtwgftpdf_sign_url = '';

								$sign_url = WP_CONTENT_DIR.'/uploads/gravity_forms/signatures/'.$rtwgftpdf_lead[$rtwgftpdf_value['id']];
								$rtwgftpdf_sign_url =
									'<b>'. esc_html($rtwgftpdf_value['label']).' :        </b>';
								
								$rtwgftpdf_sign_url = apply_filters('rtwgftpdf_remove_label',$rtwgftpdf_sign_url);

								if( !empty($rtwgft_img_width) && !empty($rtwgft_img_height) )
								{
									$rtwgftpdf_sign_url .=
									'<img width="'. $rtwgft_img_width .'px" height="'. $rtwgft_img_height .'px" id="rtwgftpdf_post_image" src="'.esc_url($sign_url).'" />';
								}
								else{
									$rtwgftpdf_sign_url .=
									'<img id="rtwgftpdf_post_image" src="'.esc_url($sign_url).'" />';
								}

								if(isset( $rtwgftpdf_editor_format_option['rtw_template_select'] ) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_two' )
								{
									if( !empty($rtwgft_img_width) && !empty($rtwgft_img_height) )
									{
										$rtwgftpdf_sign_url =
										// '<b>'. esc_html($rtwgftpdf_value['label']).' :        </b> 
										'<img width="'. $rtwgft_img_width .'px" height="'. $rtwgft_img_height .'px" id="rtwgftpdf_post_image" src="'.esc_url($sign_url).'" />';
									}
									else{
										$rtwgftpdf_sign_url =
										// '<b>'. esc_html($rtwgftpdf_value['label']).' :        </b> 
										'<img id="rtwgftpdf_post_image" src="'.esc_url($sign_url).'" />';
									}
								}
								array_push($rtwgftpdf_scnd_array, $rtwgftpdf_sign_url);
								array_push($rtwgftpdf_field_value_array, $rtwgftpdf_lead[$rtwgftpdf_value['id']]);
							}
							else
							{
								if (isset($this->rtwgftpdf_stng ['emtpy_field'] ) && $this->rtwgftpdf_stng ['emtpy_field'] == 'Yes') 
								{
									$rtwgftpdf_sign_url = $rtwgftpdf_lead[$rtwgftpdf_value['id']];
									array_push($rtwgftpdf_scnd_array, $rtwgftpdf_sign_url);
									array_push($rtwgftpdf_field_value_array, $rtwgftpdf_sign_url);
								}
							}
						}
						else
						{
							$rtwgftpdf_adv_field = '';
							$rtwgftpdf_adv_field = '<b>'. esc_html($rtwgftpdf_value['label']). ' </b>   <br>';
							$rtwgftpdf_adv_field = apply_filters('rtwgftpdf_remove_label',$rtwgftpdf_adv_field);
							$rtwgftpdf_adv_field .= esc_html(isset($rtwgftpdf_lead[$rtwgftpdf_value['id']])?$rtwgftpdf_lead[$rtwgftpdf_value['id']]:'' );
							if(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_one')
							{
								$rtwgftpdf_adv_field = '<div class="rtw_label"><b>'. esc_html($rtwgftpdf_value['label']).' </b></div><br>';

								$rtwgftpdf_adv_field .= '<div class="rtw_div">'. esc_html(isset($rtwgftpdf_lead[$rtwgftpdf_value['id']])?$rtwgftpdf_lead[$rtwgftpdf_value['id']]:'').'</div>';
							}
							elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_two')
							{
								$rtwgftpdf_adv_field = '<div class="rtw_form_other_field">' .esc_html(isset($rtwgftpdf_lead[$rtwgftpdf_value['id']])?$rtwgftpdf_lead[$rtwgftpdf_value['id']]:'').'</div>';
							}
							elseif(isset($rtwgftpdf_editor_format_option['rtw_template_select']) && $rtwgftpdf_editor_format_option['rtw_template_select'] == 'temp_three')
							{
								$rtwgftpdf_adv_field = '<div class="rtw_form_other_field">' .esc_html(isset($rtwgftpdf_lead[$rtwgftpdf_value['id']])?$rtwgftpdf_lead[$rtwgftpdf_value['id']]:'').'</div>';
							}
							array_push($rtwgftpdf_scnd_array, $rtwgftpdf_adv_field);
							array_push($rtwgftpdf_field_value_array, isset($rtwgftpdf_lead[$rtwgftpdf_value['id']])?$rtwgftpdf_lead[$rtwgftpdf_value['id']]:'');
						}
					}
				}
				
				$google_sheet_data = get_option('rtwgftpdf_google_spreadsheet_opt', array());
				// code for google sheet
				if( isset($google_sheet_data['googlesheet_enable']) && $google_sheet_data['googlesheet_enable'] == 1 && (! empty( $google_sheet_data['sheet_id'] ) ) && (! empty( $google_sheet_data['sheet_tabname'] ) ) )
				{
					$google_data = array();
					try 
					{
						if( !class_exists( 'rtwgftpdf_googlesheet' ) )
						{
							include_once( plugin_dir_path(__FILE__) . 'rtwgftpdf-gravity-form-to-pdf-googlesheet.php' );
						}
						
						$rtwgftpdf_googlesheet = new rtwgftpdf_googlesheet();
						$rtwgftpdf_googlesheet->rtwgftpdf_spreadsheet_set_title( $google_sheet_data['sheet_id'] );
						$rtwgftpdf_googlesheet->rtwgftpdf_set_worksheet_title( $google_sheet_data['sheet_tabname'] );
						$rtwgftpdf_field_n_val = array_combine($rtwgftpdf_label_array, $rtwgftpdf_field_value_array);
						
						$rtwgftpdf_googlesheet->rtwgftpdf_add_row( $rtwgftpdf_field_n_val, $google_sheet_data );
					} 
					catch ( Exception $e ) 
					{
						$google_data['ERROR_MSG'] = $e->getMessage();
            			$google_data['TRACE_STK'] = $e->getTraceAsString();
					}
				}
				
				$rtwgftpdf_post_data_new = str_replace($rtwgftpdf_frst_array, $rtwgftpdf_scnd_array, $rtwgftpdf_editor_format);
				
				$rtwgftpdf_pa = $this->rtwgftpdf_convert_to_pdf($rtwgftpdf_post_data_new, $rtwgftpdf_forms, $rtwgftpdf_form_title, $rtwgftpdf_guest_name, $rtwgftpdf_guest_email );
			}
		}
	}

	public function get_date_array_by_format( $value, $dateFormat ) {
		$format   = empty( $dateFormat ) ? 'mdy' : esc_attr( $dateFormat );
		$position = substr( $format, 0, 3 );
		$date     = array_combine( array( 'm', 'd', 'y' ), $value );            // takes our numerical array and converts it to an associative array
		$value    = array_merge( array_flip( str_split( $position ) ), $date ); // uses the mdy position as the array keys and creates a new array in the desired order

		$format='';
		if($dateFormat == 'mdy')
		{
			$format = $value['m'].'/'.$value['d'].'/'.$value['y'];
		}
		elseif($dateFormat == 'dmy')
		{
			$format = $value['d'].'/'.$value['m'].'/'.$value['y'];
		}
		elseif($dateFormat == 'dmy_dash')
		{
			$format = $value['d'].'-'.$value['m'].'-'.$value['y'];
		}
		elseif($dateFormat == 'dmy_dot')
		{
			$format = $value['d'].'.'.$value['m'].'.'.$value['y'];
		}
		elseif($dateFormat == 'ymd_slash')
		{
			$format = $value['y'].'/'.$value['m'].'/'.$value['d'];
		}
		elseif($dateFormat == 'ymd_dash')
		{
			$format = $value['y'].'-'.$value['m'].'-'.$value['d'];
		}
		elseif($dateFormat == 'ymd_dot')
		{
			$format = $value['y'].'.'.$value['m'].'.'.$value['d'];
		}
		return $format;
	}
	/**
	 * Function to provide download PDF button.
	 *
	 * @since    1.0.0
	 */
	function rtwgftpdf_after_confirmation_callback( $rtwgftpdf_confirmation, $rtwgftpdf_form, $rtwgftpdf_lead, $rtwgftpdf_ajax )
	{
		if( in_array('gp-unique-id/gp-unique-id.php', apply_filters('active_plugins', get_option('active_plugins'), array() ) ) )
		{
			$this->rtwgftpdf_after_submission_callback($rtwgftpdf_lead, $rtwgftpdf_form);
		}
		/////// compatibility with unique id add-on ///////
		
		$rtwgftpdf_verification_done = get_option( 'rtwgftpdf_verification_done', array() );

		if( !empty( $rtwgftpdf_verification_done ) && $rtwgftpdf_verification_done['status'] == true && !empty( $rtwgftpdf_verification_done['purchase_code'] ) )
		{
			$rtwgftpdf_form_id = $rtwgftpdf_lead['form_id'];
			$rtwgftpdf_basic_setting 	= get_option('rtwgftpdf_basic_setting_opt',array());

			$rtwgft_selected_forms = isset( $rtwgftpdf_basic_setting['rtwwdpd_selected_forms'] ) ? $rtwgftpdf_basic_setting['rtwwdpd_selected_forms'] : array();

			if( !isset( $rtwgftpdf_basic_setting['rtwwdpd_selected_forms'] ) )
			{
				$pdf_name = isset($rtwgftpdf_basic_setting['pdf_name']) ? $rtwgftpdf_basic_setting['pdf_name'] : 'rtwgftpdf_';

				$rtwgftpdf_pa = RTWGFTPDF_CONTENT_URL.'/'. $pdf_name .esc_html($rtwgftpdf_lead['id']).'.pdf';

				$rtwgftpdf_msg ='';
				if(isset($this->rtwgftpdf_stng['pass_pattern']) && $this->rtwgftpdf_stng['pass_pattern'] == 1)
				{
					if(is_user_logged_in())
					{
						if(isset($this->rtwgftpdf_stng['pass_Login']) && $this->rtwgftpdf_stng['pass_Login'] == 'Pass_Email')
						{
							$rtwgftpdf_msg = esc_html__('Your PDF password is first four letters of your Email.', 'rtwgftpdf-gravity-form-to-pdf');
						}
						elseif(isset($this->rtwgftpdf_stng['pass_Login']) && $this->rtwgftpdf_stng['pass_Login'] == 'Pass_Name')
						{
							$rtwgftpdf_msg = esc_html__('Your PDF password is first four letters of your Name.','rtwgftpdf-gravity-form-to-pdf');
						}
						else
						{
							$rtwgftpdf_msg = esc_html__('Your PDF password is first four letters of your Name & first four letters of your email','rtwgftpdf-gravity-form-to-pdf');
						}
					}
					else
					{
						if(isset($this->rtwgftpdf_stng['pass_Guest']) && $this->rtwgftpdf_stng['pass_Guest'] == 'Pass_N')
						{
							$rtwgftpdf_msg = esc_html__('Your PDF password is first four letters of your form first field.','rtwgftpdf-gravity-form-to-pdf');
						}
						elseif(isset($this->rtwgftpdf_stng['pass_Guest']) && $this->rtwgftpdf_stng['pass_Guest'] == 'Pass_E')
						{
							$rtwgftpdf_msg = esc_html__('Your PDF password is first four letters of your form second field.','rtwgftpdf-gravity-form-to-pdf');
						}
						else
						{
							$rtwgftpdf_msg = esc_html__('Your PDF password is first four letters of your form first & second field repectively','rtwgftpdf-gravity-form-to-pdf');
						}
					}
				}

				if( isset($this->rtwgftpdf_stng['button_img_width']) && $this->rtwgftpdf_stng['button_img_width'] != '')
				{
					$rtwgftpdf_img_width = $this->rtwgftpdf_stng['button_img_width'];
				}
				else
				{
					$rtwgftpdf_img_width = 60;
				}
				if( isset($this->rtwgftpdf_stng['button_img_height']) && $this->rtwgftpdf_stng['button_img_height'] != '')
				{
					$rtwgftpdf_img_height = $this->rtwgftpdf_stng['button_img_height'];
				}
				else
				{
					$rtwgftpdf_img_height = 30;
				}
				if( isset($this->rtwgftpdf_stng['gnrt_pdf']) && ( $this->rtwgftpdf_stng['gnrt_pdf'] == 'Download' || $this->rtwgftpdf_stng['gnrt_pdf'] == 'Both' ) )
				{
					if( isset($this->rtwgftpdf_stng['bttn_img_url']) && $this->rtwgftpdf_stng['bttn_img_url'] != '')
					{
						$rtwgftpdf_btn_img_url = $this->rtwgftpdf_stng['bttn_img_url'];
						$rtwgftpdf_img = '<a target="_blank" href="'.esc_url($rtwgftpdf_pa).'"><img src="'.esc_url($rtwgftpdf_btn_img_url).'" height="'.esc_attr($rtwgftpdf_img_height).'" width="'.esc_attr($rtwgftpdf_img_width).'"></a>';
						return $rtwgftpdf_confirmation . 
						'<p class="rtwgftpdf_notify_pdf_pass">'. esc_html__($rtwgftpdf_msg,"rtwgftpdf-gravity-form-to-pdf"). ' </p>'.$rtwgftpdf_img;
					}
					else
					{
						return $rtwgftpdf_confirmation . 
						'<p class="rtwgftpdf_notify_pdf_pass">'. esc_html__($rtwgftpdf_msg,"rtwgftpdf-gravity-form-to-pdf"). ' </p><a target="_blank" href="'. esc_url($rtwgftpdf_pa) . '"><button class="rtwgpdf" data-form_id="' . esc_attr($rtwgftpdf_form_id) . '"> Download PDF </button></a>';
					}
				}
				else
				{
					return $rtwgftpdf_confirmation;
				}
			}
			elseif(isset($rtwgftpdf_basic_setting['rtwwdpd_selected_forms']) && in_array($rtwgftpdf_form_id, $rtwgftpdf_basic_setting['rtwwdpd_selected_forms']))
			{
				$pdf_name = isset($rtwgftpdf_basic_setting['pdf_name']) ? $rtwgftpdf_basic_setting['pdf_name'] : 'rtwgftpdf_';

				$rtwgftpdf_pa = RTWGFTPDF_CONTENT_URL.'/'. $pdf_name .esc_html($rtwgftpdf_lead['id']).'.pdf';

				$rtwgftpdf_msg ='';
				if(isset($this->rtwgftpdf_stng['pass_pattern']) && $this->rtwgftpdf_stng['pass_pattern'] == 1)
				{
					if(is_user_logged_in())
					{
						if(isset($this->rtwgftpdf_stng['pass_Login']) && $this->rtwgftpdf_stng['pass_Login'] == 'Pass_Email')
						{
							$rtwgftpdf_msg = esc_html__('Your PDF password is first four letters of your Email.', 'rtwgftpdf-gravity-form-to-pdf');
						}
						elseif(isset($this->rtwgftpdf_stng['pass_Login']) && $this->rtwgftpdf_stng['pass_Login'] == 'Pass_Name')
						{
							$rtwgftpdf_msg = esc_html__('Your PDF password is first four letters of your Name.','rtwgftpdf-gravity-form-to-pdf');
						}
						else
						{
							$rtwgftpdf_msg = esc_html__('Your PDF password is first four letters of your Name & first four letters of your email','rtwgftpdf-gravity-form-to-pdf');
						}
					}
					else
					{
						if(isset($this->rtwgftpdf_stng['pass_Guest']) && $this->rtwgftpdf_stng['pass_Guest'] == 'Pass_N')
						{
							$rtwgftpdf_msg = esc_html__('Your PDF password is first four letters of your form first field.','rtwgftpdf-gravity-form-to-pdf');
						}
						elseif(isset($this->rtwgftpdf_stng['pass_Guest']) && $this->rtwgftpdf_stng['pass_Guest'] == 'Pass_E')
						{
							$rtwgftpdf_msg = esc_html__('Your PDF password is first four letters of your form second field.','rtwgftpdf-gravity-form-to-pdf');
						}
						else
						{
							$rtwgftpdf_msg = esc_html__('Your PDF password is first four letters of your form first & second field repectively','rtwgftpdf-gravity-form-to-pdf');
						}
					}
				}

				if( isset($this->rtwgftpdf_stng['button_img_width']) && $this->rtwgftpdf_stng['button_img_width'] != '')
				{
					$rtwgftpdf_img_width = $this->rtwgftpdf_stng['button_img_width'];
				}
				else
				{
					$rtwgftpdf_img_width = 60;
				}
				if( isset($this->rtwgftpdf_stng['button_img_height']) && $this->rtwgftpdf_stng['button_img_height'] != '')
				{
					$rtwgftpdf_img_height = $this->rtwgftpdf_stng['button_img_height'];
				}
				else
				{
					$rtwgftpdf_img_height = 30;
				}
				if( isset($this->rtwgftpdf_stng['gnrt_pdf']) && ( $this->rtwgftpdf_stng['gnrt_pdf'] == 'Download' || $this->rtwgftpdf_stng['gnrt_pdf'] == 'Both' ) )
				{
					if( isset($this->rtwgftpdf_stng['bttn_img_url']) && $this->rtwgftpdf_stng['bttn_img_url'] != '')
					{
						$rtwgftpdf_btn_img_url = $this->rtwgftpdf_stng['bttn_img_url'];
						$rtwgftpdf_img = '<a target="_blank" href="'.esc_url($rtwgftpdf_pa).'"><img src="'.esc_url($rtwgftpdf_btn_img_url).'" height="'.esc_attr($rtwgftpdf_img_height).'" width="'.esc_attr($rtwgftpdf_img_width).'"></a>';
						return $rtwgftpdf_confirmation . 
						'<p class="rtwgftpdf_notify_pdf_pass">'. esc_html__($rtwgftpdf_msg,"rtwgftpdf-gravity-form-to-pdf"). ' </p>'.$rtwgftpdf_img;
					}
					else
					{
						return $rtwgftpdf_confirmation . 
						'<p class="rtwgftpdf_notify_pdf_pass">'. esc_html__($rtwgftpdf_msg,"rtwgftpdf-gravity-form-to-pdf"). ' </p><a target="_blank" href="'. esc_url($rtwgftpdf_pa) . '"><button class="rtwgpdf" data-form_id="' . esc_attr($rtwgftpdf_form_id) . '"> Download PDF </button></a>';
					}
				}
				else
				{
					return $rtwgftpdf_confirmation;
				}
			}
			else
			{
				return $rtwgftpdf_confirmation;
			}
		}
		else{
			return $rtwgftpdf_confirmation;
		}
	}

	/**
	 * Function to provide PDF preview.
	 *
	 * @since    1.0.0
	 */
	public function rtwgftpdf_preview_pdf()
	{
		if(isset($_POST['rtw_preview_pdf']))
		{
			
			$found = preg_match('/id=[0-9]+/', $_POST['_wp_http_referer'], $match);
			$form_id = (int)substr($match[0], strlen("id="));
			
			$rtwgftpdf_editor_format = get_option('rtwgftpdf_editor_format_opt_'. $form_id);
			$rtwgftpdf_html = $rtwgftpdf_editor_format['editor'][1];
			
			$this->rtwgftpdf_convert_to_pdf($rtwgftpdf_html, 1, 'Title', 'abcd', 'abcd');
		}
	}

	/**
	 * Function to convert Gravity Form data to PDF.
	 *
	 * @since    1.0.0
	 */

	public function rtwgftpdf_convert_to_pdf($rtwgftpdf_html, $rtwgftpdf_form, $rtwgftpdf_form_title, $rtwgftpdf_guest_name, $rtwgftpdf_guest_email)
	{
		$rtwgftpdf_verification_done = get_option( 'rtwgftpdf_verification_done', array() );

		if( !empty( $rtwgftpdf_verification_done ) && $rtwgftpdf_verification_done['status'] == true && !empty($rtwgftpdf_verification_done['purchase_code']) )
		{
			error_reporting(0);
			ini_set('display_errors', 0);
			if( empty( $rtwgftpdf_form ) )
			{
				global $rtwgftpdf_form;
			}
			$rtwgftpdf_title = '';

			$rtwgftpdf_basic_setting 	= get_option('rtwgftpdf_basic_setting_opt',array());
			$pdf_name = isset($rtwgftpdf_basic_setting['pdf_name']) ? $rtwgftpdf_basic_setting['pdf_name'] : 'rtwgftpdf_';

			$rtwgftpdf_file_path = RTWGFTPDF_CONTENT_DIR . '/'. $pdf_name . esc_html($rtwgftpdf_form) . '.pdf';

			if (isset($this->rtwgftpdf_stng ['page_title'] ) && $this->rtwgftpdf_stng ['page_title'] == 'Yes') 
			{
				$rtwgftpdf_title = esc_html('Title : ') . esc_html($rtwgftpdf_form_title);
			}

			$rtwgftpdf_pdf_html = '<style> ';

			if ( isset($this->rtwgftpdf_stng ['pdf_css']) && !empty($this->rtwgftpdf_stng ['pdf_css']) )
			{
				$rtwgftpdf_pdf_html .= $this->rtwgftpdf_stng ['pdf_css'];
			}
			$rtwgftpdf_pdf_html .= '</style>';

			$rtwgftpdf_pdf_html .= "<h2 style=\"text-align:center;margin:0px;padding:0px;\">".apply_filters ( 'rtwgftpdf_post_title', esc_html($rtwgftpdf_title), esc_html($rtwgftpdf_form) )."</h2>";

			/*PDF Page Size*/
			if( isset( $this->rtwgftpdf_stng ['pdf_page_size'] ) && $this->rtwgftpdf_stng ['pdf_page_size'] != 'Select' ) 
			{
				$rtwgftpdf_page_size = $this->rtwgftpdf_stng ['pdf_page_size'];
			} 
			else 
			{
				$rtwgftpdf_page_size = serialize(array(210,297));
			}
			/*End PDF Page Size*/

			/*Gform HTML*/
			$rtwgftpdf_pdf_html .= $rtwgftpdf_html;

			/*PDF Page Orientation*/
			if( isset( $this->rtwgftpdf_stng ['page_orien'] ) ) 
			{
				$rtwgftpdf_page_orientation = $this->rtwgftpdf_stng ['page_orien'];
			} 
			else 
			{
				$rtwgftpdf_page_orientation = 'P';
			}
			/*End PDF Page Orientation*/

			/*PDF left margin*/
			if( isset( $this->rtwgftpdf_stng['body_left_margin'] ) && !empty( $this->rtwgftpdf_stng ['body_left_margin'] ) )
			{
				$rtwgftpdf_lft_marg = $this->rtwgftpdf_stng ['body_left_margin'];	
			}
			elseif( isset( $this->rtwgftpdf_stng['body_left_margin'] ) && $this->rtwgftpdf_stng ['body_left_margin'] == 0 )
			{
				$rtwgftpdf_lft_marg = $this->rtwgftpdf_stng ['body_left_margin'];
			} 
			else 
			{
				$rtwgftpdf_lft_marg = 15;
			}

			/*PDF right margin*/
			if( isset( $this->rtwgftpdf_stng['body_right_margin'] ) && !empty( $this->rtwgftpdf_stng ['body_right_margin'] ) )
			{
				$rtwgftpdf_rgt_marg = $this->rtwgftpdf_stng ['body_right_margin'];	
			} 
			elseif( isset( $this->rtwgftpdf_stng['body_right_margin'] ) && $this->rtwgftpdf_stng ['body_right_margin'] == 0 )
			{
				$rtwgftpdf_rgt_marg = $this->rtwgftpdf_stng ['body_right_margin'];
			}
			else 
			{
				$rtwgftpdf_rgt_marg = 15;
			}

			/*PDF top margin*/
			if( isset( $this->rtwgftpdf_stng['body_top_margin'] ) && !empty( $this->rtwgftpdf_stng ['body_top_margin'] ) )
			{
				$rtwgftpdf_top_marg = $this->rtwgftpdf_stng ['body_top_margin'];	
			} 
			elseif( isset( $this->rtwgftpdf_stng['body_top_margin'] ) && $this->rtwgftpdf_stng ['body_top_margin'] == 0 )
			{
				$rtwgftpdf_top_marg = $this->rtwgftpdf_stng ['body_top_margin'];
			}
			else 
			{
				$rtwgftpdf_top_marg = 15;
			}

			/*PDF header top margin*/
			if( isset( $this->rtwgftpdf_stng['header_top_margin'] ) && !empty( $this->rtwgftpdf_stng ['header_top_margin'] ) && $this->rtwgftpdf_stng ['header_top_margin'] != 0 )
			{
				$rtwgftpdf_hdr_top_marg = $this->rtwgftpdf_stng ['header_top_margin'];	
			} 
			elseif( isset( $this->rtwgftpdf_stng['header_top_margin'] ) && $this->rtwgftpdf_stng ['header_top_margin'] == 0 )
			{
				$rtwgftpdf_hdr_top_marg = $this->rtwgftpdf_stng ['header_top_margin'];	
			}
			else 
			{
				$rtwgftpdf_hdr_top_marg = 7;
			}

			/*PDF footer top margin*/
			if( isset( $this->rtwgftpdf_stng['footer_top_margin'] ) && !empty( $this->rtwgftpdf_stng ['footer_top_margin'] ) && $this->rtwgftpdf_stng ['footer_top_margin'] != 0 )
			{
				$rtwgftpdf_foo_top_marg = $this->rtwgftpdf_stng ['footer_top_margin'];	
			} 
			elseif( isset( $this->rtwgftpdf_stng['footer_top_margin'] ) && $this->rtwgftpdf_stng ['footer_top_margin'] = 0 )
			{
				$rtwgftpdf_foo_top_marg = $this->rtwgftpdf_stng ['footer_top_margin'];	
			} 
			else 
			{
				$rtwgftpdf_foo_top_marg = 15;
			}

			if( isset($this->rtwgftpdf_stng['body_font_family']) && !empty($this->rtwgftpdf_stng['body_font_family']) )
			{
				$rtwgftpdf_body_font_family = $this->rtwgftpdf_stng['body_font_family'];
			}
			else
			{
				$rtwgftpdf_body_font_family = "dejavusanscondensed";
			}
			if(isset($this->rtwgftpdf_stng['body_font_size']) && !empty( $this->rtwgftpdf_stng['body_font_size'] ) )
			{
				$rtwgftpdf_body_font_size = $this->rtwgftpdf_stng ['body_font_size'];
			}
			else
			{
				$rtwgftpdf_body_font_size = 10;
			}	
			if(!class_exists('mPDF'))
			{	
				include_once( RTWGFTPDF_DIR .'/includes/mpdf/autoload.php');
			}

			$rtwgftpdf_mpdf = new \Mpdf\Mpdf();

			$rtwgftpdf_mpdf = new \Mpdf\Mpdf( ['mode' => 'utf-8', 'format' => unserialize( $rtwgftpdf_page_size ), 'default_font_size' => $rtwgftpdf_body_font_size, 'default_font' => $rtwgftpdf_body_font_family, 'margin_left' => $rtwgftpdf_lft_marg, 'margin_right' => $rtwgftpdf_rgt_marg, 'margin_top' => $rtwgftpdf_top_marg, 'margin_bottom' => '20', 'margin_header' => $rtwgftpdf_hdr_top_marg, 'margin_footer' => $rtwgftpdf_foo_top_marg, 'orientation' => $rtwgftpdf_page_orientation ] );

			// $rtwgftpdf_mpdf = new mPDF( 'utf-8', unserialize( $rtwgftpdf_page_size ), $rtwgftpdf_body_font_size, $rtwgftpdf_body_font_family, $rtwgftpdf_lft_marg, $rtwgftpdf_rgt_marg, $rtwgftpdf_top_marg, 20, $rtwgftpdf_hdr_top_marg, $rtwgftpdf_foo_top_marg, $rtwgftpdf_page_orientation );

			$rtwgftpdf_mpdf->setAutoTopMargin = 'stretch';
			$rtwgftpdf_mpdf->setAutoBottomMargin = 'stretch';
			$rtwgftpdf_mpdf->SetDisplayMode('fullpage');
			if( isset( $this->rtwgftpdf_stng['header_font_size'] ) && !empty( $this->rtwgftpdf_stng['header_font_size'] ) ) 
			{
				$rtwgftpdf_hdr_font_size = $this->rtwgftpdf_stng ['header_font_size'];
			} 
			else 
			{
				$rtwgftpdf_hdr_font_size = 20;
			}

			if( isset( $this->rtwgftpdf_stng['header_font_family'] ) && !empty( $this->rtwgftpdf_stng['header_font_family'] ) )
			{
				$rtwgftpdf_mpdf->defaultheaderfontstyle = $this->rtwgftpdf_stng['header_font_family'];
			}
			else
			{
				$rtwgftpdf_mpdf->defaultheaderfontstyle = 'sans-serif';
			}

			if( isset( $this->rtwgftpdf_stng['footer_font_family'] ) && !empty( $this->rtwgftpdf_stng['footer_font_family'] ) )
			{
				$rtwgftpdf_foo_family = $this->rtwgftpdf_stng['footer_font_family'];
			}
			else
			{
				$rtwgftpdf_foo_family = 'sans-serif';
			}

			$rtwgftpdf_mpdf->defaultfooterfontstyle = esc_html($rtwgftpdf_foo_family);
			$rtwgftpdf_mpdf->defaultheaderfontsize = esc_html($rtwgftpdf_hdr_font_size);
			$rtwgftpdf_mpdf->defaultheaderfontstyle = 'B';	/* blank, B, I, or BI */
			$rtwgftpdf_mpdf->defaultheaderline = 1; 	/* 1 to include line below header/above footer */

			$rtwgftpdf_site_name=get_bloginfo ( 'name' );
			$rtwgftpdf_site_desc=get_bloginfo ( 'description' );
			$rtwgftpdf_site_url=home_url();

		/////// $this->rtwgftpdf_stng['header_html'] this variable is used for html /////////
			if( isset( $this->rtwgftpdf_stng['header_show'] ) && $this->rtwgftpdf_stng['header_show'] == 'Yes' )
			{
				if( isset( $this->rtwgftpdf_stng['header_html'] ) && !empty( $this->rtwgftpdf_stng['header_html'] ) )
				{
					$rtwgftpdf_mpdf->SetHTMLHeader('<div style="width:100%;height:70px;border-bottom: 2px solid #000000;"><div style="float:left;"><h2 style="margin:0px;padding:0px;font-size:'.esc_attr($rtwgftpdf_hdr_font_size).'px;font-family:'.$this->rtwgftpdf_stng['header_font_family'].';">'.$this->rtwgftpdf_stng['header_html'].'</div></h2><p style="margin:0px;padding:0px;font-size:'.esc_attr($rtwgftpdf_hdr_font_size).'px;font-family:'.$this->rtwgftpdf_stng['header_font_family'].';"></p><p style="margin:0px;padding:0px;font-size:'.esc_attr($rtwgftpdf_hdr_font_size).'px;font-family:'.$this->rtwgftpdf_stng['header_font_family'].';"></p></div></div>', 'O');
					$rtwgftpdf_mpdf->SetHTMLHeader('<div style="width:100%;height:70px;border-bottom: 2px solid #000000;"><div style="float:left;"><h2 style="margin:0px;padding:0px;font-size:'.esc_attr($rtwgftpdf_hdr_font_size).'px;font-family:'.$this->rtwgftpdf_stng['header_font_family'].';">'.$this->rtwgftpdf_stng['header_html'].'</div></h2><p style="margin:0px;padding:0px;font-size:'.esc_attr($rtwgftpdf_hdr_font_size).'px;font-family:'.$this->rtwgftpdf_stng['header_font_family'].';"></p><p style="margin:0px;padding:0px;font-size:'.esc_attr($rtwgftpdf_hdr_font_size).'px;font-family:'.$this->rtwgftpdf_stng['header_font_family'].';"></p></div></div>', 'E');
				}
				else
				{
					$rtwgftpdf_mpdf->SetHTMLHeader('<div style="width:100%;height:70px;border-bottom: 2px solid #000000;"><div style="float:left;"><h2 style="margin:0px;padding:0px;font-size:'.esc_attr($rtwgftpdf_hdr_font_size).'px;font-family:'.$this->rtwgftpdf_stng['header_font_family'].';">'.esc_html($rtwgftpdf_site_name).'</h2><p style="margin:0px;padding:0px;font-size:'.esc_attr($rtwgftpdf_hdr_font_size).'px;font-family:'.$this->rtwgftpdf_stng['header_font_family'].';">'.esc_html($rtwgftpdf_site_desc).'</p><p style="margin:0px;padding:0px;font-size:'.esc_attr($rtwgftpdf_hdr_font_size).'px;font-family:'.$this->rtwgftpdf_stng['header_font_family'].';">'.esc_html($rtwgftpdf_site_url).'</p></div></div>','O');
					$rtwgftpdf_mpdf->SetHTMLHeader('<div style="width:100%;height:70px;border-bottom: 2px solid #000000;"><div style="float:left;"><h2 style="margin:0px;padding:0px;font-size:'.esc_attr($rtwgftpdf_hdr_font_size).'px;font-family:'.$this->rtwgftpdf_stng['header_font_family'].';">'.esc_html($rtwgftpdf_site_name).'</h2><p style="margin:0px;padding:0px;font-size:'.esc_attr($rtwgftpdf_hdr_font_size).'px;font-family:'.$this->rtwgftpdf_stng['header_font_family'].';">'.esc_html($rtwgftpdf_site_desc).'</p><p style="margin:0px;padding:0px;font-size:'.esc_attr($rtwgftpdf_hdr_font_size).'px;font-family:'.$this->rtwgftpdf_stng['header_font_family'].';">'.esc_html($rtwgftpdf_site_url).'</p></div></div>','E');
				}
			}
			if( isset( $this->rtwgftpdf_stng['footer_font_size'] ) && !empty( $this->rtwgftpdf_stng['footer_font_size'] ) ) 
			{
				$rtwgftpdf_foo_font_size = $this->rtwgftpdf_stng ['footer_font_size'];
			} 
			else 
			{
				$rtwgftpdf_foo_font_size = 10;
			}
			$rtwgftpdf_mpdf->defaultfooterfontsize = $rtwgftpdf_foo_font_size;	/* in pts */
			$rtwgftpdf_mpdf->defaultfooterfontstyle = 'B';	/* blank, B, I, or BI */
			$rtwgftpdf_mpdf->defaultfooterline = 1; 	/* 1 to include line below header/above footer */
			/*Footer*/
			if( isset($this->rtwgftpdf_stng['footer_html']) && !empty( $this->rtwgftpdf_stng['footer_html'] ) )
			{
				$rtwgftpdf_footer_txt = $this->rtwgftpdf_stng['footer_html'];
			}
			else 
			{
				$rtwgftpdf_footer_txt = '';
			}	

			if (isset($this->rtwgftpdf_stng ['page_number'] ) && $this->rtwgftpdf_stng ['page_number'] == 'Yes') 
			{
				$rtwgftpdf_show_page_no = '{PAGENO}/{nbpg}';
			} 
			else
			{
				$rtwgftpdf_show_page_no = '';
			}
			////// $rtwgftpdf_show_page_no contains hmtl ////////////
			////// rtwgftpdf_footer_txt also conatins html of wp-editor ////////
			if( isset( $this->rtwgftpdf_stng['footer_show'] ) && $this->rtwgftpdf_stng['footer_show'] == 'Yes' )
			{
				$rtwgftpdf_mpdf->SetHTMLFooter( '<div style="width:100%;margin:0px;padding:0px;margin-top:2px;border-top: 2px solid #000000;padding-top:10px"><div style="width: 92%;margin:0px;padding:0px;float: left;font-family:'.$this->rtwgftpdf_stng['footer_font_family'].'; font-size:'.$rtwgftpdf_foo_font_size.';">'.$rtwgftpdf_footer_txt.'</div><div style="width: 8%;margin:0px;padding:0px;float: right;text-align:right;">'. $rtwgftpdf_show_page_no .'</div>', 'O' );
				$rtwgftpdf_mpdf->SetHTMLFooter( '<div style="width:100%;margin:0px;padding:0px;margin-top:2px;border-top: 2px solid #000000;padding-top:10px"><div style="width: 92%;margin:0px;padding:0px;float: left;font-family:'.$this->rtwgftpdf_stng['footer_font_family'].'; font-size:'.$rtwgftpdf_foo_font_size.';">'.$rtwgftpdf_footer_txt.'</div><div style="width: 8%;margin:0px;padding:0px;float: right;text-align:right;">'. $rtwgftpdf_show_page_no .'</div>', 'E' );
			}

			/* WATERMARK */
			if( isset($this->rtwgftpdf_stng ['enable_text_watermark'] ) )
			{
				if( isset($this->rtwgftpdf_stng ['watermark_text'] ) && !empty( $this->rtwgftpdf_stng ['watermark_text'] ) )
				{  
					$rtwgftpdf_alpha=0.2;
					if( isset( $this->rtwgftpdf_stng['watermark_text_trans'] ) && !empty($this->rtwgftpdf_stng['watermark_text_trans'] ) )
					{
						$rtwgftpdf_alpha = $this->rtwgftpdf_stng['watermark_text_trans'];
					}
					
					if( isset($this->rtwgftpdf_stng['watermark_rotation']) && !empty($this->rtwgftpdf_stng['watermark_rotation']))
					{
						$GLOBALS['rotate']= $this->rtwgftpdf_stng['watermark_rotation'];
					}
					$rtwgftpdf_mpdf->SetWatermarkText( trim($this->rtwgftpdf_stng ['watermark_text']),$rtwgftpdf_alpha );

					$rtwgftpdf_mpdf->showWatermarkText = true;
					if( isset( $this->rtwgftpdf_stng['watermark_font'] ) && !empty( $this->rtwgftpdf_stng['watermark_font'] ) )
					{
						$rtwgftpdf_mpdf->watermark_font = $this->rtwgftpdf_stng['watermark_font'];
					}
				}	
			}
			if( isset( $this->rtwgftpdf_stng ['enable_image_watermark'] ) )
			{
				if( isset( $this->rtwgftpdf_stng ['watermark_img_url'] ) && !empty($this->rtwgftpdf_stng ['watermark_img_url']) )
				{
					$rtwgftpdf_alpha = 0.2;
					if( isset( $this->rtwgftpdf_stng['watermark_image_trans'] ) && !empty($this->rtwgftpdf_stng['watermark_image_trans']) )
					{
						$rtwgftpdf_alpha = $this->rtwgftpdf_stng['watermark_image_trans'];
					}
					$rtwgftpdf_watermark_img_dim ='D';
					if( isset($this->rtwgftpdf_stng['watermark_img_dim']) && $this->rtwgftpdf_stng['watermark_img_dim'] == 'P') 
					{
						$rtwgftpdf_watermark_img_dim = 'P';
					}
					if(isset($this->rtwgftpdf_stng['watermark_img_dim']) && $this->rtwgftpdf_stng['watermark_img_dim']=='F')
					{
						$rtwgftpdf_watermark_img_dim = 'F';
					}
					if(isset($this->rtwgftpdf_stng['watermark_img_dim']) && $this->rtwgftpdf_stng['watermark_img_dim']=='INT')
					{
						$rtwgftpdf_watermark_img_dim = $this->rtwgftpdf_stng['water_img_dim_int'];
						$rtwgftpdf_watermark_img_dim = (int)$rtwgftpdf_watermark_img_dim ; 
					}
					if(isset($this->rtwgftpdf_stng['watermark_img_dim']) && $this->rtwgftpdf_stng['watermark_img_dim']=='array')
					{
						$rtwgftpdf_watermark_img_dim = array($this->rtwgftpdf_stng['watermark_img_dim_width'],$this->rtwgftpdf_stng['watermark_img_dim_height']);
					}
					$rtwgftpdf_watermark_pos = 'P';
					if(isset($this->rtwgftpdf_stng['watermark_img_pos']) && $this->rtwgftpdf_stng['watermark_img_pos']=='F')
					{
						$rtwgftpdf_watermark_pos='F';	
					}
					if(isset($this->rtwgftpdf_stng['watermark_img_pos']) && $this->rtwgftpdf_stng['watermark_img_pos']=='arrays')
					{
						$rtwgftpdf_watermark_pos=array($this->rtwgftpdf_stng['watermark_img_pos_x'],$this->rtwgftpdf_stng['watermark_img_pos_y']);
					}

					$rtwgftpdf_mpdf->SetWatermarkImage($this->rtwgftpdf_stng ['watermark_img_url'], $rtwgftpdf_alpha, $rtwgftpdf_watermark_img_dim , $rtwgftpdf_watermark_pos);
					$rtwgftpdf_mpdf->showWatermarkImage = true;
				}	
			}

			if( isset($this->rtwgftpdf_stng['rtl']) && $this->rtwgftpdf_stng['rtl'] == 1)
			{
				$rtwgftpdf_mpdf->SetDirectionality('rtl');
			}
			else
			{
				$rtwgftpdf_mpdf->SetDirectionality('ltr');
			}
			$rtwgftpdf_mpdf->showImageErrors = true;
			if ( !is_dir ( RTWGFTPDF_CONTENT_DIR ) ) 
			{
				mkdir ( RTWGFTPDF_CONTENT_DIR, 0755, true );
			}
			$fp = fopen(RTWGFTPDF_CONTENT_DIR.'/index.php','w');
			fwrite($fp, '<?php // Silence is golden');
			fclose($fp);

			$rtwgftpdf_UserPassword = '';
			$rtwgftpdf_admin_pass = '';
			if( isset($this->rtwgftpdf_stng['admin_pass']) && $this->rtwgftpdf_stng['admin_pass'] != '' )
			{
				$rtwgftpdf_admin_pass = $this->rtwgftpdf_stng['admin_pass'];
			}
			else
			{
				$rtwgftpdf_admin_pass = '12345678';
			}
			
			if(is_user_logged_in())
			{
				$rtwgftpdf_admin = wp_get_current_user();
				$rtwgftpdf_name = $rtwgftpdf_admin->user_login;
				$rtwgftpdf_email = $rtwgftpdf_admin->user_email;
				if(isset($this->rtwgftpdf_stng ['pass_pattern']) && $this->rtwgftpdf_stng ['pass_pattern'] == 1)
				{
					if($this->rtwgftpdf_stng['pass_Login'] == 'Pass_Name')
					{
						$rtwgftpdf_UserPassword = substr($rtwgftpdf_name, 0, 4);
					}
					if($this->rtwgftpdf_stng['pass_Login'] == 'Pass_Email')
					{
						$rtwgftpdf_UserPassword = substr($rtwgftpdf_email, 0, 4);
					}
					if($this->rtwgftpdf_stng['pass_Login'] == 'Pass_Comb')
					{
						$rtwgftpdf_UserPassword = substr($rtwgftpdf_name, 0, 4) . substr($rtwgftpdf_email, 0, 4);
					}
				}
			}
			else
			{
				if($this->rtwgftpdf_stng['pass_Guest'] == 'Pass_N')
				{
					$rtwgftpdf_UserPassword = substr($rtwgftpdf_guest_name, 0, 4);
				}
				if($this->rtwgftpdf_stng['pass_Guest'] == 'Pass_E')
				{
					$rtwgftpdf_UserPassword = substr($rtwgftpdf_guest_email, 0, 4);
				}
				if($this->rtwgftpdf_stng['pass_Guest'] == 'Pass_C')
				{
					$rtwgftpdf_UserPassword = substr($rtwgftpdf_guest_name, 0, 4) . substr($rtwgftpdf_guest_email, 0, 4);
				}
			}
			try
			{
				
				$rtwgftpdf_mpdf->autoScriptToLang = true;
				$rtwgftpdf_mpdf->autoLangToFont = true;
				$rtwgftpdf_mpdf->SetProtection(array('copy','print'), $rtwgftpdf_UserPassword, $rtwgftpdf_admin_pass);
				$rtwgftpdf_mpdf->SetDefaultBodyCSS('background', "url(".$this->rtwgftpdf_stng['background_img_url'].")");
				$rtwgftpdf_mpdf->SetDefaultBodyCSS('background-image-resize', 6);
				$rtwgftpdf_mpdf->SetDefaultBodyCSS('background-color', $this->rtwgftpdf_stng['back_color']);
				$rtwgftpdf_mpdf->WriteHTML($rtwgftpdf_pdf_html);
				
				if(isset($_POST['rtw_preview_pdf']))
				{
					$rtwgftpdf_mpdf->Output($rtwgftpdf_file_path,'D');
				}
				else{
					$rtwgftpdf_mpdf->Output($rtwgftpdf_file_path,'F');
				}
				chmod($rtwgftpdf_file_path, 0777);
			}
			catch( Exception $e)
			{
				echo esc_html($e);
			}

			$rtwgftpdf_file_path = RTWGFTPDF_CONTENT_URL . '/'. $pdf_name . esc_html($rtwgftpdf_form) . '.pdf';
			$rtwgftpdf_file_name = esc_html($rtwgftpdf_form) . '.pdf';
			
			$this->rtwgftpdf_pdf_path = $rtwgftpdf_file_path;
			
			return $this->rtwgftpdf_pdf_path;
		}
	}

	/**
	 * Function to add attachment in the mail.
	 *
	 * @since    1.0.0
	 */
	public function rtwgftpdf_send_email_with_attachment($rtwgftpdf_email, $rtwgftpdf_message_format, $rtwgftpdf_notification, $rtwgftpdf_entry)
	{
		$rtwgftpdf_verification_done = get_option( 'rtwgftpdf_verification_done', array() );

		if( !empty( $rtwgftpdf_verification_done ) && $rtwgftpdf_verification_done['status'] == true && !empty($rtwgftpdf_verification_done['purchase_code']) )
		{
			if( isset($this->rtwgftpdf_stng['gnrt_pdf']) && ($this->rtwgftpdf_stng['gnrt_pdf'] == 'Send_mail' || $this->rtwgftpdf_stng['gnrt_pdf'] == 'Both') )
			{
				$rtwgftpdf_basic_setting 	= get_option('rtwgftpdf_basic_setting_opt',array());

				$pdf_name = isset($rtwgftpdf_basic_setting['pdf_name']) ? $rtwgftpdf_basic_setting['pdf_name'] : 'rtwgftpdf_';

				$rtwgftpdf_file_path = RTWGFTPDF_CONTENT_DIR . '/'.$pdf_name. esc_html($rtwgftpdf_entry['id']) . '.pdf'; 

				$rtwgftpdf_email['attachments'] = array($rtwgftpdf_file_path);

				return $rtwgftpdf_email;
			}
			else
			{
				return $rtwgftpdf_email;
			}
		}
	}

	/**
	 * Function to add additional class to the text fields.
	 *
	 * @since    1.0.0
	 */

	function rtwgftpdf_field_class( $rtwgftpdf_classes, $rtwgftpdf_field, $rtwgftpdf_form )
	{
		if ( $rtwgftpdf_field->type == 'text' || $rtwgftpdf_field->type == 'name' || $rtwgftpdf_field->type == 'email' || $rtwgftpdf_field->type == 'textarea' || $rtwgftpdf_field->type == 'post_title' || $rtwgftpdf_field->type == 'post_content' || $rtwgftpdf_field->type == 'post_excerpt' || $rtwgftpdf_field->type == 'post_tags' || $rtwgftpdf_field->type == 'post_custom_field' && $rtwgftpdf_field->rtwgftpdf_disable_copy_paste_status == 'disable' )
		{
			$rtwgftpdf_classes .= esc_attr(' rtwgftpdf_disable_copy_paste');
		}
		return $rtwgftpdf_classes;
	}

	/**
	 * Function to add form review page.
	 *
	 * @since    1.0.0
	 */

	function rtwgftpdf_review_page( $rtwgftpdf_review_page, $rtwgftpdf_form, $rtwgftpdf_entry ) {
		
		if( isset($this->rtwgftpdf_stng['form_review']) && $this->rtwgftpdf_stng['form_review'] == 'Yes' )
		{
		    $rtwgftpdf_review_page['is_enabled'] = true;
		 
		    if ( $rtwgftpdf_entry ) {
		        $rtwgftpdf_review_page['content'] = GFCommon::replace_variables( '{all_fields}', $rtwgftpdf_form, $rtwgftpdf_entry );
		    }
		}
	
	    return $rtwgftpdf_review_page;
	}

	/**
	 * Function to update pdf.
	 *
	 * @since    1.1.0
	 */
	function rtwgftpdf_update_after_entry($form, $lead )
	{
		$this->rtwgftpdf_after_submission_callback($lead, $form);
	}

	/**
	 * Function to remove labels.
	 *
	 * @since    1.4.0
	 */
	function rtwgftpdf_remove_label_fxn($rtwgftpdf_ckbox_value)
	{
		if( isset($this->rtwgftpdf_stng['remove_label']) && $this->rtwgftpdf_stng['remove_label'] == 1 )
		{
			return '';
		}
		else{
			return $rtwgftpdf_ckbox_value;
		}
	}

	/**
	 * Function to remove labels.
	 *
	 * @since    1.6.3
	 */
	function rtwgftpdf_currency_fxn($currencies)
	{
		update_option('rtwgftpdf_currencies', $currencies);
		return $currencies;
	}
}